"use strict";
exports.previousTuesday = void 0;

var _index = require("../previousTuesday.cjs");
var _index2 = require("./_lib/convertToFP.cjs"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const previousTuesday = (exports.previousTuesday = (0, _index2.convertToFP)(
  _index.previousTuesday,
  1,
));
