"use strict";
exports.differenceInCalendarISOWeekYearsWithOptions = void 0;

var _index = require("../differenceInCalendarISOWeekYears.cjs");
var _index2 = require("./_lib/convertToFP.cjs"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const differenceInCalendarISOWeekYearsWithOptions =
  (exports.differenceInCalendarISOWeekYearsWithOptions = (0,
  _index2.convertToFP)(_index.differenceInCalendarISOWeekYears, 3));
