"use strict";
exports.differenceInCalendarDaysWithOptions = void 0;

var _index = require("../differenceInCalendarDays.cjs");
var _index2 = require("./_lib/convertToFP.cjs"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const differenceInCalendarDaysWithOptions =
  (exports.differenceInCalendarDaysWithOptions = (0, _index2.convertToFP)(
    _index.differenceInCalendarDays,
    3,
  ));
