export declare const isSameQuarterWithOptions: import("./types.ts").FPFn3<
  boolean,
  import("../isSameQuarter.ts").IsSameQuarterOptions | undefined,
  string | number | Date,
  string | number | Date
>;
