export declare function connectHandler(self: any): () => void;
export declare function closeHandler(self: any): () => void;
export declare function errorHandler(self: any): (error: any) => void;
export declare function readyHandler(self: any): () => void;
