"use strict";
exports.differenceInCalendarQuartersWithOptions = void 0;

var _index = require("../differenceInCalendarQuarters.cjs");
var _index2 = require("./_lib/convertToFP.cjs"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const differenceInCalendarQuartersWithOptions =
  (exports.differenceInCalendarQuartersWithOptions = (0, _index2.convertToFP)(
    _index.differenceInCalendarQuarters,
    3,
  ));
