"use strict";
exports.subDays = void 0;

var _index = require("../subDays.cjs");
var _index2 = require("./_lib/convertToFP.cjs"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const subDays = (exports.subDays = (0, _index2.convertToFP)(_index.subDays, 2));
