export declare const isSameISOWeekYearWithOptions: import("./types.ts").FPFn3<
  boolean,
  | import("../isSameISOWeekYear.ts").IsSameISOWeekYearOptions
  | undefined,
  string | number | Date,
  string | number | Date
>;
