import type { ContextOptions, DateArg } from "./types.ts";
/**
 * The {@link isSunday} function options.
 */
export interface IsSundayOptions extends ContextOptions<Date> {}
/**
 * @name isSunday
 * @category Weekday Helpers
 * @summary Is the given date Sunday?
 *
 * @description
 * Is the given date Sunday?
 *
 * @param date - The date to check
 * @param options - The options object
 *
 * @returns The date is Sunday
 *
 * @example
 * // Is 21 September 2014 Sunday?
 * const result = isSunday(new Date(2014, 8, 21))
 * //=> true
 */
export declare function isSunday(
  date: DateArg<Date> & {},
  options?: IsSundayOptions | undefined,
): boolean;
