export declare const previousSundayWithOptions: import("./types.ts").FPFn2<
  Date,
  | import("../previousSunday.ts").PreviousSundayOptions<Date>
  | undefined,
  import("../fp.ts").DateArg<Date>
>;
