'use strict';
// https://github.com/tc39/proposal-iterator-chunking
require('../modules/esnext.iterator.chunks');
require('../modules/esnext.iterator.windows');
require('../modules/esnext.iterator.sliding');
