"use strict";
exports.toDate = void 0;

var _index = require("../toDate.cjs");
var _index2 = require("./_lib/convertToFP.cjs"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const toDate = (exports.toDate = (0, _index2.convertToFP)(_index.toDate, 2));
