import ArchiveEntry from "./archivers/archive-entry.js";
import ZipArchiveEntry from "./archivers/zip/zip-archive-entry.js";
import ArchiveOutputStream from "./archivers/archive-output-stream.js";
import ZipArchiveOutputStream from "./archivers/zip/zip-archive-output-stream.js";

export {
  ArchiveEntry,
  ZipArchiveEntry,
  ArchiveOutputStream,
  ZipArchiveOutputStream,
};

export default {
  ArchiveEntry,
  ZipArchiveEntry,
  ArchiveOutputStream,
  ZipArchiveOutputStream,
};
