export declare const formatDistanceStrictWithOptions: import("./types.ts").FPFn3<
  string,
  | import("../formatDistanceStrict.ts").FormatDistanceStrictOptions
  | undefined,
  string | number | Date,
  string | number | Date
>;
