export declare const setISOWeekYearWithOptions: import("./types.ts").FPFn3<
  Date,
  | import("../setISOWeekYear.ts").SetISOWeekYearOptions<Date>
  | undefined,
  number,
  import("../fp.ts").DateArg<Date>
>;
