export declare const differenceInMonthsWithOptions: import("./types.ts").FPFn3<
  number,
  | import("../differenceInMonths.ts").DifferenceInMonthsOptions
  | undefined,
  string | number | Date,
  string | number | Date
>;
