export declare const numericPatterns: {
  month: RegExp;
  date: RegExp;
  dayOfYear: RegExp;
  week: RegExp;
  hour23h: RegExp;
  hour24h: RegExp;
  hour11h: RegExp;
  hour12h: RegExp;
  minute: RegExp;
  second: RegExp;
  singleDigit: RegExp;
  twoDigits: RegExp;
  threeDigits: RegExp;
  fourDigits: RegExp;
  anyDigitsSigned: RegExp;
  singleDigitSigned: RegExp;
  twoDigitsSigned: RegExp;
  threeDigitsSigned: RegExp;
  fourDigitsSigned: RegExp;
};
export declare const timezonePatterns: {
  basicOptionalMinutes: RegExp;
  basic: RegExp;
  basicOptionalSeconds: RegExp;
  extended: RegExp;
  extendedOptionalSeconds: RegExp;
};
