"use strict";
exports.subSecondsWithOptions = void 0;

var _index = require("../subSeconds.cjs");
var _index2 = require("./_lib/convertToFP.cjs"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const subSecondsWithOptions = (exports.subSecondsWithOptions = (0,
_index2.convertToFP)(_index.subSeconds, 3));
