"use strict";
exports.startOfHour = void 0;

var _index = require("../startOfHour.cjs");
var _index2 = require("./_lib/convertToFP.cjs"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const startOfHour = (exports.startOfHour = (0, _index2.convertToFP)(
  _index.startOfHour,
  1,
));
