"use strict";
exports.setMinutes = void 0;

var _index = require("../setMinutes.cjs");
var _index2 = require("./_lib/convertToFP.cjs"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const setMinutes = (exports.setMinutes = (0, _index2.convertToFP)(
  _index.setMinutes,
  2,
));
