"use strict";
exports.isValid = void 0;

var _index = require("../isValid.cjs");
var _index2 = require("./_lib/convertToFP.cjs"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const isValid = (exports.isValid = (0, _index2.convertToFP)(_index.isValid, 1));
