export declare const intervalToDurationWithOptions: import("./types.ts").FPFn2<
  import("../fp.ts").Duration,
  | import("../intervalToDuration.ts").IntervalToDurationOptions
  | undefined,
  import("../fp.ts").Interval<
    import("../fp.ts").DateArg<Date>,
    import("../fp.ts").DateArg<Date>
  >
>;
