export declare const areIntervalsOverlappingWithOptions: import("./types.ts").FPFn3<
  boolean,
  | import("../areIntervalsOverlapping.ts").AreIntervalsOverlappingOptions
  | undefined,
  import("../fp.ts").Interval<
    import("../fp.ts").DateArg<Date>,
    import("../fp.ts").DateArg<Date>
  >,
  import("../fp.ts").Interval<
    import("../fp.ts").DateArg<Date>,
    import("../fp.ts").DateArg<Date>
  >
>;
