export declare const eachYearOfInterval: import("./types.ts").FPFn1<
  import("../eachYearOfInterval.ts").EachYearOfIntervalResult<
    import("../fp.ts").Interval<
      import("../fp.ts").DateArg<Date>,
      import("../fp.ts").DateArg<Date>
    >,
    | import("../eachYearOfInterval.ts").EachYearOfIntervalOptions<Date>
    | undefined
  >,
  import("../fp.ts").Interval<
    import("../fp.ts").DateArg<Date>,
    import("../fp.ts").DateArg<Date>
  >
>;
