"use strict";
exports.nextThursdayWithOptions = void 0;

var _index = require("../nextThursday.cjs");
var _index2 = require("./_lib/convertToFP.cjs"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const nextThursdayWithOptions = (exports.nextThursdayWithOptions = (0,
_index2.convertToFP)(_index.nextThursday, 2));
