export declare const eachHourOfIntervalWithOptions: import("./types.ts").FPFn2<
  import("../eachHourOfInterval.ts").EachHourOfIntervalResult<
    import("../fp.ts").Interval<
      import("../fp.ts").DateArg<Date>,
      import("../fp.ts").DateArg<Date>
    >,
    | import("../eachHourOfInterval.ts").EachHourOfIntervalOptions<Date>
    | undefined
  >,
  | import("../eachHourOfInterval.ts").EachHourOfIntervalOptions<Date>
  | undefined,
  import("../fp.ts").Interval<
    import("../fp.ts").DateArg<Date>,
    import("../fp.ts").DateArg<Date>
  >
>;
