"use strict";
exports.getWeekYearWithOptions = void 0;

var _index = require("../getWeekYear.cjs");
var _index2 = require("./_lib/convertToFP.cjs"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const getWeekYearWithOptions = (exports.getWeekYearWithOptions = (0,
_index2.convertToFP)(_index.getWeekYear, 2));
