'use strict';
require('../../modules/es.array-buffer.constructor');
require('../../modules/es.array-buffer.slice');
require('../../modules/es.typed-array.int8-array');
require('./methods');
var global = require('../../internals/global-this');

module.exports = global.Int8Array;
