export declare const isWithinInterval: import("./types.ts").FPFn2<
  boolean,
  import("../fp.ts").Interval<
    import("../fp.ts").DateArg<Date>,
    import("../fp.ts").DateArg<Date>
  >,
  string | number | Date
>;
