export declare const differenceInCalendarQuartersWithOptions: import("./types.ts").FPFn3<
  number,
  | import("../differenceInCalendarQuarters.ts").DifferenceInCalendarQuartersOptions
  | undefined,
  string | number | Date,
  string | number | Date
>;
