"use strict";
exports.addHoursWithOptions = void 0;

var _index = require("../addHours.cjs");
var _index2 = require("./_lib/convertToFP.cjs"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const addHoursWithOptions = (exports.addHoursWithOptions = (0,
_index2.convertToFP)(_index.addHours, 3));
