export declare const addMillisecondsWithOptions: import("./types.ts").FPFn3<
  Date,
  | import("../addMilliseconds.ts").AddMillisecondsOptions<Date>
  | undefined,
  number,
  import("../fp.ts").DateArg<Date>
>;
