'use strict';
var parent = require('../../actual/iterator/concat');
require('../../modules/esnext.iterator.chunks');
require('../../modules/esnext.iterator.sliding');
require('../../modules/esnext.iterator.windows');

module.exports = parent;
