"use strict";
exports.intervalToDurationWithOptions = void 0;

var _index = require("../intervalToDuration.cjs");
var _index2 = require("./_lib/convertToFP.cjs"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const intervalToDurationWithOptions = (exports.intervalToDurationWithOptions =
  (0, _index2.convertToFP)(_index.intervalToDuration, 2));
