"use strict";
exports.eachMonthOfIntervalWithOptions = void 0;

var _index = require("../eachMonthOfInterval.cjs");
var _index2 = require("./_lib/convertToFP.cjs"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const eachMonthOfIntervalWithOptions = (exports.eachMonthOfIntervalWithOptions =
  (0, _index2.convertToFP)(_index.eachMonthOfInterval, 2));
