'use strict';
var parent = require('../../stable/iterator/flat-map');
require('../../modules/esnext.iterator.constructor');
require('../../modules/esnext.iterator.flat-map');

module.exports = parent;
