export declare const formatRelativeWithOptions: import("./types.ts").FPFn3<
  string,
  import("../formatRelative.ts").FormatRelativeOptions | undefined,
  string | number | Date,
  string | number | Date
>;
