export declare const differenceInCalendarISOWeeksWithOptions: import("./types.ts").FPFn3<
  number,
  | import("../differenceInCalendarISOWeeks.ts").DifferenceInCalendarISOWeeksOptions
  | undefined,
  string | number | Date,
  string | number | Date
>;
