"use strict";
exports.roundToNearestMinutes = void 0;

var _index = require("../roundToNearestMinutes.cjs");
var _index2 = require("./_lib/convertToFP.cjs"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const roundToNearestMinutes = (exports.roundToNearestMinutes = (0,
_index2.convertToFP)(_index.roundToNearestMinutes, 1));
