"use strict";
exports.getISOWeekWithOptions = void 0;

var _index = require("../getISOWeek.cjs");
var _index2 = require("./_lib/convertToFP.cjs"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const getISOWeekWithOptions = (exports.getISOWeekWithOptions = (0,
_index2.convertToFP)(_index.getISOWeek, 2));
