export declare const intervalWithOptions: import("./types.ts").FPFn3<
  import("../interval.ts").IntervalResult<
    import("../fp.ts").DateArg<Date>,
    import("../fp.ts").DateArg<Date>,
    import("../interval.ts").IntervalOptions<Date> | undefined
  >,
  import("../interval.ts").IntervalOptions<Date> | undefined,
  import("../fp.ts").DateArg<Date>,
  import("../fp.ts").DateArg<Date>
>;
