"use strict";
exports.startOfISOWeekYearWithOptions = void 0;

var _index = require("../startOfISOWeekYear.cjs");
var _index2 = require("./_lib/convertToFP.cjs"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const startOfISOWeekYearWithOptions = (exports.startOfISOWeekYearWithOptions =
  (0, _index2.convertToFP)(_index.startOfISOWeekYear, 2));
