"use strict";
/**
 * This file is generated by @ioredis/interface-generator.
 * Don't edit it manually. Instead, run `npm run generate` to update
 * this file.
 */
Object.defineProperty(exports, "__esModule", { value: true });
