"use strict";
exports.differenceInCalendarMonthsWithOptions = void 0;

var _index = require("../differenceInCalendarMonths.cjs");
var _index2 = require("./_lib/convertToFP.cjs"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const differenceInCalendarMonthsWithOptions =
  (exports.differenceInCalendarMonthsWithOptions = (0, _index2.convertToFP)(
    _index.differenceInCalendarMonths,
    3,
  ));
