"use strict";
exports.max = void 0;

var _index = require("../max.cjs");
var _index2 = require("./_lib/convertToFP.cjs"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const max = (exports.max = (0, _index2.convertToFP)(_index.max, 1));
