export * from "./locale/af.ts";
export * from "./locale/ar.ts";
export * from "./locale/ar-DZ.ts";
export * from "./locale/ar-EG.ts";
export * from "./locale/ar-MA.ts";
export * from "./locale/ar-SA.ts";
export * from "./locale/ar-TN.ts";
export * from "./locale/az.ts";
export * from "./locale/be.ts";
export * from "./locale/be-tarask.ts";
export * from "./locale/bg.ts";
export * from "./locale/bn.ts";
export * from "./locale/bs.ts";
export * from "./locale/ca.ts";
export * from "./locale/ckb.ts";
export * from "./locale/cs.ts";
export * from "./locale/cy.ts";
export * from "./locale/da.ts";
export * from "./locale/de.ts";
export * from "./locale/de-AT.ts";
export * from "./locale/el.ts";
export * from "./locale/en-AU.ts";
export * from "./locale/en-CA.ts";
export * from "./locale/en-GB.ts";
export * from "./locale/en-IE.ts";
export * from "./locale/en-IN.ts";
export * from "./locale/en-NZ.ts";
export * from "./locale/en-US.ts";
export * from "./locale/en-ZA.ts";
export * from "./locale/eo.ts";
export * from "./locale/es.ts";
export * from "./locale/et.ts";
export * from "./locale/eu.ts";
export * from "./locale/fa-IR.ts";
export * from "./locale/fi.ts";
export * from "./locale/fr.ts";
export * from "./locale/fr-CA.ts";
export * from "./locale/fr-CH.ts";
export * from "./locale/fy.ts";
export * from "./locale/gd.ts";
export * from "./locale/gl.ts";
export * from "./locale/gu.ts";
export * from "./locale/he.ts";
export * from "./locale/hi.ts";
export * from "./locale/hr.ts";
export * from "./locale/ht.ts";
export * from "./locale/hu.ts";
export * from "./locale/hy.ts";
export * from "./locale/id.ts";
export * from "./locale/is.ts";
export * from "./locale/it.ts";
export * from "./locale/it-CH.ts";
export * from "./locale/ja.ts";
export * from "./locale/ja-Hira.ts";
export * from "./locale/ka.ts";
export * from "./locale/kk.ts";
export * from "./locale/km.ts";
export * from "./locale/kn.ts";
export * from "./locale/ko.ts";
export * from "./locale/lb.ts";
export * from "./locale/lt.ts";
export * from "./locale/lv.ts";
export * from "./locale/mk.ts";
export * from "./locale/mn.ts";
export * from "./locale/ms.ts";
export * from "./locale/mt.ts";
export * from "./locale/nb.ts";
export * from "./locale/nl.ts";
export * from "./locale/nl-BE.ts";
export * from "./locale/nn.ts";
export * from "./locale/oc.ts";
export * from "./locale/pl.ts";
export * from "./locale/pt.ts";
export * from "./locale/pt-BR.ts";
export * from "./locale/ro.ts";
export * from "./locale/ru.ts";
export * from "./locale/se.ts";
export * from "./locale/sk.ts";
export * from "./locale/sl.ts";
export * from "./locale/sq.ts";
export * from "./locale/sr.ts";
export * from "./locale/sr-Latn.ts";
export * from "./locale/sv.ts";
export * from "./locale/ta.ts";
export * from "./locale/te.ts";
export * from "./locale/th.ts";
export * from "./locale/tr.ts";
export * from "./locale/ug.ts";
export * from "./locale/uk.ts";
export * from "./locale/uz.ts";
export * from "./locale/uz-Cyrl.ts";
export * from "./locale/vi.ts";
export * from "./locale/zh-CN.ts";
export * from "./locale/zh-HK.ts";
export * from "./locale/zh-TW.ts";
export type * from "./locale/types.ts";
