export declare const differenceInBusinessDaysWithOptions: import("./types.ts").FPFn3<
  number,
  | import("../differenceInBusinessDays.ts").DifferenceInBusinessDaysOptions
  | undefined,
  string | number | Date,
  string | number | Date
>;
