export declare const constructFrom: import("./types.ts").FPFn2<
  Date,
  string | number | Date,
  | import("../fp.ts").ContextFn<Date>
  | import("../fp.ts").DateArg<
      import("../fp.ts").ConstructableDate | Date
    >
  | undefined
>;
