export declare const previousThursdayWithOptions: import("./types.ts").FPFn2<
  Date,
  | import("../previousThursday.ts").PreviousThursdayOptions<Date>
  | undefined,
  import("../fp.ts").DateArg<Date>
>;
