'use strict';
require('../../../modules/es.object.to-string');
require('../../../modules/esnext.string.code-points');
var getBuiltInPrototypeMethod = require('../../../internals/get-built-in-prototype-method');

module.exports = getBuiltInPrototypeMethod('String', 'codePoints');
