export declare const clampWithOptions: import("./types.ts").FPFn3<
  Date,
  import("../clamp.ts").ClampOptions<Date> | undefined,
  import("../fp.ts").Interval<
    import("../fp.ts").DateArg<Date>,
    import("../fp.ts").DateArg<Date>
  >,
  import("../fp.ts").DateArg<Date>
>;
