import { Callback } from "./types";
export default class Script {
    private lua;
    private numberOfKeys;
    private keyPrefix;
    private readOnly;
    private sha;
    private Command;
    constructor(lua: string, numberOfKeys?: number | null, keyPrefix?: string, readOnly?: boolean);
    execute(container: any, args: any[], options: any, callback?: Callback): any;
}
