(function(){const i=document.createElement("link").relList;if(i&&i.supports&&i.supports("modulepreload"))return;for(const r of document.querySelectorAll('link[rel="modulepreload"]'))s(r);new MutationObserver(r=>{for(const o of r)if(o.type==="childList")for(const h of o.addedNodes)h.tagName==="LINK"&&h.rel==="modulepreload"&&s(h)}).observe(document,{childList:!0,subtree:!0});function f(r){const o={};return r.integrity&&(o.integrity=r.integrity),r.referrerPolicy&&(o.referrerPolicy=r.referrerPolicy),r.crossOrigin==="use-credentials"?o.credentials="include":r.crossOrigin==="anonymous"?o.credentials="omit":o.credentials="same-origin",o}function s(r){if(r.ep)return;r.ep=!0;const o=f(r);fetch(r.href,o)}})();function wg(u){return u&&u.__esModule&&Object.prototype.hasOwnProperty.call(u,"default")?u.default:u}var rr={exports:{}},Zi={};/**
 * @license React
 * react-jsx-runtime.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var y1;function Og(){if(y1)return Zi;y1=1;var u=Symbol.for("react.transitional.element"),i=Symbol.for("react.fragment");function f(s,r,o){var h=null;if(o!==void 0&&(h=""+o),r.key!==void 0&&(h=""+r.key),"key"in r){o={};for(var v in r)v!=="key"&&(o[v]=r[v])}else o=r;return r=o.ref,{$$typeof:u,type:s,key:h,ref:r!==void 0?r:null,props:o}}return Zi.Fragment=i,Zi.jsx=f,Zi.jsxs=f,Zi}var g1;function Rg(){return g1||(g1=1,rr.exports=Og()),rr.exports}var O=Rg(),or={exports:{}},Et={};/**
 * @license React
 * react.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var v1;function Dg(){if(v1)return Et;v1=1;var u=Symbol.for("react.transitional.element"),i=Symbol.for("react.portal"),f=Symbol.for("react.fragment"),s=Symbol.for("react.strict_mode"),r=Symbol.for("react.profiler"),o=Symbol.for("react.consumer"),h=Symbol.for("react.context"),v=Symbol.for("react.forward_ref"),m=Symbol.for("react.suspense"),y=Symbol.for("react.memo"),_=Symbol.for("react.lazy"),p=Symbol.for("react.activity"),b=Symbol.iterator;function T(E){return E===null||typeof E!="object"?null:(E=b&&E[b]||E["@@iterator"],typeof E=="function"?E:null)}var D={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},G=Object.assign,W={};function J(E,R,k){this.props=E,this.context=R,this.refs=W,this.updater=k||D}J.prototype.isReactComponent={},J.prototype.setState=function(E,R){if(typeof E!="object"&&typeof E!="function"&&E!=null)throw Error("takes an object of state variables to update or a function which returns an object of state variables.");this.updater.enqueueSetState(this,E,R,"setState")},J.prototype.forceUpdate=function(E){this.updater.enqueueForceUpdate(this,E,"forceUpdate")};function Z(){}Z.prototype=J.prototype;function $(E,R,k){this.props=E,this.context=R,this.refs=W,this.updater=k||D}var I=$.prototype=new Z;I.constructor=$,G(I,J.prototype),I.isPureReactComponent=!0;var B=Array.isArray;function it(){}var X={H:null,A:null,T:null,S:null},et=Object.prototype.hasOwnProperty;function ut(E,R,k){var w=k.ref;return{$$typeof:u,type:E,key:R,ref:w!==void 0?w:null,props:k}}function st(E,R){return ut(E.type,R,E.props)}function at(E){return typeof E=="object"&&E!==null&&E.$$typeof===u}function _t(E){var R={"=":"=0",":":"=2"};return"$"+E.replace(/[=:]/g,function(k){return R[k]})}var pt=/\/+/g;function yt(E,R){return typeof E=="object"&&E!==null&&E.key!=null?_t(""+E.key):R.toString(36)}function ot(E){switch(E.status){case"fulfilled":return E.value;case"rejected":throw E.reason;default:switch(typeof E.status=="string"?E.then(it,it):(E.status="pending",E.then(function(R){E.status==="pending"&&(E.status="fulfilled",E.value=R)},function(R){E.status==="pending"&&(E.status="rejected",E.reason=R)})),E.status){case"fulfilled":return E.value;case"rejected":throw E.reason}}throw E}function N(E,R,k,w,U){var L=typeof E;(L==="undefined"||L==="boolean")&&(E=null);var P=!1;if(E===null)P=!0;else switch(L){case"bigint":case"string":case"number":P=!0;break;case"object":switch(E.$$typeof){case u:case i:P=!0;break;case _:return P=E._init,N(P(E._payload),R,k,w,U)}}if(P)return U=U(E),P=w===""?"."+yt(E,0):w,B(U)?(k="",P!=null&&(k=P.replace(pt,"$&/")+"/"),N(U,R,k,"",function(Yt){return Yt})):U!=null&&(at(U)&&(U=st(U,k+(U.key==null||E&&E.key===U.key?"":(""+U.key).replace(pt,"$&/")+"/")+P)),R.push(U)),1;P=0;var H=w===""?".":w+":";if(B(E))for(var ht=0;ht<E.length;ht++)w=E[ht],L=H+yt(w,ht),P+=N(w,R,k,L,U);else if(ht=T(E),typeof ht=="function")for(E=ht.call(E),ht=0;!(w=E.next()).done;)w=w.value,L=H+yt(w,ht++),P+=N(w,R,k,L,U);else if(L==="object"){if(typeof E.then=="function")return N(ot(E),R,k,w,U);throw R=String(E),Error("Objects are not valid as a React child (found: "+(R==="[object Object]"?"object with keys {"+Object.keys(E).join(", ")+"}":R)+"). If you meant to render a collection of children, use an array instead.")}return P}function V(E,R,k){if(E==null)return E;var w=[],U=0;return N(E,w,"","",function(L){return R.call(k,L,U++)}),w}function lt(E){if(E._status===-1){var R=E._result;R=R(),R.then(function(k){(E._status===0||E._status===-1)&&(E._status=1,E._result=k)},function(k){(E._status===0||E._status===-1)&&(E._status=2,E._result=k)}),E._status===-1&&(E._status=0,E._result=R)}if(E._status===1)return E._result.default;throw E._result}var rt=typeof reportError=="function"?reportError:function(E){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var R=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof E=="object"&&E!==null&&typeof E.message=="string"?String(E.message):String(E),error:E});if(!window.dispatchEvent(R))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",E);return}console.error(E)},gt={map:V,forEach:function(E,R,k){V(E,function(){R.apply(this,arguments)},k)},count:function(E){var R=0;return V(E,function(){R++}),R},toArray:function(E){return V(E,function(R){return R})||[]},only:function(E){if(!at(E))throw Error("React.Children.only expected to receive a single React element child.");return E}};return Et.Activity=p,Et.Children=gt,Et.Component=J,Et.Fragment=f,Et.Profiler=r,Et.PureComponent=$,Et.StrictMode=s,Et.Suspense=m,Et.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=X,Et.__COMPILER_RUNTIME={__proto__:null,c:function(E){return X.H.useMemoCache(E)}},Et.cache=function(E){return function(){return E.apply(null,arguments)}},Et.cacheSignal=function(){return null},Et.cloneElement=function(E,R,k){if(E==null)throw Error("The argument must be a React element, but you passed "+E+".");var w=G({},E.props),U=E.key;if(R!=null)for(L in R.key!==void 0&&(U=""+R.key),R)!et.call(R,L)||L==="key"||L==="__self"||L==="__source"||L==="ref"&&R.ref===void 0||(w[L]=R[L]);var L=arguments.length-2;if(L===1)w.children=k;else if(1<L){for(var P=Array(L),H=0;H<L;H++)P[H]=arguments[H+2];w.children=P}return ut(E.type,U,w)},Et.createContext=function(E){return E={$$typeof:h,_currentValue:E,_currentValue2:E,_threadCount:0,Provider:null,Consumer:null},E.Provider=E,E.Consumer={$$typeof:o,_context:E},E},Et.createElement=function(E,R,k){var w,U={},L=null;if(R!=null)for(w in R.key!==void 0&&(L=""+R.key),R)et.call(R,w)&&w!=="key"&&w!=="__self"&&w!=="__source"&&(U[w]=R[w]);var P=arguments.length-2;if(P===1)U.children=k;else if(1<P){for(var H=Array(P),ht=0;ht<P;ht++)H[ht]=arguments[ht+2];U.children=H}if(E&&E.defaultProps)for(w in P=E.defaultProps,P)U[w]===void 0&&(U[w]=P[w]);return ut(E,L,U)},Et.createRef=function(){return{current:null}},Et.forwardRef=function(E){return{$$typeof:v,render:E}},Et.isValidElement=at,Et.lazy=function(E){return{$$typeof:_,_payload:{_status:-1,_result:E},_init:lt}},Et.memo=function(E,R){return{$$typeof:y,type:E,compare:R===void 0?null:R}},Et.startTransition=function(E){var R=X.T,k={};X.T=k;try{var w=E(),U=X.S;U!==null&&U(k,w),typeof w=="object"&&w!==null&&typeof w.then=="function"&&w.then(it,rt)}catch(L){rt(L)}finally{R!==null&&k.types!==null&&(R.types=k.types),X.T=R}},Et.unstable_useCacheRefresh=function(){return X.H.useCacheRefresh()},Et.use=function(E){return X.H.use(E)},Et.useActionState=function(E,R,k){return X.H.useActionState(E,R,k)},Et.useCallback=function(E,R){return X.H.useCallback(E,R)},Et.useContext=function(E){return X.H.useContext(E)},Et.useDebugValue=function(){},Et.useDeferredValue=function(E,R){return X.H.useDeferredValue(E,R)},Et.useEffect=function(E,R){return X.H.useEffect(E,R)},Et.useEffectEvent=function(E){return X.H.useEffectEvent(E)},Et.useId=function(){return X.H.useId()},Et.useImperativeHandle=function(E,R,k){return X.H.useImperativeHandle(E,R,k)},Et.useInsertionEffect=function(E,R){return X.H.useInsertionEffect(E,R)},Et.useLayoutEffect=function(E,R){return X.H.useLayoutEffect(E,R)},Et.useMemo=function(E,R){return X.H.useMemo(E,R)},Et.useOptimistic=function(E,R){return X.H.useOptimistic(E,R)},Et.useReducer=function(E,R,k){return X.H.useReducer(E,R,k)},Et.useRef=function(E){return X.H.useRef(E)},Et.useState=function(E){return X.H.useState(E)},Et.useSyncExternalStore=function(E,R,k){return X.H.useSyncExternalStore(E,R,k)},Et.useTransition=function(){return X.H.useTransition()},Et.version="19.2.1",Et}var _1;function kr(){return _1||(_1=1,or.exports=Dg()),or.exports}var Wn=kr();const mt=wg(Wn);var dr={exports:{}},Xi={},hr={exports:{}},mr={};/**
 * @license React
 * scheduler.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var p1;function zg(){return p1||(p1=1,(function(u){function i(N,V){var lt=N.length;N.push(V);t:for(;0<lt;){var rt=lt-1>>>1,gt=N[rt];if(0<r(gt,V))N[rt]=V,N[lt]=gt,lt=rt;else break t}}function f(N){return N.length===0?null:N[0]}function s(N){if(N.length===0)return null;var V=N[0],lt=N.pop();if(lt!==V){N[0]=lt;t:for(var rt=0,gt=N.length,E=gt>>>1;rt<E;){var R=2*(rt+1)-1,k=N[R],w=R+1,U=N[w];if(0>r(k,lt))w<gt&&0>r(U,k)?(N[rt]=U,N[w]=lt,rt=w):(N[rt]=k,N[R]=lt,rt=R);else if(w<gt&&0>r(U,lt))N[rt]=U,N[w]=lt,rt=w;else break t}}return V}function r(N,V){var lt=N.sortIndex-V.sortIndex;return lt!==0?lt:N.id-V.id}if(u.unstable_now=void 0,typeof performance=="object"&&typeof performance.now=="function"){var o=performance;u.unstable_now=function(){return o.now()}}else{var h=Date,v=h.now();u.unstable_now=function(){return h.now()-v}}var m=[],y=[],_=1,p=null,b=3,T=!1,D=!1,G=!1,W=!1,J=typeof setTimeout=="function"?setTimeout:null,Z=typeof clearTimeout=="function"?clearTimeout:null,$=typeof setImmediate<"u"?setImmediate:null;function I(N){for(var V=f(y);V!==null;){if(V.callback===null)s(y);else if(V.startTime<=N)s(y),V.sortIndex=V.expirationTime,i(m,V);else break;V=f(y)}}function B(N){if(G=!1,I(N),!D)if(f(m)!==null)D=!0,it||(it=!0,_t());else{var V=f(y);V!==null&&ot(B,V.startTime-N)}}var it=!1,X=-1,et=5,ut=-1;function st(){return W?!0:!(u.unstable_now()-ut<et)}function at(){if(W=!1,it){var N=u.unstable_now();ut=N;var V=!0;try{t:{D=!1,G&&(G=!1,Z(X),X=-1),T=!0;var lt=b;try{e:{for(I(N),p=f(m);p!==null&&!(p.expirationTime>N&&st());){var rt=p.callback;if(typeof rt=="function"){p.callback=null,b=p.priorityLevel;var gt=rt(p.expirationTime<=N);if(N=u.unstable_now(),typeof gt=="function"){p.callback=gt,I(N),V=!0;break e}p===f(m)&&s(m),I(N)}else s(m);p=f(m)}if(p!==null)V=!0;else{var E=f(y);E!==null&&ot(B,E.startTime-N),V=!1}}break t}finally{p=null,b=lt,T=!1}V=void 0}}finally{V?_t():it=!1}}}var _t;if(typeof $=="function")_t=function(){$(at)};else if(typeof MessageChannel<"u"){var pt=new MessageChannel,yt=pt.port2;pt.port1.onmessage=at,_t=function(){yt.postMessage(null)}}else _t=function(){J(at,0)};function ot(N,V){X=J(function(){N(u.unstable_now())},V)}u.unstable_IdlePriority=5,u.unstable_ImmediatePriority=1,u.unstable_LowPriority=4,u.unstable_NormalPriority=3,u.unstable_Profiling=null,u.unstable_UserBlockingPriority=2,u.unstable_cancelCallback=function(N){N.callback=null},u.unstable_forceFrameRate=function(N){0>N||125<N?console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported"):et=0<N?Math.floor(1e3/N):5},u.unstable_getCurrentPriorityLevel=function(){return b},u.unstable_next=function(N){switch(b){case 1:case 2:case 3:var V=3;break;default:V=b}var lt=b;b=V;try{return N()}finally{b=lt}},u.unstable_requestPaint=function(){W=!0},u.unstable_runWithPriority=function(N,V){switch(N){case 1:case 2:case 3:case 4:case 5:break;default:N=3}var lt=b;b=N;try{return V()}finally{b=lt}},u.unstable_scheduleCallback=function(N,V,lt){var rt=u.unstable_now();switch(typeof lt=="object"&&lt!==null?(lt=lt.delay,lt=typeof lt=="number"&&0<lt?rt+lt:rt):lt=rt,N){case 1:var gt=-1;break;case 2:gt=250;break;case 5:gt=1073741823;break;case 4:gt=1e4;break;default:gt=5e3}return gt=lt+gt,N={id:_++,callback:V,priorityLevel:N,startTime:lt,expirationTime:gt,sortIndex:-1},lt>rt?(N.sortIndex=lt,i(y,N),f(m)===null&&N===f(y)&&(G?(Z(X),X=-1):G=!0,ot(B,lt-rt))):(N.sortIndex=gt,i(m,N),D||T||(D=!0,it||(it=!0,_t()))),N},u.unstable_shouldYield=st,u.unstable_wrapCallback=function(N){var V=b;return function(){var lt=b;b=V;try{return N.apply(this,arguments)}finally{b=lt}}}})(mr)),mr}var b1;function Ng(){return b1||(b1=1,hr.exports=zg()),hr.exports}var yr={exports:{}},He={};/**
 * @license React
 * react-dom.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var S1;function Mg(){if(S1)return He;S1=1;var u=kr();function i(m){var y="https://react.dev/errors/"+m;if(1<arguments.length){y+="?args[]="+encodeURIComponent(arguments[1]);for(var _=2;_<arguments.length;_++)y+="&args[]="+encodeURIComponent(arguments[_])}return"Minified React error #"+m+"; visit "+y+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function f(){}var s={d:{f,r:function(){throw Error(i(522))},D:f,C:f,L:f,m:f,X:f,S:f,M:f},p:0,findDOMNode:null},r=Symbol.for("react.portal");function o(m,y,_){var p=3<arguments.length&&arguments[3]!==void 0?arguments[3]:null;return{$$typeof:r,key:p==null?null:""+p,children:m,containerInfo:y,implementation:_}}var h=u.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE;function v(m,y){if(m==="font")return"";if(typeof y=="string")return y==="use-credentials"?y:""}return He.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=s,He.createPortal=function(m,y){var _=2<arguments.length&&arguments[2]!==void 0?arguments[2]:null;if(!y||y.nodeType!==1&&y.nodeType!==9&&y.nodeType!==11)throw Error(i(299));return o(m,y,null,_)},He.flushSync=function(m){var y=h.T,_=s.p;try{if(h.T=null,s.p=2,m)return m()}finally{h.T=y,s.p=_,s.d.f()}},He.preconnect=function(m,y){typeof m=="string"&&(y?(y=y.crossOrigin,y=typeof y=="string"?y==="use-credentials"?y:"":void 0):y=null,s.d.C(m,y))},He.prefetchDNS=function(m){typeof m=="string"&&s.d.D(m)},He.preinit=function(m,y){if(typeof m=="string"&&y&&typeof y.as=="string"){var _=y.as,p=v(_,y.crossOrigin),b=typeof y.integrity=="string"?y.integrity:void 0,T=typeof y.fetchPriority=="string"?y.fetchPriority:void 0;_==="style"?s.d.S(m,typeof y.precedence=="string"?y.precedence:void 0,{crossOrigin:p,integrity:b,fetchPriority:T}):_==="script"&&s.d.X(m,{crossOrigin:p,integrity:b,fetchPriority:T,nonce:typeof y.nonce=="string"?y.nonce:void 0})}},He.preinitModule=function(m,y){if(typeof m=="string")if(typeof y=="object"&&y!==null){if(y.as==null||y.as==="script"){var _=v(y.as,y.crossOrigin);s.d.M(m,{crossOrigin:_,integrity:typeof y.integrity=="string"?y.integrity:void 0,nonce:typeof y.nonce=="string"?y.nonce:void 0})}}else y==null&&s.d.M(m)},He.preload=function(m,y){if(typeof m=="string"&&typeof y=="object"&&y!==null&&typeof y.as=="string"){var _=y.as,p=v(_,y.crossOrigin);s.d.L(m,_,{crossOrigin:p,integrity:typeof y.integrity=="string"?y.integrity:void 0,nonce:typeof y.nonce=="string"?y.nonce:void 0,type:typeof y.type=="string"?y.type:void 0,fetchPriority:typeof y.fetchPriority=="string"?y.fetchPriority:void 0,referrerPolicy:typeof y.referrerPolicy=="string"?y.referrerPolicy:void 0,imageSrcSet:typeof y.imageSrcSet=="string"?y.imageSrcSet:void 0,imageSizes:typeof y.imageSizes=="string"?y.imageSizes:void 0,media:typeof y.media=="string"?y.media:void 0})}},He.preloadModule=function(m,y){if(typeof m=="string")if(y){var _=v(y.as,y.crossOrigin);s.d.m(m,{as:typeof y.as=="string"&&y.as!=="script"?y.as:void 0,crossOrigin:_,integrity:typeof y.integrity=="string"?y.integrity:void 0})}else s.d.m(m)},He.requestFormReset=function(m){s.d.r(m)},He.unstable_batchedUpdates=function(m,y){return m(y)},He.useFormState=function(m,y,_){return h.H.useFormState(m,y,_)},He.useFormStatus=function(){return h.H.useHostTransitionStatus()},He.version="19.2.1",He}var E1;function Ug(){if(E1)return yr.exports;E1=1;function u(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(u)}catch(i){console.error(i)}}return u(),yr.exports=Mg(),yr.exports}/**
 * @license React
 * react-dom-client.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var T1;function Cg(){if(T1)return Xi;T1=1;var u=Ng(),i=kr(),f=Ug();function s(t){var e="https://react.dev/errors/"+t;if(1<arguments.length){e+="?args[]="+encodeURIComponent(arguments[1]);for(var n=2;n<arguments.length;n++)e+="&args[]="+encodeURIComponent(arguments[n])}return"Minified React error #"+t+"; visit "+e+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function r(t){return!(!t||t.nodeType!==1&&t.nodeType!==9&&t.nodeType!==11)}function o(t){var e=t,n=t;if(t.alternate)for(;e.return;)e=e.return;else{t=e;do e=t,(e.flags&4098)!==0&&(n=e.return),t=e.return;while(t)}return e.tag===3?n:null}function h(t){if(t.tag===13){var e=t.memoizedState;if(e===null&&(t=t.alternate,t!==null&&(e=t.memoizedState)),e!==null)return e.dehydrated}return null}function v(t){if(t.tag===31){var e=t.memoizedState;if(e===null&&(t=t.alternate,t!==null&&(e=t.memoizedState)),e!==null)return e.dehydrated}return null}function m(t){if(o(t)!==t)throw Error(s(188))}function y(t){var e=t.alternate;if(!e){if(e=o(t),e===null)throw Error(s(188));return e!==t?null:t}for(var n=t,a=e;;){var l=n.return;if(l===null)break;var c=l.alternate;if(c===null){if(a=l.return,a!==null){n=a;continue}break}if(l.child===c.child){for(c=l.child;c;){if(c===n)return m(l),t;if(c===a)return m(l),e;c=c.sibling}throw Error(s(188))}if(n.return!==a.return)n=l,a=c;else{for(var d=!1,g=l.child;g;){if(g===n){d=!0,n=l,a=c;break}if(g===a){d=!0,a=l,n=c;break}g=g.sibling}if(!d){for(g=c.child;g;){if(g===n){d=!0,n=c,a=l;break}if(g===a){d=!0,a=c,n=l;break}g=g.sibling}if(!d)throw Error(s(189))}}if(n.alternate!==a)throw Error(s(190))}if(n.tag!==3)throw Error(s(188));return n.stateNode.current===n?t:e}function _(t){var e=t.tag;if(e===5||e===26||e===27||e===6)return t;for(t=t.child;t!==null;){if(e=_(t),e!==null)return e;t=t.sibling}return null}var p=Object.assign,b=Symbol.for("react.element"),T=Symbol.for("react.transitional.element"),D=Symbol.for("react.portal"),G=Symbol.for("react.fragment"),W=Symbol.for("react.strict_mode"),J=Symbol.for("react.profiler"),Z=Symbol.for("react.consumer"),$=Symbol.for("react.context"),I=Symbol.for("react.forward_ref"),B=Symbol.for("react.suspense"),it=Symbol.for("react.suspense_list"),X=Symbol.for("react.memo"),et=Symbol.for("react.lazy"),ut=Symbol.for("react.activity"),st=Symbol.for("react.memo_cache_sentinel"),at=Symbol.iterator;function _t(t){return t===null||typeof t!="object"?null:(t=at&&t[at]||t["@@iterator"],typeof t=="function"?t:null)}var pt=Symbol.for("react.client.reference");function yt(t){if(t==null)return null;if(typeof t=="function")return t.$$typeof===pt?null:t.displayName||t.name||null;if(typeof t=="string")return t;switch(t){case G:return"Fragment";case J:return"Profiler";case W:return"StrictMode";case B:return"Suspense";case it:return"SuspenseList";case ut:return"Activity"}if(typeof t=="object")switch(t.$$typeof){case D:return"Portal";case $:return t.displayName||"Context";case Z:return(t._context.displayName||"Context")+".Consumer";case I:var e=t.render;return t=t.displayName,t||(t=e.displayName||e.name||"",t=t!==""?"ForwardRef("+t+")":"ForwardRef"),t;case X:return e=t.displayName||null,e!==null?e:yt(t.type)||"Memo";case et:e=t._payload,t=t._init;try{return yt(t(e))}catch{}}return null}var ot=Array.isArray,N=i.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,V=f.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,lt={pending:!1,data:null,method:null,action:null},rt=[],gt=-1;function E(t){return{current:t}}function R(t){0>gt||(t.current=rt[gt],rt[gt]=null,gt--)}function k(t,e){gt++,rt[gt]=t.current,t.current=e}var w=E(null),U=E(null),L=E(null),P=E(null);function H(t,e){switch(k(L,e),k(U,t),k(w,null),e.nodeType){case 9:case 11:t=(t=e.documentElement)&&(t=t.namespaceURI)?Bd(t):0;break;default:if(t=e.tagName,e=e.namespaceURI)e=Bd(e),t=Yd(e,t);else switch(t){case"svg":t=1;break;case"math":t=2;break;default:t=0}}R(w),k(w,t)}function ht(){R(w),R(U),R(L)}function Yt(t){t.memoizedState!==null&&k(P,t);var e=w.current,n=Yd(e,t.type);e!==n&&(k(U,t),k(w,n))}function Ft(t){U.current===t&&(R(w),R(U)),P.current===t&&(R(P),Bi._currentValue=lt)}var ae,oe;function Jt(t){if(ae===void 0)try{throw Error()}catch(n){var e=n.stack.trim().match(/\n( *(at )?)/);ae=e&&e[1]||"",oe=-1<n.stack.indexOf(`
    at`)?" (<anonymous>)":-1<n.stack.indexOf("@")?"@unknown:0:0":""}return`
`+ae+t+oe}var Gt=!1;function kt(t,e){if(!t||Gt)return"";Gt=!0;var n=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{var a={DetermineComponentFrameRoot:function(){try{if(e){var K=function(){throw Error()};if(Object.defineProperty(K.prototype,"props",{set:function(){throw Error()}}),typeof Reflect=="object"&&Reflect.construct){try{Reflect.construct(K,[])}catch(j){var C=j}Reflect.construct(t,[],K)}else{try{K.call()}catch(j){C=j}t.call(K.prototype)}}else{try{throw Error()}catch(j){C=j}(K=t())&&typeof K.catch=="function"&&K.catch(function(){})}}catch(j){if(j&&C&&typeof j.stack=="string")return[j.stack,C.stack]}return[null,null]}};a.DetermineComponentFrameRoot.displayName="DetermineComponentFrameRoot";var l=Object.getOwnPropertyDescriptor(a.DetermineComponentFrameRoot,"name");l&&l.configurable&&Object.defineProperty(a.DetermineComponentFrameRoot,"name",{value:"DetermineComponentFrameRoot"});var c=a.DetermineComponentFrameRoot(),d=c[0],g=c[1];if(d&&g){var S=d.split(`
`),M=g.split(`
`);for(l=a=0;a<S.length&&!S[a].includes("DetermineComponentFrameRoot");)a++;for(;l<M.length&&!M[l].includes("DetermineComponentFrameRoot");)l++;if(a===S.length||l===M.length)for(a=S.length-1,l=M.length-1;1<=a&&0<=l&&S[a]!==M[l];)l--;for(;1<=a&&0<=l;a--,l--)if(S[a]!==M[l]){if(a!==1||l!==1)do if(a--,l--,0>l||S[a]!==M[l]){var q=`
`+S[a].replace(" at new "," at ");return t.displayName&&q.includes("<anonymous>")&&(q=q.replace("<anonymous>",t.displayName)),q}while(1<=a&&0<=l);break}}}finally{Gt=!1,Error.prepareStackTrace=n}return(n=t?t.displayName||t.name:"")?Jt(n):""}function je(t,e){switch(t.tag){case 26:case 27:case 5:return Jt(t.type);case 16:return Jt("Lazy");case 13:return t.child!==e&&e!==null?Jt("Suspense Fallback"):Jt("Suspense");case 19:return Jt("SuspenseList");case 0:case 15:return kt(t.type,!1);case 11:return kt(t.type.render,!1);case 1:return kt(t.type,!0);case 31:return Jt("Activity");default:return""}}function Be(t){try{var e="",n=null;do e+=je(t,n),n=t,t=t.return;while(t);return e}catch(a){return`
Error generating stack: `+a.message+`
`+a.stack}}var qe=Object.prototype.hasOwnProperty,Ce=u.unstable_scheduleCallback,Ae=u.unstable_cancelCallback,wn=u.unstable_shouldYield,nl=u.unstable_requestPaint,xe=u.unstable_now,al=u.unstable_getCurrentPriorityLevel,ll=u.unstable_ImmediatePriority,_e=u.unstable_UserBlockingPriority,ea=u.unstable_NormalPriority,Jc=u.unstable_LowPriority,Wl=u.unstable_IdlePriority,kc=u.log,Ic=u.unstable_setDisableYieldValue,Ua=null,Y=null;function tt(t){if(typeof kc=="function"&&Ic(t),Y&&typeof Y.setStrictMode=="function")try{Y.setStrictMode(Ua,t)}catch{}}var F=Math.clz32?Math.clz32:St,nt=Math.log,ct=Math.LN2;function St(t){return t>>>=0,t===0?32:31-(nt(t)/ct|0)|0}var wt=256,de=262144,Le=4194304;function pn(t){var e=t&42;if(e!==0)return e;switch(t&-t){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:return 64;case 128:return 128;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:return t&261888;case 262144:case 524288:case 1048576:case 2097152:return t&3932160;case 4194304:case 8388608:case 16777216:case 33554432:return t&62914560;case 67108864:return 67108864;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 0;default:return t}}function Ca(t,e,n){var a=t.pendingLanes;if(a===0)return 0;var l=0,c=t.suspendedLanes,d=t.pingedLanes;t=t.warmLanes;var g=a&134217727;return g!==0?(a=g&~c,a!==0?l=pn(a):(d&=g,d!==0?l=pn(d):n||(n=g&~t,n!==0&&(l=pn(n))))):(g=a&~c,g!==0?l=pn(g):d!==0?l=pn(d):n||(n=a&~t,n!==0&&(l=pn(n)))),l===0?0:e!==0&&e!==l&&(e&c)===0&&(c=l&-l,n=e&-e,c>=n||c===32&&(n&4194048)!==0)?e:l}function na(t,e){return(t.pendingLanes&~(t.suspendedLanes&~t.pingedLanes)&e)===0}function h3(t,e){switch(t){case 1:case 2:case 4:case 8:case 64:return e+250;case 16:case 32:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return e+5e3;case 4194304:case 8388608:case 16777216:case 33554432:return-1;case 67108864:case 134217728:case 268435456:case 536870912:case 1073741824:return-1;default:return-1}}function po(){var t=Le;return Le<<=1,(Le&62914560)===0&&(Le=4194304),t}function Wc(t){for(var e=[],n=0;31>n;n++)e.push(t);return e}function $l(t,e){t.pendingLanes|=e,e!==268435456&&(t.suspendedLanes=0,t.pingedLanes=0,t.warmLanes=0)}function m3(t,e,n,a,l,c){var d=t.pendingLanes;t.pendingLanes=n,t.suspendedLanes=0,t.pingedLanes=0,t.warmLanes=0,t.expiredLanes&=n,t.entangledLanes&=n,t.errorRecoveryDisabledLanes&=n,t.shellSuspendCounter=0;var g=t.entanglements,S=t.expirationTimes,M=t.hiddenUpdates;for(n=d&~n;0<n;){var q=31-F(n),K=1<<q;g[q]=0,S[q]=-1;var C=M[q];if(C!==null)for(M[q]=null,q=0;q<C.length;q++){var j=C[q];j!==null&&(j.lane&=-536870913)}n&=~K}a!==0&&bo(t,a,0),c!==0&&l===0&&t.tag!==0&&(t.suspendedLanes|=c&~(d&~e))}function bo(t,e,n){t.pendingLanes|=e,t.suspendedLanes&=~e;var a=31-F(e);t.entangledLanes|=e,t.entanglements[a]=t.entanglements[a]|1073741824|n&261930}function So(t,e){var n=t.entangledLanes|=e;for(t=t.entanglements;n;){var a=31-F(n),l=1<<a;l&e|t[a]&e&&(t[a]|=e),n&=~l}}function Eo(t,e){var n=e&-e;return n=(n&42)!==0?1:$c(n),(n&(t.suspendedLanes|e))!==0?0:n}function $c(t){switch(t){case 2:t=1;break;case 8:t=4;break;case 32:t=16;break;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:t=128;break;case 268435456:t=134217728;break;default:t=0}return t}function Pc(t){return t&=-t,2<t?8<t?(t&134217727)!==0?32:268435456:8:2}function To(){var t=V.p;return t!==0?t:(t=window.event,t===void 0?32:s1(t.type))}function Ao(t,e){var n=V.p;try{return V.p=t,e()}finally{V.p=n}}var aa=Math.random().toString(36).slice(2),we="__reactFiber$"+aa,Ze="__reactProps$"+aa,il="__reactContainer$"+aa,ts="__reactEvents$"+aa,y3="__reactListeners$"+aa,g3="__reactHandles$"+aa,xo="__reactResources$"+aa,Pl="__reactMarker$"+aa;function es(t){delete t[we],delete t[Ze],delete t[ts],delete t[y3],delete t[g3]}function ul(t){var e=t[we];if(e)return e;for(var n=t.parentNode;n;){if(e=n[il]||n[we]){if(n=e.alternate,e.child!==null||n!==null&&n.child!==null)for(t=Fd(t);t!==null;){if(n=t[we])return n;t=Fd(t)}return e}t=n,n=t.parentNode}return null}function cl(t){if(t=t[we]||t[il]){var e=t.tag;if(e===5||e===6||e===13||e===31||e===26||e===27||e===3)return t}return null}function ti(t){var e=t.tag;if(e===5||e===26||e===27||e===6)return t.stateNode;throw Error(s(33))}function sl(t){var e=t[xo];return e||(e=t[xo]={hoistableStyles:new Map,hoistableScripts:new Map}),e}function be(t){t[Pl]=!0}var wo=new Set,Oo={};function La(t,e){fl(t,e),fl(t+"Capture",e)}function fl(t,e){for(Oo[t]=e,t=0;t<e.length;t++)wo.add(e[t])}var v3=RegExp("^[:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD][:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$"),Ro={},Do={};function _3(t){return qe.call(Do,t)?!0:qe.call(Ro,t)?!1:v3.test(t)?Do[t]=!0:(Ro[t]=!0,!1)}function uu(t,e,n){if(_3(e))if(n===null)t.removeAttribute(e);else{switch(typeof n){case"undefined":case"function":case"symbol":t.removeAttribute(e);return;case"boolean":var a=e.toLowerCase().slice(0,5);if(a!=="data-"&&a!=="aria-"){t.removeAttribute(e);return}}t.setAttribute(e,""+n)}}function cu(t,e,n){if(n===null)t.removeAttribute(e);else{switch(typeof n){case"undefined":case"function":case"symbol":case"boolean":t.removeAttribute(e);return}t.setAttribute(e,""+n)}}function Un(t,e,n,a){if(a===null)t.removeAttribute(n);else{switch(typeof a){case"undefined":case"function":case"symbol":case"boolean":t.removeAttribute(n);return}t.setAttributeNS(e,n,""+a)}}function un(t){switch(typeof t){case"bigint":case"boolean":case"number":case"string":case"undefined":return t;case"object":return t;default:return""}}function zo(t){var e=t.type;return(t=t.nodeName)&&t.toLowerCase()==="input"&&(e==="checkbox"||e==="radio")}function p3(t,e,n){var a=Object.getOwnPropertyDescriptor(t.constructor.prototype,e);if(!t.hasOwnProperty(e)&&typeof a<"u"&&typeof a.get=="function"&&typeof a.set=="function"){var l=a.get,c=a.set;return Object.defineProperty(t,e,{configurable:!0,get:function(){return l.call(this)},set:function(d){n=""+d,c.call(this,d)}}),Object.defineProperty(t,e,{enumerable:a.enumerable}),{getValue:function(){return n},setValue:function(d){n=""+d},stopTracking:function(){t._valueTracker=null,delete t[e]}}}}function ns(t){if(!t._valueTracker){var e=zo(t)?"checked":"value";t._valueTracker=p3(t,e,""+t[e])}}function No(t){if(!t)return!1;var e=t._valueTracker;if(!e)return!0;var n=e.getValue(),a="";return t&&(a=zo(t)?t.checked?"true":"false":t.value),t=a,t!==n?(e.setValue(t),!0):!1}function su(t){if(t=t||(typeof document<"u"?document:void 0),typeof t>"u")return null;try{return t.activeElement||t.body}catch{return t.body}}var b3=/[\n"\\]/g;function cn(t){return t.replace(b3,function(e){return"\\"+e.charCodeAt(0).toString(16)+" "})}function as(t,e,n,a,l,c,d,g){t.name="",d!=null&&typeof d!="function"&&typeof d!="symbol"&&typeof d!="boolean"?t.type=d:t.removeAttribute("type"),e!=null?d==="number"?(e===0&&t.value===""||t.value!=e)&&(t.value=""+un(e)):t.value!==""+un(e)&&(t.value=""+un(e)):d!=="submit"&&d!=="reset"||t.removeAttribute("value"),e!=null?ls(t,d,un(e)):n!=null?ls(t,d,un(n)):a!=null&&t.removeAttribute("value"),l==null&&c!=null&&(t.defaultChecked=!!c),l!=null&&(t.checked=l&&typeof l!="function"&&typeof l!="symbol"),g!=null&&typeof g!="function"&&typeof g!="symbol"&&typeof g!="boolean"?t.name=""+un(g):t.removeAttribute("name")}function Mo(t,e,n,a,l,c,d,g){if(c!=null&&typeof c!="function"&&typeof c!="symbol"&&typeof c!="boolean"&&(t.type=c),e!=null||n!=null){if(!(c!=="submit"&&c!=="reset"||e!=null)){ns(t);return}n=n!=null?""+un(n):"",e=e!=null?""+un(e):n,g||e===t.value||(t.value=e),t.defaultValue=e}a=a??l,a=typeof a!="function"&&typeof a!="symbol"&&!!a,t.checked=g?t.checked:!!a,t.defaultChecked=!!a,d!=null&&typeof d!="function"&&typeof d!="symbol"&&typeof d!="boolean"&&(t.name=d),ns(t)}function ls(t,e,n){e==="number"&&su(t.ownerDocument)===t||t.defaultValue===""+n||(t.defaultValue=""+n)}function rl(t,e,n,a){if(t=t.options,e){e={};for(var l=0;l<n.length;l++)e["$"+n[l]]=!0;for(n=0;n<t.length;n++)l=e.hasOwnProperty("$"+t[n].value),t[n].selected!==l&&(t[n].selected=l),l&&a&&(t[n].defaultSelected=!0)}else{for(n=""+un(n),e=null,l=0;l<t.length;l++){if(t[l].value===n){t[l].selected=!0,a&&(t[l].defaultSelected=!0);return}e!==null||t[l].disabled||(e=t[l])}e!==null&&(e.selected=!0)}}function Uo(t,e,n){if(e!=null&&(e=""+un(e),e!==t.value&&(t.value=e),n==null)){t.defaultValue!==e&&(t.defaultValue=e);return}t.defaultValue=n!=null?""+un(n):""}function Co(t,e,n,a){if(e==null){if(a!=null){if(n!=null)throw Error(s(92));if(ot(a)){if(1<a.length)throw Error(s(93));a=a[0]}n=a}n==null&&(n=""),e=n}n=un(e),t.defaultValue=n,a=t.textContent,a===n&&a!==""&&a!==null&&(t.value=a),ns(t)}function ol(t,e){if(e){var n=t.firstChild;if(n&&n===t.lastChild&&n.nodeType===3){n.nodeValue=e;return}}t.textContent=e}var S3=new Set("animationIterationCount aspectRatio borderImageOutset borderImageSlice borderImageWidth boxFlex boxFlexGroup boxOrdinalGroup columnCount columns flex flexGrow flexPositive flexShrink flexNegative flexOrder gridArea gridRow gridRowEnd gridRowSpan gridRowStart gridColumn gridColumnEnd gridColumnSpan gridColumnStart fontWeight lineClamp lineHeight opacity order orphans scale tabSize widows zIndex zoom fillOpacity floodOpacity stopOpacity strokeDasharray strokeDashoffset strokeMiterlimit strokeOpacity strokeWidth MozAnimationIterationCount MozBoxFlex MozBoxFlexGroup MozLineClamp msAnimationIterationCount msFlex msZoom msFlexGrow msFlexNegative msFlexOrder msFlexPositive msFlexShrink msGridColumn msGridColumnSpan msGridRow msGridRowSpan WebkitAnimationIterationCount WebkitBoxFlex WebKitBoxFlexGroup WebkitBoxOrdinalGroup WebkitColumnCount WebkitColumns WebkitFlex WebkitFlexGrow WebkitFlexPositive WebkitFlexShrink WebkitLineClamp".split(" "));function Lo(t,e,n){var a=e.indexOf("--")===0;n==null||typeof n=="boolean"||n===""?a?t.setProperty(e,""):e==="float"?t.cssFloat="":t[e]="":a?t.setProperty(e,n):typeof n!="number"||n===0||S3.has(e)?e==="float"?t.cssFloat=n:t[e]=(""+n).trim():t[e]=n+"px"}function Ho(t,e,n){if(e!=null&&typeof e!="object")throw Error(s(62));if(t=t.style,n!=null){for(var a in n)!n.hasOwnProperty(a)||e!=null&&e.hasOwnProperty(a)||(a.indexOf("--")===0?t.setProperty(a,""):a==="float"?t.cssFloat="":t[a]="");for(var l in e)a=e[l],e.hasOwnProperty(l)&&n[l]!==a&&Lo(t,l,a)}else for(var c in e)e.hasOwnProperty(c)&&Lo(t,c,e[c])}function is(t){if(t.indexOf("-")===-1)return!1;switch(t){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}var E3=new Map([["acceptCharset","accept-charset"],["htmlFor","for"],["httpEquiv","http-equiv"],["crossOrigin","crossorigin"],["accentHeight","accent-height"],["alignmentBaseline","alignment-baseline"],["arabicForm","arabic-form"],["baselineShift","baseline-shift"],["capHeight","cap-height"],["clipPath","clip-path"],["clipRule","clip-rule"],["colorInterpolation","color-interpolation"],["colorInterpolationFilters","color-interpolation-filters"],["colorProfile","color-profile"],["colorRendering","color-rendering"],["dominantBaseline","dominant-baseline"],["enableBackground","enable-background"],["fillOpacity","fill-opacity"],["fillRule","fill-rule"],["floodColor","flood-color"],["floodOpacity","flood-opacity"],["fontFamily","font-family"],["fontSize","font-size"],["fontSizeAdjust","font-size-adjust"],["fontStretch","font-stretch"],["fontStyle","font-style"],["fontVariant","font-variant"],["fontWeight","font-weight"],["glyphName","glyph-name"],["glyphOrientationHorizontal","glyph-orientation-horizontal"],["glyphOrientationVertical","glyph-orientation-vertical"],["horizAdvX","horiz-adv-x"],["horizOriginX","horiz-origin-x"],["imageRendering","image-rendering"],["letterSpacing","letter-spacing"],["lightingColor","lighting-color"],["markerEnd","marker-end"],["markerMid","marker-mid"],["markerStart","marker-start"],["overlinePosition","overline-position"],["overlineThickness","overline-thickness"],["paintOrder","paint-order"],["panose-1","panose-1"],["pointerEvents","pointer-events"],["renderingIntent","rendering-intent"],["shapeRendering","shape-rendering"],["stopColor","stop-color"],["stopOpacity","stop-opacity"],["strikethroughPosition","strikethrough-position"],["strikethroughThickness","strikethrough-thickness"],["strokeDasharray","stroke-dasharray"],["strokeDashoffset","stroke-dashoffset"],["strokeLinecap","stroke-linecap"],["strokeLinejoin","stroke-linejoin"],["strokeMiterlimit","stroke-miterlimit"],["strokeOpacity","stroke-opacity"],["strokeWidth","stroke-width"],["textAnchor","text-anchor"],["textDecoration","text-decoration"],["textRendering","text-rendering"],["transformOrigin","transform-origin"],["underlinePosition","underline-position"],["underlineThickness","underline-thickness"],["unicodeBidi","unicode-bidi"],["unicodeRange","unicode-range"],["unitsPerEm","units-per-em"],["vAlphabetic","v-alphabetic"],["vHanging","v-hanging"],["vIdeographic","v-ideographic"],["vMathematical","v-mathematical"],["vectorEffect","vector-effect"],["vertAdvY","vert-adv-y"],["vertOriginX","vert-origin-x"],["vertOriginY","vert-origin-y"],["wordSpacing","word-spacing"],["writingMode","writing-mode"],["xmlnsXlink","xmlns:xlink"],["xHeight","x-height"]]),T3=/^[\u0000-\u001F ]*j[\r\n\t]*a[\r\n\t]*v[\r\n\t]*a[\r\n\t]*s[\r\n\t]*c[\r\n\t]*r[\r\n\t]*i[\r\n\t]*p[\r\n\t]*t[\r\n\t]*:/i;function fu(t){return T3.test(""+t)?"javascript:throw new Error('React has blocked a javascript: URL as a security precaution.')":t}function Cn(){}var us=null;function cs(t){return t=t.target||t.srcElement||window,t.correspondingUseElement&&(t=t.correspondingUseElement),t.nodeType===3?t.parentNode:t}var dl=null,hl=null;function jo(t){var e=cl(t);if(e&&(t=e.stateNode)){var n=t[Ze]||null;t:switch(t=e.stateNode,e.type){case"input":if(as(t,n.value,n.defaultValue,n.defaultValue,n.checked,n.defaultChecked,n.type,n.name),e=n.name,n.type==="radio"&&e!=null){for(n=t;n.parentNode;)n=n.parentNode;for(n=n.querySelectorAll('input[name="'+cn(""+e)+'"][type="radio"]'),e=0;e<n.length;e++){var a=n[e];if(a!==t&&a.form===t.form){var l=a[Ze]||null;if(!l)throw Error(s(90));as(a,l.value,l.defaultValue,l.defaultValue,l.checked,l.defaultChecked,l.type,l.name)}}for(e=0;e<n.length;e++)a=n[e],a.form===t.form&&No(a)}break t;case"textarea":Uo(t,n.value,n.defaultValue);break t;case"select":e=n.value,e!=null&&rl(t,!!n.multiple,e,!1)}}}var ss=!1;function Bo(t,e,n){if(ss)return t(e,n);ss=!0;try{var a=t(e);return a}finally{if(ss=!1,(dl!==null||hl!==null)&&(Iu(),dl&&(e=dl,t=hl,hl=dl=null,jo(e),t)))for(e=0;e<t.length;e++)jo(t[e])}}function ei(t,e){var n=t.stateNode;if(n===null)return null;var a=n[Ze]||null;if(a===null)return null;n=a[e];t:switch(e){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(a=!a.disabled)||(t=t.type,a=!(t==="button"||t==="input"||t==="select"||t==="textarea")),t=!a;break t;default:t=!1}if(t)return null;if(n&&typeof n!="function")throw Error(s(231,e,typeof n));return n}var Ln=!(typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"),fs=!1;if(Ln)try{var ni={};Object.defineProperty(ni,"passive",{get:function(){fs=!0}}),window.addEventListener("test",ni,ni),window.removeEventListener("test",ni,ni)}catch{fs=!1}var la=null,rs=null,ru=null;function Yo(){if(ru)return ru;var t,e=rs,n=e.length,a,l="value"in la?la.value:la.textContent,c=l.length;for(t=0;t<n&&e[t]===l[t];t++);var d=n-t;for(a=1;a<=d&&e[n-a]===l[c-a];a++);return ru=l.slice(t,1<a?1-a:void 0)}function ou(t){var e=t.keyCode;return"charCode"in t?(t=t.charCode,t===0&&e===13&&(t=13)):t=e,t===10&&(t=13),32<=t||t===13?t:0}function du(){return!0}function Go(){return!1}function Xe(t){function e(n,a,l,c,d){this._reactName=n,this._targetInst=l,this.type=a,this.nativeEvent=c,this.target=d,this.currentTarget=null;for(var g in t)t.hasOwnProperty(g)&&(n=t[g],this[g]=n?n(c):c[g]);return this.isDefaultPrevented=(c.defaultPrevented!=null?c.defaultPrevented:c.returnValue===!1)?du:Go,this.isPropagationStopped=Go,this}return p(e.prototype,{preventDefault:function(){this.defaultPrevented=!0;var n=this.nativeEvent;n&&(n.preventDefault?n.preventDefault():typeof n.returnValue!="unknown"&&(n.returnValue=!1),this.isDefaultPrevented=du)},stopPropagation:function(){var n=this.nativeEvent;n&&(n.stopPropagation?n.stopPropagation():typeof n.cancelBubble!="unknown"&&(n.cancelBubble=!0),this.isPropagationStopped=du)},persist:function(){},isPersistent:du}),e}var Ha={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(t){return t.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},hu=Xe(Ha),ai=p({},Ha,{view:0,detail:0}),A3=Xe(ai),os,ds,li,mu=p({},ai,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:ms,button:0,buttons:0,relatedTarget:function(t){return t.relatedTarget===void 0?t.fromElement===t.srcElement?t.toElement:t.fromElement:t.relatedTarget},movementX:function(t){return"movementX"in t?t.movementX:(t!==li&&(li&&t.type==="mousemove"?(os=t.screenX-li.screenX,ds=t.screenY-li.screenY):ds=os=0,li=t),os)},movementY:function(t){return"movementY"in t?t.movementY:ds}}),qo=Xe(mu),x3=p({},mu,{dataTransfer:0}),w3=Xe(x3),O3=p({},ai,{relatedTarget:0}),hs=Xe(O3),R3=p({},Ha,{animationName:0,elapsedTime:0,pseudoElement:0}),D3=Xe(R3),z3=p({},Ha,{clipboardData:function(t){return"clipboardData"in t?t.clipboardData:window.clipboardData}}),N3=Xe(z3),M3=p({},Ha,{data:0}),Zo=Xe(M3),U3={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},C3={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},L3={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function H3(t){var e=this.nativeEvent;return e.getModifierState?e.getModifierState(t):(t=L3[t])?!!e[t]:!1}function ms(){return H3}var j3=p({},ai,{key:function(t){if(t.key){var e=U3[t.key]||t.key;if(e!=="Unidentified")return e}return t.type==="keypress"?(t=ou(t),t===13?"Enter":String.fromCharCode(t)):t.type==="keydown"||t.type==="keyup"?C3[t.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:ms,charCode:function(t){return t.type==="keypress"?ou(t):0},keyCode:function(t){return t.type==="keydown"||t.type==="keyup"?t.keyCode:0},which:function(t){return t.type==="keypress"?ou(t):t.type==="keydown"||t.type==="keyup"?t.keyCode:0}}),B3=Xe(j3),Y3=p({},mu,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0}),Xo=Xe(Y3),G3=p({},ai,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:ms}),q3=Xe(G3),Z3=p({},Ha,{propertyName:0,elapsedTime:0,pseudoElement:0}),X3=Xe(Z3),V3=p({},mu,{deltaX:function(t){return"deltaX"in t?t.deltaX:"wheelDeltaX"in t?-t.wheelDeltaX:0},deltaY:function(t){return"deltaY"in t?t.deltaY:"wheelDeltaY"in t?-t.wheelDeltaY:"wheelDelta"in t?-t.wheelDelta:0},deltaZ:0,deltaMode:0}),Q3=Xe(V3),F3=p({},Ha,{newState:0,oldState:0}),K3=Xe(F3),J3=[9,13,27,32],ys=Ln&&"CompositionEvent"in window,ii=null;Ln&&"documentMode"in document&&(ii=document.documentMode);var k3=Ln&&"TextEvent"in window&&!ii,Vo=Ln&&(!ys||ii&&8<ii&&11>=ii),Qo=" ",Fo=!1;function Ko(t,e){switch(t){case"keyup":return J3.indexOf(e.keyCode)!==-1;case"keydown":return e.keyCode!==229;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function Jo(t){return t=t.detail,typeof t=="object"&&"data"in t?t.data:null}var ml=!1;function I3(t,e){switch(t){case"compositionend":return Jo(e);case"keypress":return e.which!==32?null:(Fo=!0,Qo);case"textInput":return t=e.data,t===Qo&&Fo?null:t;default:return null}}function W3(t,e){if(ml)return t==="compositionend"||!ys&&Ko(t,e)?(t=Yo(),ru=rs=la=null,ml=!1,t):null;switch(t){case"paste":return null;case"keypress":if(!(e.ctrlKey||e.altKey||e.metaKey)||e.ctrlKey&&e.altKey){if(e.char&&1<e.char.length)return e.char;if(e.which)return String.fromCharCode(e.which)}return null;case"compositionend":return Vo&&e.locale!=="ko"?null:e.data;default:return null}}var $3={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function ko(t){var e=t&&t.nodeName&&t.nodeName.toLowerCase();return e==="input"?!!$3[t.type]:e==="textarea"}function Io(t,e,n,a){dl?hl?hl.push(a):hl=[a]:dl=a,e=ac(e,"onChange"),0<e.length&&(n=new hu("onChange","change",null,n,a),t.push({event:n,listeners:e}))}var ui=null,ci=null;function P3(t){Md(t,0)}function yu(t){var e=ti(t);if(No(e))return t}function Wo(t,e){if(t==="change")return e}var $o=!1;if(Ln){var gs;if(Ln){var vs="oninput"in document;if(!vs){var Po=document.createElement("div");Po.setAttribute("oninput","return;"),vs=typeof Po.oninput=="function"}gs=vs}else gs=!1;$o=gs&&(!document.documentMode||9<document.documentMode)}function t0(){ui&&(ui.detachEvent("onpropertychange",e0),ci=ui=null)}function e0(t){if(t.propertyName==="value"&&yu(ci)){var e=[];Io(e,ci,t,cs(t)),Bo(P3,e)}}function ty(t,e,n){t==="focusin"?(t0(),ui=e,ci=n,ui.attachEvent("onpropertychange",e0)):t==="focusout"&&t0()}function ey(t){if(t==="selectionchange"||t==="keyup"||t==="keydown")return yu(ci)}function ny(t,e){if(t==="click")return yu(e)}function ay(t,e){if(t==="input"||t==="change")return yu(e)}function ly(t,e){return t===e&&(t!==0||1/t===1/e)||t!==t&&e!==e}var Ie=typeof Object.is=="function"?Object.is:ly;function si(t,e){if(Ie(t,e))return!0;if(typeof t!="object"||t===null||typeof e!="object"||e===null)return!1;var n=Object.keys(t),a=Object.keys(e);if(n.length!==a.length)return!1;for(a=0;a<n.length;a++){var l=n[a];if(!qe.call(e,l)||!Ie(t[l],e[l]))return!1}return!0}function n0(t){for(;t&&t.firstChild;)t=t.firstChild;return t}function a0(t,e){var n=n0(t);t=0;for(var a;n;){if(n.nodeType===3){if(a=t+n.textContent.length,t<=e&&a>=e)return{node:n,offset:e-t};t=a}t:{for(;n;){if(n.nextSibling){n=n.nextSibling;break t}n=n.parentNode}n=void 0}n=n0(n)}}function l0(t,e){return t&&e?t===e?!0:t&&t.nodeType===3?!1:e&&e.nodeType===3?l0(t,e.parentNode):"contains"in t?t.contains(e):t.compareDocumentPosition?!!(t.compareDocumentPosition(e)&16):!1:!1}function i0(t){t=t!=null&&t.ownerDocument!=null&&t.ownerDocument.defaultView!=null?t.ownerDocument.defaultView:window;for(var e=su(t.document);e instanceof t.HTMLIFrameElement;){try{var n=typeof e.contentWindow.location.href=="string"}catch{n=!1}if(n)t=e.contentWindow;else break;e=su(t.document)}return e}function _s(t){var e=t&&t.nodeName&&t.nodeName.toLowerCase();return e&&(e==="input"&&(t.type==="text"||t.type==="search"||t.type==="tel"||t.type==="url"||t.type==="password")||e==="textarea"||t.contentEditable==="true")}var iy=Ln&&"documentMode"in document&&11>=document.documentMode,yl=null,ps=null,fi=null,bs=!1;function u0(t,e,n){var a=n.window===n?n.document:n.nodeType===9?n:n.ownerDocument;bs||yl==null||yl!==su(a)||(a=yl,"selectionStart"in a&&_s(a)?a={start:a.selectionStart,end:a.selectionEnd}:(a=(a.ownerDocument&&a.ownerDocument.defaultView||window).getSelection(),a={anchorNode:a.anchorNode,anchorOffset:a.anchorOffset,focusNode:a.focusNode,focusOffset:a.focusOffset}),fi&&si(fi,a)||(fi=a,a=ac(ps,"onSelect"),0<a.length&&(e=new hu("onSelect","select",null,e,n),t.push({event:e,listeners:a}),e.target=yl)))}function ja(t,e){var n={};return n[t.toLowerCase()]=e.toLowerCase(),n["Webkit"+t]="webkit"+e,n["Moz"+t]="moz"+e,n}var gl={animationend:ja("Animation","AnimationEnd"),animationiteration:ja("Animation","AnimationIteration"),animationstart:ja("Animation","AnimationStart"),transitionrun:ja("Transition","TransitionRun"),transitionstart:ja("Transition","TransitionStart"),transitioncancel:ja("Transition","TransitionCancel"),transitionend:ja("Transition","TransitionEnd")},Ss={},c0={};Ln&&(c0=document.createElement("div").style,"AnimationEvent"in window||(delete gl.animationend.animation,delete gl.animationiteration.animation,delete gl.animationstart.animation),"TransitionEvent"in window||delete gl.transitionend.transition);function Ba(t){if(Ss[t])return Ss[t];if(!gl[t])return t;var e=gl[t],n;for(n in e)if(e.hasOwnProperty(n)&&n in c0)return Ss[t]=e[n];return t}var s0=Ba("animationend"),f0=Ba("animationiteration"),r0=Ba("animationstart"),uy=Ba("transitionrun"),cy=Ba("transitionstart"),sy=Ba("transitioncancel"),o0=Ba("transitionend"),d0=new Map,Es="abort auxClick beforeToggle cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll toggle touchMove waiting wheel".split(" ");Es.push("scrollEnd");function bn(t,e){d0.set(t,e),La(e,[t])}var gu=typeof reportError=="function"?reportError:function(t){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var e=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof t=="object"&&t!==null&&typeof t.message=="string"?String(t.message):String(t),error:t});if(!window.dispatchEvent(e))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",t);return}console.error(t)},sn=[],vl=0,Ts=0;function vu(){for(var t=vl,e=Ts=vl=0;e<t;){var n=sn[e];sn[e++]=null;var a=sn[e];sn[e++]=null;var l=sn[e];sn[e++]=null;var c=sn[e];if(sn[e++]=null,a!==null&&l!==null){var d=a.pending;d===null?l.next=l:(l.next=d.next,d.next=l),a.pending=l}c!==0&&h0(n,l,c)}}function _u(t,e,n,a){sn[vl++]=t,sn[vl++]=e,sn[vl++]=n,sn[vl++]=a,Ts|=a,t.lanes|=a,t=t.alternate,t!==null&&(t.lanes|=a)}function As(t,e,n,a){return _u(t,e,n,a),pu(t)}function Ya(t,e){return _u(t,null,null,e),pu(t)}function h0(t,e,n){t.lanes|=n;var a=t.alternate;a!==null&&(a.lanes|=n);for(var l=!1,c=t.return;c!==null;)c.childLanes|=n,a=c.alternate,a!==null&&(a.childLanes|=n),c.tag===22&&(t=c.stateNode,t===null||t._visibility&1||(l=!0)),t=c,c=c.return;return t.tag===3?(c=t.stateNode,l&&e!==null&&(l=31-F(n),t=c.hiddenUpdates,a=t[l],a===null?t[l]=[e]:a.push(e),e.lane=n|536870912),c):null}function pu(t){if(50<Ni)throw Ni=0,Cf=null,Error(s(185));for(var e=t.return;e!==null;)t=e,e=t.return;return t.tag===3?t.stateNode:null}var _l={};function fy(t,e,n,a){this.tag=t,this.key=n,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.refCleanup=this.ref=null,this.pendingProps=e,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=a,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function We(t,e,n,a){return new fy(t,e,n,a)}function xs(t){return t=t.prototype,!(!t||!t.isReactComponent)}function Hn(t,e){var n=t.alternate;return n===null?(n=We(t.tag,e,t.key,t.mode),n.elementType=t.elementType,n.type=t.type,n.stateNode=t.stateNode,n.alternate=t,t.alternate=n):(n.pendingProps=e,n.type=t.type,n.flags=0,n.subtreeFlags=0,n.deletions=null),n.flags=t.flags&65011712,n.childLanes=t.childLanes,n.lanes=t.lanes,n.child=t.child,n.memoizedProps=t.memoizedProps,n.memoizedState=t.memoizedState,n.updateQueue=t.updateQueue,e=t.dependencies,n.dependencies=e===null?null:{lanes:e.lanes,firstContext:e.firstContext},n.sibling=t.sibling,n.index=t.index,n.ref=t.ref,n.refCleanup=t.refCleanup,n}function m0(t,e){t.flags&=65011714;var n=t.alternate;return n===null?(t.childLanes=0,t.lanes=e,t.child=null,t.subtreeFlags=0,t.memoizedProps=null,t.memoizedState=null,t.updateQueue=null,t.dependencies=null,t.stateNode=null):(t.childLanes=n.childLanes,t.lanes=n.lanes,t.child=n.child,t.subtreeFlags=0,t.deletions=null,t.memoizedProps=n.memoizedProps,t.memoizedState=n.memoizedState,t.updateQueue=n.updateQueue,t.type=n.type,e=n.dependencies,t.dependencies=e===null?null:{lanes:e.lanes,firstContext:e.firstContext}),t}function bu(t,e,n,a,l,c){var d=0;if(a=t,typeof t=="function")xs(t)&&(d=1);else if(typeof t=="string")d=mg(t,n,w.current)?26:t==="html"||t==="head"||t==="body"?27:5;else t:switch(t){case ut:return t=We(31,n,e,l),t.elementType=ut,t.lanes=c,t;case G:return Ga(n.children,l,c,e);case W:d=8,l|=24;break;case J:return t=We(12,n,e,l|2),t.elementType=J,t.lanes=c,t;case B:return t=We(13,n,e,l),t.elementType=B,t.lanes=c,t;case it:return t=We(19,n,e,l),t.elementType=it,t.lanes=c,t;default:if(typeof t=="object"&&t!==null)switch(t.$$typeof){case $:d=10;break t;case Z:d=9;break t;case I:d=11;break t;case X:d=14;break t;case et:d=16,a=null;break t}d=29,n=Error(s(130,t===null?"null":typeof t,"")),a=null}return e=We(d,n,e,l),e.elementType=t,e.type=a,e.lanes=c,e}function Ga(t,e,n,a){return t=We(7,t,a,e),t.lanes=n,t}function ws(t,e,n){return t=We(6,t,null,e),t.lanes=n,t}function y0(t){var e=We(18,null,null,0);return e.stateNode=t,e}function Os(t,e,n){return e=We(4,t.children!==null?t.children:[],t.key,e),e.lanes=n,e.stateNode={containerInfo:t.containerInfo,pendingChildren:null,implementation:t.implementation},e}var g0=new WeakMap;function fn(t,e){if(typeof t=="object"&&t!==null){var n=g0.get(t);return n!==void 0?n:(e={value:t,source:e,stack:Be(e)},g0.set(t,e),e)}return{value:t,source:e,stack:Be(e)}}var pl=[],bl=0,Su=null,ri=0,rn=[],on=0,ia=null,On=1,Rn="";function jn(t,e){pl[bl++]=ri,pl[bl++]=Su,Su=t,ri=e}function v0(t,e,n){rn[on++]=On,rn[on++]=Rn,rn[on++]=ia,ia=t;var a=On;t=Rn;var l=32-F(a)-1;a&=~(1<<l),n+=1;var c=32-F(e)+l;if(30<c){var d=l-l%5;c=(a&(1<<d)-1).toString(32),a>>=d,l-=d,On=1<<32-F(e)+l|n<<l|a,Rn=c+t}else On=1<<c|n<<l|a,Rn=t}function Rs(t){t.return!==null&&(jn(t,1),v0(t,1,0))}function Ds(t){for(;t===Su;)Su=pl[--bl],pl[bl]=null,ri=pl[--bl],pl[bl]=null;for(;t===ia;)ia=rn[--on],rn[on]=null,Rn=rn[--on],rn[on]=null,On=rn[--on],rn[on]=null}function _0(t,e){rn[on++]=On,rn[on++]=Rn,rn[on++]=ia,On=e.id,Rn=e.overflow,ia=t}var Oe=null,It=null,Ut=!1,ua=null,dn=!1,zs=Error(s(519));function ca(t){var e=Error(s(418,1<arguments.length&&arguments[1]!==void 0&&arguments[1]?"text":"HTML",""));throw oi(fn(e,t)),zs}function p0(t){var e=t.stateNode,n=t.type,a=t.memoizedProps;switch(e[we]=t,e[Ze]=a,n){case"dialog":Rt("cancel",e),Rt("close",e);break;case"iframe":case"object":case"embed":Rt("load",e);break;case"video":case"audio":for(n=0;n<Ui.length;n++)Rt(Ui[n],e);break;case"source":Rt("error",e);break;case"img":case"image":case"link":Rt("error",e),Rt("load",e);break;case"details":Rt("toggle",e);break;case"input":Rt("invalid",e),Mo(e,a.value,a.defaultValue,a.checked,a.defaultChecked,a.type,a.name,!0);break;case"select":Rt("invalid",e);break;case"textarea":Rt("invalid",e),Co(e,a.value,a.defaultValue,a.children)}n=a.children,typeof n!="string"&&typeof n!="number"&&typeof n!="bigint"||e.textContent===""+n||a.suppressHydrationWarning===!0||Hd(e.textContent,n)?(a.popover!=null&&(Rt("beforetoggle",e),Rt("toggle",e)),a.onScroll!=null&&Rt("scroll",e),a.onScrollEnd!=null&&Rt("scrollend",e),a.onClick!=null&&(e.onclick=Cn),e=!0):e=!1,e||ca(t,!0)}function b0(t){for(Oe=t.return;Oe;)switch(Oe.tag){case 5:case 31:case 13:dn=!1;return;case 27:case 3:dn=!0;return;default:Oe=Oe.return}}function Sl(t){if(t!==Oe)return!1;if(!Ut)return b0(t),Ut=!0,!1;var e=t.tag,n;if((n=e!==3&&e!==27)&&((n=e===5)&&(n=t.type,n=!(n!=="form"&&n!=="button")||kf(t.type,t.memoizedProps)),n=!n),n&&It&&ca(t),b0(t),e===13){if(t=t.memoizedState,t=t!==null?t.dehydrated:null,!t)throw Error(s(317));It=Qd(t)}else if(e===31){if(t=t.memoizedState,t=t!==null?t.dehydrated:null,!t)throw Error(s(317));It=Qd(t)}else e===27?(e=It,Sa(t.type)?(t=tr,tr=null,It=t):It=e):It=Oe?mn(t.stateNode.nextSibling):null;return!0}function qa(){It=Oe=null,Ut=!1}function Ns(){var t=ua;return t!==null&&(Ke===null?Ke=t:Ke.push.apply(Ke,t),ua=null),t}function oi(t){ua===null?ua=[t]:ua.push(t)}var Ms=E(null),Za=null,Bn=null;function sa(t,e,n){k(Ms,e._currentValue),e._currentValue=n}function Yn(t){t._currentValue=Ms.current,R(Ms)}function Us(t,e,n){for(;t!==null;){var a=t.alternate;if((t.childLanes&e)!==e?(t.childLanes|=e,a!==null&&(a.childLanes|=e)):a!==null&&(a.childLanes&e)!==e&&(a.childLanes|=e),t===n)break;t=t.return}}function Cs(t,e,n,a){var l=t.child;for(l!==null&&(l.return=t);l!==null;){var c=l.dependencies;if(c!==null){var d=l.child;c=c.firstContext;t:for(;c!==null;){var g=c;c=l;for(var S=0;S<e.length;S++)if(g.context===e[S]){c.lanes|=n,g=c.alternate,g!==null&&(g.lanes|=n),Us(c.return,n,t),a||(d=null);break t}c=g.next}}else if(l.tag===18){if(d=l.return,d===null)throw Error(s(341));d.lanes|=n,c=d.alternate,c!==null&&(c.lanes|=n),Us(d,n,t),d=null}else d=l.child;if(d!==null)d.return=l;else for(d=l;d!==null;){if(d===t){d=null;break}if(l=d.sibling,l!==null){l.return=d.return,d=l;break}d=d.return}l=d}}function El(t,e,n,a){t=null;for(var l=e,c=!1;l!==null;){if(!c){if((l.flags&524288)!==0)c=!0;else if((l.flags&262144)!==0)break}if(l.tag===10){var d=l.alternate;if(d===null)throw Error(s(387));if(d=d.memoizedProps,d!==null){var g=l.type;Ie(l.pendingProps.value,d.value)||(t!==null?t.push(g):t=[g])}}else if(l===P.current){if(d=l.alternate,d===null)throw Error(s(387));d.memoizedState.memoizedState!==l.memoizedState.memoizedState&&(t!==null?t.push(Bi):t=[Bi])}l=l.return}t!==null&&Cs(e,t,n,a),e.flags|=262144}function Eu(t){for(t=t.firstContext;t!==null;){if(!Ie(t.context._currentValue,t.memoizedValue))return!0;t=t.next}return!1}function Xa(t){Za=t,Bn=null,t=t.dependencies,t!==null&&(t.firstContext=null)}function Re(t){return S0(Za,t)}function Tu(t,e){return Za===null&&Xa(t),S0(t,e)}function S0(t,e){var n=e._currentValue;if(e={context:e,memoizedValue:n,next:null},Bn===null){if(t===null)throw Error(s(308));Bn=e,t.dependencies={lanes:0,firstContext:e},t.flags|=524288}else Bn=Bn.next=e;return n}var ry=typeof AbortController<"u"?AbortController:function(){var t=[],e=this.signal={aborted:!1,addEventListener:function(n,a){t.push(a)}};this.abort=function(){e.aborted=!0,t.forEach(function(n){return n()})}},oy=u.unstable_scheduleCallback,dy=u.unstable_NormalPriority,he={$$typeof:$,Consumer:null,Provider:null,_currentValue:null,_currentValue2:null,_threadCount:0};function Ls(){return{controller:new ry,data:new Map,refCount:0}}function di(t){t.refCount--,t.refCount===0&&oy(dy,function(){t.controller.abort()})}var hi=null,Hs=0,Tl=0,Al=null;function hy(t,e){if(hi===null){var n=hi=[];Hs=0,Tl=Gf(),Al={status:"pending",value:void 0,then:function(a){n.push(a)}}}return Hs++,e.then(E0,E0),e}function E0(){if(--Hs===0&&hi!==null){Al!==null&&(Al.status="fulfilled");var t=hi;hi=null,Tl=0,Al=null;for(var e=0;e<t.length;e++)(0,t[e])()}}function my(t,e){var n=[],a={status:"pending",value:null,reason:null,then:function(l){n.push(l)}};return t.then(function(){a.status="fulfilled",a.value=e;for(var l=0;l<n.length;l++)(0,n[l])(e)},function(l){for(a.status="rejected",a.reason=l,l=0;l<n.length;l++)(0,n[l])(void 0)}),a}var T0=N.S;N.S=function(t,e){ud=xe(),typeof e=="object"&&e!==null&&typeof e.then=="function"&&hy(t,e),T0!==null&&T0(t,e)};var Va=E(null);function js(){var t=Va.current;return t!==null?t:Kt.pooledCache}function Au(t,e){e===null?k(Va,Va.current):k(Va,e.pool)}function A0(){var t=js();return t===null?null:{parent:he._currentValue,pool:t}}var xl=Error(s(460)),Bs=Error(s(474)),xu=Error(s(542)),wu={then:function(){}};function x0(t){return t=t.status,t==="fulfilled"||t==="rejected"}function w0(t,e,n){switch(n=t[n],n===void 0?t.push(e):n!==e&&(e.then(Cn,Cn),e=n),e.status){case"fulfilled":return e.value;case"rejected":throw t=e.reason,R0(t),t;default:if(typeof e.status=="string")e.then(Cn,Cn);else{if(t=Kt,t!==null&&100<t.shellSuspendCounter)throw Error(s(482));t=e,t.status="pending",t.then(function(a){if(e.status==="pending"){var l=e;l.status="fulfilled",l.value=a}},function(a){if(e.status==="pending"){var l=e;l.status="rejected",l.reason=a}})}switch(e.status){case"fulfilled":return e.value;case"rejected":throw t=e.reason,R0(t),t}throw Fa=e,xl}}function Qa(t){try{var e=t._init;return e(t._payload)}catch(n){throw n!==null&&typeof n=="object"&&typeof n.then=="function"?(Fa=n,xl):n}}var Fa=null;function O0(){if(Fa===null)throw Error(s(459));var t=Fa;return Fa=null,t}function R0(t){if(t===xl||t===xu)throw Error(s(483))}var wl=null,mi=0;function Ou(t){var e=mi;return mi+=1,wl===null&&(wl=[]),w0(wl,t,e)}function yi(t,e){e=e.props.ref,t.ref=e!==void 0?e:null}function Ru(t,e){throw e.$$typeof===b?Error(s(525)):(t=Object.prototype.toString.call(e),Error(s(31,t==="[object Object]"?"object with keys {"+Object.keys(e).join(", ")+"}":t)))}function D0(t){function e(x,A){if(t){var z=x.deletions;z===null?(x.deletions=[A],x.flags|=16):z.push(A)}}function n(x,A){if(!t)return null;for(;A!==null;)e(x,A),A=A.sibling;return null}function a(x){for(var A=new Map;x!==null;)x.key!==null?A.set(x.key,x):A.set(x.index,x),x=x.sibling;return A}function l(x,A){return x=Hn(x,A),x.index=0,x.sibling=null,x}function c(x,A,z){return x.index=z,t?(z=x.alternate,z!==null?(z=z.index,z<A?(x.flags|=67108866,A):z):(x.flags|=67108866,A)):(x.flags|=1048576,A)}function d(x){return t&&x.alternate===null&&(x.flags|=67108866),x}function g(x,A,z,Q){return A===null||A.tag!==6?(A=ws(z,x.mode,Q),A.return=x,A):(A=l(A,z),A.return=x,A)}function S(x,A,z,Q){var vt=z.type;return vt===G?q(x,A,z.props.children,Q,z.key):A!==null&&(A.elementType===vt||typeof vt=="object"&&vt!==null&&vt.$$typeof===et&&Qa(vt)===A.type)?(A=l(A,z.props),yi(A,z),A.return=x,A):(A=bu(z.type,z.key,z.props,null,x.mode,Q),yi(A,z),A.return=x,A)}function M(x,A,z,Q){return A===null||A.tag!==4||A.stateNode.containerInfo!==z.containerInfo||A.stateNode.implementation!==z.implementation?(A=Os(z,x.mode,Q),A.return=x,A):(A=l(A,z.children||[]),A.return=x,A)}function q(x,A,z,Q,vt){return A===null||A.tag!==7?(A=Ga(z,x.mode,Q,vt),A.return=x,A):(A=l(A,z),A.return=x,A)}function K(x,A,z){if(typeof A=="string"&&A!==""||typeof A=="number"||typeof A=="bigint")return A=ws(""+A,x.mode,z),A.return=x,A;if(typeof A=="object"&&A!==null){switch(A.$$typeof){case T:return z=bu(A.type,A.key,A.props,null,x.mode,z),yi(z,A),z.return=x,z;case D:return A=Os(A,x.mode,z),A.return=x,A;case et:return A=Qa(A),K(x,A,z)}if(ot(A)||_t(A))return A=Ga(A,x.mode,z,null),A.return=x,A;if(typeof A.then=="function")return K(x,Ou(A),z);if(A.$$typeof===$)return K(x,Tu(x,A),z);Ru(x,A)}return null}function C(x,A,z,Q){var vt=A!==null?A.key:null;if(typeof z=="string"&&z!==""||typeof z=="number"||typeof z=="bigint")return vt!==null?null:g(x,A,""+z,Q);if(typeof z=="object"&&z!==null){switch(z.$$typeof){case T:return z.key===vt?S(x,A,z,Q):null;case D:return z.key===vt?M(x,A,z,Q):null;case et:return z=Qa(z),C(x,A,z,Q)}if(ot(z)||_t(z))return vt!==null?null:q(x,A,z,Q,null);if(typeof z.then=="function")return C(x,A,Ou(z),Q);if(z.$$typeof===$)return C(x,A,Tu(x,z),Q);Ru(x,z)}return null}function j(x,A,z,Q,vt){if(typeof Q=="string"&&Q!==""||typeof Q=="number"||typeof Q=="bigint")return x=x.get(z)||null,g(A,x,""+Q,vt);if(typeof Q=="object"&&Q!==null){switch(Q.$$typeof){case T:return x=x.get(Q.key===null?z:Q.key)||null,S(A,x,Q,vt);case D:return x=x.get(Q.key===null?z:Q.key)||null,M(A,x,Q,vt);case et:return Q=Qa(Q),j(x,A,z,Q,vt)}if(ot(Q)||_t(Q))return x=x.get(z)||null,q(A,x,Q,vt,null);if(typeof Q.then=="function")return j(x,A,z,Ou(Q),vt);if(Q.$$typeof===$)return j(x,A,z,Tu(A,Q),vt);Ru(A,Q)}return null}function ft(x,A,z,Q){for(var vt=null,Ht=null,dt=A,xt=A=0,Mt=null;dt!==null&&xt<z.length;xt++){dt.index>xt?(Mt=dt,dt=null):Mt=dt.sibling;var jt=C(x,dt,z[xt],Q);if(jt===null){dt===null&&(dt=Mt);break}t&&dt&&jt.alternate===null&&e(x,dt),A=c(jt,A,xt),Ht===null?vt=jt:Ht.sibling=jt,Ht=jt,dt=Mt}if(xt===z.length)return n(x,dt),Ut&&jn(x,xt),vt;if(dt===null){for(;xt<z.length;xt++)dt=K(x,z[xt],Q),dt!==null&&(A=c(dt,A,xt),Ht===null?vt=dt:Ht.sibling=dt,Ht=dt);return Ut&&jn(x,xt),vt}for(dt=a(dt);xt<z.length;xt++)Mt=j(dt,x,xt,z[xt],Q),Mt!==null&&(t&&Mt.alternate!==null&&dt.delete(Mt.key===null?xt:Mt.key),A=c(Mt,A,xt),Ht===null?vt=Mt:Ht.sibling=Mt,Ht=Mt);return t&&dt.forEach(function(wa){return e(x,wa)}),Ut&&jn(x,xt),vt}function bt(x,A,z,Q){if(z==null)throw Error(s(151));for(var vt=null,Ht=null,dt=A,xt=A=0,Mt=null,jt=z.next();dt!==null&&!jt.done;xt++,jt=z.next()){dt.index>xt?(Mt=dt,dt=null):Mt=dt.sibling;var wa=C(x,dt,jt.value,Q);if(wa===null){dt===null&&(dt=Mt);break}t&&dt&&wa.alternate===null&&e(x,dt),A=c(wa,A,xt),Ht===null?vt=wa:Ht.sibling=wa,Ht=wa,dt=Mt}if(jt.done)return n(x,dt),Ut&&jn(x,xt),vt;if(dt===null){for(;!jt.done;xt++,jt=z.next())jt=K(x,jt.value,Q),jt!==null&&(A=c(jt,A,xt),Ht===null?vt=jt:Ht.sibling=jt,Ht=jt);return Ut&&jn(x,xt),vt}for(dt=a(dt);!jt.done;xt++,jt=z.next())jt=j(dt,x,xt,jt.value,Q),jt!==null&&(t&&jt.alternate!==null&&dt.delete(jt.key===null?xt:jt.key),A=c(jt,A,xt),Ht===null?vt=jt:Ht.sibling=jt,Ht=jt);return t&&dt.forEach(function(xg){return e(x,xg)}),Ut&&jn(x,xt),vt}function Qt(x,A,z,Q){if(typeof z=="object"&&z!==null&&z.type===G&&z.key===null&&(z=z.props.children),typeof z=="object"&&z!==null){switch(z.$$typeof){case T:t:{for(var vt=z.key;A!==null;){if(A.key===vt){if(vt=z.type,vt===G){if(A.tag===7){n(x,A.sibling),Q=l(A,z.props.children),Q.return=x,x=Q;break t}}else if(A.elementType===vt||typeof vt=="object"&&vt!==null&&vt.$$typeof===et&&Qa(vt)===A.type){n(x,A.sibling),Q=l(A,z.props),yi(Q,z),Q.return=x,x=Q;break t}n(x,A);break}else e(x,A);A=A.sibling}z.type===G?(Q=Ga(z.props.children,x.mode,Q,z.key),Q.return=x,x=Q):(Q=bu(z.type,z.key,z.props,null,x.mode,Q),yi(Q,z),Q.return=x,x=Q)}return d(x);case D:t:{for(vt=z.key;A!==null;){if(A.key===vt)if(A.tag===4&&A.stateNode.containerInfo===z.containerInfo&&A.stateNode.implementation===z.implementation){n(x,A.sibling),Q=l(A,z.children||[]),Q.return=x,x=Q;break t}else{n(x,A);break}else e(x,A);A=A.sibling}Q=Os(z,x.mode,Q),Q.return=x,x=Q}return d(x);case et:return z=Qa(z),Qt(x,A,z,Q)}if(ot(z))return ft(x,A,z,Q);if(_t(z)){if(vt=_t(z),typeof vt!="function")throw Error(s(150));return z=vt.call(z),bt(x,A,z,Q)}if(typeof z.then=="function")return Qt(x,A,Ou(z),Q);if(z.$$typeof===$)return Qt(x,A,Tu(x,z),Q);Ru(x,z)}return typeof z=="string"&&z!==""||typeof z=="number"||typeof z=="bigint"?(z=""+z,A!==null&&A.tag===6?(n(x,A.sibling),Q=l(A,z),Q.return=x,x=Q):(n(x,A),Q=ws(z,x.mode,Q),Q.return=x,x=Q),d(x)):n(x,A)}return function(x,A,z,Q){try{mi=0;var vt=Qt(x,A,z,Q);return wl=null,vt}catch(dt){if(dt===xl||dt===xu)throw dt;var Ht=We(29,dt,null,x.mode);return Ht.lanes=Q,Ht.return=x,Ht}finally{}}}var Ka=D0(!0),z0=D0(!1),fa=!1;function Ys(t){t.updateQueue={baseState:t.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,lanes:0,hiddenCallbacks:null},callbacks:null}}function Gs(t,e){t=t.updateQueue,e.updateQueue===t&&(e.updateQueue={baseState:t.baseState,firstBaseUpdate:t.firstBaseUpdate,lastBaseUpdate:t.lastBaseUpdate,shared:t.shared,callbacks:null})}function ra(t){return{lane:t,tag:0,payload:null,callback:null,next:null}}function oa(t,e,n){var a=t.updateQueue;if(a===null)return null;if(a=a.shared,(Bt&2)!==0){var l=a.pending;return l===null?e.next=e:(e.next=l.next,l.next=e),a.pending=e,e=pu(t),h0(t,null,n),e}return _u(t,a,e,n),pu(t)}function gi(t,e,n){if(e=e.updateQueue,e!==null&&(e=e.shared,(n&4194048)!==0)){var a=e.lanes;a&=t.pendingLanes,n|=a,e.lanes=n,So(t,n)}}function qs(t,e){var n=t.updateQueue,a=t.alternate;if(a!==null&&(a=a.updateQueue,n===a)){var l=null,c=null;if(n=n.firstBaseUpdate,n!==null){do{var d={lane:n.lane,tag:n.tag,payload:n.payload,callback:null,next:null};c===null?l=c=d:c=c.next=d,n=n.next}while(n!==null);c===null?l=c=e:c=c.next=e}else l=c=e;n={baseState:a.baseState,firstBaseUpdate:l,lastBaseUpdate:c,shared:a.shared,callbacks:a.callbacks},t.updateQueue=n;return}t=n.lastBaseUpdate,t===null?n.firstBaseUpdate=e:t.next=e,n.lastBaseUpdate=e}var Zs=!1;function vi(){if(Zs){var t=Al;if(t!==null)throw t}}function _i(t,e,n,a){Zs=!1;var l=t.updateQueue;fa=!1;var c=l.firstBaseUpdate,d=l.lastBaseUpdate,g=l.shared.pending;if(g!==null){l.shared.pending=null;var S=g,M=S.next;S.next=null,d===null?c=M:d.next=M,d=S;var q=t.alternate;q!==null&&(q=q.updateQueue,g=q.lastBaseUpdate,g!==d&&(g===null?q.firstBaseUpdate=M:g.next=M,q.lastBaseUpdate=S))}if(c!==null){var K=l.baseState;d=0,q=M=S=null,g=c;do{var C=g.lane&-536870913,j=C!==g.lane;if(j?(Nt&C)===C:(a&C)===C){C!==0&&C===Tl&&(Zs=!0),q!==null&&(q=q.next={lane:0,tag:g.tag,payload:g.payload,callback:null,next:null});t:{var ft=t,bt=g;C=e;var Qt=n;switch(bt.tag){case 1:if(ft=bt.payload,typeof ft=="function"){K=ft.call(Qt,K,C);break t}K=ft;break t;case 3:ft.flags=ft.flags&-65537|128;case 0:if(ft=bt.payload,C=typeof ft=="function"?ft.call(Qt,K,C):ft,C==null)break t;K=p({},K,C);break t;case 2:fa=!0}}C=g.callback,C!==null&&(t.flags|=64,j&&(t.flags|=8192),j=l.callbacks,j===null?l.callbacks=[C]:j.push(C))}else j={lane:C,tag:g.tag,payload:g.payload,callback:g.callback,next:null},q===null?(M=q=j,S=K):q=q.next=j,d|=C;if(g=g.next,g===null){if(g=l.shared.pending,g===null)break;j=g,g=j.next,j.next=null,l.lastBaseUpdate=j,l.shared.pending=null}}while(!0);q===null&&(S=K),l.baseState=S,l.firstBaseUpdate=M,l.lastBaseUpdate=q,c===null&&(l.shared.lanes=0),ga|=d,t.lanes=d,t.memoizedState=K}}function N0(t,e){if(typeof t!="function")throw Error(s(191,t));t.call(e)}function M0(t,e){var n=t.callbacks;if(n!==null)for(t.callbacks=null,t=0;t<n.length;t++)N0(n[t],e)}var Ol=E(null),Du=E(0);function U0(t,e){t=Jn,k(Du,t),k(Ol,e),Jn=t|e.baseLanes}function Xs(){k(Du,Jn),k(Ol,Ol.current)}function Vs(){Jn=Du.current,R(Ol),R(Du)}var $e=E(null),hn=null;function da(t){var e=t.alternate;k(se,se.current&1),k($e,t),hn===null&&(e===null||Ol.current!==null||e.memoizedState!==null)&&(hn=t)}function Qs(t){k(se,se.current),k($e,t),hn===null&&(hn=t)}function C0(t){t.tag===22?(k(se,se.current),k($e,t),hn===null&&(hn=t)):ha()}function ha(){k(se,se.current),k($e,$e.current)}function Pe(t){R($e),hn===t&&(hn=null),R(se)}var se=E(0);function zu(t){for(var e=t;e!==null;){if(e.tag===13){var n=e.memoizedState;if(n!==null&&(n=n.dehydrated,n===null||$f(n)||Pf(n)))return e}else if(e.tag===19&&(e.memoizedProps.revealOrder==="forwards"||e.memoizedProps.revealOrder==="backwards"||e.memoizedProps.revealOrder==="unstable_legacy-backwards"||e.memoizedProps.revealOrder==="together")){if((e.flags&128)!==0)return e}else if(e.child!==null){e.child.return=e,e=e.child;continue}if(e===t)break;for(;e.sibling===null;){if(e.return===null||e.return===t)return null;e=e.return}e.sibling.return=e.return,e=e.sibling}return null}var Gn=0,Tt=null,Xt=null,me=null,Nu=!1,Rl=!1,Ja=!1,Mu=0,pi=0,Dl=null,yy=0;function ie(){throw Error(s(321))}function Fs(t,e){if(e===null)return!1;for(var n=0;n<e.length&&n<t.length;n++)if(!Ie(t[n],e[n]))return!1;return!0}function Ks(t,e,n,a,l,c){return Gn=c,Tt=e,e.memoizedState=null,e.updateQueue=null,e.lanes=0,N.H=t===null||t.memoizedState===null?v2:ff,Ja=!1,c=n(a,l),Ja=!1,Rl&&(c=H0(e,n,a,l)),L0(t),c}function L0(t){N.H=Ei;var e=Xt!==null&&Xt.next!==null;if(Gn=0,me=Xt=Tt=null,Nu=!1,pi=0,Dl=null,e)throw Error(s(300));t===null||ye||(t=t.dependencies,t!==null&&Eu(t)&&(ye=!0))}function H0(t,e,n,a){Tt=t;var l=0;do{if(Rl&&(Dl=null),pi=0,Rl=!1,25<=l)throw Error(s(301));if(l+=1,me=Xt=null,t.updateQueue!=null){var c=t.updateQueue;c.lastEffect=null,c.events=null,c.stores=null,c.memoCache!=null&&(c.memoCache.index=0)}N.H=_2,c=e(n,a)}while(Rl);return c}function gy(){var t=N.H,e=t.useState()[0];return e=typeof e.then=="function"?bi(e):e,t=t.useState()[0],(Xt!==null?Xt.memoizedState:null)!==t&&(Tt.flags|=1024),e}function Js(){var t=Mu!==0;return Mu=0,t}function ks(t,e,n){e.updateQueue=t.updateQueue,e.flags&=-2053,t.lanes&=~n}function Is(t){if(Nu){for(t=t.memoizedState;t!==null;){var e=t.queue;e!==null&&(e.pending=null),t=t.next}Nu=!1}Gn=0,me=Xt=Tt=null,Rl=!1,pi=Mu=0,Dl=null}function Ye(){var t={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return me===null?Tt.memoizedState=me=t:me=me.next=t,me}function fe(){if(Xt===null){var t=Tt.alternate;t=t!==null?t.memoizedState:null}else t=Xt.next;var e=me===null?Tt.memoizedState:me.next;if(e!==null)me=e,Xt=t;else{if(t===null)throw Tt.alternate===null?Error(s(467)):Error(s(310));Xt=t,t={memoizedState:Xt.memoizedState,baseState:Xt.baseState,baseQueue:Xt.baseQueue,queue:Xt.queue,next:null},me===null?Tt.memoizedState=me=t:me=me.next=t}return me}function Uu(){return{lastEffect:null,events:null,stores:null,memoCache:null}}function bi(t){var e=pi;return pi+=1,Dl===null&&(Dl=[]),t=w0(Dl,t,e),e=Tt,(me===null?e.memoizedState:me.next)===null&&(e=e.alternate,N.H=e===null||e.memoizedState===null?v2:ff),t}function Cu(t){if(t!==null&&typeof t=="object"){if(typeof t.then=="function")return bi(t);if(t.$$typeof===$)return Re(t)}throw Error(s(438,String(t)))}function Ws(t){var e=null,n=Tt.updateQueue;if(n!==null&&(e=n.memoCache),e==null){var a=Tt.alternate;a!==null&&(a=a.updateQueue,a!==null&&(a=a.memoCache,a!=null&&(e={data:a.data.map(function(l){return l.slice()}),index:0})))}if(e==null&&(e={data:[],index:0}),n===null&&(n=Uu(),Tt.updateQueue=n),n.memoCache=e,n=e.data[e.index],n===void 0)for(n=e.data[e.index]=Array(t),a=0;a<t;a++)n[a]=st;return e.index++,n}function qn(t,e){return typeof e=="function"?e(t):e}function Lu(t){var e=fe();return $s(e,Xt,t)}function $s(t,e,n){var a=t.queue;if(a===null)throw Error(s(311));a.lastRenderedReducer=n;var l=t.baseQueue,c=a.pending;if(c!==null){if(l!==null){var d=l.next;l.next=c.next,c.next=d}e.baseQueue=l=c,a.pending=null}if(c=t.baseState,l===null)t.memoizedState=c;else{e=l.next;var g=d=null,S=null,M=e,q=!1;do{var K=M.lane&-536870913;if(K!==M.lane?(Nt&K)===K:(Gn&K)===K){var C=M.revertLane;if(C===0)S!==null&&(S=S.next={lane:0,revertLane:0,gesture:null,action:M.action,hasEagerState:M.hasEagerState,eagerState:M.eagerState,next:null}),K===Tl&&(q=!0);else if((Gn&C)===C){M=M.next,C===Tl&&(q=!0);continue}else K={lane:0,revertLane:M.revertLane,gesture:null,action:M.action,hasEagerState:M.hasEagerState,eagerState:M.eagerState,next:null},S===null?(g=S=K,d=c):S=S.next=K,Tt.lanes|=C,ga|=C;K=M.action,Ja&&n(c,K),c=M.hasEagerState?M.eagerState:n(c,K)}else C={lane:K,revertLane:M.revertLane,gesture:M.gesture,action:M.action,hasEagerState:M.hasEagerState,eagerState:M.eagerState,next:null},S===null?(g=S=C,d=c):S=S.next=C,Tt.lanes|=K,ga|=K;M=M.next}while(M!==null&&M!==e);if(S===null?d=c:S.next=g,!Ie(c,t.memoizedState)&&(ye=!0,q&&(n=Al,n!==null)))throw n;t.memoizedState=c,t.baseState=d,t.baseQueue=S,a.lastRenderedState=c}return l===null&&(a.lanes=0),[t.memoizedState,a.dispatch]}function Ps(t){var e=fe(),n=e.queue;if(n===null)throw Error(s(311));n.lastRenderedReducer=t;var a=n.dispatch,l=n.pending,c=e.memoizedState;if(l!==null){n.pending=null;var d=l=l.next;do c=t(c,d.action),d=d.next;while(d!==l);Ie(c,e.memoizedState)||(ye=!0),e.memoizedState=c,e.baseQueue===null&&(e.baseState=c),n.lastRenderedState=c}return[c,a]}function j0(t,e,n){var a=Tt,l=fe(),c=Ut;if(c){if(n===void 0)throw Error(s(407));n=n()}else n=e();var d=!Ie((Xt||l).memoizedState,n);if(d&&(l.memoizedState=n,ye=!0),l=l.queue,nf(G0.bind(null,a,l,t),[t]),l.getSnapshot!==e||d||me!==null&&me.memoizedState.tag&1){if(a.flags|=2048,zl(9,{destroy:void 0},Y0.bind(null,a,l,n,e),null),Kt===null)throw Error(s(349));c||(Gn&127)!==0||B0(a,e,n)}return n}function B0(t,e,n){t.flags|=16384,t={getSnapshot:e,value:n},e=Tt.updateQueue,e===null?(e=Uu(),Tt.updateQueue=e,e.stores=[t]):(n=e.stores,n===null?e.stores=[t]:n.push(t))}function Y0(t,e,n,a){e.value=n,e.getSnapshot=a,q0(e)&&Z0(t)}function G0(t,e,n){return n(function(){q0(e)&&Z0(t)})}function q0(t){var e=t.getSnapshot;t=t.value;try{var n=e();return!Ie(t,n)}catch{return!0}}function Z0(t){var e=Ya(t,2);e!==null&&Je(e,t,2)}function tf(t){var e=Ye();if(typeof t=="function"){var n=t;if(t=n(),Ja){tt(!0);try{n()}finally{tt(!1)}}}return e.memoizedState=e.baseState=t,e.queue={pending:null,lanes:0,dispatch:null,lastRenderedReducer:qn,lastRenderedState:t},e}function X0(t,e,n,a){return t.baseState=n,$s(t,Xt,typeof a=="function"?a:qn)}function vy(t,e,n,a,l){if(Bu(t))throw Error(s(485));if(t=e.action,t!==null){var c={payload:l,action:t,next:null,isTransition:!0,status:"pending",value:null,reason:null,listeners:[],then:function(d){c.listeners.push(d)}};N.T!==null?n(!0):c.isTransition=!1,a(c),n=e.pending,n===null?(c.next=e.pending=c,V0(e,c)):(c.next=n.next,e.pending=n.next=c)}}function V0(t,e){var n=e.action,a=e.payload,l=t.state;if(e.isTransition){var c=N.T,d={};N.T=d;try{var g=n(l,a),S=N.S;S!==null&&S(d,g),Q0(t,e,g)}catch(M){ef(t,e,M)}finally{c!==null&&d.types!==null&&(c.types=d.types),N.T=c}}else try{c=n(l,a),Q0(t,e,c)}catch(M){ef(t,e,M)}}function Q0(t,e,n){n!==null&&typeof n=="object"&&typeof n.then=="function"?n.then(function(a){F0(t,e,a)},function(a){return ef(t,e,a)}):F0(t,e,n)}function F0(t,e,n){e.status="fulfilled",e.value=n,K0(e),t.state=n,e=t.pending,e!==null&&(n=e.next,n===e?t.pending=null:(n=n.next,e.next=n,V0(t,n)))}function ef(t,e,n){var a=t.pending;if(t.pending=null,a!==null){a=a.next;do e.status="rejected",e.reason=n,K0(e),e=e.next;while(e!==a)}t.action=null}function K0(t){t=t.listeners;for(var e=0;e<t.length;e++)(0,t[e])()}function J0(t,e){return e}function k0(t,e){if(Ut){var n=Kt.formState;if(n!==null){t:{var a=Tt;if(Ut){if(It){e:{for(var l=It,c=dn;l.nodeType!==8;){if(!c){l=null;break e}if(l=mn(l.nextSibling),l===null){l=null;break e}}c=l.data,l=c==="F!"||c==="F"?l:null}if(l){It=mn(l.nextSibling),a=l.data==="F!";break t}}ca(a)}a=!1}a&&(e=n[0])}}return n=Ye(),n.memoizedState=n.baseState=e,a={pending:null,lanes:0,dispatch:null,lastRenderedReducer:J0,lastRenderedState:e},n.queue=a,n=m2.bind(null,Tt,a),a.dispatch=n,a=tf(!1),c=sf.bind(null,Tt,!1,a.queue),a=Ye(),l={state:e,dispatch:null,action:t,pending:null},a.queue=l,n=vy.bind(null,Tt,l,c,n),l.dispatch=n,a.memoizedState=t,[e,n,!1]}function I0(t){var e=fe();return W0(e,Xt,t)}function W0(t,e,n){if(e=$s(t,e,J0)[0],t=Lu(qn)[0],typeof e=="object"&&e!==null&&typeof e.then=="function")try{var a=bi(e)}catch(d){throw d===xl?xu:d}else a=e;e=fe();var l=e.queue,c=l.dispatch;return n!==e.memoizedState&&(Tt.flags|=2048,zl(9,{destroy:void 0},_y.bind(null,l,n),null)),[a,c,t]}function _y(t,e){t.action=e}function $0(t){var e=fe(),n=Xt;if(n!==null)return W0(e,n,t);fe(),e=e.memoizedState,n=fe();var a=n.queue.dispatch;return n.memoizedState=t,[e,a,!1]}function zl(t,e,n,a){return t={tag:t,create:n,deps:a,inst:e,next:null},e=Tt.updateQueue,e===null&&(e=Uu(),Tt.updateQueue=e),n=e.lastEffect,n===null?e.lastEffect=t.next=t:(a=n.next,n.next=t,t.next=a,e.lastEffect=t),t}function P0(){return fe().memoizedState}function Hu(t,e,n,a){var l=Ye();Tt.flags|=t,l.memoizedState=zl(1|e,{destroy:void 0},n,a===void 0?null:a)}function ju(t,e,n,a){var l=fe();a=a===void 0?null:a;var c=l.memoizedState.inst;Xt!==null&&a!==null&&Fs(a,Xt.memoizedState.deps)?l.memoizedState=zl(e,c,n,a):(Tt.flags|=t,l.memoizedState=zl(1|e,c,n,a))}function t2(t,e){Hu(8390656,8,t,e)}function nf(t,e){ju(2048,8,t,e)}function py(t){Tt.flags|=4;var e=Tt.updateQueue;if(e===null)e=Uu(),Tt.updateQueue=e,e.events=[t];else{var n=e.events;n===null?e.events=[t]:n.push(t)}}function e2(t){var e=fe().memoizedState;return py({ref:e,nextImpl:t}),function(){if((Bt&2)!==0)throw Error(s(440));return e.impl.apply(void 0,arguments)}}function n2(t,e){return ju(4,2,t,e)}function a2(t,e){return ju(4,4,t,e)}function l2(t,e){if(typeof e=="function"){t=t();var n=e(t);return function(){typeof n=="function"?n():e(null)}}if(e!=null)return t=t(),e.current=t,function(){e.current=null}}function i2(t,e,n){n=n!=null?n.concat([t]):null,ju(4,4,l2.bind(null,e,t),n)}function af(){}function u2(t,e){var n=fe();e=e===void 0?null:e;var a=n.memoizedState;return e!==null&&Fs(e,a[1])?a[0]:(n.memoizedState=[t,e],t)}function c2(t,e){var n=fe();e=e===void 0?null:e;var a=n.memoizedState;if(e!==null&&Fs(e,a[1]))return a[0];if(a=t(),Ja){tt(!0);try{t()}finally{tt(!1)}}return n.memoizedState=[a,e],a}function lf(t,e,n){return n===void 0||(Gn&1073741824)!==0&&(Nt&261930)===0?t.memoizedState=e:(t.memoizedState=n,t=sd(),Tt.lanes|=t,ga|=t,n)}function s2(t,e,n,a){return Ie(n,e)?n:Ol.current!==null?(t=lf(t,n,a),Ie(t,e)||(ye=!0),t):(Gn&42)===0||(Gn&1073741824)!==0&&(Nt&261930)===0?(ye=!0,t.memoizedState=n):(t=sd(),Tt.lanes|=t,ga|=t,e)}function f2(t,e,n,a,l){var c=V.p;V.p=c!==0&&8>c?c:8;var d=N.T,g={};N.T=g,sf(t,!1,e,n);try{var S=l(),M=N.S;if(M!==null&&M(g,S),S!==null&&typeof S=="object"&&typeof S.then=="function"){var q=my(S,a);Si(t,e,q,nn(t))}else Si(t,e,a,nn(t))}catch(K){Si(t,e,{then:function(){},status:"rejected",reason:K},nn())}finally{V.p=c,d!==null&&g.types!==null&&(d.types=g.types),N.T=d}}function by(){}function uf(t,e,n,a){if(t.tag!==5)throw Error(s(476));var l=r2(t).queue;f2(t,l,e,lt,n===null?by:function(){return o2(t),n(a)})}function r2(t){var e=t.memoizedState;if(e!==null)return e;e={memoizedState:lt,baseState:lt,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:qn,lastRenderedState:lt},next:null};var n={};return e.next={memoizedState:n,baseState:n,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:qn,lastRenderedState:n},next:null},t.memoizedState=e,t=t.alternate,t!==null&&(t.memoizedState=e),e}function o2(t){var e=r2(t);e.next===null&&(e=t.alternate.memoizedState),Si(t,e.next.queue,{},nn())}function cf(){return Re(Bi)}function d2(){return fe().memoizedState}function h2(){return fe().memoizedState}function Sy(t){for(var e=t.return;e!==null;){switch(e.tag){case 24:case 3:var n=nn();t=ra(n);var a=oa(e,t,n);a!==null&&(Je(a,e,n),gi(a,e,n)),e={cache:Ls()},t.payload=e;return}e=e.return}}function Ey(t,e,n){var a=nn();n={lane:a,revertLane:0,gesture:null,action:n,hasEagerState:!1,eagerState:null,next:null},Bu(t)?y2(e,n):(n=As(t,e,n,a),n!==null&&(Je(n,t,a),g2(n,e,a)))}function m2(t,e,n){var a=nn();Si(t,e,n,a)}function Si(t,e,n,a){var l={lane:a,revertLane:0,gesture:null,action:n,hasEagerState:!1,eagerState:null,next:null};if(Bu(t))y2(e,l);else{var c=t.alternate;if(t.lanes===0&&(c===null||c.lanes===0)&&(c=e.lastRenderedReducer,c!==null))try{var d=e.lastRenderedState,g=c(d,n);if(l.hasEagerState=!0,l.eagerState=g,Ie(g,d))return _u(t,e,l,0),Kt===null&&vu(),!1}catch{}finally{}if(n=As(t,e,l,a),n!==null)return Je(n,t,a),g2(n,e,a),!0}return!1}function sf(t,e,n,a){if(a={lane:2,revertLane:Gf(),gesture:null,action:a,hasEagerState:!1,eagerState:null,next:null},Bu(t)){if(e)throw Error(s(479))}else e=As(t,n,a,2),e!==null&&Je(e,t,2)}function Bu(t){var e=t.alternate;return t===Tt||e!==null&&e===Tt}function y2(t,e){Rl=Nu=!0;var n=t.pending;n===null?e.next=e:(e.next=n.next,n.next=e),t.pending=e}function g2(t,e,n){if((n&4194048)!==0){var a=e.lanes;a&=t.pendingLanes,n|=a,e.lanes=n,So(t,n)}}var Ei={readContext:Re,use:Cu,useCallback:ie,useContext:ie,useEffect:ie,useImperativeHandle:ie,useLayoutEffect:ie,useInsertionEffect:ie,useMemo:ie,useReducer:ie,useRef:ie,useState:ie,useDebugValue:ie,useDeferredValue:ie,useTransition:ie,useSyncExternalStore:ie,useId:ie,useHostTransitionStatus:ie,useFormState:ie,useActionState:ie,useOptimistic:ie,useMemoCache:ie,useCacheRefresh:ie};Ei.useEffectEvent=ie;var v2={readContext:Re,use:Cu,useCallback:function(t,e){return Ye().memoizedState=[t,e===void 0?null:e],t},useContext:Re,useEffect:t2,useImperativeHandle:function(t,e,n){n=n!=null?n.concat([t]):null,Hu(4194308,4,l2.bind(null,e,t),n)},useLayoutEffect:function(t,e){return Hu(4194308,4,t,e)},useInsertionEffect:function(t,e){Hu(4,2,t,e)},useMemo:function(t,e){var n=Ye();e=e===void 0?null:e;var a=t();if(Ja){tt(!0);try{t()}finally{tt(!1)}}return n.memoizedState=[a,e],a},useReducer:function(t,e,n){var a=Ye();if(n!==void 0){var l=n(e);if(Ja){tt(!0);try{n(e)}finally{tt(!1)}}}else l=e;return a.memoizedState=a.baseState=l,t={pending:null,lanes:0,dispatch:null,lastRenderedReducer:t,lastRenderedState:l},a.queue=t,t=t.dispatch=Ey.bind(null,Tt,t),[a.memoizedState,t]},useRef:function(t){var e=Ye();return t={current:t},e.memoizedState=t},useState:function(t){t=tf(t);var e=t.queue,n=m2.bind(null,Tt,e);return e.dispatch=n,[t.memoizedState,n]},useDebugValue:af,useDeferredValue:function(t,e){var n=Ye();return lf(n,t,e)},useTransition:function(){var t=tf(!1);return t=f2.bind(null,Tt,t.queue,!0,!1),Ye().memoizedState=t,[!1,t]},useSyncExternalStore:function(t,e,n){var a=Tt,l=Ye();if(Ut){if(n===void 0)throw Error(s(407));n=n()}else{if(n=e(),Kt===null)throw Error(s(349));(Nt&127)!==0||B0(a,e,n)}l.memoizedState=n;var c={value:n,getSnapshot:e};return l.queue=c,t2(G0.bind(null,a,c,t),[t]),a.flags|=2048,zl(9,{destroy:void 0},Y0.bind(null,a,c,n,e),null),n},useId:function(){var t=Ye(),e=Kt.identifierPrefix;if(Ut){var n=Rn,a=On;n=(a&~(1<<32-F(a)-1)).toString(32)+n,e="_"+e+"R_"+n,n=Mu++,0<n&&(e+="H"+n.toString(32)),e+="_"}else n=yy++,e="_"+e+"r_"+n.toString(32)+"_";return t.memoizedState=e},useHostTransitionStatus:cf,useFormState:k0,useActionState:k0,useOptimistic:function(t){var e=Ye();e.memoizedState=e.baseState=t;var n={pending:null,lanes:0,dispatch:null,lastRenderedReducer:null,lastRenderedState:null};return e.queue=n,e=sf.bind(null,Tt,!0,n),n.dispatch=e,[t,e]},useMemoCache:Ws,useCacheRefresh:function(){return Ye().memoizedState=Sy.bind(null,Tt)},useEffectEvent:function(t){var e=Ye(),n={impl:t};return e.memoizedState=n,function(){if((Bt&2)!==0)throw Error(s(440));return n.impl.apply(void 0,arguments)}}},ff={readContext:Re,use:Cu,useCallback:u2,useContext:Re,useEffect:nf,useImperativeHandle:i2,useInsertionEffect:n2,useLayoutEffect:a2,useMemo:c2,useReducer:Lu,useRef:P0,useState:function(){return Lu(qn)},useDebugValue:af,useDeferredValue:function(t,e){var n=fe();return s2(n,Xt.memoizedState,t,e)},useTransition:function(){var t=Lu(qn)[0],e=fe().memoizedState;return[typeof t=="boolean"?t:bi(t),e]},useSyncExternalStore:j0,useId:d2,useHostTransitionStatus:cf,useFormState:I0,useActionState:I0,useOptimistic:function(t,e){var n=fe();return X0(n,Xt,t,e)},useMemoCache:Ws,useCacheRefresh:h2};ff.useEffectEvent=e2;var _2={readContext:Re,use:Cu,useCallback:u2,useContext:Re,useEffect:nf,useImperativeHandle:i2,useInsertionEffect:n2,useLayoutEffect:a2,useMemo:c2,useReducer:Ps,useRef:P0,useState:function(){return Ps(qn)},useDebugValue:af,useDeferredValue:function(t,e){var n=fe();return Xt===null?lf(n,t,e):s2(n,Xt.memoizedState,t,e)},useTransition:function(){var t=Ps(qn)[0],e=fe().memoizedState;return[typeof t=="boolean"?t:bi(t),e]},useSyncExternalStore:j0,useId:d2,useHostTransitionStatus:cf,useFormState:$0,useActionState:$0,useOptimistic:function(t,e){var n=fe();return Xt!==null?X0(n,Xt,t,e):(n.baseState=t,[t,n.queue.dispatch])},useMemoCache:Ws,useCacheRefresh:h2};_2.useEffectEvent=e2;function rf(t,e,n,a){e=t.memoizedState,n=n(a,e),n=n==null?e:p({},e,n),t.memoizedState=n,t.lanes===0&&(t.updateQueue.baseState=n)}var of={enqueueSetState:function(t,e,n){t=t._reactInternals;var a=nn(),l=ra(a);l.payload=e,n!=null&&(l.callback=n),e=oa(t,l,a),e!==null&&(Je(e,t,a),gi(e,t,a))},enqueueReplaceState:function(t,e,n){t=t._reactInternals;var a=nn(),l=ra(a);l.tag=1,l.payload=e,n!=null&&(l.callback=n),e=oa(t,l,a),e!==null&&(Je(e,t,a),gi(e,t,a))},enqueueForceUpdate:function(t,e){t=t._reactInternals;var n=nn(),a=ra(n);a.tag=2,e!=null&&(a.callback=e),e=oa(t,a,n),e!==null&&(Je(e,t,n),gi(e,t,n))}};function p2(t,e,n,a,l,c,d){return t=t.stateNode,typeof t.shouldComponentUpdate=="function"?t.shouldComponentUpdate(a,c,d):e.prototype&&e.prototype.isPureReactComponent?!si(n,a)||!si(l,c):!0}function b2(t,e,n,a){t=e.state,typeof e.componentWillReceiveProps=="function"&&e.componentWillReceiveProps(n,a),typeof e.UNSAFE_componentWillReceiveProps=="function"&&e.UNSAFE_componentWillReceiveProps(n,a),e.state!==t&&of.enqueueReplaceState(e,e.state,null)}function ka(t,e){var n=e;if("ref"in e){n={};for(var a in e)a!=="ref"&&(n[a]=e[a])}if(t=t.defaultProps){n===e&&(n=p({},n));for(var l in t)n[l]===void 0&&(n[l]=t[l])}return n}function S2(t){gu(t)}function E2(t){console.error(t)}function T2(t){gu(t)}function Yu(t,e){try{var n=t.onUncaughtError;n(e.value,{componentStack:e.stack})}catch(a){setTimeout(function(){throw a})}}function A2(t,e,n){try{var a=t.onCaughtError;a(n.value,{componentStack:n.stack,errorBoundary:e.tag===1?e.stateNode:null})}catch(l){setTimeout(function(){throw l})}}function df(t,e,n){return n=ra(n),n.tag=3,n.payload={element:null},n.callback=function(){Yu(t,e)},n}function x2(t){return t=ra(t),t.tag=3,t}function w2(t,e,n,a){var l=n.type.getDerivedStateFromError;if(typeof l=="function"){var c=a.value;t.payload=function(){return l(c)},t.callback=function(){A2(e,n,a)}}var d=n.stateNode;d!==null&&typeof d.componentDidCatch=="function"&&(t.callback=function(){A2(e,n,a),typeof l!="function"&&(va===null?va=new Set([this]):va.add(this));var g=a.stack;this.componentDidCatch(a.value,{componentStack:g!==null?g:""})})}function Ty(t,e,n,a,l){if(n.flags|=32768,a!==null&&typeof a=="object"&&typeof a.then=="function"){if(e=n.alternate,e!==null&&El(e,n,l,!0),n=$e.current,n!==null){switch(n.tag){case 31:case 13:return hn===null?Wu():n.alternate===null&&ue===0&&(ue=3),n.flags&=-257,n.flags|=65536,n.lanes=l,a===wu?n.flags|=16384:(e=n.updateQueue,e===null?n.updateQueue=new Set([a]):e.add(a),jf(t,a,l)),!1;case 22:return n.flags|=65536,a===wu?n.flags|=16384:(e=n.updateQueue,e===null?(e={transitions:null,markerInstances:null,retryQueue:new Set([a])},n.updateQueue=e):(n=e.retryQueue,n===null?e.retryQueue=new Set([a]):n.add(a)),jf(t,a,l)),!1}throw Error(s(435,n.tag))}return jf(t,a,l),Wu(),!1}if(Ut)return e=$e.current,e!==null?((e.flags&65536)===0&&(e.flags|=256),e.flags|=65536,e.lanes=l,a!==zs&&(t=Error(s(422),{cause:a}),oi(fn(t,n)))):(a!==zs&&(e=Error(s(423),{cause:a}),oi(fn(e,n))),t=t.current.alternate,t.flags|=65536,l&=-l,t.lanes|=l,a=fn(a,n),l=df(t.stateNode,a,l),qs(t,l),ue!==4&&(ue=2)),!1;var c=Error(s(520),{cause:a});if(c=fn(c,n),zi===null?zi=[c]:zi.push(c),ue!==4&&(ue=2),e===null)return!0;a=fn(a,n),n=e;do{switch(n.tag){case 3:return n.flags|=65536,t=l&-l,n.lanes|=t,t=df(n.stateNode,a,t),qs(n,t),!1;case 1:if(e=n.type,c=n.stateNode,(n.flags&128)===0&&(typeof e.getDerivedStateFromError=="function"||c!==null&&typeof c.componentDidCatch=="function"&&(va===null||!va.has(c))))return n.flags|=65536,l&=-l,n.lanes|=l,l=x2(l),w2(l,t,n,a),qs(n,l),!1}n=n.return}while(n!==null);return!1}var hf=Error(s(461)),ye=!1;function De(t,e,n,a){e.child=t===null?z0(e,null,n,a):Ka(e,t.child,n,a)}function O2(t,e,n,a,l){n=n.render;var c=e.ref;if("ref"in a){var d={};for(var g in a)g!=="ref"&&(d[g]=a[g])}else d=a;return Xa(e),a=Ks(t,e,n,d,c,l),g=Js(),t!==null&&!ye?(ks(t,e,l),Zn(t,e,l)):(Ut&&g&&Rs(e),e.flags|=1,De(t,e,a,l),e.child)}function R2(t,e,n,a,l){if(t===null){var c=n.type;return typeof c=="function"&&!xs(c)&&c.defaultProps===void 0&&n.compare===null?(e.tag=15,e.type=c,D2(t,e,c,a,l)):(t=bu(n.type,null,a,e,e.mode,l),t.ref=e.ref,t.return=e,e.child=t)}if(c=t.child,!Sf(t,l)){var d=c.memoizedProps;if(n=n.compare,n=n!==null?n:si,n(d,a)&&t.ref===e.ref)return Zn(t,e,l)}return e.flags|=1,t=Hn(c,a),t.ref=e.ref,t.return=e,e.child=t}function D2(t,e,n,a,l){if(t!==null){var c=t.memoizedProps;if(si(c,a)&&t.ref===e.ref)if(ye=!1,e.pendingProps=a=c,Sf(t,l))(t.flags&131072)!==0&&(ye=!0);else return e.lanes=t.lanes,Zn(t,e,l)}return mf(t,e,n,a,l)}function z2(t,e,n,a){var l=a.children,c=t!==null?t.memoizedState:null;if(t===null&&e.stateNode===null&&(e.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),a.mode==="hidden"){if((e.flags&128)!==0){if(c=c!==null?c.baseLanes|n:n,t!==null){for(a=e.child=t.child,l=0;a!==null;)l=l|a.lanes|a.childLanes,a=a.sibling;a=l&~c}else a=0,e.child=null;return N2(t,e,c,n,a)}if((n&536870912)!==0)e.memoizedState={baseLanes:0,cachePool:null},t!==null&&Au(e,c!==null?c.cachePool:null),c!==null?U0(e,c):Xs(),C0(e);else return a=e.lanes=536870912,N2(t,e,c!==null?c.baseLanes|n:n,n,a)}else c!==null?(Au(e,c.cachePool),U0(e,c),ha(),e.memoizedState=null):(t!==null&&Au(e,null),Xs(),ha());return De(t,e,l,n),e.child}function Ti(t,e){return t!==null&&t.tag===22||e.stateNode!==null||(e.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),e.sibling}function N2(t,e,n,a,l){var c=js();return c=c===null?null:{parent:he._currentValue,pool:c},e.memoizedState={baseLanes:n,cachePool:c},t!==null&&Au(e,null),Xs(),C0(e),t!==null&&El(t,e,a,!0),e.childLanes=l,null}function Gu(t,e){return e=Zu({mode:e.mode,children:e.children},t.mode),e.ref=t.ref,t.child=e,e.return=t,e}function M2(t,e,n){return Ka(e,t.child,null,n),t=Gu(e,e.pendingProps),t.flags|=2,Pe(e),e.memoizedState=null,t}function Ay(t,e,n){var a=e.pendingProps,l=(e.flags&128)!==0;if(e.flags&=-129,t===null){if(Ut){if(a.mode==="hidden")return t=Gu(e,a),e.lanes=536870912,Ti(null,t);if(Qs(e),(t=It)?(t=Vd(t,dn),t=t!==null&&t.data==="&"?t:null,t!==null&&(e.memoizedState={dehydrated:t,treeContext:ia!==null?{id:On,overflow:Rn}:null,retryLane:536870912,hydrationErrors:null},n=y0(t),n.return=e,e.child=n,Oe=e,It=null)):t=null,t===null)throw ca(e);return e.lanes=536870912,null}return Gu(e,a)}var c=t.memoizedState;if(c!==null){var d=c.dehydrated;if(Qs(e),l)if(e.flags&256)e.flags&=-257,e=M2(t,e,n);else if(e.memoizedState!==null)e.child=t.child,e.flags|=128,e=null;else throw Error(s(558));else if(ye||El(t,e,n,!1),l=(n&t.childLanes)!==0,ye||l){if(a=Kt,a!==null&&(d=Eo(a,n),d!==0&&d!==c.retryLane))throw c.retryLane=d,Ya(t,d),Je(a,t,d),hf;Wu(),e=M2(t,e,n)}else t=c.treeContext,It=mn(d.nextSibling),Oe=e,Ut=!0,ua=null,dn=!1,t!==null&&_0(e,t),e=Gu(e,a),e.flags|=4096;return e}return t=Hn(t.child,{mode:a.mode,children:a.children}),t.ref=e.ref,e.child=t,t.return=e,t}function qu(t,e){var n=e.ref;if(n===null)t!==null&&t.ref!==null&&(e.flags|=4194816);else{if(typeof n!="function"&&typeof n!="object")throw Error(s(284));(t===null||t.ref!==n)&&(e.flags|=4194816)}}function mf(t,e,n,a,l){return Xa(e),n=Ks(t,e,n,a,void 0,l),a=Js(),t!==null&&!ye?(ks(t,e,l),Zn(t,e,l)):(Ut&&a&&Rs(e),e.flags|=1,De(t,e,n,l),e.child)}function U2(t,e,n,a,l,c){return Xa(e),e.updateQueue=null,n=H0(e,a,n,l),L0(t),a=Js(),t!==null&&!ye?(ks(t,e,c),Zn(t,e,c)):(Ut&&a&&Rs(e),e.flags|=1,De(t,e,n,c),e.child)}function C2(t,e,n,a,l){if(Xa(e),e.stateNode===null){var c=_l,d=n.contextType;typeof d=="object"&&d!==null&&(c=Re(d)),c=new n(a,c),e.memoizedState=c.state!==null&&c.state!==void 0?c.state:null,c.updater=of,e.stateNode=c,c._reactInternals=e,c=e.stateNode,c.props=a,c.state=e.memoizedState,c.refs={},Ys(e),d=n.contextType,c.context=typeof d=="object"&&d!==null?Re(d):_l,c.state=e.memoizedState,d=n.getDerivedStateFromProps,typeof d=="function"&&(rf(e,n,d,a),c.state=e.memoizedState),typeof n.getDerivedStateFromProps=="function"||typeof c.getSnapshotBeforeUpdate=="function"||typeof c.UNSAFE_componentWillMount!="function"&&typeof c.componentWillMount!="function"||(d=c.state,typeof c.componentWillMount=="function"&&c.componentWillMount(),typeof c.UNSAFE_componentWillMount=="function"&&c.UNSAFE_componentWillMount(),d!==c.state&&of.enqueueReplaceState(c,c.state,null),_i(e,a,c,l),vi(),c.state=e.memoizedState),typeof c.componentDidMount=="function"&&(e.flags|=4194308),a=!0}else if(t===null){c=e.stateNode;var g=e.memoizedProps,S=ka(n,g);c.props=S;var M=c.context,q=n.contextType;d=_l,typeof q=="object"&&q!==null&&(d=Re(q));var K=n.getDerivedStateFromProps;q=typeof K=="function"||typeof c.getSnapshotBeforeUpdate=="function",g=e.pendingProps!==g,q||typeof c.UNSAFE_componentWillReceiveProps!="function"&&typeof c.componentWillReceiveProps!="function"||(g||M!==d)&&b2(e,c,a,d),fa=!1;var C=e.memoizedState;c.state=C,_i(e,a,c,l),vi(),M=e.memoizedState,g||C!==M||fa?(typeof K=="function"&&(rf(e,n,K,a),M=e.memoizedState),(S=fa||p2(e,n,S,a,C,M,d))?(q||typeof c.UNSAFE_componentWillMount!="function"&&typeof c.componentWillMount!="function"||(typeof c.componentWillMount=="function"&&c.componentWillMount(),typeof c.UNSAFE_componentWillMount=="function"&&c.UNSAFE_componentWillMount()),typeof c.componentDidMount=="function"&&(e.flags|=4194308)):(typeof c.componentDidMount=="function"&&(e.flags|=4194308),e.memoizedProps=a,e.memoizedState=M),c.props=a,c.state=M,c.context=d,a=S):(typeof c.componentDidMount=="function"&&(e.flags|=4194308),a=!1)}else{c=e.stateNode,Gs(t,e),d=e.memoizedProps,q=ka(n,d),c.props=q,K=e.pendingProps,C=c.context,M=n.contextType,S=_l,typeof M=="object"&&M!==null&&(S=Re(M)),g=n.getDerivedStateFromProps,(M=typeof g=="function"||typeof c.getSnapshotBeforeUpdate=="function")||typeof c.UNSAFE_componentWillReceiveProps!="function"&&typeof c.componentWillReceiveProps!="function"||(d!==K||C!==S)&&b2(e,c,a,S),fa=!1,C=e.memoizedState,c.state=C,_i(e,a,c,l),vi();var j=e.memoizedState;d!==K||C!==j||fa||t!==null&&t.dependencies!==null&&Eu(t.dependencies)?(typeof g=="function"&&(rf(e,n,g,a),j=e.memoizedState),(q=fa||p2(e,n,q,a,C,j,S)||t!==null&&t.dependencies!==null&&Eu(t.dependencies))?(M||typeof c.UNSAFE_componentWillUpdate!="function"&&typeof c.componentWillUpdate!="function"||(typeof c.componentWillUpdate=="function"&&c.componentWillUpdate(a,j,S),typeof c.UNSAFE_componentWillUpdate=="function"&&c.UNSAFE_componentWillUpdate(a,j,S)),typeof c.componentDidUpdate=="function"&&(e.flags|=4),typeof c.getSnapshotBeforeUpdate=="function"&&(e.flags|=1024)):(typeof c.componentDidUpdate!="function"||d===t.memoizedProps&&C===t.memoizedState||(e.flags|=4),typeof c.getSnapshotBeforeUpdate!="function"||d===t.memoizedProps&&C===t.memoizedState||(e.flags|=1024),e.memoizedProps=a,e.memoizedState=j),c.props=a,c.state=j,c.context=S,a=q):(typeof c.componentDidUpdate!="function"||d===t.memoizedProps&&C===t.memoizedState||(e.flags|=4),typeof c.getSnapshotBeforeUpdate!="function"||d===t.memoizedProps&&C===t.memoizedState||(e.flags|=1024),a=!1)}return c=a,qu(t,e),a=(e.flags&128)!==0,c||a?(c=e.stateNode,n=a&&typeof n.getDerivedStateFromError!="function"?null:c.render(),e.flags|=1,t!==null&&a?(e.child=Ka(e,t.child,null,l),e.child=Ka(e,null,n,l)):De(t,e,n,l),e.memoizedState=c.state,t=e.child):t=Zn(t,e,l),t}function L2(t,e,n,a){return qa(),e.flags|=256,De(t,e,n,a),e.child}var yf={dehydrated:null,treeContext:null,retryLane:0,hydrationErrors:null};function gf(t){return{baseLanes:t,cachePool:A0()}}function vf(t,e,n){return t=t!==null?t.childLanes&~n:0,e&&(t|=en),t}function H2(t,e,n){var a=e.pendingProps,l=!1,c=(e.flags&128)!==0,d;if((d=c)||(d=t!==null&&t.memoizedState===null?!1:(se.current&2)!==0),d&&(l=!0,e.flags&=-129),d=(e.flags&32)!==0,e.flags&=-33,t===null){if(Ut){if(l?da(e):ha(),(t=It)?(t=Vd(t,dn),t=t!==null&&t.data!=="&"?t:null,t!==null&&(e.memoizedState={dehydrated:t,treeContext:ia!==null?{id:On,overflow:Rn}:null,retryLane:536870912,hydrationErrors:null},n=y0(t),n.return=e,e.child=n,Oe=e,It=null)):t=null,t===null)throw ca(e);return Pf(t)?e.lanes=32:e.lanes=536870912,null}var g=a.children;return a=a.fallback,l?(ha(),l=e.mode,g=Zu({mode:"hidden",children:g},l),a=Ga(a,l,n,null),g.return=e,a.return=e,g.sibling=a,e.child=g,a=e.child,a.memoizedState=gf(n),a.childLanes=vf(t,d,n),e.memoizedState=yf,Ti(null,a)):(da(e),_f(e,g))}var S=t.memoizedState;if(S!==null&&(g=S.dehydrated,g!==null)){if(c)e.flags&256?(da(e),e.flags&=-257,e=pf(t,e,n)):e.memoizedState!==null?(ha(),e.child=t.child,e.flags|=128,e=null):(ha(),g=a.fallback,l=e.mode,a=Zu({mode:"visible",children:a.children},l),g=Ga(g,l,n,null),g.flags|=2,a.return=e,g.return=e,a.sibling=g,e.child=a,Ka(e,t.child,null,n),a=e.child,a.memoizedState=gf(n),a.childLanes=vf(t,d,n),e.memoizedState=yf,e=Ti(null,a));else if(da(e),Pf(g)){if(d=g.nextSibling&&g.nextSibling.dataset,d)var M=d.dgst;d=M,a=Error(s(419)),a.stack="",a.digest=d,oi({value:a,source:null,stack:null}),e=pf(t,e,n)}else if(ye||El(t,e,n,!1),d=(n&t.childLanes)!==0,ye||d){if(d=Kt,d!==null&&(a=Eo(d,n),a!==0&&a!==S.retryLane))throw S.retryLane=a,Ya(t,a),Je(d,t,a),hf;$f(g)||Wu(),e=pf(t,e,n)}else $f(g)?(e.flags|=192,e.child=t.child,e=null):(t=S.treeContext,It=mn(g.nextSibling),Oe=e,Ut=!0,ua=null,dn=!1,t!==null&&_0(e,t),e=_f(e,a.children),e.flags|=4096);return e}return l?(ha(),g=a.fallback,l=e.mode,S=t.child,M=S.sibling,a=Hn(S,{mode:"hidden",children:a.children}),a.subtreeFlags=S.subtreeFlags&65011712,M!==null?g=Hn(M,g):(g=Ga(g,l,n,null),g.flags|=2),g.return=e,a.return=e,a.sibling=g,e.child=a,Ti(null,a),a=e.child,g=t.child.memoizedState,g===null?g=gf(n):(l=g.cachePool,l!==null?(S=he._currentValue,l=l.parent!==S?{parent:S,pool:S}:l):l=A0(),g={baseLanes:g.baseLanes|n,cachePool:l}),a.memoizedState=g,a.childLanes=vf(t,d,n),e.memoizedState=yf,Ti(t.child,a)):(da(e),n=t.child,t=n.sibling,n=Hn(n,{mode:"visible",children:a.children}),n.return=e,n.sibling=null,t!==null&&(d=e.deletions,d===null?(e.deletions=[t],e.flags|=16):d.push(t)),e.child=n,e.memoizedState=null,n)}function _f(t,e){return e=Zu({mode:"visible",children:e},t.mode),e.return=t,t.child=e}function Zu(t,e){return t=We(22,t,null,e),t.lanes=0,t}function pf(t,e,n){return Ka(e,t.child,null,n),t=_f(e,e.pendingProps.children),t.flags|=2,e.memoizedState=null,t}function j2(t,e,n){t.lanes|=e;var a=t.alternate;a!==null&&(a.lanes|=e),Us(t.return,e,n)}function bf(t,e,n,a,l,c){var d=t.memoizedState;d===null?t.memoizedState={isBackwards:e,rendering:null,renderingStartTime:0,last:a,tail:n,tailMode:l,treeForkCount:c}:(d.isBackwards=e,d.rendering=null,d.renderingStartTime=0,d.last=a,d.tail=n,d.tailMode=l,d.treeForkCount=c)}function B2(t,e,n){var a=e.pendingProps,l=a.revealOrder,c=a.tail;a=a.children;var d=se.current,g=(d&2)!==0;if(g?(d=d&1|2,e.flags|=128):d&=1,k(se,d),De(t,e,a,n),a=Ut?ri:0,!g&&t!==null&&(t.flags&128)!==0)t:for(t=e.child;t!==null;){if(t.tag===13)t.memoizedState!==null&&j2(t,n,e);else if(t.tag===19)j2(t,n,e);else if(t.child!==null){t.child.return=t,t=t.child;continue}if(t===e)break t;for(;t.sibling===null;){if(t.return===null||t.return===e)break t;t=t.return}t.sibling.return=t.return,t=t.sibling}switch(l){case"forwards":for(n=e.child,l=null;n!==null;)t=n.alternate,t!==null&&zu(t)===null&&(l=n),n=n.sibling;n=l,n===null?(l=e.child,e.child=null):(l=n.sibling,n.sibling=null),bf(e,!1,l,n,c,a);break;case"backwards":case"unstable_legacy-backwards":for(n=null,l=e.child,e.child=null;l!==null;){if(t=l.alternate,t!==null&&zu(t)===null){e.child=l;break}t=l.sibling,l.sibling=n,n=l,l=t}bf(e,!0,n,null,c,a);break;case"together":bf(e,!1,null,null,void 0,a);break;default:e.memoizedState=null}return e.child}function Zn(t,e,n){if(t!==null&&(e.dependencies=t.dependencies),ga|=e.lanes,(n&e.childLanes)===0)if(t!==null){if(El(t,e,n,!1),(n&e.childLanes)===0)return null}else return null;if(t!==null&&e.child!==t.child)throw Error(s(153));if(e.child!==null){for(t=e.child,n=Hn(t,t.pendingProps),e.child=n,n.return=e;t.sibling!==null;)t=t.sibling,n=n.sibling=Hn(t,t.pendingProps),n.return=e;n.sibling=null}return e.child}function Sf(t,e){return(t.lanes&e)!==0?!0:(t=t.dependencies,!!(t!==null&&Eu(t)))}function xy(t,e,n){switch(e.tag){case 3:H(e,e.stateNode.containerInfo),sa(e,he,t.memoizedState.cache),qa();break;case 27:case 5:Yt(e);break;case 4:H(e,e.stateNode.containerInfo);break;case 10:sa(e,e.type,e.memoizedProps.value);break;case 31:if(e.memoizedState!==null)return e.flags|=128,Qs(e),null;break;case 13:var a=e.memoizedState;if(a!==null)return a.dehydrated!==null?(da(e),e.flags|=128,null):(n&e.child.childLanes)!==0?H2(t,e,n):(da(e),t=Zn(t,e,n),t!==null?t.sibling:null);da(e);break;case 19:var l=(t.flags&128)!==0;if(a=(n&e.childLanes)!==0,a||(El(t,e,n,!1),a=(n&e.childLanes)!==0),l){if(a)return B2(t,e,n);e.flags|=128}if(l=e.memoizedState,l!==null&&(l.rendering=null,l.tail=null,l.lastEffect=null),k(se,se.current),a)break;return null;case 22:return e.lanes=0,z2(t,e,n,e.pendingProps);case 24:sa(e,he,t.memoizedState.cache)}return Zn(t,e,n)}function Y2(t,e,n){if(t!==null)if(t.memoizedProps!==e.pendingProps)ye=!0;else{if(!Sf(t,n)&&(e.flags&128)===0)return ye=!1,xy(t,e,n);ye=(t.flags&131072)!==0}else ye=!1,Ut&&(e.flags&1048576)!==0&&v0(e,ri,e.index);switch(e.lanes=0,e.tag){case 16:t:{var a=e.pendingProps;if(t=Qa(e.elementType),e.type=t,typeof t=="function")xs(t)?(a=ka(t,a),e.tag=1,e=C2(null,e,t,a,n)):(e.tag=0,e=mf(null,e,t,a,n));else{if(t!=null){var l=t.$$typeof;if(l===I){e.tag=11,e=O2(null,e,t,a,n);break t}else if(l===X){e.tag=14,e=R2(null,e,t,a,n);break t}}throw e=yt(t)||t,Error(s(306,e,""))}}return e;case 0:return mf(t,e,e.type,e.pendingProps,n);case 1:return a=e.type,l=ka(a,e.pendingProps),C2(t,e,a,l,n);case 3:t:{if(H(e,e.stateNode.containerInfo),t===null)throw Error(s(387));a=e.pendingProps;var c=e.memoizedState;l=c.element,Gs(t,e),_i(e,a,null,n);var d=e.memoizedState;if(a=d.cache,sa(e,he,a),a!==c.cache&&Cs(e,[he],n,!0),vi(),a=d.element,c.isDehydrated)if(c={element:a,isDehydrated:!1,cache:d.cache},e.updateQueue.baseState=c,e.memoizedState=c,e.flags&256){e=L2(t,e,a,n);break t}else if(a!==l){l=fn(Error(s(424)),e),oi(l),e=L2(t,e,a,n);break t}else{switch(t=e.stateNode.containerInfo,t.nodeType){case 9:t=t.body;break;default:t=t.nodeName==="HTML"?t.ownerDocument.body:t}for(It=mn(t.firstChild),Oe=e,Ut=!0,ua=null,dn=!0,n=z0(e,null,a,n),e.child=n;n;)n.flags=n.flags&-3|4096,n=n.sibling}else{if(qa(),a===l){e=Zn(t,e,n);break t}De(t,e,a,n)}e=e.child}return e;case 26:return qu(t,e),t===null?(n=Id(e.type,null,e.pendingProps,null))?e.memoizedState=n:Ut||(n=e.type,t=e.pendingProps,a=lc(L.current).createElement(n),a[we]=e,a[Ze]=t,ze(a,n,t),be(a),e.stateNode=a):e.memoizedState=Id(e.type,t.memoizedProps,e.pendingProps,t.memoizedState),null;case 27:return Yt(e),t===null&&Ut&&(a=e.stateNode=Kd(e.type,e.pendingProps,L.current),Oe=e,dn=!0,l=It,Sa(e.type)?(tr=l,It=mn(a.firstChild)):It=l),De(t,e,e.pendingProps.children,n),qu(t,e),t===null&&(e.flags|=4194304),e.child;case 5:return t===null&&Ut&&((l=a=It)&&(a=eg(a,e.type,e.pendingProps,dn),a!==null?(e.stateNode=a,Oe=e,It=mn(a.firstChild),dn=!1,l=!0):l=!1),l||ca(e)),Yt(e),l=e.type,c=e.pendingProps,d=t!==null?t.memoizedProps:null,a=c.children,kf(l,c)?a=null:d!==null&&kf(l,d)&&(e.flags|=32),e.memoizedState!==null&&(l=Ks(t,e,gy,null,null,n),Bi._currentValue=l),qu(t,e),De(t,e,a,n),e.child;case 6:return t===null&&Ut&&((t=n=It)&&(n=ng(n,e.pendingProps,dn),n!==null?(e.stateNode=n,Oe=e,It=null,t=!0):t=!1),t||ca(e)),null;case 13:return H2(t,e,n);case 4:return H(e,e.stateNode.containerInfo),a=e.pendingProps,t===null?e.child=Ka(e,null,a,n):De(t,e,a,n),e.child;case 11:return O2(t,e,e.type,e.pendingProps,n);case 7:return De(t,e,e.pendingProps,n),e.child;case 8:return De(t,e,e.pendingProps.children,n),e.child;case 12:return De(t,e,e.pendingProps.children,n),e.child;case 10:return a=e.pendingProps,sa(e,e.type,a.value),De(t,e,a.children,n),e.child;case 9:return l=e.type._context,a=e.pendingProps.children,Xa(e),l=Re(l),a=a(l),e.flags|=1,De(t,e,a,n),e.child;case 14:return R2(t,e,e.type,e.pendingProps,n);case 15:return D2(t,e,e.type,e.pendingProps,n);case 19:return B2(t,e,n);case 31:return Ay(t,e,n);case 22:return z2(t,e,n,e.pendingProps);case 24:return Xa(e),a=Re(he),t===null?(l=js(),l===null&&(l=Kt,c=Ls(),l.pooledCache=c,c.refCount++,c!==null&&(l.pooledCacheLanes|=n),l=c),e.memoizedState={parent:a,cache:l},Ys(e),sa(e,he,l)):((t.lanes&n)!==0&&(Gs(t,e),_i(e,null,null,n),vi()),l=t.memoizedState,c=e.memoizedState,l.parent!==a?(l={parent:a,cache:a},e.memoizedState=l,e.lanes===0&&(e.memoizedState=e.updateQueue.baseState=l),sa(e,he,a)):(a=c.cache,sa(e,he,a),a!==l.cache&&Cs(e,[he],n,!0))),De(t,e,e.pendingProps.children,n),e.child;case 29:throw e.pendingProps}throw Error(s(156,e.tag))}function Xn(t){t.flags|=4}function Ef(t,e,n,a,l){if((e=(t.mode&32)!==0)&&(e=!1),e){if(t.flags|=16777216,(l&335544128)===l)if(t.stateNode.complete)t.flags|=8192;else if(dd())t.flags|=8192;else throw Fa=wu,Bs}else t.flags&=-16777217}function G2(t,e){if(e.type!=="stylesheet"||(e.state.loading&4)!==0)t.flags&=-16777217;else if(t.flags|=16777216,!e1(e))if(dd())t.flags|=8192;else throw Fa=wu,Bs}function Xu(t,e){e!==null&&(t.flags|=4),t.flags&16384&&(e=t.tag!==22?po():536870912,t.lanes|=e,Cl|=e)}function Ai(t,e){if(!Ut)switch(t.tailMode){case"hidden":e=t.tail;for(var n=null;e!==null;)e.alternate!==null&&(n=e),e=e.sibling;n===null?t.tail=null:n.sibling=null;break;case"collapsed":n=t.tail;for(var a=null;n!==null;)n.alternate!==null&&(a=n),n=n.sibling;a===null?e||t.tail===null?t.tail=null:t.tail.sibling=null:a.sibling=null}}function Wt(t){var e=t.alternate!==null&&t.alternate.child===t.child,n=0,a=0;if(e)for(var l=t.child;l!==null;)n|=l.lanes|l.childLanes,a|=l.subtreeFlags&65011712,a|=l.flags&65011712,l.return=t,l=l.sibling;else for(l=t.child;l!==null;)n|=l.lanes|l.childLanes,a|=l.subtreeFlags,a|=l.flags,l.return=t,l=l.sibling;return t.subtreeFlags|=a,t.childLanes=n,e}function wy(t,e,n){var a=e.pendingProps;switch(Ds(e),e.tag){case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return Wt(e),null;case 1:return Wt(e),null;case 3:return n=e.stateNode,a=null,t!==null&&(a=t.memoizedState.cache),e.memoizedState.cache!==a&&(e.flags|=2048),Yn(he),ht(),n.pendingContext&&(n.context=n.pendingContext,n.pendingContext=null),(t===null||t.child===null)&&(Sl(e)?Xn(e):t===null||t.memoizedState.isDehydrated&&(e.flags&256)===0||(e.flags|=1024,Ns())),Wt(e),null;case 26:var l=e.type,c=e.memoizedState;return t===null?(Xn(e),c!==null?(Wt(e),G2(e,c)):(Wt(e),Ef(e,l,null,a,n))):c?c!==t.memoizedState?(Xn(e),Wt(e),G2(e,c)):(Wt(e),e.flags&=-16777217):(t=t.memoizedProps,t!==a&&Xn(e),Wt(e),Ef(e,l,t,a,n)),null;case 27:if(Ft(e),n=L.current,l=e.type,t!==null&&e.stateNode!=null)t.memoizedProps!==a&&Xn(e);else{if(!a){if(e.stateNode===null)throw Error(s(166));return Wt(e),null}t=w.current,Sl(e)?p0(e):(t=Kd(l,a,n),e.stateNode=t,Xn(e))}return Wt(e),null;case 5:if(Ft(e),l=e.type,t!==null&&e.stateNode!=null)t.memoizedProps!==a&&Xn(e);else{if(!a){if(e.stateNode===null)throw Error(s(166));return Wt(e),null}if(c=w.current,Sl(e))p0(e);else{var d=lc(L.current);switch(c){case 1:c=d.createElementNS("http://www.w3.org/2000/svg",l);break;case 2:c=d.createElementNS("http://www.w3.org/1998/Math/MathML",l);break;default:switch(l){case"svg":c=d.createElementNS("http://www.w3.org/2000/svg",l);break;case"math":c=d.createElementNS("http://www.w3.org/1998/Math/MathML",l);break;case"script":c=d.createElement("div"),c.innerHTML="<script><\/script>",c=c.removeChild(c.firstChild);break;case"select":c=typeof a.is=="string"?d.createElement("select",{is:a.is}):d.createElement("select"),a.multiple?c.multiple=!0:a.size&&(c.size=a.size);break;default:c=typeof a.is=="string"?d.createElement(l,{is:a.is}):d.createElement(l)}}c[we]=e,c[Ze]=a;t:for(d=e.child;d!==null;){if(d.tag===5||d.tag===6)c.appendChild(d.stateNode);else if(d.tag!==4&&d.tag!==27&&d.child!==null){d.child.return=d,d=d.child;continue}if(d===e)break t;for(;d.sibling===null;){if(d.return===null||d.return===e)break t;d=d.return}d.sibling.return=d.return,d=d.sibling}e.stateNode=c;t:switch(ze(c,l,a),l){case"button":case"input":case"select":case"textarea":a=!!a.autoFocus;break t;case"img":a=!0;break t;default:a=!1}a&&Xn(e)}}return Wt(e),Ef(e,e.type,t===null?null:t.memoizedProps,e.pendingProps,n),null;case 6:if(t&&e.stateNode!=null)t.memoizedProps!==a&&Xn(e);else{if(typeof a!="string"&&e.stateNode===null)throw Error(s(166));if(t=L.current,Sl(e)){if(t=e.stateNode,n=e.memoizedProps,a=null,l=Oe,l!==null)switch(l.tag){case 27:case 5:a=l.memoizedProps}t[we]=e,t=!!(t.nodeValue===n||a!==null&&a.suppressHydrationWarning===!0||Hd(t.nodeValue,n)),t||ca(e,!0)}else t=lc(t).createTextNode(a),t[we]=e,e.stateNode=t}return Wt(e),null;case 31:if(n=e.memoizedState,t===null||t.memoizedState!==null){if(a=Sl(e),n!==null){if(t===null){if(!a)throw Error(s(318));if(t=e.memoizedState,t=t!==null?t.dehydrated:null,!t)throw Error(s(557));t[we]=e}else qa(),(e.flags&128)===0&&(e.memoizedState=null),e.flags|=4;Wt(e),t=!1}else n=Ns(),t!==null&&t.memoizedState!==null&&(t.memoizedState.hydrationErrors=n),t=!0;if(!t)return e.flags&256?(Pe(e),e):(Pe(e),null);if((e.flags&128)!==0)throw Error(s(558))}return Wt(e),null;case 13:if(a=e.memoizedState,t===null||t.memoizedState!==null&&t.memoizedState.dehydrated!==null){if(l=Sl(e),a!==null&&a.dehydrated!==null){if(t===null){if(!l)throw Error(s(318));if(l=e.memoizedState,l=l!==null?l.dehydrated:null,!l)throw Error(s(317));l[we]=e}else qa(),(e.flags&128)===0&&(e.memoizedState=null),e.flags|=4;Wt(e),l=!1}else l=Ns(),t!==null&&t.memoizedState!==null&&(t.memoizedState.hydrationErrors=l),l=!0;if(!l)return e.flags&256?(Pe(e),e):(Pe(e),null)}return Pe(e),(e.flags&128)!==0?(e.lanes=n,e):(n=a!==null,t=t!==null&&t.memoizedState!==null,n&&(a=e.child,l=null,a.alternate!==null&&a.alternate.memoizedState!==null&&a.alternate.memoizedState.cachePool!==null&&(l=a.alternate.memoizedState.cachePool.pool),c=null,a.memoizedState!==null&&a.memoizedState.cachePool!==null&&(c=a.memoizedState.cachePool.pool),c!==l&&(a.flags|=2048)),n!==t&&n&&(e.child.flags|=8192),Xu(e,e.updateQueue),Wt(e),null);case 4:return ht(),t===null&&Vf(e.stateNode.containerInfo),Wt(e),null;case 10:return Yn(e.type),Wt(e),null;case 19:if(R(se),a=e.memoizedState,a===null)return Wt(e),null;if(l=(e.flags&128)!==0,c=a.rendering,c===null)if(l)Ai(a,!1);else{if(ue!==0||t!==null&&(t.flags&128)!==0)for(t=e.child;t!==null;){if(c=zu(t),c!==null){for(e.flags|=128,Ai(a,!1),t=c.updateQueue,e.updateQueue=t,Xu(e,t),e.subtreeFlags=0,t=n,n=e.child;n!==null;)m0(n,t),n=n.sibling;return k(se,se.current&1|2),Ut&&jn(e,a.treeForkCount),e.child}t=t.sibling}a.tail!==null&&xe()>Ju&&(e.flags|=128,l=!0,Ai(a,!1),e.lanes=4194304)}else{if(!l)if(t=zu(c),t!==null){if(e.flags|=128,l=!0,t=t.updateQueue,e.updateQueue=t,Xu(e,t),Ai(a,!0),a.tail===null&&a.tailMode==="hidden"&&!c.alternate&&!Ut)return Wt(e),null}else 2*xe()-a.renderingStartTime>Ju&&n!==536870912&&(e.flags|=128,l=!0,Ai(a,!1),e.lanes=4194304);a.isBackwards?(c.sibling=e.child,e.child=c):(t=a.last,t!==null?t.sibling=c:e.child=c,a.last=c)}return a.tail!==null?(t=a.tail,a.rendering=t,a.tail=t.sibling,a.renderingStartTime=xe(),t.sibling=null,n=se.current,k(se,l?n&1|2:n&1),Ut&&jn(e,a.treeForkCount),t):(Wt(e),null);case 22:case 23:return Pe(e),Vs(),a=e.memoizedState!==null,t!==null?t.memoizedState!==null!==a&&(e.flags|=8192):a&&(e.flags|=8192),a?(n&536870912)!==0&&(e.flags&128)===0&&(Wt(e),e.subtreeFlags&6&&(e.flags|=8192)):Wt(e),n=e.updateQueue,n!==null&&Xu(e,n.retryQueue),n=null,t!==null&&t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(n=t.memoizedState.cachePool.pool),a=null,e.memoizedState!==null&&e.memoizedState.cachePool!==null&&(a=e.memoizedState.cachePool.pool),a!==n&&(e.flags|=2048),t!==null&&R(Va),null;case 24:return n=null,t!==null&&(n=t.memoizedState.cache),e.memoizedState.cache!==n&&(e.flags|=2048),Yn(he),Wt(e),null;case 25:return null;case 30:return null}throw Error(s(156,e.tag))}function Oy(t,e){switch(Ds(e),e.tag){case 1:return t=e.flags,t&65536?(e.flags=t&-65537|128,e):null;case 3:return Yn(he),ht(),t=e.flags,(t&65536)!==0&&(t&128)===0?(e.flags=t&-65537|128,e):null;case 26:case 27:case 5:return Ft(e),null;case 31:if(e.memoizedState!==null){if(Pe(e),e.alternate===null)throw Error(s(340));qa()}return t=e.flags,t&65536?(e.flags=t&-65537|128,e):null;case 13:if(Pe(e),t=e.memoizedState,t!==null&&t.dehydrated!==null){if(e.alternate===null)throw Error(s(340));qa()}return t=e.flags,t&65536?(e.flags=t&-65537|128,e):null;case 19:return R(se),null;case 4:return ht(),null;case 10:return Yn(e.type),null;case 22:case 23:return Pe(e),Vs(),t!==null&&R(Va),t=e.flags,t&65536?(e.flags=t&-65537|128,e):null;case 24:return Yn(he),null;case 25:return null;default:return null}}function q2(t,e){switch(Ds(e),e.tag){case 3:Yn(he),ht();break;case 26:case 27:case 5:Ft(e);break;case 4:ht();break;case 31:e.memoizedState!==null&&Pe(e);break;case 13:Pe(e);break;case 19:R(se);break;case 10:Yn(e.type);break;case 22:case 23:Pe(e),Vs(),t!==null&&R(Va);break;case 24:Yn(he)}}function xi(t,e){try{var n=e.updateQueue,a=n!==null?n.lastEffect:null;if(a!==null){var l=a.next;n=l;do{if((n.tag&t)===t){a=void 0;var c=n.create,d=n.inst;a=c(),d.destroy=a}n=n.next}while(n!==l)}}catch(g){Zt(e,e.return,g)}}function ma(t,e,n){try{var a=e.updateQueue,l=a!==null?a.lastEffect:null;if(l!==null){var c=l.next;a=c;do{if((a.tag&t)===t){var d=a.inst,g=d.destroy;if(g!==void 0){d.destroy=void 0,l=e;var S=n,M=g;try{M()}catch(q){Zt(l,S,q)}}}a=a.next}while(a!==c)}}catch(q){Zt(e,e.return,q)}}function Z2(t){var e=t.updateQueue;if(e!==null){var n=t.stateNode;try{M0(e,n)}catch(a){Zt(t,t.return,a)}}}function X2(t,e,n){n.props=ka(t.type,t.memoizedProps),n.state=t.memoizedState;try{n.componentWillUnmount()}catch(a){Zt(t,e,a)}}function wi(t,e){try{var n=t.ref;if(n!==null){switch(t.tag){case 26:case 27:case 5:var a=t.stateNode;break;case 30:a=t.stateNode;break;default:a=t.stateNode}typeof n=="function"?t.refCleanup=n(a):n.current=a}}catch(l){Zt(t,e,l)}}function Dn(t,e){var n=t.ref,a=t.refCleanup;if(n!==null)if(typeof a=="function")try{a()}catch(l){Zt(t,e,l)}finally{t.refCleanup=null,t=t.alternate,t!=null&&(t.refCleanup=null)}else if(typeof n=="function")try{n(null)}catch(l){Zt(t,e,l)}else n.current=null}function V2(t){var e=t.type,n=t.memoizedProps,a=t.stateNode;try{t:switch(e){case"button":case"input":case"select":case"textarea":n.autoFocus&&a.focus();break t;case"img":n.src?a.src=n.src:n.srcSet&&(a.srcset=n.srcSet)}}catch(l){Zt(t,t.return,l)}}function Tf(t,e,n){try{var a=t.stateNode;ky(a,t.type,n,e),a[Ze]=e}catch(l){Zt(t,t.return,l)}}function Q2(t){return t.tag===5||t.tag===3||t.tag===26||t.tag===27&&Sa(t.type)||t.tag===4}function Af(t){t:for(;;){for(;t.sibling===null;){if(t.return===null||Q2(t.return))return null;t=t.return}for(t.sibling.return=t.return,t=t.sibling;t.tag!==5&&t.tag!==6&&t.tag!==18;){if(t.tag===27&&Sa(t.type)||t.flags&2||t.child===null||t.tag===4)continue t;t.child.return=t,t=t.child}if(!(t.flags&2))return t.stateNode}}function xf(t,e,n){var a=t.tag;if(a===5||a===6)t=t.stateNode,e?(n.nodeType===9?n.body:n.nodeName==="HTML"?n.ownerDocument.body:n).insertBefore(t,e):(e=n.nodeType===9?n.body:n.nodeName==="HTML"?n.ownerDocument.body:n,e.appendChild(t),n=n._reactRootContainer,n!=null||e.onclick!==null||(e.onclick=Cn));else if(a!==4&&(a===27&&Sa(t.type)&&(n=t.stateNode,e=null),t=t.child,t!==null))for(xf(t,e,n),t=t.sibling;t!==null;)xf(t,e,n),t=t.sibling}function Vu(t,e,n){var a=t.tag;if(a===5||a===6)t=t.stateNode,e?n.insertBefore(t,e):n.appendChild(t);else if(a!==4&&(a===27&&Sa(t.type)&&(n=t.stateNode),t=t.child,t!==null))for(Vu(t,e,n),t=t.sibling;t!==null;)Vu(t,e,n),t=t.sibling}function F2(t){var e=t.stateNode,n=t.memoizedProps;try{for(var a=t.type,l=e.attributes;l.length;)e.removeAttributeNode(l[0]);ze(e,a,n),e[we]=t,e[Ze]=n}catch(c){Zt(t,t.return,c)}}var Vn=!1,ge=!1,wf=!1,K2=typeof WeakSet=="function"?WeakSet:Set,Se=null;function Ry(t,e){if(t=t.containerInfo,Kf=oc,t=i0(t),_s(t)){if("selectionStart"in t)var n={start:t.selectionStart,end:t.selectionEnd};else t:{n=(n=t.ownerDocument)&&n.defaultView||window;var a=n.getSelection&&n.getSelection();if(a&&a.rangeCount!==0){n=a.anchorNode;var l=a.anchorOffset,c=a.focusNode;a=a.focusOffset;try{n.nodeType,c.nodeType}catch{n=null;break t}var d=0,g=-1,S=-1,M=0,q=0,K=t,C=null;e:for(;;){for(var j;K!==n||l!==0&&K.nodeType!==3||(g=d+l),K!==c||a!==0&&K.nodeType!==3||(S=d+a),K.nodeType===3&&(d+=K.nodeValue.length),(j=K.firstChild)!==null;)C=K,K=j;for(;;){if(K===t)break e;if(C===n&&++M===l&&(g=d),C===c&&++q===a&&(S=d),(j=K.nextSibling)!==null)break;K=C,C=K.parentNode}K=j}n=g===-1||S===-1?null:{start:g,end:S}}else n=null}n=n||{start:0,end:0}}else n=null;for(Jf={focusedElem:t,selectionRange:n},oc=!1,Se=e;Se!==null;)if(e=Se,t=e.child,(e.subtreeFlags&1028)!==0&&t!==null)t.return=e,Se=t;else for(;Se!==null;){switch(e=Se,c=e.alternate,t=e.flags,e.tag){case 0:if((t&4)!==0&&(t=e.updateQueue,t=t!==null?t.events:null,t!==null))for(n=0;n<t.length;n++)l=t[n],l.ref.impl=l.nextImpl;break;case 11:case 15:break;case 1:if((t&1024)!==0&&c!==null){t=void 0,n=e,l=c.memoizedProps,c=c.memoizedState,a=n.stateNode;try{var ft=ka(n.type,l);t=a.getSnapshotBeforeUpdate(ft,c),a.__reactInternalSnapshotBeforeUpdate=t}catch(bt){Zt(n,n.return,bt)}}break;case 3:if((t&1024)!==0){if(t=e.stateNode.containerInfo,n=t.nodeType,n===9)Wf(t);else if(n===1)switch(t.nodeName){case"HEAD":case"HTML":case"BODY":Wf(t);break;default:t.textContent=""}}break;case 5:case 26:case 27:case 6:case 4:case 17:break;default:if((t&1024)!==0)throw Error(s(163))}if(t=e.sibling,t!==null){t.return=e.return,Se=t;break}Se=e.return}}function J2(t,e,n){var a=n.flags;switch(n.tag){case 0:case 11:case 15:Fn(t,n),a&4&&xi(5,n);break;case 1:if(Fn(t,n),a&4)if(t=n.stateNode,e===null)try{t.componentDidMount()}catch(d){Zt(n,n.return,d)}else{var l=ka(n.type,e.memoizedProps);e=e.memoizedState;try{t.componentDidUpdate(l,e,t.__reactInternalSnapshotBeforeUpdate)}catch(d){Zt(n,n.return,d)}}a&64&&Z2(n),a&512&&wi(n,n.return);break;case 3:if(Fn(t,n),a&64&&(t=n.updateQueue,t!==null)){if(e=null,n.child!==null)switch(n.child.tag){case 27:case 5:e=n.child.stateNode;break;case 1:e=n.child.stateNode}try{M0(t,e)}catch(d){Zt(n,n.return,d)}}break;case 27:e===null&&a&4&&F2(n);case 26:case 5:Fn(t,n),e===null&&a&4&&V2(n),a&512&&wi(n,n.return);break;case 12:Fn(t,n);break;case 31:Fn(t,n),a&4&&W2(t,n);break;case 13:Fn(t,n),a&4&&$2(t,n),a&64&&(t=n.memoizedState,t!==null&&(t=t.dehydrated,t!==null&&(n=jy.bind(null,n),ag(t,n))));break;case 22:if(a=n.memoizedState!==null||Vn,!a){e=e!==null&&e.memoizedState!==null||ge,l=Vn;var c=ge;Vn=a,(ge=e)&&!c?Kn(t,n,(n.subtreeFlags&8772)!==0):Fn(t,n),Vn=l,ge=c}break;case 30:break;default:Fn(t,n)}}function k2(t){var e=t.alternate;e!==null&&(t.alternate=null,k2(e)),t.child=null,t.deletions=null,t.sibling=null,t.tag===5&&(e=t.stateNode,e!==null&&es(e)),t.stateNode=null,t.return=null,t.dependencies=null,t.memoizedProps=null,t.memoizedState=null,t.pendingProps=null,t.stateNode=null,t.updateQueue=null}var te=null,Ve=!1;function Qn(t,e,n){for(n=n.child;n!==null;)I2(t,e,n),n=n.sibling}function I2(t,e,n){if(Y&&typeof Y.onCommitFiberUnmount=="function")try{Y.onCommitFiberUnmount(Ua,n)}catch{}switch(n.tag){case 26:ge||Dn(n,e),Qn(t,e,n),n.memoizedState?n.memoizedState.count--:n.stateNode&&(n=n.stateNode,n.parentNode.removeChild(n));break;case 27:ge||Dn(n,e);var a=te,l=Ve;Sa(n.type)&&(te=n.stateNode,Ve=!1),Qn(t,e,n),Li(n.stateNode),te=a,Ve=l;break;case 5:ge||Dn(n,e);case 6:if(a=te,l=Ve,te=null,Qn(t,e,n),te=a,Ve=l,te!==null)if(Ve)try{(te.nodeType===9?te.body:te.nodeName==="HTML"?te.ownerDocument.body:te).removeChild(n.stateNode)}catch(c){Zt(n,e,c)}else try{te.removeChild(n.stateNode)}catch(c){Zt(n,e,c)}break;case 18:te!==null&&(Ve?(t=te,Zd(t.nodeType===9?t.body:t.nodeName==="HTML"?t.ownerDocument.body:t,n.stateNode),Zl(t)):Zd(te,n.stateNode));break;case 4:a=te,l=Ve,te=n.stateNode.containerInfo,Ve=!0,Qn(t,e,n),te=a,Ve=l;break;case 0:case 11:case 14:case 15:ma(2,n,e),ge||ma(4,n,e),Qn(t,e,n);break;case 1:ge||(Dn(n,e),a=n.stateNode,typeof a.componentWillUnmount=="function"&&X2(n,e,a)),Qn(t,e,n);break;case 21:Qn(t,e,n);break;case 22:ge=(a=ge)||n.memoizedState!==null,Qn(t,e,n),ge=a;break;default:Qn(t,e,n)}}function W2(t,e){if(e.memoizedState===null&&(t=e.alternate,t!==null&&(t=t.memoizedState,t!==null))){t=t.dehydrated;try{Zl(t)}catch(n){Zt(e,e.return,n)}}}function $2(t,e){if(e.memoizedState===null&&(t=e.alternate,t!==null&&(t=t.memoizedState,t!==null&&(t=t.dehydrated,t!==null))))try{Zl(t)}catch(n){Zt(e,e.return,n)}}function Dy(t){switch(t.tag){case 31:case 13:case 19:var e=t.stateNode;return e===null&&(e=t.stateNode=new K2),e;case 22:return t=t.stateNode,e=t._retryCache,e===null&&(e=t._retryCache=new K2),e;default:throw Error(s(435,t.tag))}}function Qu(t,e){var n=Dy(t);e.forEach(function(a){if(!n.has(a)){n.add(a);var l=By.bind(null,t,a);a.then(l,l)}})}function Qe(t,e){var n=e.deletions;if(n!==null)for(var a=0;a<n.length;a++){var l=n[a],c=t,d=e,g=d;t:for(;g!==null;){switch(g.tag){case 27:if(Sa(g.type)){te=g.stateNode,Ve=!1;break t}break;case 5:te=g.stateNode,Ve=!1;break t;case 3:case 4:te=g.stateNode.containerInfo,Ve=!0;break t}g=g.return}if(te===null)throw Error(s(160));I2(c,d,l),te=null,Ve=!1,c=l.alternate,c!==null&&(c.return=null),l.return=null}if(e.subtreeFlags&13886)for(e=e.child;e!==null;)P2(e,t),e=e.sibling}var Sn=null;function P2(t,e){var n=t.alternate,a=t.flags;switch(t.tag){case 0:case 11:case 14:case 15:Qe(e,t),Fe(t),a&4&&(ma(3,t,t.return),xi(3,t),ma(5,t,t.return));break;case 1:Qe(e,t),Fe(t),a&512&&(ge||n===null||Dn(n,n.return)),a&64&&Vn&&(t=t.updateQueue,t!==null&&(a=t.callbacks,a!==null&&(n=t.shared.hiddenCallbacks,t.shared.hiddenCallbacks=n===null?a:n.concat(a))));break;case 26:var l=Sn;if(Qe(e,t),Fe(t),a&512&&(ge||n===null||Dn(n,n.return)),a&4){var c=n!==null?n.memoizedState:null;if(a=t.memoizedState,n===null)if(a===null)if(t.stateNode===null){t:{a=t.type,n=t.memoizedProps,l=l.ownerDocument||l;e:switch(a){case"title":c=l.getElementsByTagName("title")[0],(!c||c[Pl]||c[we]||c.namespaceURI==="http://www.w3.org/2000/svg"||c.hasAttribute("itemprop"))&&(c=l.createElement(a),l.head.insertBefore(c,l.querySelector("head > title"))),ze(c,a,n),c[we]=t,be(c),a=c;break t;case"link":var d=Pd("link","href",l).get(a+(n.href||""));if(d){for(var g=0;g<d.length;g++)if(c=d[g],c.getAttribute("href")===(n.href==null||n.href===""?null:n.href)&&c.getAttribute("rel")===(n.rel==null?null:n.rel)&&c.getAttribute("title")===(n.title==null?null:n.title)&&c.getAttribute("crossorigin")===(n.crossOrigin==null?null:n.crossOrigin)){d.splice(g,1);break e}}c=l.createElement(a),ze(c,a,n),l.head.appendChild(c);break;case"meta":if(d=Pd("meta","content",l).get(a+(n.content||""))){for(g=0;g<d.length;g++)if(c=d[g],c.getAttribute("content")===(n.content==null?null:""+n.content)&&c.getAttribute("name")===(n.name==null?null:n.name)&&c.getAttribute("property")===(n.property==null?null:n.property)&&c.getAttribute("http-equiv")===(n.httpEquiv==null?null:n.httpEquiv)&&c.getAttribute("charset")===(n.charSet==null?null:n.charSet)){d.splice(g,1);break e}}c=l.createElement(a),ze(c,a,n),l.head.appendChild(c);break;default:throw Error(s(468,a))}c[we]=t,be(c),a=c}t.stateNode=a}else t1(l,t.type,t.stateNode);else t.stateNode=$d(l,a,t.memoizedProps);else c!==a?(c===null?n.stateNode!==null&&(n=n.stateNode,n.parentNode.removeChild(n)):c.count--,a===null?t1(l,t.type,t.stateNode):$d(l,a,t.memoizedProps)):a===null&&t.stateNode!==null&&Tf(t,t.memoizedProps,n.memoizedProps)}break;case 27:Qe(e,t),Fe(t),a&512&&(ge||n===null||Dn(n,n.return)),n!==null&&a&4&&Tf(t,t.memoizedProps,n.memoizedProps);break;case 5:if(Qe(e,t),Fe(t),a&512&&(ge||n===null||Dn(n,n.return)),t.flags&32){l=t.stateNode;try{ol(l,"")}catch(ft){Zt(t,t.return,ft)}}a&4&&t.stateNode!=null&&(l=t.memoizedProps,Tf(t,l,n!==null?n.memoizedProps:l)),a&1024&&(wf=!0);break;case 6:if(Qe(e,t),Fe(t),a&4){if(t.stateNode===null)throw Error(s(162));a=t.memoizedProps,n=t.stateNode;try{n.nodeValue=a}catch(ft){Zt(t,t.return,ft)}}break;case 3:if(cc=null,l=Sn,Sn=ic(e.containerInfo),Qe(e,t),Sn=l,Fe(t),a&4&&n!==null&&n.memoizedState.isDehydrated)try{Zl(e.containerInfo)}catch(ft){Zt(t,t.return,ft)}wf&&(wf=!1,td(t));break;case 4:a=Sn,Sn=ic(t.stateNode.containerInfo),Qe(e,t),Fe(t),Sn=a;break;case 12:Qe(e,t),Fe(t);break;case 31:Qe(e,t),Fe(t),a&4&&(a=t.updateQueue,a!==null&&(t.updateQueue=null,Qu(t,a)));break;case 13:Qe(e,t),Fe(t),t.child.flags&8192&&t.memoizedState!==null!=(n!==null&&n.memoizedState!==null)&&(Ku=xe()),a&4&&(a=t.updateQueue,a!==null&&(t.updateQueue=null,Qu(t,a)));break;case 22:l=t.memoizedState!==null;var S=n!==null&&n.memoizedState!==null,M=Vn,q=ge;if(Vn=M||l,ge=q||S,Qe(e,t),ge=q,Vn=M,Fe(t),a&8192)t:for(e=t.stateNode,e._visibility=l?e._visibility&-2:e._visibility|1,l&&(n===null||S||Vn||ge||Ia(t)),n=null,e=t;;){if(e.tag===5||e.tag===26){if(n===null){S=n=e;try{if(c=S.stateNode,l)d=c.style,typeof d.setProperty=="function"?d.setProperty("display","none","important"):d.display="none";else{g=S.stateNode;var K=S.memoizedProps.style,C=K!=null&&K.hasOwnProperty("display")?K.display:null;g.style.display=C==null||typeof C=="boolean"?"":(""+C).trim()}}catch(ft){Zt(S,S.return,ft)}}}else if(e.tag===6){if(n===null){S=e;try{S.stateNode.nodeValue=l?"":S.memoizedProps}catch(ft){Zt(S,S.return,ft)}}}else if(e.tag===18){if(n===null){S=e;try{var j=S.stateNode;l?Xd(j,!0):Xd(S.stateNode,!1)}catch(ft){Zt(S,S.return,ft)}}}else if((e.tag!==22&&e.tag!==23||e.memoizedState===null||e===t)&&e.child!==null){e.child.return=e,e=e.child;continue}if(e===t)break t;for(;e.sibling===null;){if(e.return===null||e.return===t)break t;n===e&&(n=null),e=e.return}n===e&&(n=null),e.sibling.return=e.return,e=e.sibling}a&4&&(a=t.updateQueue,a!==null&&(n=a.retryQueue,n!==null&&(a.retryQueue=null,Qu(t,n))));break;case 19:Qe(e,t),Fe(t),a&4&&(a=t.updateQueue,a!==null&&(t.updateQueue=null,Qu(t,a)));break;case 30:break;case 21:break;default:Qe(e,t),Fe(t)}}function Fe(t){var e=t.flags;if(e&2){try{for(var n,a=t.return;a!==null;){if(Q2(a)){n=a;break}a=a.return}if(n==null)throw Error(s(160));switch(n.tag){case 27:var l=n.stateNode,c=Af(t);Vu(t,c,l);break;case 5:var d=n.stateNode;n.flags&32&&(ol(d,""),n.flags&=-33);var g=Af(t);Vu(t,g,d);break;case 3:case 4:var S=n.stateNode.containerInfo,M=Af(t);xf(t,M,S);break;default:throw Error(s(161))}}catch(q){Zt(t,t.return,q)}t.flags&=-3}e&4096&&(t.flags&=-4097)}function td(t){if(t.subtreeFlags&1024)for(t=t.child;t!==null;){var e=t;td(e),e.tag===5&&e.flags&1024&&e.stateNode.reset(),t=t.sibling}}function Fn(t,e){if(e.subtreeFlags&8772)for(e=e.child;e!==null;)J2(t,e.alternate,e),e=e.sibling}function Ia(t){for(t=t.child;t!==null;){var e=t;switch(e.tag){case 0:case 11:case 14:case 15:ma(4,e,e.return),Ia(e);break;case 1:Dn(e,e.return);var n=e.stateNode;typeof n.componentWillUnmount=="function"&&X2(e,e.return,n),Ia(e);break;case 27:Li(e.stateNode);case 26:case 5:Dn(e,e.return),Ia(e);break;case 22:e.memoizedState===null&&Ia(e);break;case 30:Ia(e);break;default:Ia(e)}t=t.sibling}}function Kn(t,e,n){for(n=n&&(e.subtreeFlags&8772)!==0,e=e.child;e!==null;){var a=e.alternate,l=t,c=e,d=c.flags;switch(c.tag){case 0:case 11:case 15:Kn(l,c,n),xi(4,c);break;case 1:if(Kn(l,c,n),a=c,l=a.stateNode,typeof l.componentDidMount=="function")try{l.componentDidMount()}catch(M){Zt(a,a.return,M)}if(a=c,l=a.updateQueue,l!==null){var g=a.stateNode;try{var S=l.shared.hiddenCallbacks;if(S!==null)for(l.shared.hiddenCallbacks=null,l=0;l<S.length;l++)N0(S[l],g)}catch(M){Zt(a,a.return,M)}}n&&d&64&&Z2(c),wi(c,c.return);break;case 27:F2(c);case 26:case 5:Kn(l,c,n),n&&a===null&&d&4&&V2(c),wi(c,c.return);break;case 12:Kn(l,c,n);break;case 31:Kn(l,c,n),n&&d&4&&W2(l,c);break;case 13:Kn(l,c,n),n&&d&4&&$2(l,c);break;case 22:c.memoizedState===null&&Kn(l,c,n),wi(c,c.return);break;case 30:break;default:Kn(l,c,n)}e=e.sibling}}function Of(t,e){var n=null;t!==null&&t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(n=t.memoizedState.cachePool.pool),t=null,e.memoizedState!==null&&e.memoizedState.cachePool!==null&&(t=e.memoizedState.cachePool.pool),t!==n&&(t!=null&&t.refCount++,n!=null&&di(n))}function Rf(t,e){t=null,e.alternate!==null&&(t=e.alternate.memoizedState.cache),e=e.memoizedState.cache,e!==t&&(e.refCount++,t!=null&&di(t))}function En(t,e,n,a){if(e.subtreeFlags&10256)for(e=e.child;e!==null;)ed(t,e,n,a),e=e.sibling}function ed(t,e,n,a){var l=e.flags;switch(e.tag){case 0:case 11:case 15:En(t,e,n,a),l&2048&&xi(9,e);break;case 1:En(t,e,n,a);break;case 3:En(t,e,n,a),l&2048&&(t=null,e.alternate!==null&&(t=e.alternate.memoizedState.cache),e=e.memoizedState.cache,e!==t&&(e.refCount++,t!=null&&di(t)));break;case 12:if(l&2048){En(t,e,n,a),t=e.stateNode;try{var c=e.memoizedProps,d=c.id,g=c.onPostCommit;typeof g=="function"&&g(d,e.alternate===null?"mount":"update",t.passiveEffectDuration,-0)}catch(S){Zt(e,e.return,S)}}else En(t,e,n,a);break;case 31:En(t,e,n,a);break;case 13:En(t,e,n,a);break;case 23:break;case 22:c=e.stateNode,d=e.alternate,e.memoizedState!==null?c._visibility&2?En(t,e,n,a):Oi(t,e):c._visibility&2?En(t,e,n,a):(c._visibility|=2,Nl(t,e,n,a,(e.subtreeFlags&10256)!==0||!1)),l&2048&&Of(d,e);break;case 24:En(t,e,n,a),l&2048&&Rf(e.alternate,e);break;default:En(t,e,n,a)}}function Nl(t,e,n,a,l){for(l=l&&((e.subtreeFlags&10256)!==0||!1),e=e.child;e!==null;){var c=t,d=e,g=n,S=a,M=d.flags;switch(d.tag){case 0:case 11:case 15:Nl(c,d,g,S,l),xi(8,d);break;case 23:break;case 22:var q=d.stateNode;d.memoizedState!==null?q._visibility&2?Nl(c,d,g,S,l):Oi(c,d):(q._visibility|=2,Nl(c,d,g,S,l)),l&&M&2048&&Of(d.alternate,d);break;case 24:Nl(c,d,g,S,l),l&&M&2048&&Rf(d.alternate,d);break;default:Nl(c,d,g,S,l)}e=e.sibling}}function Oi(t,e){if(e.subtreeFlags&10256)for(e=e.child;e!==null;){var n=t,a=e,l=a.flags;switch(a.tag){case 22:Oi(n,a),l&2048&&Of(a.alternate,a);break;case 24:Oi(n,a),l&2048&&Rf(a.alternate,a);break;default:Oi(n,a)}e=e.sibling}}var Ri=8192;function Ml(t,e,n){if(t.subtreeFlags&Ri)for(t=t.child;t!==null;)nd(t,e,n),t=t.sibling}function nd(t,e,n){switch(t.tag){case 26:Ml(t,e,n),t.flags&Ri&&t.memoizedState!==null&&yg(n,Sn,t.memoizedState,t.memoizedProps);break;case 5:Ml(t,e,n);break;case 3:case 4:var a=Sn;Sn=ic(t.stateNode.containerInfo),Ml(t,e,n),Sn=a;break;case 22:t.memoizedState===null&&(a=t.alternate,a!==null&&a.memoizedState!==null?(a=Ri,Ri=16777216,Ml(t,e,n),Ri=a):Ml(t,e,n));break;default:Ml(t,e,n)}}function ad(t){var e=t.alternate;if(e!==null&&(t=e.child,t!==null)){e.child=null;do e=t.sibling,t.sibling=null,t=e;while(t!==null)}}function Di(t){var e=t.deletions;if((t.flags&16)!==0){if(e!==null)for(var n=0;n<e.length;n++){var a=e[n];Se=a,id(a,t)}ad(t)}if(t.subtreeFlags&10256)for(t=t.child;t!==null;)ld(t),t=t.sibling}function ld(t){switch(t.tag){case 0:case 11:case 15:Di(t),t.flags&2048&&ma(9,t,t.return);break;case 3:Di(t);break;case 12:Di(t);break;case 22:var e=t.stateNode;t.memoizedState!==null&&e._visibility&2&&(t.return===null||t.return.tag!==13)?(e._visibility&=-3,Fu(t)):Di(t);break;default:Di(t)}}function Fu(t){var e=t.deletions;if((t.flags&16)!==0){if(e!==null)for(var n=0;n<e.length;n++){var a=e[n];Se=a,id(a,t)}ad(t)}for(t=t.child;t!==null;){switch(e=t,e.tag){case 0:case 11:case 15:ma(8,e,e.return),Fu(e);break;case 22:n=e.stateNode,n._visibility&2&&(n._visibility&=-3,Fu(e));break;default:Fu(e)}t=t.sibling}}function id(t,e){for(;Se!==null;){var n=Se;switch(n.tag){case 0:case 11:case 15:ma(8,n,e);break;case 23:case 22:if(n.memoizedState!==null&&n.memoizedState.cachePool!==null){var a=n.memoizedState.cachePool.pool;a!=null&&a.refCount++}break;case 24:di(n.memoizedState.cache)}if(a=n.child,a!==null)a.return=n,Se=a;else t:for(n=t;Se!==null;){a=Se;var l=a.sibling,c=a.return;if(k2(a),a===n){Se=null;break t}if(l!==null){l.return=c,Se=l;break t}Se=c}}}var zy={getCacheForType:function(t){var e=Re(he),n=e.data.get(t);return n===void 0&&(n=t(),e.data.set(t,n)),n},cacheSignal:function(){return Re(he).controller.signal}},Ny=typeof WeakMap=="function"?WeakMap:Map,Bt=0,Kt=null,Ot=null,Nt=0,qt=0,tn=null,ya=!1,Ul=!1,Df=!1,Jn=0,ue=0,ga=0,Wa=0,zf=0,en=0,Cl=0,zi=null,Ke=null,Nf=!1,Ku=0,ud=0,Ju=1/0,ku=null,va=null,pe=0,_a=null,Ll=null,kn=0,Mf=0,Uf=null,cd=null,Ni=0,Cf=null;function nn(){return(Bt&2)!==0&&Nt!==0?Nt&-Nt:N.T!==null?Gf():To()}function sd(){if(en===0)if((Nt&536870912)===0||Ut){var t=de;de<<=1,(de&3932160)===0&&(de=262144),en=t}else en=536870912;return t=$e.current,t!==null&&(t.flags|=32),en}function Je(t,e,n){(t===Kt&&(qt===2||qt===9)||t.cancelPendingCommit!==null)&&(Hl(t,0),pa(t,Nt,en,!1)),$l(t,n),((Bt&2)===0||t!==Kt)&&(t===Kt&&((Bt&2)===0&&(Wa|=n),ue===4&&pa(t,Nt,en,!1)),zn(t))}function fd(t,e,n){if((Bt&6)!==0)throw Error(s(327));var a=!n&&(e&127)===0&&(e&t.expiredLanes)===0||na(t,e),l=a?Cy(t,e):Hf(t,e,!0),c=a;do{if(l===0){Ul&&!a&&pa(t,e,0,!1);break}else{if(n=t.current.alternate,c&&!My(n)){l=Hf(t,e,!1),c=!1;continue}if(l===2){if(c=e,t.errorRecoveryDisabledLanes&c)var d=0;else d=t.pendingLanes&-536870913,d=d!==0?d:d&536870912?536870912:0;if(d!==0){e=d;t:{var g=t;l=zi;var S=g.current.memoizedState.isDehydrated;if(S&&(Hl(g,d).flags|=256),d=Hf(g,d,!1),d!==2){if(Df&&!S){g.errorRecoveryDisabledLanes|=c,Wa|=c,l=4;break t}c=Ke,Ke=l,c!==null&&(Ke===null?Ke=c:Ke.push.apply(Ke,c))}l=d}if(c=!1,l!==2)continue}}if(l===1){Hl(t,0),pa(t,e,0,!0);break}t:{switch(a=t,c=l,c){case 0:case 1:throw Error(s(345));case 4:if((e&4194048)!==e)break;case 6:pa(a,e,en,!ya);break t;case 2:Ke=null;break;case 3:case 5:break;default:throw Error(s(329))}if((e&62914560)===e&&(l=Ku+300-xe(),10<l)){if(pa(a,e,en,!ya),Ca(a,0,!0)!==0)break t;kn=e,a.timeoutHandle=Gd(rd.bind(null,a,n,Ke,ku,Nf,e,en,Wa,Cl,ya,c,"Throttled",-0,0),l);break t}rd(a,n,Ke,ku,Nf,e,en,Wa,Cl,ya,c,null,-0,0)}}break}while(!0);zn(t)}function rd(t,e,n,a,l,c,d,g,S,M,q,K,C,j){if(t.timeoutHandle=-1,K=e.subtreeFlags,K&8192||(K&16785408)===16785408){K={stylesheets:null,count:0,imgCount:0,imgBytes:0,suspenseyImages:[],waitingForImages:!0,waitingForViewTransition:!1,unsuspend:Cn},nd(e,c,K);var ft=(c&62914560)===c?Ku-xe():(c&4194048)===c?ud-xe():0;if(ft=gg(K,ft),ft!==null){kn=c,t.cancelPendingCommit=ft(_d.bind(null,t,e,c,n,a,l,d,g,S,q,K,null,C,j)),pa(t,c,d,!M);return}}_d(t,e,c,n,a,l,d,g,S)}function My(t){for(var e=t;;){var n=e.tag;if((n===0||n===11||n===15)&&e.flags&16384&&(n=e.updateQueue,n!==null&&(n=n.stores,n!==null)))for(var a=0;a<n.length;a++){var l=n[a],c=l.getSnapshot;l=l.value;try{if(!Ie(c(),l))return!1}catch{return!1}}if(n=e.child,e.subtreeFlags&16384&&n!==null)n.return=e,e=n;else{if(e===t)break;for(;e.sibling===null;){if(e.return===null||e.return===t)return!0;e=e.return}e.sibling.return=e.return,e=e.sibling}}return!0}function pa(t,e,n,a){e&=~zf,e&=~Wa,t.suspendedLanes|=e,t.pingedLanes&=~e,a&&(t.warmLanes|=e),a=t.expirationTimes;for(var l=e;0<l;){var c=31-F(l),d=1<<c;a[c]=-1,l&=~d}n!==0&&bo(t,n,e)}function Iu(){return(Bt&6)===0?(Mi(0),!1):!0}function Lf(){if(Ot!==null){if(qt===0)var t=Ot.return;else t=Ot,Bn=Za=null,Is(t),wl=null,mi=0,t=Ot;for(;t!==null;)q2(t.alternate,t),t=t.return;Ot=null}}function Hl(t,e){var n=t.timeoutHandle;n!==-1&&(t.timeoutHandle=-1,$y(n)),n=t.cancelPendingCommit,n!==null&&(t.cancelPendingCommit=null,n()),kn=0,Lf(),Kt=t,Ot=n=Hn(t.current,null),Nt=e,qt=0,tn=null,ya=!1,Ul=na(t,e),Df=!1,Cl=en=zf=Wa=ga=ue=0,Ke=zi=null,Nf=!1,(e&8)!==0&&(e|=e&32);var a=t.entangledLanes;if(a!==0)for(t=t.entanglements,a&=e;0<a;){var l=31-F(a),c=1<<l;e|=t[l],a&=~c}return Jn=e,vu(),n}function od(t,e){Tt=null,N.H=Ei,e===xl||e===xu?(e=O0(),qt=3):e===Bs?(e=O0(),qt=4):qt=e===hf?8:e!==null&&typeof e=="object"&&typeof e.then=="function"?6:1,tn=e,Ot===null&&(ue=1,Yu(t,fn(e,t.current)))}function dd(){var t=$e.current;return t===null?!0:(Nt&4194048)===Nt?hn===null:(Nt&62914560)===Nt||(Nt&536870912)!==0?t===hn:!1}function hd(){var t=N.H;return N.H=Ei,t===null?Ei:t}function md(){var t=N.A;return N.A=zy,t}function Wu(){ue=4,ya||(Nt&4194048)!==Nt&&$e.current!==null||(Ul=!0),(ga&134217727)===0&&(Wa&134217727)===0||Kt===null||pa(Kt,Nt,en,!1)}function Hf(t,e,n){var a=Bt;Bt|=2;var l=hd(),c=md();(Kt!==t||Nt!==e)&&(ku=null,Hl(t,e)),e=!1;var d=ue;t:do try{if(qt!==0&&Ot!==null){var g=Ot,S=tn;switch(qt){case 8:Lf(),d=6;break t;case 3:case 2:case 9:case 6:$e.current===null&&(e=!0);var M=qt;if(qt=0,tn=null,jl(t,g,S,M),n&&Ul){d=0;break t}break;default:M=qt,qt=0,tn=null,jl(t,g,S,M)}}Uy(),d=ue;break}catch(q){od(t,q)}while(!0);return e&&t.shellSuspendCounter++,Bn=Za=null,Bt=a,N.H=l,N.A=c,Ot===null&&(Kt=null,Nt=0,vu()),d}function Uy(){for(;Ot!==null;)yd(Ot)}function Cy(t,e){var n=Bt;Bt|=2;var a=hd(),l=md();Kt!==t||Nt!==e?(ku=null,Ju=xe()+500,Hl(t,e)):Ul=na(t,e);t:do try{if(qt!==0&&Ot!==null){e=Ot;var c=tn;e:switch(qt){case 1:qt=0,tn=null,jl(t,e,c,1);break;case 2:case 9:if(x0(c)){qt=0,tn=null,gd(e);break}e=function(){qt!==2&&qt!==9||Kt!==t||(qt=7),zn(t)},c.then(e,e);break t;case 3:qt=7;break t;case 4:qt=5;break t;case 7:x0(c)?(qt=0,tn=null,gd(e)):(qt=0,tn=null,jl(t,e,c,7));break;case 5:var d=null;switch(Ot.tag){case 26:d=Ot.memoizedState;case 5:case 27:var g=Ot;if(d?e1(d):g.stateNode.complete){qt=0,tn=null;var S=g.sibling;if(S!==null)Ot=S;else{var M=g.return;M!==null?(Ot=M,$u(M)):Ot=null}break e}}qt=0,tn=null,jl(t,e,c,5);break;case 6:qt=0,tn=null,jl(t,e,c,6);break;case 8:Lf(),ue=6;break t;default:throw Error(s(462))}}Ly();break}catch(q){od(t,q)}while(!0);return Bn=Za=null,N.H=a,N.A=l,Bt=n,Ot!==null?0:(Kt=null,Nt=0,vu(),ue)}function Ly(){for(;Ot!==null&&!wn();)yd(Ot)}function yd(t){var e=Y2(t.alternate,t,Jn);t.memoizedProps=t.pendingProps,e===null?$u(t):Ot=e}function gd(t){var e=t,n=e.alternate;switch(e.tag){case 15:case 0:e=U2(n,e,e.pendingProps,e.type,void 0,Nt);break;case 11:e=U2(n,e,e.pendingProps,e.type.render,e.ref,Nt);break;case 5:Is(e);default:q2(n,e),e=Ot=m0(e,Jn),e=Y2(n,e,Jn)}t.memoizedProps=t.pendingProps,e===null?$u(t):Ot=e}function jl(t,e,n,a){Bn=Za=null,Is(e),wl=null,mi=0;var l=e.return;try{if(Ty(t,l,e,n,Nt)){ue=1,Yu(t,fn(n,t.current)),Ot=null;return}}catch(c){if(l!==null)throw Ot=l,c;ue=1,Yu(t,fn(n,t.current)),Ot=null;return}e.flags&32768?(Ut||a===1?t=!0:Ul||(Nt&536870912)!==0?t=!1:(ya=t=!0,(a===2||a===9||a===3||a===6)&&(a=$e.current,a!==null&&a.tag===13&&(a.flags|=16384))),vd(e,t)):$u(e)}function $u(t){var e=t;do{if((e.flags&32768)!==0){vd(e,ya);return}t=e.return;var n=wy(e.alternate,e,Jn);if(n!==null){Ot=n;return}if(e=e.sibling,e!==null){Ot=e;return}Ot=e=t}while(e!==null);ue===0&&(ue=5)}function vd(t,e){do{var n=Oy(t.alternate,t);if(n!==null){n.flags&=32767,Ot=n;return}if(n=t.return,n!==null&&(n.flags|=32768,n.subtreeFlags=0,n.deletions=null),!e&&(t=t.sibling,t!==null)){Ot=t;return}Ot=t=n}while(t!==null);ue=6,Ot=null}function _d(t,e,n,a,l,c,d,g,S){t.cancelPendingCommit=null;do Pu();while(pe!==0);if((Bt&6)!==0)throw Error(s(327));if(e!==null){if(e===t.current)throw Error(s(177));if(c=e.lanes|e.childLanes,c|=Ts,m3(t,n,c,d,g,S),t===Kt&&(Ot=Kt=null,Nt=0),Ll=e,_a=t,kn=n,Mf=c,Uf=l,cd=a,(e.subtreeFlags&10256)!==0||(e.flags&10256)!==0?(t.callbackNode=null,t.callbackPriority=0,Yy(ea,function(){return Td(),null})):(t.callbackNode=null,t.callbackPriority=0),a=(e.flags&13878)!==0,(e.subtreeFlags&13878)!==0||a){a=N.T,N.T=null,l=V.p,V.p=2,d=Bt,Bt|=4;try{Ry(t,e,n)}finally{Bt=d,V.p=l,N.T=a}}pe=1,pd(),bd(),Sd()}}function pd(){if(pe===1){pe=0;var t=_a,e=Ll,n=(e.flags&13878)!==0;if((e.subtreeFlags&13878)!==0||n){n=N.T,N.T=null;var a=V.p;V.p=2;var l=Bt;Bt|=4;try{P2(e,t);var c=Jf,d=i0(t.containerInfo),g=c.focusedElem,S=c.selectionRange;if(d!==g&&g&&g.ownerDocument&&l0(g.ownerDocument.documentElement,g)){if(S!==null&&_s(g)){var M=S.start,q=S.end;if(q===void 0&&(q=M),"selectionStart"in g)g.selectionStart=M,g.selectionEnd=Math.min(q,g.value.length);else{var K=g.ownerDocument||document,C=K&&K.defaultView||window;if(C.getSelection){var j=C.getSelection(),ft=g.textContent.length,bt=Math.min(S.start,ft),Qt=S.end===void 0?bt:Math.min(S.end,ft);!j.extend&&bt>Qt&&(d=Qt,Qt=bt,bt=d);var x=a0(g,bt),A=a0(g,Qt);if(x&&A&&(j.rangeCount!==1||j.anchorNode!==x.node||j.anchorOffset!==x.offset||j.focusNode!==A.node||j.focusOffset!==A.offset)){var z=K.createRange();z.setStart(x.node,x.offset),j.removeAllRanges(),bt>Qt?(j.addRange(z),j.extend(A.node,A.offset)):(z.setEnd(A.node,A.offset),j.addRange(z))}}}}for(K=[],j=g;j=j.parentNode;)j.nodeType===1&&K.push({element:j,left:j.scrollLeft,top:j.scrollTop});for(typeof g.focus=="function"&&g.focus(),g=0;g<K.length;g++){var Q=K[g];Q.element.scrollLeft=Q.left,Q.element.scrollTop=Q.top}}oc=!!Kf,Jf=Kf=null}finally{Bt=l,V.p=a,N.T=n}}t.current=e,pe=2}}function bd(){if(pe===2){pe=0;var t=_a,e=Ll,n=(e.flags&8772)!==0;if((e.subtreeFlags&8772)!==0||n){n=N.T,N.T=null;var a=V.p;V.p=2;var l=Bt;Bt|=4;try{J2(t,e.alternate,e)}finally{Bt=l,V.p=a,N.T=n}}pe=3}}function Sd(){if(pe===4||pe===3){pe=0,nl();var t=_a,e=Ll,n=kn,a=cd;(e.subtreeFlags&10256)!==0||(e.flags&10256)!==0?pe=5:(pe=0,Ll=_a=null,Ed(t,t.pendingLanes));var l=t.pendingLanes;if(l===0&&(va=null),Pc(n),e=e.stateNode,Y&&typeof Y.onCommitFiberRoot=="function")try{Y.onCommitFiberRoot(Ua,e,void 0,(e.current.flags&128)===128)}catch{}if(a!==null){e=N.T,l=V.p,V.p=2,N.T=null;try{for(var c=t.onRecoverableError,d=0;d<a.length;d++){var g=a[d];c(g.value,{componentStack:g.stack})}}finally{N.T=e,V.p=l}}(kn&3)!==0&&Pu(),zn(t),l=t.pendingLanes,(n&261930)!==0&&(l&42)!==0?t===Cf?Ni++:(Ni=0,Cf=t):Ni=0,Mi(0)}}function Ed(t,e){(t.pooledCacheLanes&=e)===0&&(e=t.pooledCache,e!=null&&(t.pooledCache=null,di(e)))}function Pu(){return pd(),bd(),Sd(),Td()}function Td(){if(pe!==5)return!1;var t=_a,e=Mf;Mf=0;var n=Pc(kn),a=N.T,l=V.p;try{V.p=32>n?32:n,N.T=null,n=Uf,Uf=null;var c=_a,d=kn;if(pe=0,Ll=_a=null,kn=0,(Bt&6)!==0)throw Error(s(331));var g=Bt;if(Bt|=4,ld(c.current),ed(c,c.current,d,n),Bt=g,Mi(0,!1),Y&&typeof Y.onPostCommitFiberRoot=="function")try{Y.onPostCommitFiberRoot(Ua,c)}catch{}return!0}finally{V.p=l,N.T=a,Ed(t,e)}}function Ad(t,e,n){e=fn(n,e),e=df(t.stateNode,e,2),t=oa(t,e,2),t!==null&&($l(t,2),zn(t))}function Zt(t,e,n){if(t.tag===3)Ad(t,t,n);else for(;e!==null;){if(e.tag===3){Ad(e,t,n);break}else if(e.tag===1){var a=e.stateNode;if(typeof e.type.getDerivedStateFromError=="function"||typeof a.componentDidCatch=="function"&&(va===null||!va.has(a))){t=fn(n,t),n=x2(2),a=oa(e,n,2),a!==null&&(w2(n,a,e,t),$l(a,2),zn(a));break}}e=e.return}}function jf(t,e,n){var a=t.pingCache;if(a===null){a=t.pingCache=new Ny;var l=new Set;a.set(e,l)}else l=a.get(e),l===void 0&&(l=new Set,a.set(e,l));l.has(n)||(Df=!0,l.add(n),t=Hy.bind(null,t,e,n),e.then(t,t))}function Hy(t,e,n){var a=t.pingCache;a!==null&&a.delete(e),t.pingedLanes|=t.suspendedLanes&n,t.warmLanes&=~n,Kt===t&&(Nt&n)===n&&(ue===4||ue===3&&(Nt&62914560)===Nt&&300>xe()-Ku?(Bt&2)===0&&Hl(t,0):zf|=n,Cl===Nt&&(Cl=0)),zn(t)}function xd(t,e){e===0&&(e=po()),t=Ya(t,e),t!==null&&($l(t,e),zn(t))}function jy(t){var e=t.memoizedState,n=0;e!==null&&(n=e.retryLane),xd(t,n)}function By(t,e){var n=0;switch(t.tag){case 31:case 13:var a=t.stateNode,l=t.memoizedState;l!==null&&(n=l.retryLane);break;case 19:a=t.stateNode;break;case 22:a=t.stateNode._retryCache;break;default:throw Error(s(314))}a!==null&&a.delete(e),xd(t,n)}function Yy(t,e){return Ce(t,e)}var tc=null,Bl=null,Bf=!1,ec=!1,Yf=!1,ba=0;function zn(t){t!==Bl&&t.next===null&&(Bl===null?tc=Bl=t:Bl=Bl.next=t),ec=!0,Bf||(Bf=!0,qy())}function Mi(t,e){if(!Yf&&ec){Yf=!0;do for(var n=!1,a=tc;a!==null;){if(t!==0){var l=a.pendingLanes;if(l===0)var c=0;else{var d=a.suspendedLanes,g=a.pingedLanes;c=(1<<31-F(42|t)+1)-1,c&=l&~(d&~g),c=c&201326741?c&201326741|1:c?c|2:0}c!==0&&(n=!0,Dd(a,c))}else c=Nt,c=Ca(a,a===Kt?c:0,a.cancelPendingCommit!==null||a.timeoutHandle!==-1),(c&3)===0||na(a,c)||(n=!0,Dd(a,c));a=a.next}while(n);Yf=!1}}function Gy(){wd()}function wd(){ec=Bf=!1;var t=0;ba!==0&&Wy()&&(t=ba);for(var e=xe(),n=null,a=tc;a!==null;){var l=a.next,c=Od(a,e);c===0?(a.next=null,n===null?tc=l:n.next=l,l===null&&(Bl=n)):(n=a,(t!==0||(c&3)!==0)&&(ec=!0)),a=l}pe!==0&&pe!==5||Mi(t),ba!==0&&(ba=0)}function Od(t,e){for(var n=t.suspendedLanes,a=t.pingedLanes,l=t.expirationTimes,c=t.pendingLanes&-62914561;0<c;){var d=31-F(c),g=1<<d,S=l[d];S===-1?((g&n)===0||(g&a)!==0)&&(l[d]=h3(g,e)):S<=e&&(t.expiredLanes|=g),c&=~g}if(e=Kt,n=Nt,n=Ca(t,t===e?n:0,t.cancelPendingCommit!==null||t.timeoutHandle!==-1),a=t.callbackNode,n===0||t===e&&(qt===2||qt===9)||t.cancelPendingCommit!==null)return a!==null&&a!==null&&Ae(a),t.callbackNode=null,t.callbackPriority=0;if((n&3)===0||na(t,n)){if(e=n&-n,e===t.callbackPriority)return e;switch(a!==null&&Ae(a),Pc(n)){case 2:case 8:n=_e;break;case 32:n=ea;break;case 268435456:n=Wl;break;default:n=ea}return a=Rd.bind(null,t),n=Ce(n,a),t.callbackPriority=e,t.callbackNode=n,e}return a!==null&&a!==null&&Ae(a),t.callbackPriority=2,t.callbackNode=null,2}function Rd(t,e){if(pe!==0&&pe!==5)return t.callbackNode=null,t.callbackPriority=0,null;var n=t.callbackNode;if(Pu()&&t.callbackNode!==n)return null;var a=Nt;return a=Ca(t,t===Kt?a:0,t.cancelPendingCommit!==null||t.timeoutHandle!==-1),a===0?null:(fd(t,a,e),Od(t,xe()),t.callbackNode!=null&&t.callbackNode===n?Rd.bind(null,t):null)}function Dd(t,e){if(Pu())return null;fd(t,e,!0)}function qy(){Py(function(){(Bt&6)!==0?Ce(ll,Gy):wd()})}function Gf(){if(ba===0){var t=Tl;t===0&&(t=wt,wt<<=1,(wt&261888)===0&&(wt=256)),ba=t}return ba}function zd(t){return t==null||typeof t=="symbol"||typeof t=="boolean"?null:typeof t=="function"?t:fu(""+t)}function Nd(t,e){var n=e.ownerDocument.createElement("input");return n.name=e.name,n.value=e.value,t.id&&n.setAttribute("form",t.id),e.parentNode.insertBefore(n,e),t=new FormData(t),n.parentNode.removeChild(n),t}function Zy(t,e,n,a,l){if(e==="submit"&&n&&n.stateNode===l){var c=zd((l[Ze]||null).action),d=a.submitter;d&&(e=(e=d[Ze]||null)?zd(e.formAction):d.getAttribute("formAction"),e!==null&&(c=e,d=null));var g=new hu("action","action",null,a,l);t.push({event:g,listeners:[{instance:null,listener:function(){if(a.defaultPrevented){if(ba!==0){var S=d?Nd(l,d):new FormData(l);uf(n,{pending:!0,data:S,method:l.method,action:c},null,S)}}else typeof c=="function"&&(g.preventDefault(),S=d?Nd(l,d):new FormData(l),uf(n,{pending:!0,data:S,method:l.method,action:c},c,S))},currentTarget:l}]})}}for(var qf=0;qf<Es.length;qf++){var Zf=Es[qf],Xy=Zf.toLowerCase(),Vy=Zf[0].toUpperCase()+Zf.slice(1);bn(Xy,"on"+Vy)}bn(s0,"onAnimationEnd"),bn(f0,"onAnimationIteration"),bn(r0,"onAnimationStart"),bn("dblclick","onDoubleClick"),bn("focusin","onFocus"),bn("focusout","onBlur"),bn(uy,"onTransitionRun"),bn(cy,"onTransitionStart"),bn(sy,"onTransitionCancel"),bn(o0,"onTransitionEnd"),fl("onMouseEnter",["mouseout","mouseover"]),fl("onMouseLeave",["mouseout","mouseover"]),fl("onPointerEnter",["pointerout","pointerover"]),fl("onPointerLeave",["pointerout","pointerover"]),La("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),La("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),La("onBeforeInput",["compositionend","keypress","textInput","paste"]),La("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),La("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),La("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var Ui="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),Qy=new Set("beforetoggle cancel close invalid load scroll scrollend toggle".split(" ").concat(Ui));function Md(t,e){e=(e&4)!==0;for(var n=0;n<t.length;n++){var a=t[n],l=a.event;a=a.listeners;t:{var c=void 0;if(e)for(var d=a.length-1;0<=d;d--){var g=a[d],S=g.instance,M=g.currentTarget;if(g=g.listener,S!==c&&l.isPropagationStopped())break t;c=g,l.currentTarget=M;try{c(l)}catch(q){gu(q)}l.currentTarget=null,c=S}else for(d=0;d<a.length;d++){if(g=a[d],S=g.instance,M=g.currentTarget,g=g.listener,S!==c&&l.isPropagationStopped())break t;c=g,l.currentTarget=M;try{c(l)}catch(q){gu(q)}l.currentTarget=null,c=S}}}}function Rt(t,e){var n=e[ts];n===void 0&&(n=e[ts]=new Set);var a=t+"__bubble";n.has(a)||(Ud(e,t,2,!1),n.add(a))}function Xf(t,e,n){var a=0;e&&(a|=4),Ud(n,t,a,e)}var nc="_reactListening"+Math.random().toString(36).slice(2);function Vf(t){if(!t[nc]){t[nc]=!0,wo.forEach(function(n){n!=="selectionchange"&&(Qy.has(n)||Xf(n,!1,t),Xf(n,!0,t))});var e=t.nodeType===9?t:t.ownerDocument;e===null||e[nc]||(e[nc]=!0,Xf("selectionchange",!1,e))}}function Ud(t,e,n,a){switch(s1(e)){case 2:var l=pg;break;case 8:l=bg;break;default:l=ir}n=l.bind(null,e,n,t),l=void 0,!fs||e!=="touchstart"&&e!=="touchmove"&&e!=="wheel"||(l=!0),a?l!==void 0?t.addEventListener(e,n,{capture:!0,passive:l}):t.addEventListener(e,n,!0):l!==void 0?t.addEventListener(e,n,{passive:l}):t.addEventListener(e,n,!1)}function Qf(t,e,n,a,l){var c=a;if((e&1)===0&&(e&2)===0&&a!==null)t:for(;;){if(a===null)return;var d=a.tag;if(d===3||d===4){var g=a.stateNode.containerInfo;if(g===l)break;if(d===4)for(d=a.return;d!==null;){var S=d.tag;if((S===3||S===4)&&d.stateNode.containerInfo===l)return;d=d.return}for(;g!==null;){if(d=ul(g),d===null)return;if(S=d.tag,S===5||S===6||S===26||S===27){a=c=d;continue t}g=g.parentNode}}a=a.return}Bo(function(){var M=c,q=cs(n),K=[];t:{var C=d0.get(t);if(C!==void 0){var j=hu,ft=t;switch(t){case"keypress":if(ou(n)===0)break t;case"keydown":case"keyup":j=B3;break;case"focusin":ft="focus",j=hs;break;case"focusout":ft="blur",j=hs;break;case"beforeblur":case"afterblur":j=hs;break;case"click":if(n.button===2)break t;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":j=qo;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":j=w3;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":j=q3;break;case s0:case f0:case r0:j=D3;break;case o0:j=X3;break;case"scroll":case"scrollend":j=A3;break;case"wheel":j=Q3;break;case"copy":case"cut":case"paste":j=N3;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":j=Xo;break;case"toggle":case"beforetoggle":j=K3}var bt=(e&4)!==0,Qt=!bt&&(t==="scroll"||t==="scrollend"),x=bt?C!==null?C+"Capture":null:C;bt=[];for(var A=M,z;A!==null;){var Q=A;if(z=Q.stateNode,Q=Q.tag,Q!==5&&Q!==26&&Q!==27||z===null||x===null||(Q=ei(A,x),Q!=null&&bt.push(Ci(A,Q,z))),Qt)break;A=A.return}0<bt.length&&(C=new j(C,ft,null,n,q),K.push({event:C,listeners:bt}))}}if((e&7)===0){t:{if(C=t==="mouseover"||t==="pointerover",j=t==="mouseout"||t==="pointerout",C&&n!==us&&(ft=n.relatedTarget||n.fromElement)&&(ul(ft)||ft[il]))break t;if((j||C)&&(C=q.window===q?q:(C=q.ownerDocument)?C.defaultView||C.parentWindow:window,j?(ft=n.relatedTarget||n.toElement,j=M,ft=ft?ul(ft):null,ft!==null&&(Qt=o(ft),bt=ft.tag,ft!==Qt||bt!==5&&bt!==27&&bt!==6)&&(ft=null)):(j=null,ft=M),j!==ft)){if(bt=qo,Q="onMouseLeave",x="onMouseEnter",A="mouse",(t==="pointerout"||t==="pointerover")&&(bt=Xo,Q="onPointerLeave",x="onPointerEnter",A="pointer"),Qt=j==null?C:ti(j),z=ft==null?C:ti(ft),C=new bt(Q,A+"leave",j,n,q),C.target=Qt,C.relatedTarget=z,Q=null,ul(q)===M&&(bt=new bt(x,A+"enter",ft,n,q),bt.target=z,bt.relatedTarget=Qt,Q=bt),Qt=Q,j&&ft)e:{for(bt=Fy,x=j,A=ft,z=0,Q=x;Q;Q=bt(Q))z++;Q=0;for(var vt=A;vt;vt=bt(vt))Q++;for(;0<z-Q;)x=bt(x),z--;for(;0<Q-z;)A=bt(A),Q--;for(;z--;){if(x===A||A!==null&&x===A.alternate){bt=x;break e}x=bt(x),A=bt(A)}bt=null}else bt=null;j!==null&&Cd(K,C,j,bt,!1),ft!==null&&Qt!==null&&Cd(K,Qt,ft,bt,!0)}}t:{if(C=M?ti(M):window,j=C.nodeName&&C.nodeName.toLowerCase(),j==="select"||j==="input"&&C.type==="file")var Ht=Wo;else if(ko(C))if($o)Ht=ay;else{Ht=ey;var dt=ty}else j=C.nodeName,!j||j.toLowerCase()!=="input"||C.type!=="checkbox"&&C.type!=="radio"?M&&is(M.elementType)&&(Ht=Wo):Ht=ny;if(Ht&&(Ht=Ht(t,M))){Io(K,Ht,n,q);break t}dt&&dt(t,C,M),t==="focusout"&&M&&C.type==="number"&&M.memoizedProps.value!=null&&ls(C,"number",C.value)}switch(dt=M?ti(M):window,t){case"focusin":(ko(dt)||dt.contentEditable==="true")&&(yl=dt,ps=M,fi=null);break;case"focusout":fi=ps=yl=null;break;case"mousedown":bs=!0;break;case"contextmenu":case"mouseup":case"dragend":bs=!1,u0(K,n,q);break;case"selectionchange":if(iy)break;case"keydown":case"keyup":u0(K,n,q)}var xt;if(ys)t:{switch(t){case"compositionstart":var Mt="onCompositionStart";break t;case"compositionend":Mt="onCompositionEnd";break t;case"compositionupdate":Mt="onCompositionUpdate";break t}Mt=void 0}else ml?Ko(t,n)&&(Mt="onCompositionEnd"):t==="keydown"&&n.keyCode===229&&(Mt="onCompositionStart");Mt&&(Vo&&n.locale!=="ko"&&(ml||Mt!=="onCompositionStart"?Mt==="onCompositionEnd"&&ml&&(xt=Yo()):(la=q,rs="value"in la?la.value:la.textContent,ml=!0)),dt=ac(M,Mt),0<dt.length&&(Mt=new Zo(Mt,t,null,n,q),K.push({event:Mt,listeners:dt}),xt?Mt.data=xt:(xt=Jo(n),xt!==null&&(Mt.data=xt)))),(xt=k3?I3(t,n):W3(t,n))&&(Mt=ac(M,"onBeforeInput"),0<Mt.length&&(dt=new Zo("onBeforeInput","beforeinput",null,n,q),K.push({event:dt,listeners:Mt}),dt.data=xt)),Zy(K,t,M,n,q)}Md(K,e)})}function Ci(t,e,n){return{instance:t,listener:e,currentTarget:n}}function ac(t,e){for(var n=e+"Capture",a=[];t!==null;){var l=t,c=l.stateNode;if(l=l.tag,l!==5&&l!==26&&l!==27||c===null||(l=ei(t,n),l!=null&&a.unshift(Ci(t,l,c)),l=ei(t,e),l!=null&&a.push(Ci(t,l,c))),t.tag===3)return a;t=t.return}return[]}function Fy(t){if(t===null)return null;do t=t.return;while(t&&t.tag!==5&&t.tag!==27);return t||null}function Cd(t,e,n,a,l){for(var c=e._reactName,d=[];n!==null&&n!==a;){var g=n,S=g.alternate,M=g.stateNode;if(g=g.tag,S!==null&&S===a)break;g!==5&&g!==26&&g!==27||M===null||(S=M,l?(M=ei(n,c),M!=null&&d.unshift(Ci(n,M,S))):l||(M=ei(n,c),M!=null&&d.push(Ci(n,M,S)))),n=n.return}d.length!==0&&t.push({event:e,listeners:d})}var Ky=/\r\n?/g,Jy=/\u0000|\uFFFD/g;function Ld(t){return(typeof t=="string"?t:""+t).replace(Ky,`
`).replace(Jy,"")}function Hd(t,e){return e=Ld(e),Ld(t)===e}function Vt(t,e,n,a,l,c){switch(n){case"children":typeof a=="string"?e==="body"||e==="textarea"&&a===""||ol(t,a):(typeof a=="number"||typeof a=="bigint")&&e!=="body"&&ol(t,""+a);break;case"className":cu(t,"class",a);break;case"tabIndex":cu(t,"tabindex",a);break;case"dir":case"role":case"viewBox":case"width":case"height":cu(t,n,a);break;case"style":Ho(t,a,c);break;case"data":if(e!=="object"){cu(t,"data",a);break}case"src":case"href":if(a===""&&(e!=="a"||n!=="href")){t.removeAttribute(n);break}if(a==null||typeof a=="function"||typeof a=="symbol"||typeof a=="boolean"){t.removeAttribute(n);break}a=fu(""+a),t.setAttribute(n,a);break;case"action":case"formAction":if(typeof a=="function"){t.setAttribute(n,"javascript:throw new Error('A React form was unexpectedly submitted. If you called form.submit() manually, consider using form.requestSubmit() instead. If you\\'re trying to use event.stopPropagation() in a submit event handler, consider also calling event.preventDefault().')");break}else typeof c=="function"&&(n==="formAction"?(e!=="input"&&Vt(t,e,"name",l.name,l,null),Vt(t,e,"formEncType",l.formEncType,l,null),Vt(t,e,"formMethod",l.formMethod,l,null),Vt(t,e,"formTarget",l.formTarget,l,null)):(Vt(t,e,"encType",l.encType,l,null),Vt(t,e,"method",l.method,l,null),Vt(t,e,"target",l.target,l,null)));if(a==null||typeof a=="symbol"||typeof a=="boolean"){t.removeAttribute(n);break}a=fu(""+a),t.setAttribute(n,a);break;case"onClick":a!=null&&(t.onclick=Cn);break;case"onScroll":a!=null&&Rt("scroll",t);break;case"onScrollEnd":a!=null&&Rt("scrollend",t);break;case"dangerouslySetInnerHTML":if(a!=null){if(typeof a!="object"||!("__html"in a))throw Error(s(61));if(n=a.__html,n!=null){if(l.children!=null)throw Error(s(60));t.innerHTML=n}}break;case"multiple":t.multiple=a&&typeof a!="function"&&typeof a!="symbol";break;case"muted":t.muted=a&&typeof a!="function"&&typeof a!="symbol";break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"defaultValue":case"defaultChecked":case"innerHTML":case"ref":break;case"autoFocus":break;case"xlinkHref":if(a==null||typeof a=="function"||typeof a=="boolean"||typeof a=="symbol"){t.removeAttribute("xlink:href");break}n=fu(""+a),t.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",n);break;case"contentEditable":case"spellCheck":case"draggable":case"value":case"autoReverse":case"externalResourcesRequired":case"focusable":case"preserveAlpha":a!=null&&typeof a!="function"&&typeof a!="symbol"?t.setAttribute(n,""+a):t.removeAttribute(n);break;case"inert":case"allowFullScreen":case"async":case"autoPlay":case"controls":case"default":case"defer":case"disabled":case"disablePictureInPicture":case"disableRemotePlayback":case"formNoValidate":case"hidden":case"loop":case"noModule":case"noValidate":case"open":case"playsInline":case"readOnly":case"required":case"reversed":case"scoped":case"seamless":case"itemScope":a&&typeof a!="function"&&typeof a!="symbol"?t.setAttribute(n,""):t.removeAttribute(n);break;case"capture":case"download":a===!0?t.setAttribute(n,""):a!==!1&&a!=null&&typeof a!="function"&&typeof a!="symbol"?t.setAttribute(n,a):t.removeAttribute(n);break;case"cols":case"rows":case"size":case"span":a!=null&&typeof a!="function"&&typeof a!="symbol"&&!isNaN(a)&&1<=a?t.setAttribute(n,a):t.removeAttribute(n);break;case"rowSpan":case"start":a==null||typeof a=="function"||typeof a=="symbol"||isNaN(a)?t.removeAttribute(n):t.setAttribute(n,a);break;case"popover":Rt("beforetoggle",t),Rt("toggle",t),uu(t,"popover",a);break;case"xlinkActuate":Un(t,"http://www.w3.org/1999/xlink","xlink:actuate",a);break;case"xlinkArcrole":Un(t,"http://www.w3.org/1999/xlink","xlink:arcrole",a);break;case"xlinkRole":Un(t,"http://www.w3.org/1999/xlink","xlink:role",a);break;case"xlinkShow":Un(t,"http://www.w3.org/1999/xlink","xlink:show",a);break;case"xlinkTitle":Un(t,"http://www.w3.org/1999/xlink","xlink:title",a);break;case"xlinkType":Un(t,"http://www.w3.org/1999/xlink","xlink:type",a);break;case"xmlBase":Un(t,"http://www.w3.org/XML/1998/namespace","xml:base",a);break;case"xmlLang":Un(t,"http://www.w3.org/XML/1998/namespace","xml:lang",a);break;case"xmlSpace":Un(t,"http://www.w3.org/XML/1998/namespace","xml:space",a);break;case"is":uu(t,"is",a);break;case"innerText":case"textContent":break;default:(!(2<n.length)||n[0]!=="o"&&n[0]!=="O"||n[1]!=="n"&&n[1]!=="N")&&(n=E3.get(n)||n,uu(t,n,a))}}function Ff(t,e,n,a,l,c){switch(n){case"style":Ho(t,a,c);break;case"dangerouslySetInnerHTML":if(a!=null){if(typeof a!="object"||!("__html"in a))throw Error(s(61));if(n=a.__html,n!=null){if(l.children!=null)throw Error(s(60));t.innerHTML=n}}break;case"children":typeof a=="string"?ol(t,a):(typeof a=="number"||typeof a=="bigint")&&ol(t,""+a);break;case"onScroll":a!=null&&Rt("scroll",t);break;case"onScrollEnd":a!=null&&Rt("scrollend",t);break;case"onClick":a!=null&&(t.onclick=Cn);break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"innerHTML":case"ref":break;case"innerText":case"textContent":break;default:if(!Oo.hasOwnProperty(n))t:{if(n[0]==="o"&&n[1]==="n"&&(l=n.endsWith("Capture"),e=n.slice(2,l?n.length-7:void 0),c=t[Ze]||null,c=c!=null?c[n]:null,typeof c=="function"&&t.removeEventListener(e,c,l),typeof a=="function")){typeof c!="function"&&c!==null&&(n in t?t[n]=null:t.hasAttribute(n)&&t.removeAttribute(n)),t.addEventListener(e,a,l);break t}n in t?t[n]=a:a===!0?t.setAttribute(n,""):uu(t,n,a)}}}function ze(t,e,n){switch(e){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"img":Rt("error",t),Rt("load",t);var a=!1,l=!1,c;for(c in n)if(n.hasOwnProperty(c)){var d=n[c];if(d!=null)switch(c){case"src":a=!0;break;case"srcSet":l=!0;break;case"children":case"dangerouslySetInnerHTML":throw Error(s(137,e));default:Vt(t,e,c,d,n,null)}}l&&Vt(t,e,"srcSet",n.srcSet,n,null),a&&Vt(t,e,"src",n.src,n,null);return;case"input":Rt("invalid",t);var g=c=d=l=null,S=null,M=null;for(a in n)if(n.hasOwnProperty(a)){var q=n[a];if(q!=null)switch(a){case"name":l=q;break;case"type":d=q;break;case"checked":S=q;break;case"defaultChecked":M=q;break;case"value":c=q;break;case"defaultValue":g=q;break;case"children":case"dangerouslySetInnerHTML":if(q!=null)throw Error(s(137,e));break;default:Vt(t,e,a,q,n,null)}}Mo(t,c,g,S,M,d,l,!1);return;case"select":Rt("invalid",t),a=d=c=null;for(l in n)if(n.hasOwnProperty(l)&&(g=n[l],g!=null))switch(l){case"value":c=g;break;case"defaultValue":d=g;break;case"multiple":a=g;default:Vt(t,e,l,g,n,null)}e=c,n=d,t.multiple=!!a,e!=null?rl(t,!!a,e,!1):n!=null&&rl(t,!!a,n,!0);return;case"textarea":Rt("invalid",t),c=l=a=null;for(d in n)if(n.hasOwnProperty(d)&&(g=n[d],g!=null))switch(d){case"value":a=g;break;case"defaultValue":l=g;break;case"children":c=g;break;case"dangerouslySetInnerHTML":if(g!=null)throw Error(s(91));break;default:Vt(t,e,d,g,n,null)}Co(t,a,l,c);return;case"option":for(S in n)if(n.hasOwnProperty(S)&&(a=n[S],a!=null))switch(S){case"selected":t.selected=a&&typeof a!="function"&&typeof a!="symbol";break;default:Vt(t,e,S,a,n,null)}return;case"dialog":Rt("beforetoggle",t),Rt("toggle",t),Rt("cancel",t),Rt("close",t);break;case"iframe":case"object":Rt("load",t);break;case"video":case"audio":for(a=0;a<Ui.length;a++)Rt(Ui[a],t);break;case"image":Rt("error",t),Rt("load",t);break;case"details":Rt("toggle",t);break;case"embed":case"source":case"link":Rt("error",t),Rt("load",t);case"area":case"base":case"br":case"col":case"hr":case"keygen":case"meta":case"param":case"track":case"wbr":case"menuitem":for(M in n)if(n.hasOwnProperty(M)&&(a=n[M],a!=null))switch(M){case"children":case"dangerouslySetInnerHTML":throw Error(s(137,e));default:Vt(t,e,M,a,n,null)}return;default:if(is(e)){for(q in n)n.hasOwnProperty(q)&&(a=n[q],a!==void 0&&Ff(t,e,q,a,n,void 0));return}}for(g in n)n.hasOwnProperty(g)&&(a=n[g],a!=null&&Vt(t,e,g,a,n,null))}function ky(t,e,n,a){switch(e){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"input":var l=null,c=null,d=null,g=null,S=null,M=null,q=null;for(j in n){var K=n[j];if(n.hasOwnProperty(j)&&K!=null)switch(j){case"checked":break;case"value":break;case"defaultValue":S=K;default:a.hasOwnProperty(j)||Vt(t,e,j,null,a,K)}}for(var C in a){var j=a[C];if(K=n[C],a.hasOwnProperty(C)&&(j!=null||K!=null))switch(C){case"type":c=j;break;case"name":l=j;break;case"checked":M=j;break;case"defaultChecked":q=j;break;case"value":d=j;break;case"defaultValue":g=j;break;case"children":case"dangerouslySetInnerHTML":if(j!=null)throw Error(s(137,e));break;default:j!==K&&Vt(t,e,C,j,a,K)}}as(t,d,g,S,M,q,c,l);return;case"select":j=d=g=C=null;for(c in n)if(S=n[c],n.hasOwnProperty(c)&&S!=null)switch(c){case"value":break;case"multiple":j=S;default:a.hasOwnProperty(c)||Vt(t,e,c,null,a,S)}for(l in a)if(c=a[l],S=n[l],a.hasOwnProperty(l)&&(c!=null||S!=null))switch(l){case"value":C=c;break;case"defaultValue":g=c;break;case"multiple":d=c;default:c!==S&&Vt(t,e,l,c,a,S)}e=g,n=d,a=j,C!=null?rl(t,!!n,C,!1):!!a!=!!n&&(e!=null?rl(t,!!n,e,!0):rl(t,!!n,n?[]:"",!1));return;case"textarea":j=C=null;for(g in n)if(l=n[g],n.hasOwnProperty(g)&&l!=null&&!a.hasOwnProperty(g))switch(g){case"value":break;case"children":break;default:Vt(t,e,g,null,a,l)}for(d in a)if(l=a[d],c=n[d],a.hasOwnProperty(d)&&(l!=null||c!=null))switch(d){case"value":C=l;break;case"defaultValue":j=l;break;case"children":break;case"dangerouslySetInnerHTML":if(l!=null)throw Error(s(91));break;default:l!==c&&Vt(t,e,d,l,a,c)}Uo(t,C,j);return;case"option":for(var ft in n)if(C=n[ft],n.hasOwnProperty(ft)&&C!=null&&!a.hasOwnProperty(ft))switch(ft){case"selected":t.selected=!1;break;default:Vt(t,e,ft,null,a,C)}for(S in a)if(C=a[S],j=n[S],a.hasOwnProperty(S)&&C!==j&&(C!=null||j!=null))switch(S){case"selected":t.selected=C&&typeof C!="function"&&typeof C!="symbol";break;default:Vt(t,e,S,C,a,j)}return;case"img":case"link":case"area":case"base":case"br":case"col":case"embed":case"hr":case"keygen":case"meta":case"param":case"source":case"track":case"wbr":case"menuitem":for(var bt in n)C=n[bt],n.hasOwnProperty(bt)&&C!=null&&!a.hasOwnProperty(bt)&&Vt(t,e,bt,null,a,C);for(M in a)if(C=a[M],j=n[M],a.hasOwnProperty(M)&&C!==j&&(C!=null||j!=null))switch(M){case"children":case"dangerouslySetInnerHTML":if(C!=null)throw Error(s(137,e));break;default:Vt(t,e,M,C,a,j)}return;default:if(is(e)){for(var Qt in n)C=n[Qt],n.hasOwnProperty(Qt)&&C!==void 0&&!a.hasOwnProperty(Qt)&&Ff(t,e,Qt,void 0,a,C);for(q in a)C=a[q],j=n[q],!a.hasOwnProperty(q)||C===j||C===void 0&&j===void 0||Ff(t,e,q,C,a,j);return}}for(var x in n)C=n[x],n.hasOwnProperty(x)&&C!=null&&!a.hasOwnProperty(x)&&Vt(t,e,x,null,a,C);for(K in a)C=a[K],j=n[K],!a.hasOwnProperty(K)||C===j||C==null&&j==null||Vt(t,e,K,C,a,j)}function jd(t){switch(t){case"css":case"script":case"font":case"img":case"image":case"input":case"link":return!0;default:return!1}}function Iy(){if(typeof performance.getEntriesByType=="function"){for(var t=0,e=0,n=performance.getEntriesByType("resource"),a=0;a<n.length;a++){var l=n[a],c=l.transferSize,d=l.initiatorType,g=l.duration;if(c&&g&&jd(d)){for(d=0,g=l.responseEnd,a+=1;a<n.length;a++){var S=n[a],M=S.startTime;if(M>g)break;var q=S.transferSize,K=S.initiatorType;q&&jd(K)&&(S=S.responseEnd,d+=q*(S<g?1:(g-M)/(S-M)))}if(--a,e+=8*(c+d)/(l.duration/1e3),t++,10<t)break}}if(0<t)return e/t/1e6}return navigator.connection&&(t=navigator.connection.downlink,typeof t=="number")?t:5}var Kf=null,Jf=null;function lc(t){return t.nodeType===9?t:t.ownerDocument}function Bd(t){switch(t){case"http://www.w3.org/2000/svg":return 1;case"http://www.w3.org/1998/Math/MathML":return 2;default:return 0}}function Yd(t,e){if(t===0)switch(e){case"svg":return 1;case"math":return 2;default:return 0}return t===1&&e==="foreignObject"?0:t}function kf(t,e){return t==="textarea"||t==="noscript"||typeof e.children=="string"||typeof e.children=="number"||typeof e.children=="bigint"||typeof e.dangerouslySetInnerHTML=="object"&&e.dangerouslySetInnerHTML!==null&&e.dangerouslySetInnerHTML.__html!=null}var If=null;function Wy(){var t=window.event;return t&&t.type==="popstate"?t===If?!1:(If=t,!0):(If=null,!1)}var Gd=typeof setTimeout=="function"?setTimeout:void 0,$y=typeof clearTimeout=="function"?clearTimeout:void 0,qd=typeof Promise=="function"?Promise:void 0,Py=typeof queueMicrotask=="function"?queueMicrotask:typeof qd<"u"?function(t){return qd.resolve(null).then(t).catch(tg)}:Gd;function tg(t){setTimeout(function(){throw t})}function Sa(t){return t==="head"}function Zd(t,e){var n=e,a=0;do{var l=n.nextSibling;if(t.removeChild(n),l&&l.nodeType===8)if(n=l.data,n==="/$"||n==="/&"){if(a===0){t.removeChild(l),Zl(e);return}a--}else if(n==="$"||n==="$?"||n==="$~"||n==="$!"||n==="&")a++;else if(n==="html")Li(t.ownerDocument.documentElement);else if(n==="head"){n=t.ownerDocument.head,Li(n);for(var c=n.firstChild;c;){var d=c.nextSibling,g=c.nodeName;c[Pl]||g==="SCRIPT"||g==="STYLE"||g==="LINK"&&c.rel.toLowerCase()==="stylesheet"||n.removeChild(c),c=d}}else n==="body"&&Li(t.ownerDocument.body);n=l}while(n);Zl(e)}function Xd(t,e){var n=t;t=0;do{var a=n.nextSibling;if(n.nodeType===1?e?(n._stashedDisplay=n.style.display,n.style.display="none"):(n.style.display=n._stashedDisplay||"",n.getAttribute("style")===""&&n.removeAttribute("style")):n.nodeType===3&&(e?(n._stashedText=n.nodeValue,n.nodeValue=""):n.nodeValue=n._stashedText||""),a&&a.nodeType===8)if(n=a.data,n==="/$"){if(t===0)break;t--}else n!=="$"&&n!=="$?"&&n!=="$~"&&n!=="$!"||t++;n=a}while(n)}function Wf(t){var e=t.firstChild;for(e&&e.nodeType===10&&(e=e.nextSibling);e;){var n=e;switch(e=e.nextSibling,n.nodeName){case"HTML":case"HEAD":case"BODY":Wf(n),es(n);continue;case"SCRIPT":case"STYLE":continue;case"LINK":if(n.rel.toLowerCase()==="stylesheet")continue}t.removeChild(n)}}function eg(t,e,n,a){for(;t.nodeType===1;){var l=n;if(t.nodeName.toLowerCase()!==e.toLowerCase()){if(!a&&(t.nodeName!=="INPUT"||t.type!=="hidden"))break}else if(a){if(!t[Pl])switch(e){case"meta":if(!t.hasAttribute("itemprop"))break;return t;case"link":if(c=t.getAttribute("rel"),c==="stylesheet"&&t.hasAttribute("data-precedence"))break;if(c!==l.rel||t.getAttribute("href")!==(l.href==null||l.href===""?null:l.href)||t.getAttribute("crossorigin")!==(l.crossOrigin==null?null:l.crossOrigin)||t.getAttribute("title")!==(l.title==null?null:l.title))break;return t;case"style":if(t.hasAttribute("data-precedence"))break;return t;case"script":if(c=t.getAttribute("src"),(c!==(l.src==null?null:l.src)||t.getAttribute("type")!==(l.type==null?null:l.type)||t.getAttribute("crossorigin")!==(l.crossOrigin==null?null:l.crossOrigin))&&c&&t.hasAttribute("async")&&!t.hasAttribute("itemprop"))break;return t;default:return t}}else if(e==="input"&&t.type==="hidden"){var c=l.name==null?null:""+l.name;if(l.type==="hidden"&&t.getAttribute("name")===c)return t}else return t;if(t=mn(t.nextSibling),t===null)break}return null}function ng(t,e,n){if(e==="")return null;for(;t.nodeType!==3;)if((t.nodeType!==1||t.nodeName!=="INPUT"||t.type!=="hidden")&&!n||(t=mn(t.nextSibling),t===null))return null;return t}function Vd(t,e){for(;t.nodeType!==8;)if((t.nodeType!==1||t.nodeName!=="INPUT"||t.type!=="hidden")&&!e||(t=mn(t.nextSibling),t===null))return null;return t}function $f(t){return t.data==="$?"||t.data==="$~"}function Pf(t){return t.data==="$!"||t.data==="$?"&&t.ownerDocument.readyState!=="loading"}function ag(t,e){var n=t.ownerDocument;if(t.data==="$~")t._reactRetry=e;else if(t.data!=="$?"||n.readyState!=="loading")e();else{var a=function(){e(),n.removeEventListener("DOMContentLoaded",a)};n.addEventListener("DOMContentLoaded",a),t._reactRetry=a}}function mn(t){for(;t!=null;t=t.nextSibling){var e=t.nodeType;if(e===1||e===3)break;if(e===8){if(e=t.data,e==="$"||e==="$!"||e==="$?"||e==="$~"||e==="&"||e==="F!"||e==="F")break;if(e==="/$"||e==="/&")return null}}return t}var tr=null;function Qd(t){t=t.nextSibling;for(var e=0;t;){if(t.nodeType===8){var n=t.data;if(n==="/$"||n==="/&"){if(e===0)return mn(t.nextSibling);e--}else n!=="$"&&n!=="$!"&&n!=="$?"&&n!=="$~"&&n!=="&"||e++}t=t.nextSibling}return null}function Fd(t){t=t.previousSibling;for(var e=0;t;){if(t.nodeType===8){var n=t.data;if(n==="$"||n==="$!"||n==="$?"||n==="$~"||n==="&"){if(e===0)return t;e--}else n!=="/$"&&n!=="/&"||e++}t=t.previousSibling}return null}function Kd(t,e,n){switch(e=lc(n),t){case"html":if(t=e.documentElement,!t)throw Error(s(452));return t;case"head":if(t=e.head,!t)throw Error(s(453));return t;case"body":if(t=e.body,!t)throw Error(s(454));return t;default:throw Error(s(451))}}function Li(t){for(var e=t.attributes;e.length;)t.removeAttributeNode(e[0]);es(t)}var yn=new Map,Jd=new Set;function ic(t){return typeof t.getRootNode=="function"?t.getRootNode():t.nodeType===9?t:t.ownerDocument}var In=V.d;V.d={f:lg,r:ig,D:ug,C:cg,L:sg,m:fg,X:og,S:rg,M:dg};function lg(){var t=In.f(),e=Iu();return t||e}function ig(t){var e=cl(t);e!==null&&e.tag===5&&e.type==="form"?o2(e):In.r(t)}var Yl=typeof document>"u"?null:document;function kd(t,e,n){var a=Yl;if(a&&typeof e=="string"&&e){var l=cn(e);l='link[rel="'+t+'"][href="'+l+'"]',typeof n=="string"&&(l+='[crossorigin="'+n+'"]'),Jd.has(l)||(Jd.add(l),t={rel:t,crossOrigin:n,href:e},a.querySelector(l)===null&&(e=a.createElement("link"),ze(e,"link",t),be(e),a.head.appendChild(e)))}}function ug(t){In.D(t),kd("dns-prefetch",t,null)}function cg(t,e){In.C(t,e),kd("preconnect",t,e)}function sg(t,e,n){In.L(t,e,n);var a=Yl;if(a&&t&&e){var l='link[rel="preload"][as="'+cn(e)+'"]';e==="image"&&n&&n.imageSrcSet?(l+='[imagesrcset="'+cn(n.imageSrcSet)+'"]',typeof n.imageSizes=="string"&&(l+='[imagesizes="'+cn(n.imageSizes)+'"]')):l+='[href="'+cn(t)+'"]';var c=l;switch(e){case"style":c=Gl(t);break;case"script":c=ql(t)}yn.has(c)||(t=p({rel:"preload",href:e==="image"&&n&&n.imageSrcSet?void 0:t,as:e},n),yn.set(c,t),a.querySelector(l)!==null||e==="style"&&a.querySelector(Hi(c))||e==="script"&&a.querySelector(ji(c))||(e=a.createElement("link"),ze(e,"link",t),be(e),a.head.appendChild(e)))}}function fg(t,e){In.m(t,e);var n=Yl;if(n&&t){var a=e&&typeof e.as=="string"?e.as:"script",l='link[rel="modulepreload"][as="'+cn(a)+'"][href="'+cn(t)+'"]',c=l;switch(a){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":c=ql(t)}if(!yn.has(c)&&(t=p({rel:"modulepreload",href:t},e),yn.set(c,t),n.querySelector(l)===null)){switch(a){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":if(n.querySelector(ji(c)))return}a=n.createElement("link"),ze(a,"link",t),be(a),n.head.appendChild(a)}}}function rg(t,e,n){In.S(t,e,n);var a=Yl;if(a&&t){var l=sl(a).hoistableStyles,c=Gl(t);e=e||"default";var d=l.get(c);if(!d){var g={loading:0,preload:null};if(d=a.querySelector(Hi(c)))g.loading=5;else{t=p({rel:"stylesheet",href:t,"data-precedence":e},n),(n=yn.get(c))&&er(t,n);var S=d=a.createElement("link");be(S),ze(S,"link",t),S._p=new Promise(function(M,q){S.onload=M,S.onerror=q}),S.addEventListener("load",function(){g.loading|=1}),S.addEventListener("error",function(){g.loading|=2}),g.loading|=4,uc(d,e,a)}d={type:"stylesheet",instance:d,count:1,state:g},l.set(c,d)}}}function og(t,e){In.X(t,e);var n=Yl;if(n&&t){var a=sl(n).hoistableScripts,l=ql(t),c=a.get(l);c||(c=n.querySelector(ji(l)),c||(t=p({src:t,async:!0},e),(e=yn.get(l))&&nr(t,e),c=n.createElement("script"),be(c),ze(c,"link",t),n.head.appendChild(c)),c={type:"script",instance:c,count:1,state:null},a.set(l,c))}}function dg(t,e){In.M(t,e);var n=Yl;if(n&&t){var a=sl(n).hoistableScripts,l=ql(t),c=a.get(l);c||(c=n.querySelector(ji(l)),c||(t=p({src:t,async:!0,type:"module"},e),(e=yn.get(l))&&nr(t,e),c=n.createElement("script"),be(c),ze(c,"link",t),n.head.appendChild(c)),c={type:"script",instance:c,count:1,state:null},a.set(l,c))}}function Id(t,e,n,a){var l=(l=L.current)?ic(l):null;if(!l)throw Error(s(446));switch(t){case"meta":case"title":return null;case"style":return typeof n.precedence=="string"&&typeof n.href=="string"?(e=Gl(n.href),n=sl(l).hoistableStyles,a=n.get(e),a||(a={type:"style",instance:null,count:0,state:null},n.set(e,a)),a):{type:"void",instance:null,count:0,state:null};case"link":if(n.rel==="stylesheet"&&typeof n.href=="string"&&typeof n.precedence=="string"){t=Gl(n.href);var c=sl(l).hoistableStyles,d=c.get(t);if(d||(l=l.ownerDocument||l,d={type:"stylesheet",instance:null,count:0,state:{loading:0,preload:null}},c.set(t,d),(c=l.querySelector(Hi(t)))&&!c._p&&(d.instance=c,d.state.loading=5),yn.has(t)||(n={rel:"preload",as:"style",href:n.href,crossOrigin:n.crossOrigin,integrity:n.integrity,media:n.media,hrefLang:n.hrefLang,referrerPolicy:n.referrerPolicy},yn.set(t,n),c||hg(l,t,n,d.state))),e&&a===null)throw Error(s(528,""));return d}if(e&&a!==null)throw Error(s(529,""));return null;case"script":return e=n.async,n=n.src,typeof n=="string"&&e&&typeof e!="function"&&typeof e!="symbol"?(e=ql(n),n=sl(l).hoistableScripts,a=n.get(e),a||(a={type:"script",instance:null,count:0,state:null},n.set(e,a)),a):{type:"void",instance:null,count:0,state:null};default:throw Error(s(444,t))}}function Gl(t){return'href="'+cn(t)+'"'}function Hi(t){return'link[rel="stylesheet"]['+t+"]"}function Wd(t){return p({},t,{"data-precedence":t.precedence,precedence:null})}function hg(t,e,n,a){t.querySelector('link[rel="preload"][as="style"]['+e+"]")?a.loading=1:(e=t.createElement("link"),a.preload=e,e.addEventListener("load",function(){return a.loading|=1}),e.addEventListener("error",function(){return a.loading|=2}),ze(e,"link",n),be(e),t.head.appendChild(e))}function ql(t){return'[src="'+cn(t)+'"]'}function ji(t){return"script[async]"+t}function $d(t,e,n){if(e.count++,e.instance===null)switch(e.type){case"style":var a=t.querySelector('style[data-href~="'+cn(n.href)+'"]');if(a)return e.instance=a,be(a),a;var l=p({},n,{"data-href":n.href,"data-precedence":n.precedence,href:null,precedence:null});return a=(t.ownerDocument||t).createElement("style"),be(a),ze(a,"style",l),uc(a,n.precedence,t),e.instance=a;case"stylesheet":l=Gl(n.href);var c=t.querySelector(Hi(l));if(c)return e.state.loading|=4,e.instance=c,be(c),c;a=Wd(n),(l=yn.get(l))&&er(a,l),c=(t.ownerDocument||t).createElement("link"),be(c);var d=c;return d._p=new Promise(function(g,S){d.onload=g,d.onerror=S}),ze(c,"link",a),e.state.loading|=4,uc(c,n.precedence,t),e.instance=c;case"script":return c=ql(n.src),(l=t.querySelector(ji(c)))?(e.instance=l,be(l),l):(a=n,(l=yn.get(c))&&(a=p({},n),nr(a,l)),t=t.ownerDocument||t,l=t.createElement("script"),be(l),ze(l,"link",a),t.head.appendChild(l),e.instance=l);case"void":return null;default:throw Error(s(443,e.type))}else e.type==="stylesheet"&&(e.state.loading&4)===0&&(a=e.instance,e.state.loading|=4,uc(a,n.precedence,t));return e.instance}function uc(t,e,n){for(var a=n.querySelectorAll('link[rel="stylesheet"][data-precedence],style[data-precedence]'),l=a.length?a[a.length-1]:null,c=l,d=0;d<a.length;d++){var g=a[d];if(g.dataset.precedence===e)c=g;else if(c!==l)break}c?c.parentNode.insertBefore(t,c.nextSibling):(e=n.nodeType===9?n.head:n,e.insertBefore(t,e.firstChild))}function er(t,e){t.crossOrigin==null&&(t.crossOrigin=e.crossOrigin),t.referrerPolicy==null&&(t.referrerPolicy=e.referrerPolicy),t.title==null&&(t.title=e.title)}function nr(t,e){t.crossOrigin==null&&(t.crossOrigin=e.crossOrigin),t.referrerPolicy==null&&(t.referrerPolicy=e.referrerPolicy),t.integrity==null&&(t.integrity=e.integrity)}var cc=null;function Pd(t,e,n){if(cc===null){var a=new Map,l=cc=new Map;l.set(n,a)}else l=cc,a=l.get(n),a||(a=new Map,l.set(n,a));if(a.has(t))return a;for(a.set(t,null),n=n.getElementsByTagName(t),l=0;l<n.length;l++){var c=n[l];if(!(c[Pl]||c[we]||t==="link"&&c.getAttribute("rel")==="stylesheet")&&c.namespaceURI!=="http://www.w3.org/2000/svg"){var d=c.getAttribute(e)||"";d=t+d;var g=a.get(d);g?g.push(c):a.set(d,[c])}}return a}function t1(t,e,n){t=t.ownerDocument||t,t.head.insertBefore(n,e==="title"?t.querySelector("head > title"):null)}function mg(t,e,n){if(n===1||e.itemProp!=null)return!1;switch(t){case"meta":case"title":return!0;case"style":if(typeof e.precedence!="string"||typeof e.href!="string"||e.href==="")break;return!0;case"link":if(typeof e.rel!="string"||typeof e.href!="string"||e.href===""||e.onLoad||e.onError)break;switch(e.rel){case"stylesheet":return t=e.disabled,typeof e.precedence=="string"&&t==null;default:return!0}case"script":if(e.async&&typeof e.async!="function"&&typeof e.async!="symbol"&&!e.onLoad&&!e.onError&&e.src&&typeof e.src=="string")return!0}return!1}function e1(t){return!(t.type==="stylesheet"&&(t.state.loading&3)===0)}function yg(t,e,n,a){if(n.type==="stylesheet"&&(typeof a.media!="string"||matchMedia(a.media).matches!==!1)&&(n.state.loading&4)===0){if(n.instance===null){var l=Gl(a.href),c=e.querySelector(Hi(l));if(c){e=c._p,e!==null&&typeof e=="object"&&typeof e.then=="function"&&(t.count++,t=sc.bind(t),e.then(t,t)),n.state.loading|=4,n.instance=c,be(c);return}c=e.ownerDocument||e,a=Wd(a),(l=yn.get(l))&&er(a,l),c=c.createElement("link"),be(c);var d=c;d._p=new Promise(function(g,S){d.onload=g,d.onerror=S}),ze(c,"link",a),n.instance=c}t.stylesheets===null&&(t.stylesheets=new Map),t.stylesheets.set(n,e),(e=n.state.preload)&&(n.state.loading&3)===0&&(t.count++,n=sc.bind(t),e.addEventListener("load",n),e.addEventListener("error",n))}}var ar=0;function gg(t,e){return t.stylesheets&&t.count===0&&rc(t,t.stylesheets),0<t.count||0<t.imgCount?function(n){var a=setTimeout(function(){if(t.stylesheets&&rc(t,t.stylesheets),t.unsuspend){var c=t.unsuspend;t.unsuspend=null,c()}},6e4+e);0<t.imgBytes&&ar===0&&(ar=62500*Iy());var l=setTimeout(function(){if(t.waitingForImages=!1,t.count===0&&(t.stylesheets&&rc(t,t.stylesheets),t.unsuspend)){var c=t.unsuspend;t.unsuspend=null,c()}},(t.imgBytes>ar?50:800)+e);return t.unsuspend=n,function(){t.unsuspend=null,clearTimeout(a),clearTimeout(l)}}:null}function sc(){if(this.count--,this.count===0&&(this.imgCount===0||!this.waitingForImages)){if(this.stylesheets)rc(this,this.stylesheets);else if(this.unsuspend){var t=this.unsuspend;this.unsuspend=null,t()}}}var fc=null;function rc(t,e){t.stylesheets=null,t.unsuspend!==null&&(t.count++,fc=new Map,e.forEach(vg,t),fc=null,sc.call(t))}function vg(t,e){if(!(e.state.loading&4)){var n=fc.get(t);if(n)var a=n.get(null);else{n=new Map,fc.set(t,n);for(var l=t.querySelectorAll("link[data-precedence],style[data-precedence]"),c=0;c<l.length;c++){var d=l[c];(d.nodeName==="LINK"||d.getAttribute("media")!=="not all")&&(n.set(d.dataset.precedence,d),a=d)}a&&n.set(null,a)}l=e.instance,d=l.getAttribute("data-precedence"),c=n.get(d)||a,c===a&&n.set(null,l),n.set(d,l),this.count++,a=sc.bind(this),l.addEventListener("load",a),l.addEventListener("error",a),c?c.parentNode.insertBefore(l,c.nextSibling):(t=t.nodeType===9?t.head:t,t.insertBefore(l,t.firstChild)),e.state.loading|=4}}var Bi={$$typeof:$,Provider:null,Consumer:null,_currentValue:lt,_currentValue2:lt,_threadCount:0};function _g(t,e,n,a,l,c,d,g,S){this.tag=1,this.containerInfo=t,this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.callbackNode=this.next=this.pendingContext=this.context=this.cancelPendingCommit=null,this.callbackPriority=0,this.expirationTimes=Wc(-1),this.entangledLanes=this.shellSuspendCounter=this.errorRecoveryDisabledLanes=this.expiredLanes=this.warmLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=Wc(0),this.hiddenUpdates=Wc(null),this.identifierPrefix=a,this.onUncaughtError=l,this.onCaughtError=c,this.onRecoverableError=d,this.pooledCache=null,this.pooledCacheLanes=0,this.formState=S,this.incompleteTransitions=new Map}function n1(t,e,n,a,l,c,d,g,S,M,q,K){return t=new _g(t,e,n,d,S,M,q,K,g),e=1,c===!0&&(e|=24),c=We(3,null,null,e),t.current=c,c.stateNode=t,e=Ls(),e.refCount++,t.pooledCache=e,e.refCount++,c.memoizedState={element:a,isDehydrated:n,cache:e},Ys(c),t}function a1(t){return t?(t=_l,t):_l}function l1(t,e,n,a,l,c){l=a1(l),a.context===null?a.context=l:a.pendingContext=l,a=ra(e),a.payload={element:n},c=c===void 0?null:c,c!==null&&(a.callback=c),n=oa(t,a,e),n!==null&&(Je(n,t,e),gi(n,t,e))}function i1(t,e){if(t=t.memoizedState,t!==null&&t.dehydrated!==null){var n=t.retryLane;t.retryLane=n!==0&&n<e?n:e}}function lr(t,e){i1(t,e),(t=t.alternate)&&i1(t,e)}function u1(t){if(t.tag===13||t.tag===31){var e=Ya(t,67108864);e!==null&&Je(e,t,67108864),lr(t,67108864)}}function c1(t){if(t.tag===13||t.tag===31){var e=nn();e=$c(e);var n=Ya(t,e);n!==null&&Je(n,t,e),lr(t,e)}}var oc=!0;function pg(t,e,n,a){var l=N.T;N.T=null;var c=V.p;try{V.p=2,ir(t,e,n,a)}finally{V.p=c,N.T=l}}function bg(t,e,n,a){var l=N.T;N.T=null;var c=V.p;try{V.p=8,ir(t,e,n,a)}finally{V.p=c,N.T=l}}function ir(t,e,n,a){if(oc){var l=ur(a);if(l===null)Qf(t,e,a,dc,n),f1(t,a);else if(Eg(l,t,e,n,a))a.stopPropagation();else if(f1(t,a),e&4&&-1<Sg.indexOf(t)){for(;l!==null;){var c=cl(l);if(c!==null)switch(c.tag){case 3:if(c=c.stateNode,c.current.memoizedState.isDehydrated){var d=pn(c.pendingLanes);if(d!==0){var g=c;for(g.pendingLanes|=2,g.entangledLanes|=2;d;){var S=1<<31-F(d);g.entanglements[1]|=S,d&=~S}zn(c),(Bt&6)===0&&(Ju=xe()+500,Mi(0))}}break;case 31:case 13:g=Ya(c,2),g!==null&&Je(g,c,2),Iu(),lr(c,2)}if(c=ur(a),c===null&&Qf(t,e,a,dc,n),c===l)break;l=c}l!==null&&a.stopPropagation()}else Qf(t,e,a,null,n)}}function ur(t){return t=cs(t),cr(t)}var dc=null;function cr(t){if(dc=null,t=ul(t),t!==null){var e=o(t);if(e===null)t=null;else{var n=e.tag;if(n===13){if(t=h(e),t!==null)return t;t=null}else if(n===31){if(t=v(e),t!==null)return t;t=null}else if(n===3){if(e.stateNode.current.memoizedState.isDehydrated)return e.tag===3?e.stateNode.containerInfo:null;t=null}else e!==t&&(t=null)}}return dc=t,null}function s1(t){switch(t){case"beforetoggle":case"cancel":case"click":case"close":case"contextmenu":case"copy":case"cut":case"auxclick":case"dblclick":case"dragend":case"dragstart":case"drop":case"focusin":case"focusout":case"input":case"invalid":case"keydown":case"keypress":case"keyup":case"mousedown":case"mouseup":case"paste":case"pause":case"play":case"pointercancel":case"pointerdown":case"pointerup":case"ratechange":case"reset":case"resize":case"seeked":case"submit":case"toggle":case"touchcancel":case"touchend":case"touchstart":case"volumechange":case"change":case"selectionchange":case"textInput":case"compositionstart":case"compositionend":case"compositionupdate":case"beforeblur":case"afterblur":case"beforeinput":case"blur":case"fullscreenchange":case"focus":case"hashchange":case"popstate":case"select":case"selectstart":return 2;case"drag":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"mousemove":case"mouseout":case"mouseover":case"pointermove":case"pointerout":case"pointerover":case"scroll":case"touchmove":case"wheel":case"mouseenter":case"mouseleave":case"pointerenter":case"pointerleave":return 8;case"message":switch(al()){case ll:return 2;case _e:return 8;case ea:case Jc:return 32;case Wl:return 268435456;default:return 32}default:return 32}}var sr=!1,Ea=null,Ta=null,Aa=null,Yi=new Map,Gi=new Map,xa=[],Sg="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset".split(" ");function f1(t,e){switch(t){case"focusin":case"focusout":Ea=null;break;case"dragenter":case"dragleave":Ta=null;break;case"mouseover":case"mouseout":Aa=null;break;case"pointerover":case"pointerout":Yi.delete(e.pointerId);break;case"gotpointercapture":case"lostpointercapture":Gi.delete(e.pointerId)}}function qi(t,e,n,a,l,c){return t===null||t.nativeEvent!==c?(t={blockedOn:e,domEventName:n,eventSystemFlags:a,nativeEvent:c,targetContainers:[l]},e!==null&&(e=cl(e),e!==null&&u1(e)),t):(t.eventSystemFlags|=a,e=t.targetContainers,l!==null&&e.indexOf(l)===-1&&e.push(l),t)}function Eg(t,e,n,a,l){switch(e){case"focusin":return Ea=qi(Ea,t,e,n,a,l),!0;case"dragenter":return Ta=qi(Ta,t,e,n,a,l),!0;case"mouseover":return Aa=qi(Aa,t,e,n,a,l),!0;case"pointerover":var c=l.pointerId;return Yi.set(c,qi(Yi.get(c)||null,t,e,n,a,l)),!0;case"gotpointercapture":return c=l.pointerId,Gi.set(c,qi(Gi.get(c)||null,t,e,n,a,l)),!0}return!1}function r1(t){var e=ul(t.target);if(e!==null){var n=o(e);if(n!==null){if(e=n.tag,e===13){if(e=h(n),e!==null){t.blockedOn=e,Ao(t.priority,function(){c1(n)});return}}else if(e===31){if(e=v(n),e!==null){t.blockedOn=e,Ao(t.priority,function(){c1(n)});return}}else if(e===3&&n.stateNode.current.memoizedState.isDehydrated){t.blockedOn=n.tag===3?n.stateNode.containerInfo:null;return}}}t.blockedOn=null}function hc(t){if(t.blockedOn!==null)return!1;for(var e=t.targetContainers;0<e.length;){var n=ur(t.nativeEvent);if(n===null){n=t.nativeEvent;var a=new n.constructor(n.type,n);us=a,n.target.dispatchEvent(a),us=null}else return e=cl(n),e!==null&&u1(e),t.blockedOn=n,!1;e.shift()}return!0}function o1(t,e,n){hc(t)&&n.delete(e)}function Tg(){sr=!1,Ea!==null&&hc(Ea)&&(Ea=null),Ta!==null&&hc(Ta)&&(Ta=null),Aa!==null&&hc(Aa)&&(Aa=null),Yi.forEach(o1),Gi.forEach(o1)}function mc(t,e){t.blockedOn===e&&(t.blockedOn=null,sr||(sr=!0,u.unstable_scheduleCallback(u.unstable_NormalPriority,Tg)))}var yc=null;function d1(t){yc!==t&&(yc=t,u.unstable_scheduleCallback(u.unstable_NormalPriority,function(){yc===t&&(yc=null);for(var e=0;e<t.length;e+=3){var n=t[e],a=t[e+1],l=t[e+2];if(typeof a!="function"){if(cr(a||n)===null)continue;break}var c=cl(n);c!==null&&(t.splice(e,3),e-=3,uf(c,{pending:!0,data:l,method:n.method,action:a},a,l))}}))}function Zl(t){function e(S){return mc(S,t)}Ea!==null&&mc(Ea,t),Ta!==null&&mc(Ta,t),Aa!==null&&mc(Aa,t),Yi.forEach(e),Gi.forEach(e);for(var n=0;n<xa.length;n++){var a=xa[n];a.blockedOn===t&&(a.blockedOn=null)}for(;0<xa.length&&(n=xa[0],n.blockedOn===null);)r1(n),n.blockedOn===null&&xa.shift();if(n=(t.ownerDocument||t).$$reactFormReplay,n!=null)for(a=0;a<n.length;a+=3){var l=n[a],c=n[a+1],d=l[Ze]||null;if(typeof c=="function")d||d1(n);else if(d){var g=null;if(c&&c.hasAttribute("formAction")){if(l=c,d=c[Ze]||null)g=d.formAction;else if(cr(l)!==null)continue}else g=d.action;typeof g=="function"?n[a+1]=g:(n.splice(a,3),a-=3),d1(n)}}}function h1(){function t(c){c.canIntercept&&c.info==="react-transition"&&c.intercept({handler:function(){return new Promise(function(d){return l=d})},focusReset:"manual",scroll:"manual"})}function e(){l!==null&&(l(),l=null),a||setTimeout(n,20)}function n(){if(!a&&!navigation.transition){var c=navigation.currentEntry;c&&c.url!=null&&navigation.navigate(c.url,{state:c.getState(),info:"react-transition",history:"replace"})}}if(typeof navigation=="object"){var a=!1,l=null;return navigation.addEventListener("navigate",t),navigation.addEventListener("navigatesuccess",e),navigation.addEventListener("navigateerror",e),setTimeout(n,100),function(){a=!0,navigation.removeEventListener("navigate",t),navigation.removeEventListener("navigatesuccess",e),navigation.removeEventListener("navigateerror",e),l!==null&&(l(),l=null)}}}function fr(t){this._internalRoot=t}gc.prototype.render=fr.prototype.render=function(t){var e=this._internalRoot;if(e===null)throw Error(s(409));var n=e.current,a=nn();l1(n,a,t,e,null,null)},gc.prototype.unmount=fr.prototype.unmount=function(){var t=this._internalRoot;if(t!==null){this._internalRoot=null;var e=t.containerInfo;l1(t.current,2,null,t,null,null),Iu(),e[il]=null}};function gc(t){this._internalRoot=t}gc.prototype.unstable_scheduleHydration=function(t){if(t){var e=To();t={blockedOn:null,target:t,priority:e};for(var n=0;n<xa.length&&e!==0&&e<xa[n].priority;n++);xa.splice(n,0,t),n===0&&r1(t)}};var m1=i.version;if(m1!=="19.2.1")throw Error(s(527,m1,"19.2.1"));V.findDOMNode=function(t){var e=t._reactInternals;if(e===void 0)throw typeof t.render=="function"?Error(s(188)):(t=Object.keys(t).join(","),Error(s(268,t)));return t=y(e),t=t!==null?_(t):null,t=t===null?null:t.stateNode,t};var Ag={bundleType:0,version:"19.2.1",rendererPackageName:"react-dom",currentDispatcherRef:N,reconcilerVersion:"19.2.1"};if(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__<"u"){var vc=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!vc.isDisabled&&vc.supportsFiber)try{Ua=vc.inject(Ag),Y=vc}catch{}}return Xi.createRoot=function(t,e){if(!r(t))throw Error(s(299));var n=!1,a="",l=S2,c=E2,d=T2;return e!=null&&(e.unstable_strictMode===!0&&(n=!0),e.identifierPrefix!==void 0&&(a=e.identifierPrefix),e.onUncaughtError!==void 0&&(l=e.onUncaughtError),e.onCaughtError!==void 0&&(c=e.onCaughtError),e.onRecoverableError!==void 0&&(d=e.onRecoverableError)),e=n1(t,1,!1,null,null,n,a,null,l,c,d,h1),t[il]=e.current,Vf(t),new fr(e)},Xi.hydrateRoot=function(t,e,n){if(!r(t))throw Error(s(299));var a=!1,l="",c=S2,d=E2,g=T2,S=null;return n!=null&&(n.unstable_strictMode===!0&&(a=!0),n.identifierPrefix!==void 0&&(l=n.identifierPrefix),n.onUncaughtError!==void 0&&(c=n.onUncaughtError),n.onCaughtError!==void 0&&(d=n.onCaughtError),n.onRecoverableError!==void 0&&(g=n.onRecoverableError),n.formState!==void 0&&(S=n.formState)),e=n1(t,1,!0,e,n??null,a,l,S,c,d,g,h1),e.context=a1(null),n=e.current,a=nn(),a=$c(a),l=ra(a),l.callback=null,oa(n,l,a),n=a,e.current.lanes=n,$l(e,n),zn(e),t[il]=e.current,Vf(t),new gc(e)},Xi.version="19.2.1",Xi}var A1;function Lg(){if(A1)return dr.exports;A1=1;function u(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(u)}catch(i){console.error(i)}}return u(),dr.exports=Cg(),dr.exports}var Hg=Lg();function jg(){const u=mt.useRef(null),[i]=yh(u);return[i,u]}function yh(u){const[i,f]=mt.useState(new DOMRect(0,0,10,10)),s=mt.useCallback(()=>{const r=u==null?void 0:u.current;r&&f(r.getBoundingClientRect())},[u]);return mt.useLayoutEffect(()=>{const r=u==null?void 0:u.current;if(!r)return;s();const o=new ResizeObserver(s);return o.observe(r),window.addEventListener("resize",s),()=>{o.disconnect(),window.removeEventListener("resize",s)}},[s,u]),[i,s]}function x1(u,i){u&&(i=Pa.getObject(u,i));const[f,s]=mt.useState(i),r=mt.useCallback(o=>{u?Pa.setObject(u,o):s(o)},[u,s]);return mt.useEffect(()=>{if(u){const o=()=>s(Pa.getObject(u,i));return Pa.onChangeEmitter.addEventListener(u,o),()=>Pa.onChangeEmitter.removeEventListener(u,o)}},[i,u]),[f,r]}class Bg{constructor(){this.onChangeEmitter=new EventTarget}getString(i,f){return localStorage[i]||f}setString(i,f){var s;localStorage[i]=f,this.onChangeEmitter.dispatchEvent(new Event(i)),(s=window.saveSettings)==null||s.call(window)}getObject(i,f){if(!localStorage[i])return f;try{return JSON.parse(localStorage[i])}catch{return f}}setObject(i,f){var s;localStorage[i]=JSON.stringify(f),this.onChangeEmitter.dispatchEvent(new Event(i)),(s=window.saveSettings)==null||s.call(window)}}const Pa=new Bg;function Ji(...u){return u.filter(Boolean).join(" ")}function Yg(u){u&&(u!=null&&u.scrollIntoViewIfNeeded?u.scrollIntoViewIfNeeded(!1):u==null||u.scrollIntoView())}const Gg="system",gh="theme",qg=[{label:"Dark mode",value:"dark-mode"},{label:"Light mode",value:"light-mode"},{label:"System",value:"system"}],vh=window.matchMedia("(prefers-color-scheme: dark)");function Zg(){document.playwrightThemeInitialized||(document.playwrightThemeInitialized=!0,document.defaultView.addEventListener("focus",u=>{u.target.document.nodeType===Node.DOCUMENT_NODE&&document.body.classList.remove("inactive")},!1),document.defaultView.addEventListener("blur",u=>{document.body.classList.add("inactive")},!1),Dr(zr()),vh.addEventListener("change",()=>{Dr(zr())}))}const Xg=new Set;function Dr(u){const i=Vg(),f=u==="system"?vh.matches?"dark-mode":"light-mode":u;if(i!==f){i&&document.documentElement.classList.remove(i),document.documentElement.classList.add(f);for(const s of Xg)s(f)}}function zr(){return Pa.getString(gh,Gg)}function Vg(){return document.documentElement.classList.contains("dark-mode")?"dark-mode":document.documentElement.classList.contains("light-mode")?"light-mode":null}function Qg(){const[u,i]=mt.useState(zr());return mt.useEffect(()=>{Pa.setString(gh,u),Dr(u)},[u]),[u,i]}const Fg="data:image/svg+xml,%3csvg%20xmlns='http://www.w3.org/2000/svg'%20viewBox='-10%20-10%20276%20276'%3e%3clinearGradient%20id='a'%20x1='145'%20x2='34'%20y1='253'%20y2='61'%20gradientUnits='userSpaceOnUse'%3e%3cstop%20offset='0'%20stop-color='%231e8e3e'/%3e%3cstop%20offset='1'%20stop-color='%2334a853'/%3e%3c/linearGradient%3e%3clinearGradient%20id='b'%20x1='111'%20x2='222'%20y1='254'%20y2='62'%20gradientUnits='userSpaceOnUse'%3e%3cstop%20offset='0'%20stop-color='%23fcc934'/%3e%3cstop%20offset='1'%20stop-color='%23fbbc04'/%3e%3c/linearGradient%3e%3clinearGradient%20id='c'%20x1='17'%20x2='239'%20y1='80'%20y2='80'%20gradientUnits='userSpaceOnUse'%3e%3cstop%20offset='0'%20stop-color='%23d93025'/%3e%3cstop%20offset='1'%20stop-color='%23ea4335'/%3e%3c/linearGradient%3e%3ccircle%20cx='128'%20cy='128'%20r='64'%20fill='%23fff'/%3e%3cpath%20fill='url(%23a)'%20d='M96%20183.4A63.7%2063.7%200%200%201%2072.6%20160L17.2%2064A128%20128%200%200%200%20128%20256l55.4-96A64%2064%200%200%201%2096%20183.4Z'/%3e%3cpath%20fill='url(%23b)'%20d='M192%20128a63.7%2063.7%200%200%201-8.6%2032L128%20256A128%20128%200%200%200%20238.9%2064h-111a64%2064%200%200%201%2064%2064Z'/%3e%3ccircle%20cx='128'%20cy='128'%20r='52'%20fill='%231a73e8'/%3e%3cpath%20fill='url(%23c)'%20d='M96%2072.6a63.7%2063.7%200%200%201%2032-8.6h110.8a128%20128%200%200%200-221.7%200l55.5%2096A64%2064%200%200%201%2096%2072.6Z'/%3e%3c/svg%3e",Kg="data:image/svg+xml,%3csvg%20xmlns='http://www.w3.org/2000/svg'%20fill='%23fff'%20viewBox='-190%20-190%205180%205180'%3e%3clinearGradient%20id='a'%20x1='2149'%20x2='4207'%20y1='4638'%20y2='1076'%20gradientUnits='userSpaceOnUse'%3e%3cstop%20offset='0'%20stop-color='%23fcc934'/%3e%3cstop%20offset='1'%20stop-color='%23fbbc04'/%3e%3c/linearGradient%3e%3clinearGradient%20id='b'%20x1='2823'%20x2='-214'%20y1='4031'%20y2='2278'%20gradientUnits='userSpaceOnUse'%3e%3cstop%20offset='0'%20stop-color='%231e8e3e'/%3e%3cstop%20offset='1'%20stop-color='%2334a853'/%3e%3c/linearGradient%3e%3clinearGradient%20id='c'%20x1='371'%20x2='4429'%20y1='1501'%20y2='1501'%20gradientUnits='userSpaceOnUse'%3e%3cstop%20offset='0'%20stop-color='%23d93025'/%3e%3cstop%20offset='1'%20stop-color='%23ea4335'/%3e%3c/linearGradient%3e%3cpath%20fill='%23202124'%20d='M4400%203676c-45%2080-93%20157-145%20228l541-228z'/%3e%3cpath%20d='M2399%203600a1200%201200%200%201%200-1%200z'/%3e%3cpath%20fill='url(%23a)'%20d='M3440%203001%202402%204800a2394%202394%200%200%200%202398-2400c0-421-112-835-323-1200H2400l-2%201a1198%201198%200%200%201%201041%201800z'/%3e%3cpath%20fill='url(%23b)'%20d='M1360%203001%20322%201202a2398%202398%200%200%200%202078%203598l1038-1799v-1a1199%201199%200%200%201-2078%202z'/%3e%3cpath%20fill='%231a73e8'%20d='M2399%203351a950%20950%200%201%200%200-1900%20950%20950%200%200%200%200%201900z'/%3e%3cpath%20fill='url(%23c)'%20d='M2399%201200h2076a2396%202396%200%200%200-4153%202l1038%201800h2a1200%201200%200%200%201%201037-1802z'/%3e%3cpath%20fill='%233c4043'%20d='M1575%202250c0-40%2033-74%2075-74h3149v1500H1649a75%2075%200%200%201-74-75z'/%3e%3cpath%20d='M2442%202883a199%20199%200%200%200%20115-185c1-44-10-87-34-124a244%20244%200%200%200-94-86c-38-20-81-30-125-30h-317v880h334c46%201%2090-10%20131-32a250%20250%200%200%200%20135-220%20216%20216%200%200%200-145-203zm-40%20325c-23%2014-50%2022-76%2021h-226v-286h222c28%200%2055%206%2079%2020a146%20146%200%200%201%2070%20123c0%2024-6%2047-17%2068-13%2022-30%2041-53%2054zm25-444a140%20140%200%200%201-124%2070h-203v-267h209c25%200%2050%207%2071%2020a140%20140%200%200%201%2065%20113c0%2022-6%2044-18%2063zm733-40a296%20296%200%200%200-160-42%20292%20292%200%200%200-264%20171%20389%20389%200%200%200%203%20340%20300%20300%200%200%200%20270%20164%20300%20300%200%200%200%20276-167l3-5-96-48-3%205c-40%2072-100%20110-176%20110a192%20192%200%200%201-168-95%20240%20240%200%200%201-32-112h481l1-4a377%20377%200%200%200-32-200%20277%20277%200%200%200-103-117zm-160%2064c35-1%2070%208%20100%2026%2025%2015%2045%2037%2059%2064%2010%2022%2018%2045%2020%2070h-360c10-44%2031-84%2063-114s74-47%20118-46zm657%20462a76%2076%200%200%201-62-25c-12-15-18-40-18-73v-340h150v-105h-150v-175h-114v175h-108v105h108v364c0%2027%203%2053%2012%2078a160%20160%200%200%200%2094%2090c23%2010%2047%2014%2071%2013%2017%200%2033%200%2050-3%2012-3%2025-7%2037-13l4-1v-115l-9%205c-20%2013-42%2020-65%2020zm656-500a283%20283%200%200%200-200-68c-50%200-100%2010-144%2033-40%2020-76%2051-101%2090l-3%204%2086%2066%203-5c17-26%2040-47%2067-61%2028-15%2060-22%2092-22%2043-2%2085%2013%20118%2040a142%20142%200%200%201%2046%20108v29a418%20418%200%200%200-170-36c-75%200-139%2019-189%2056s-75%2092-75%20160a205%20205%200%200%200%20114%20186%20268%20268%200%200%200%20245-5c30-17%2056-41%2076-70v83h108v-401c0-78-25-141-73-186zm-224%20504c-34%202-67-10-94-30a96%2096%200%200%201-36-79%20108%20108%200%200%201%2040-88c28-22%2070-34%20124-34a315%20315%200%200%201%20155%2042%20198%20198%200%200%201-95%20164c-28%2017-60%2026-94%2025z'/%3e%3c/svg%3e",Jg="data:image/svg+xml,%3csvg%20xmlns='http://www.w3.org/2000/svg'%20viewBox='-10%20-10%20276%20276'%3e%3ccircle%20cx='128'%20cy='128'%20r='64'%20fill='%23fff'/%3e%3cpath%20fill='%23fbbc04'%20d='M96%20183.4A63.7%2063.7%200%200%201%2072.6%20160L17.2%2064A128%20128%200%200%200%20128%20256l55.4-96A64%2064%200%200%201%2096%20183.4Z'/%3e%3cpath%20fill='%23fdd663'%20d='M192%20128a63.7%2063.7%200%200%201-8.6%2032L128%20256A128%20128%200%200%200%20238.9%2064h-111a64%2064%200%200%201%2064%2064Z'/%3e%3ccircle%20cx='128'%20cy='128'%20r='52'%20fill='%23fbbc04'/%3e%3cpath%20fill='%23f29900'%20d='M96%2072.6a63.7%2063.7%200%200%201%2032-8.6h110.8a128%20128%200%200%200-221.7%200l55.5%2096A64%2064%200%200%201%2096%2072.6Z'/%3e%3c/svg%3e",kg="data:image/svg+xml,%3csvg%20xmlns='http://www.w3.org/2000/svg'%20fill='%23fff'%20viewBox='-190%20-190%205180%205180'%3e%3clinearGradient%20id='a'%20x1='2149'%20x2='4207'%20y1='4638'%20y2='1076'%20gradientUnits='userSpaceOnUse'%3e%3cstop%20offset='0'%20stop-color='%23fcc934'/%3e%3cstop%20offset='1'%20stop-color='%23fbbc04'/%3e%3c/linearGradient%3e%3clinearGradient%20id='b'%20x1='2823'%20x2='-214'%20y1='4031'%20y2='2278'%20gradientUnits='userSpaceOnUse'%3e%3cstop%20offset='0'%20stop-color='%231e8e3e'/%3e%3cstop%20offset='1'%20stop-color='%2334a853'/%3e%3c/linearGradient%3e%3clinearGradient%20id='c'%20x1='371'%20x2='4429'%20y1='1501'%20y2='1501'%20gradientUnits='userSpaceOnUse'%3e%3cstop%20offset='0'%20stop-color='%23d93025'/%3e%3cstop%20offset='1'%20stop-color='%23ea4335'/%3e%3c/linearGradient%3e%3cpath%20fill='%23202124'%20d='M4400%203676c-45%2080-93%20157-145%20228l541-228z'/%3e%3cpath%20d='M2399%203600a1200%201200%200%201%200-1%200z'/%3e%3cpath%20fill='url(%23a)'%20d='M3440%203001%202402%204800a2394%202394%200%200%200%202398-2400c0-421-112-835-323-1200H2400l-2%201a1198%201198%200%200%201%201041%201800z'/%3e%3cpath%20fill='url(%23b)'%20d='M1360%203001%20322%201202a2398%202398%200%200%200%202078%203598l1038-1799v-1a1199%201199%200%200%201-2078%202z'/%3e%3cpath%20fill='%231a73e8'%20d='M2399%203351a950%20950%200%201%200%200-1900%20950%20950%200%200%200%200%201900z'/%3e%3cpath%20fill='url(%23c)'%20d='M2399%201200h2076a2396%202396%200%200%200-4153%202l1038%201800h2a1200%201200%200%200%201%201037-1802z'/%3e%3cpath%20fill='%233c4043'%20d='M1987%202326c0-70%200-106%2022-128s57-22%20128-22h2662v1500H2137c-70%200-106%200-128-22s-22-57-22-128z'/%3e%3cpath%20d='M2865%202532a480%20480%200%200%200-236-56h-267v881h267a480%20480%200%200%200%20236-56c66-36%20120-90%20155-155%2037-70%2056-150%2054-229%202-80-17-158-54-229-35-65-90-120-155-156zm-390%2054h154c102%200%20182%2030%20240%2087%2060%2058%2090%20140%2090%20244s-30%20186-90%20244a330%20330%200%200%201-240%2087h-154zm1153%20157a295%20295%200%200%200-158-42c-57%200-112%2016-160%2047-45%2030-81%2073-105%20123-25%2053-38%20110-37%20170%200%2060%2013%20118%2040%20172a302%20302%200%200%200%20270%20163%20300%20300%200%200%200%20276-167l2-6-96-47-2%204c-41%2073-100%20110-176%20110a193%20193%200%200%201-168-95c-20-34-30-72-33-112h482v-4c4-10%205-22%205-33a380%20380%200%200%200-36-168c-23-48-60-87-104-115zm-160%2064c36-2%2070%207%20101%2026%2025%2015%2045%2037%2058%2064%2011%2022%2018%2045%2021%2070h-360c10-44%2030-84%2062-115%2032-30%2075-46%20118-45zm837-87-190%20496-187-493-1-3h-122l251%20634%202%204h110l256-638z'/%3e%3c/svg%3e",gr="data:image/svg+xml,%3csvg%20xmlns='http://www.w3.org/2000/svg'%20viewBox='-10%20-10%20276%20276'%3e%3ccircle%20cx='128'%20cy='128'%20r='64'%20fill='%23fff'/%3e%3cpath%20fill='%23669df6'%20d='M96%20183.4A63.7%2063.7%200%200%201%2072.6%20160L17.2%2064A128%20128%200%200%200%20128%20256l55.4-96A64%2064%200%200%201%2096%20183.4Z'/%3e%3cpath%20fill='%23aecbfa'%20d='M192%20128a63.7%2063.7%200%200%201-8.6%2032L128%20256A128%20128%200%200%200%20238.9%2064h-111a64%2064%200%200%201%2064%2064Z'/%3e%3ccircle%20cx='128'%20cy='128'%20r='52'%20fill='%231a73e8'/%3e%3cpath%20fill='%231967d2'%20d='M96%2072.6a63.7%2063.7%200%200%201%2032-8.6h110.8a128%20128%200%200%200-221.7%200l55.5%2096A64%2064%200%200%201%2096%2072.6Z'/%3e%3c/svg%3e",w1="/assets/firefox-1bWoP6pv.svg",O1="/assets/firefox-beta-k3eOH_eK.svg",Ig="/assets/firefox-nightly-Cp5nfeDT.svg",Wg="/assets/safari-na3_-uQk.svg",_c="data:image/svg+xml,%3csvg%20xmlns='http://www.w3.org/2000/svg'%20xmlns:x='http://www.w3.org/1999/xlink'%20viewBox='0%200%2027600%2027600'%3e%3clinearGradient%20id='a'%20gradientUnits='userSpaceOnUse'/%3e%3clinearGradient%20id='b'%20x1='6870'%20x2='24704'%20y1='18705'%20y2='18705'%20x:href='%23a'%3e%3cstop%20offset='0'%20stop-color='%230c59a4'/%3e%3cstop%20offset='1'%20stop-color='%23114a8b'/%3e%3c/linearGradient%3e%3clinearGradient%20id='c'%20x1='16272'%20x2='5133'%20y1='10968'%20y2='23102'%20x:href='%23a'%3e%3cstop%20offset='0'%20stop-color='%231b9de2'/%3e%3cstop%20offset='.16'%20stop-color='%231595df'/%3e%3cstop%20offset='.67'%20stop-color='%230680d7'/%3e%3cstop%20offset='1'%20stop-color='%230078d4'/%3e%3c/linearGradient%3e%3cradialGradient%20id='d'%20cx='16720'%20cy='18747'%20r='9538'%20x:href='%23a'%3e%3cstop%20offset='.72'%20stop-opacity='0'/%3e%3cstop%20offset='.95'%20stop-opacity='.53'/%3e%3cstop%20offset='1'/%3e%3c/radialGradient%3e%3cradialGradient%20id='e'%20cx='7130'%20cy='19866'%20r='14324'%20gradientTransform='matrix(.14843%20-.98892%20.79688%20.1196%20-8759%2025542)'%20x:href='%23a'%3e%3cstop%20offset='.76'%20stop-opacity='0'/%3e%3cstop%20offset='.95'%20stop-opacity='.5'/%3e%3cstop%20offset='1'/%3e%3c/radialGradient%3e%3cradialGradient%20id='f'%20cx='2523'%20cy='4680'%20r='20243'%20gradientTransform='matrix(-.03715%20.99931%20-2.12836%20-.07913%2013579%203530)'%20x:href='%23a'%3e%3cstop%20offset='0'%20stop-color='%2335c1f1'/%3e%3cstop%20offset='.11'%20stop-color='%2334c1ed'/%3e%3cstop%20offset='.23'%20stop-color='%232fc2df'/%3e%3cstop%20offset='.31'%20stop-color='%232bc3d2'/%3e%3cstop%20offset='.67'%20stop-color='%2336c752'/%3e%3c/radialGradient%3e%3cradialGradient%20id='g'%20cx='24247'%20cy='7758'%20r='9734'%20gradientTransform='matrix(.28109%20.95968%20-.78353%20.22949%2024510%20-16292)'%20x:href='%23a'%3e%3cstop%20offset='0'%20stop-color='%2366eb6e'/%3e%3cstop%20offset='1'%20stop-color='%2366eb6e'%20stop-opacity='0'/%3e%3c/radialGradient%3e%3cpath%20id='h'%20d='M24105%2020053a9345%209345%200%2001-1053%20472%2010202%2010202%200%2001-3590%20646c-4732%200-8855-3255-8855-7432%200-1175%20680-2193%201643-2729-4280%20180-5380%204640-5380%207253%200%207387%206810%208137%208276%208137%20791%200%201984-230%202704-456l130-44a12834%2012834%200%20006660-5282c220-350-168-757-535-565z'/%3e%3cpath%20id='i'%20d='M11571%2025141a7913%207913%200%2001-2273-2137%208145%208145%200%2001-1514-4740%208093%208093%200%20013093-6395%208082%208082%200%20011373-859c312-148%20846-414%201554-404a3236%203236%200%20012569%201297%203184%203184%200%2001636%201866c0-21%202446-7960-8005-7960-4390%200-8004%204166-8004%207820%200%202319%20538%204170%201212%205604a12833%2012833%200%20007684%206757%2012795%2012795%200%20003908%20610c1414%200%202774-233%204045-656a7575%207575%200%2001-6278-803z'/%3e%3cpath%20id='j'%20d='M16231%2015886c-80%20105-330%20250-330%20566%200%20260%20170%20512%20472%20723%201438%201003%204149%20868%204156%20868a5954%205954%200%20003027-839%206147%206147%200%20001133-850%206180%206180%200%20001910-4437c26-2242-796-3732-1133-4392-2120-4141-6694-6525-11668-6525-7011%200-12703%205635-12798%2012620%2047-3654%203679-6605%207996-6605%20350%200%202346%2034%204200%201007%201634%20858%202490%201894%203086%202921%20618%201067%20728%202415%20728%202952s-271%201333-780%201990z'/%3e%3cuse%20fill='url(%23b)'%20x:href='%23h'/%3e%3cuse%20fill='url(%23d)'%20opacity='.35'%20x:href='%23h'/%3e%3cuse%20fill='url(%23c)'%20x:href='%23i'/%3e%3cuse%20fill='url(%23e)'%20opacity='.4'%20x:href='%23i'/%3e%3cuse%20fill='url(%23f)'%20x:href='%23j'/%3e%3cuse%20fill='url(%23g)'%20x:href='%23j'/%3e%3c/svg%3e",R1={chromium:gr,"chromium-headless-shell":gr,"chrome-for-testing":gr,chrome:Fg,"chrome-beta":Kg,"chrome-dev":kg,"chrome-canary":Jg,firefox:w1,"moz-firefox":w1,"firefox-beta":O1,"moz-firefox-beta":O1,"moz-firefox-nightly":Ig,webkit:Wg,msedge:_c,"msedge-beta":_c,"msedge-dev":_c,"msedge-canary":_c},$g=({browserName:u,channel:i})=>{const f=i&&R1[i]?i:u,s=f?R1[f]:void 0;if(s)return O.jsx("img",{className:"browser-icon-img",src:s,alt:"","aria-hidden":"true"});const r=u?u[0].toUpperCase():"?";return O.jsx("span",{className:"browser-icon-fallback","aria-hidden":"true",children:r})},Pg=()=>O.jsx("svg",{viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"2",strokeLinecap:"round",strokeLinejoin:"round","aria-hidden":"true",children:O.jsx("polyline",{points:"15 18 9 12 15 6"})}),tv=()=>O.jsx("svg",{viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"2",strokeLinecap:"round",strokeLinejoin:"round","aria-hidden":"true",children:O.jsx("polyline",{points:"9 18 15 12 9 6"})}),ev=()=>O.jsx("svg",{width:"20",height:"20",viewBox:"0 -960 960 960",style:{fill:"currentColor"},"aria-hidden":"true",children:O.jsx("path",{d:"M240-80q-33 0-56.5-23.5T160-160v-400q0-33 23.5-56.5T240-640h40v-80q0-83 58.5-141.5T480-920q83 0 141.5 58.5T680-720v80h40q33 0 56.5 23.5T800-560v400q0 33-23.5 56.5T720-80H240Zm0-80h480v-400H240v400Zm296.5-143.5Q560-327 560-360t-23.5-56.5Q513-440 480-440t-56.5 23.5Q400-393 400-360t23.5 56.5Q447-280 480-280t56.5-23.5ZM360-640h240v-80q0-50-35-85t-85-35q-50 0-85 35t-35 85v80ZM240-160v-400 400Z"})}),nv=()=>O.jsx("svg",{width:"20",height:"20",viewBox:"0 -960 960 960",style:{fill:"currentColor"},"aria-hidden":"true",children:O.jsx("path",{d:"M240-160h480v-400H240v400Zm296.5-143.5Q560-327 560-360t-23.5-56.5Q513-440 480-440t-56.5 23.5Q400-393 400-360t23.5 56.5Q447-280 480-280t56.5-23.5ZM240-160v-400 400Zm0 80q-33 0-56.5-23.5T160-160v-400q0-33 23.5-56.5T240-640h280v-80q0-83 58.5-141.5T720-920q83 0 141.5 58.5T920-720h-80q0-50-35-85t-85-35q-50 0-85 35t-35 85v80h120q33 0 56.5 23.5T800-560v400q0 33-23.5 56.5T720-80H240Z"})}),av=()=>O.jsx("svg",{width:"20",height:"20",viewBox:"0 -960 960 960",style:{fill:"currentColor"},"aria-hidden":"true",children:O.jsx("path",{d:"M680-80v-120H560v-80h120v-120h80v120h120v80H760v120h-80ZM200-200v-200h80v120h120v80H200Zm0-360v-200h200v80H280v120h-80Zm480 0v-120H560v-80h200v200h-80Z"})}),_h=()=>O.jsx("svg",{width:"20",height:"20",viewBox:"0 -960 960 960",style:{fill:"currentColor"},"aria-hidden":"true",children:O.jsx("path",{d:"M480-320 280-520l56-58 104 104v-326h80v326l104-104 56 58-200 200ZM240-160q-33 0-56.5-23.5T160-240v-120h80v120h480v-120h80v120q0 33-23.5 56.5T720-160H240Z"})}),lv=()=>O.jsxs("svg",{viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"2",strokeLinecap:"round",strokeLinejoin:"round","aria-hidden":"true",children:[O.jsx("polyline",{points:"23 4 23 10 17 10"}),O.jsx("path",{d:"M20.49 15a9 9 0 1 1-2.12-9.36L23 10"})]}),iv=()=>O.jsx("svg",{viewBox:"0 0 16 16",fill:"currentColor","aria-hidden":"true",children:O.jsx("path",{d:"M8 0a8.2 8.2 0 0 1 .701.031C9.444.095 9.99.645 10.16 1.29l.288 1.107c.018.066.079.158.212.224.231.114.454.243.668.386.123.082.233.09.299.071l1.103-.303c.644-.176 1.392.021 1.82.63.27.385.506.792.704 1.218.315.675.111 1.422-.364 1.891l-.814.806c-.049.048-.098.147-.088.294.016.257.016.515 0 .772-.01.147.038.246.088.294l.814.806c.475.469.679 1.216.364 1.891a7.977 7.977 0 0 1-.704 1.217c-.428.61-1.176.807-1.82.63l-1.102-.302c-.067-.019-.177-.011-.3.071a5.909 5.909 0 0 1-.668.386c-.133.066-.194.158-.211.224l-.29 1.106c-.168.646-.715 1.196-1.458 1.26a8.006 8.006 0 0 1-1.402 0c-.743-.064-1.289-.614-1.458-1.26l-.289-1.106c-.018-.066-.079-.158-.212-.224a5.738 5.738 0 0 1-.668-.386c-.123-.082-.233-.09-.299-.071l-1.103.303c-.644.176-1.392-.021-1.82-.63a8.12 8.12 0 0 1-.704-1.218c-.315-.675-.111-1.422.363-1.891l.815-.806c.05-.048.098-.147.088-.294a6.214 6.214 0 0 1 0-.772c.01-.147-.038-.246-.088-.294l-.815-.806C.635 6.045.431 5.298.746 4.623a7.92 7.92 0 0 1 .704-1.217c.428-.61 1.176-.807 1.82-.63l1.102.302c.067.019.177.011.3-.071.214-.143.437-.272.668-.386.133-.066.194-.158.211-.224l.29-1.106C6.009.645 6.556.095 7.299.03 7.53.01 7.764 0 8 0Zm-.571 1.525c-.036.003-.108.036-.137.146l-.289 1.105c-.147.561-.549.967-.998 1.189-.173.086-.34.183-.5.29-.417.278-.97.423-1.529.27l-1.103-.303c-.109-.03-.175.016-.195.045-.22.312-.412.644-.573.99-.014.031-.021.11.059.19l.815.806c.411.406.562.957.53 1.456a4.709 4.709 0 0 0 0 .582c.032.499-.119 1.05-.53 1.456l-.815.806c-.081.08-.073.159-.059.19.162.346.353.677.573.989.02.03.085.076.195.046l1.102-.303c.56-.153 1.113-.008 1.53.27.161.107.328.204.501.29.447.222.85.629.997 1.189l.289 1.105c.029.109.101.143.137.146a6.6 6.6 0 0 0 1.142 0c.036-.003.108-.036.137-.146l.289-1.105c.147-.561.549-.967.998-1.189.173-.086.34-.183.5-.29.417-.278.97-.423 1.529-.27l1.103.303c.109.029.175-.016.195-.045.22-.313.411-.644.573-.99.014-.031.021-.11-.059-.19l-.815-.806c-.411-.406-.562-.957-.53-1.456a4.709 4.709 0 0 0 0-.582c-.032-.499.119-1.05.53-1.456l.815-.806c.081-.08.073-.159.059-.19a6.464 6.464 0 0 0-.573-.989c-.02-.03-.085-.076-.195-.046l-1.102.303c-.56.153-1.113.008-1.53-.27a4.44 4.44 0 0 0-.501-.29c-.447-.222-.85-.629-.997-1.189l-.289-1.105c-.029-.11-.101-.143-.137-.146a6.6 6.6 0 0 0-1.142 0ZM11 8a3 3 0 1 1-6 0 3 3 0 0 1 6 0ZM9.5 8a1.5 1.5 0 1 0-3.001.001A1.5 1.5 0 0 0 9.5 8Z"})});function wc(u){if(!u||!u.naturalWidth||!u.naturalHeight)return null;const i=u.getBoundingClientRect(),f=u.naturalWidth/u.naturalHeight,s=i.width/i.height;if(f>s){const o=i.width/f;return{rect:i,renderW:i.width,renderH:o,offsetX:0,offsetY:(i.height-o)/2}}const r=i.height*f;return{rect:i,renderW:r,renderH:i.height,offsetX:(i.width-r)/2,offsetY:0}}function Nr(u,i,f,s,r){const o=(s-u.rect.left-u.offsetX)/u.renderW,h=(r-u.rect.top-u.offsetY)/u.renderH;return{x:Math.round(o*i),y:Math.round(h*f)}}const ln=Wn.forwardRef(function({children:i,title:f="",icon:s,disabled:r=!1,toggled:o=!1,onClick:h=()=>{},style:v,testId:m,className:y,ariaLabel:_,errorBadge:p},b){const T=Wn.useId();return O.jsxs("button",{ref:b,className:Ji(y,"toolbar-button",s,o&&"toggled"),onMouseDown:D1,onClick:h,onDoubleClick:D1,title:f,disabled:!!r,style:v,"data-testid":m,"aria-label":_||f,"aria-describedby":p?T:void 0,children:[s&&O.jsx("span",{className:`codicon codicon-${s}`,style:i?{marginRight:5}:{}}),i,p&&O.jsx("span",{id:T,className:"toolbar-button-error-badge",title:p,"aria-label":p})]})}),D1=u=>{u.stopPropagation(),u.preventDefault()},uv=({blob:u,blobUrl:i,onSave:f,onClose:s})=>{const r=mt.useCallback(async()=>{await f(u)},[f,u]);return O.jsx("div",{className:"modal-overlay",role:"dialog","aria-modal":"true","aria-label":"Recording preview",children:O.jsxs("div",{className:"modal",children:[O.jsxs("div",{className:"modal-toolbar",children:[O.jsx("div",{className:"modal-title",children:"Recording"}),O.jsx(ln,{title:"Save recording",onClick:r,children:O.jsx(_h,{})}),O.jsx(ln,{title:"Discard",icon:"close",onClick:s})]}),O.jsx("div",{className:"modal-body recording-body",children:O.jsx("video",{className:"recording-video",src:i,controls:!0,autoPlay:!0})})]})})};async function ph(u,i,f,s){if(!u.naturalWidth||!u.naturalHeight||!i||!f)return null;const r=document.createElement("canvas");r.width=u.naturalWidth,r.height=u.naturalHeight;const o=r.getContext("2d");if(!o)return null;o.drawImage(u,0,0,r.width,r.height);const h=r.width/i,v=r.height/f,m=Math.max(11,Math.round(14*v));o.font=`500 ${m}px -apple-system, system-ui, sans-serif`,o.textBaseline="middle";for(const y of s){const[_,p,b]=y.color.split(" ").map(Number),T=`rgb(${_}, ${p}, ${b})`,D=`rgba(${_}, ${p}, ${b}, 0.12)`,G=y.x*h,W=y.y*v,J=y.width*h,Z=y.height*v;if(o.fillStyle=D,o.fillRect(G,W,J,Z),o.lineWidth=Math.max(2,Math.round(2*v)),o.strokeStyle=T,o.strokeRect(G,W,J,Z),y.text){const $=Math.max(4,Math.round(6*v)),I=Math.max(2,Math.round(3*v)),it=o.measureText(y.text).width+$*2,X=m+I*2,et=G-o.lineWidth/2,ut=W-X;o.fillStyle=T,o.fillRect(et,ut,it,X),o.fillStyle="#fff",o.fillText(y.text,et+$,ut+X/2)}}return await new Promise(y=>r.toBlob(y,"image/png"))}async function bh(u,i){var _;const f=new Date().toISOString().replace(/[:.]/g,"-"),s=i??`annotations-${f}.png`,r=(((_=s.match(/\.[^./\\]+$/))==null?void 0:_[0])??".bin").toLowerCase(),o=u.type||{".png":"image/png",".zip":"application/zip"}[r]||"application/octet-stream",h={".png":"PNG image",".zip":"Zip archive"}[r]||"File",v=window.showSaveFilePicker;if(v){try{const b=await(await v({suggestedName:s,startIn:"downloads",types:[{description:h,accept:{[o]:[r]}}]})).createWritable();await b.write(u),await b.close()}catch(p){if((p==null?void 0:p.name)==="AbortError")return!1;throw p}return!0}const m=URL.createObjectURL(u),y=document.createElement("a");return y.href=m,y.download=s,document.body.appendChild(y),y.click(),document.body.removeChild(y),URL.revokeObjectURL(m),!0}const Sh=[{name:"blue",rgb:"54 116 209"},{name:"red",rgb:"229 62 62"},{name:"green",rgb:"56 161 105"},{name:"orange",rgb:"221 107 32"},{name:"purple",rgb:"128 90 213"},{name:"pink",rgb:"213 63 140"}],cv=Sh[0].rgb,sv=["nw","n","ne","e","se","s","sw","w"],z1=4;function fv(){return"ann-"+Math.random().toString(36).slice(2,10)}function N1(u){return{x:Math.min(u.startX,u.x),y:Math.min(u.startY,u.y),width:Math.abs(u.x-u.startX),height:Math.abs(u.y-u.startY)}}function rv(u,i,f,s){let r=u.x,o=u.y,h=u.x+u.width,v=u.y+u.height;switch(i){case"move":r+=f,o+=s,h+=f,v+=s;break;case"nw":r+=f,o+=s;break;case"n":o+=s;break;case"ne":h+=f,o+=s;break;case"e":h+=f;break;case"se":h+=f,v+=s;break;case"s":v+=s;break;case"sw":r+=f,v+=s;break;case"w":r+=f;break}return{x:Math.min(r,h),y:Math.min(o,v),width:Math.abs(h-r),height:Math.abs(v-o)}}function ov(u,i,f,s,r){const o=u.rect.left-i.left+u.offsetX,h=u.rect.top-i.top+u.offsetY;return{left:o+r.x/f*u.renderW,top:h+r.y/s*u.renderH,width:r.width/f*u.renderW,height:r.height/s*u.renderH}}const dv=({color:u,onChange:i})=>O.jsx("div",{className:"annotations-color-picker",role:"radiogroup","aria-label":"Annotation color",children:Sh.map(({name:f,rgb:s})=>O.jsx("button",{type:"button",role:"radio","aria-checked":u===s,title:`Use ${f}`,className:"annotations-color-swatch"+(u===s?" selected":""),style:{"--annotation-color":s},onClick:()=>i(s)},f))}),Eh=mt.forwardRef(({active:u,displayRef:i,screenRef:f,viewportWidth:s,viewportHeight:r,annotations:o,onAnnotationsChange:h,focusAnnotationId:v},m)=>{var k;const[y,_]=mt.useState(null),[p,b]=mt.useState(null),[T,D]=mt.useState(null),[G,W]=mt.useState(cv),[J,Z]=mt.useState(null),[,$]=mt.useState(0),I=mt.useCallback(()=>$(w=>w+1),[]),B=mt.useRef(null),it=mt.useRef(o),X=mt.useRef(v);mt.useLayoutEffect(()=>{it.current=o,X.current=v});const et=(p==null?void 0:p.id)??null,ut=p!=null&&p.editing?p.id:null;mt.useEffect(()=>{if(!u)return;const w=()=>I(),U=i.current,L=()=>I();return window.addEventListener("resize",w),U==null||U.addEventListener("load",L),()=>{window.removeEventListener("resize",w),U==null||U.removeEventListener("load",L)}},[u,i,I]),mt.useEffect(()=>{var w;if(u){const U=X.current;if(U){const L=it.current.find(P=>P.id===U);if(L){Z({...L}),b({id:U,editing:!0});return}}(w=B.current)==null||w.focus()}else b(null)},[u]),mt.useEffect(()=>{if(!T)return;const w=L=>{const P=wc(i.current);if(!P||!s||!r)return;const H=Nr(P,s,r,L.clientX,L.clientY),ht=H.x-T.startVx,Yt=H.y-T.startVy;ht===0&&Yt===0||h(it.current.map(Ft=>Ft.id===T.id?{...Ft,...rv(T.orig,T.kind,ht,Yt)}:Ft))},U=()=>D(null);return window.addEventListener("mousemove",w),window.addEventListener("mouseup",U),()=>{window.removeEventListener("mousemove",w),window.removeEventListener("mouseup",U)}},[T,i,s,r,h]);function st(w){if(!s||!r)return null;const U=wc(i.current);return U?Nr(U,s,r,w.clientX,w.clientY):null}function at(w,U){for(let L=o.length-1;L>=0;L--){const P=o[L];if(w>=P.x&&w<=P.x+P.width&&U>=P.y&&U<=P.y+P.height)return P}}function _t(w){var P;if(w.button!==0)return;(P=B.current)==null||P.focus();const U=st(w);if(!U)return;const L=at(U.x,U.y);if(w.preventDefault(),L){b({id:L.id,editing:!1}),D({kind:"move",id:L.id,orig:{x:L.x,y:L.y,width:L.width,height:L.height},startVx:U.x,startVy:U.y});return}_({startX:U.x,startY:U.y,x:U.x,y:U.y}),b(null)}function pt(w){if(T||!y)return;const U=st(w);U&&(y.x===U.x&&y.y===U.y||_({...y,x:U.x,y:U.y}))}function yt(w){if(!y)return;w.preventDefault();const U=N1(y);if(_(null),U.width<z1||U.height<z1)return;const L=fv();h([...o,{id:L,...U,text:"",color:G}]),b({id:L,editing:!0})}function ot(w,U,L){var H;L.preventDefault(),L.stopPropagation(),(H=B.current)==null||H.focus();const P=st(L);P&&(b({id:U.id,editing:!1}),D({kind:w,id:U.id,orig:{x:U.x,y:U.y,width:U.width,height:U.height},startVx:P.x,startVy:P.y}))}function N(w,U){et&&h(o.map(L=>L.id===et?{...L,x:L.x+w,y:L.y+U}:L))}function V(){var w;b(U=>U!=null&&U.editing?{...U,editing:!1}:U),(w=B.current)==null||w.focus()}function lt(w){if(w.key==="Escape"){w.preventDefault(),y?_(null):ut?V():et&&b(null);return}if((w.key==="Delete"||w.key==="Backspace")&&et&&!ut){w.preventDefault(),h(o.filter(U=>U.id!==et)),b(null);return}if(et&&!ut){const U=w.shiftKey?1:5;if(w.key==="ArrowLeft"){w.preventDefault(),N(-U,0);return}if(w.key==="ArrowRight"){w.preventDefault(),N(U,0);return}if(w.key==="ArrowUp"){w.preventDefault(),N(0,-U);return}if(w.key==="ArrowDown"){w.preventDefault(),N(0,U);return}}}if(mt.useEffect(()=>{ut||Z(null)},[ut]),mt.useImperativeHandle(m,()=>({clearSelection:()=>{_(null),b(null)}}),[]),!u)return null;const rt=wc(i.current),gt=((k=f.current)==null?void 0:k.getBoundingClientRect())??null,E=w=>rt&&gt&&s&&r?ov(rt,gt,s,r,w):null,R=ut?o.find(w=>w.id===ut):void 0;return O.jsxs("div",{ref:B,className:"annotations-layer",tabIndex:0,onMouseDown:_t,onMouseMove:pt,onMouseUp:yt,onKeyDown:lt,onContextMenu:w=>w.preventDefault(),children:[o.map(w=>{const U=E(w);if(!U)return null;const L=w.id===et,P=w.id===ut;return O.jsxs("div",{className:"annotations-rect"+(L?" selected":"")+(P?" editing":"")+(w.text?"":" empty"),style:{...U,"--annotation-color":w.color},onDoubleClick:H=>{H.preventDefault(),H.stopPropagation(),ut!==w.id&&Z({...w}),b({id:w.id,editing:!0})},children:[w.text&&O.jsx("div",{className:"annotations-label",onMouseDown:H=>{H.preventDefault(),H.stopPropagation(),ut!==w.id&&Z({...w}),b({id:w.id,editing:!0})},children:w.text}),L&&!P&&sv.map(H=>O.jsx("div",{className:"annotations-handle annotations-handle-"+H,onMouseDown:ht=>ot(H,w,ht)},H))]},w.id)}),y&&(()=>{const w=E(N1(y));return w?O.jsx("div",{className:"annotations-rect draft",style:{...w,"--annotation-color":G}}):null})(),R&&(()=>{const w=E(R);if(!w)return null;const U={left:w.left,top:w.top+w.height+6,"--annotation-color":R.color};return O.jsxs("div",{className:"annotations-popover",style:U,onMouseDown:L=>L.stopPropagation(),onClick:L=>L.stopPropagation(),children:[O.jsx("textarea",{className:"annotations-textarea",autoFocus:!0,onFocus:L=>{const P=L.target.value.length;L.target.setSelectionRange(P,P)},value:R.text,placeholder:"Task or comment…",onChange:L=>{const P=L.target.value;h(o.map(H=>H.id===R.id?{...H,text:P}:H))},onKeyDown:L=>{(L.key==="Enter"&&!L.shiftKey&&!L.ctrlKey&&!L.metaKey||L.key==="Escape")&&(L.preventDefault(),V()),L.stopPropagation()},onKeyUp:L=>L.stopPropagation()}),O.jsxs("div",{className:"annotations-popover-footer",children:[O.jsx(dv,{color:R.color,onChange:L=>{h(o.map(P=>P.id===R.id?{...P,color:L}:P)),W(L)}}),O.jsx("div",{className:"annotations-popover-actions",children:J?O.jsxs(O.Fragment,{children:[O.jsx("button",{className:"annotations-action-btn",onClick:()=>{var P;const L=J;h(o.map(H=>H.id===L.id?L:H)),b(null),(P=B.current)==null||P.focus()},children:"Cancel"}),O.jsx("button",{className:"annotations-action-btn",onClick:V,children:"Done"})]}):O.jsxs(O.Fragment,{children:[O.jsx("button",{className:"annotations-action-btn danger",onClick:()=>{var L;h(o.filter(P=>P.id!==R.id)),b(null),(L=B.current)==null||L.focus()},children:"Discard"}),O.jsx("button",{className:"annotations-action-btn",onClick:V,children:"Add"})]})})]})]})})()]})});Eh.displayName="Annotations";const hv=({model:u,session:i,onSubmit:f})=>{const[s,r]=mt.useState(!1),[o,h]=mt.useState(null);return O.jsxs("aside",{className:"annotate-sidebar","aria-label":"Annotation screenshots",children:[O.jsx("div",{className:"annotate-sidebar-header dashboard-shell-sidebar-header",children:O.jsx("h2",{className:"dashboard-shell-sidebar-title",children:"UI Review"})}),O.jsx("div",{className:"annotate-sidebar-list",children:i.frames.map(v=>{const m=v.id===i.selectedFrameId,y=v.annotations;return O.jsxs("div",{className:"annotate-sidebar-thumb"+(m?" selected":""),children:[O.jsx("button",{className:"annotate-sidebar-thumb-button",onClick:()=>u.selectAnnotateFrame(v.id),title:`${v.sessionTitle||"session"} · ${v.title||"tab"}
${v.url}`,"aria-pressed":m,children:O.jsxs("span",{className:"annotate-sidebar-thumb-img-wrap",style:{aspectRatio:`${v.viewportWidth} / ${v.viewportHeight}`},children:[O.jsx("img",{className:"annotate-sidebar-thumb-img",alt:"",src:"data:image/png;base64,"+v.data}),v.annotations.map(_=>O.jsx("span",{className:"annotate-sidebar-thumb-rect"+(_.id===o?" hovered":""),style:{left:`${_.x/v.viewportWidth*100}%`,top:`${_.y/v.viewportHeight*100}%`,width:`${_.width/v.viewportWidth*100}%`,height:`${_.height/v.viewportHeight*100}%`,"--annotation-color":_.color}},_.id))]})}),y.length>0&&O.jsx("ul",{className:"annotate-sidebar-comments",children:y.map(_=>O.jsx("li",{children:O.jsx("button",{className:"annotate-sidebar-comment"+(_.text?"":" empty"),style:{"--annotation-color":_.color},onClick:()=>u.selectAnnotateFrame(v.id,_.id),onMouseEnter:()=>h(_.id),onMouseLeave:()=>h(null),title:"Edit comment",children:_.text||"Empty comment"})},_.id))}),O.jsx(ln,{className:"annotate-sidebar-thumb-remove",icon:"close",title:"Remove screenshot",onClick:_=>{_.stopPropagation(),u.removeAnnotateFrame(v.id)}})]},v.id)})}),O.jsx("div",{className:"annotate-sidebar-feedback-wrap","data-value":i.feedback,children:O.jsx("textarea",{className:"annotate-sidebar-feedback",placeholder:"Feedback…",value:i.feedback,onChange:v=>u.updateFeedback(v.target.value)})}),O.jsx("button",{className:"annotate-sidebar-submit",disabled:s,onClick:async()=>{r(!0);try{await f()}finally{r(!1)}},children:s?"Submitting…":"Submit"})]})},mv=({model:u,frame:i,focusAnnotationId:f})=>{const s=mt.useRef(null),r=mt.useRef(null),o=mt.useRef(null),h=mt.useCallback(y=>{u.updateFrameAnnotations(i.id,y)},[u,i.id]),v=mt.useCallback(async()=>{const y=r.current;if(!y)return;const _=await ph(y,i.viewportWidth,i.viewportHeight,i.annotations);if(!_)return;const p=(i.title||i.url||"screenshot").replace(/[^a-z0-9]+/gi,"-").slice(0,40)||"screenshot",b=new Date().toISOString().replace(/[:.]/g,"-");await bh(_,`annotations-${b}-${p}.png`)},[i]),m=mt.useCallback(()=>{var y;u.updateFrameAnnotations(i.id,[]),(y=s.current)==null||y.clearSelection()},[u,i.id]);return O.jsx("div",{className:"annotate-overlay",role:"dialog","aria-label":`Annotate screenshot from ${i.title||i.url||"page"}`,children:O.jsxs("div",{className:"annotate-overlay-window",children:[O.jsxs("div",{className:"annotate-overlay-chrome",children:[O.jsxs("span",{className:"annotate-overlay-titlebar",children:[O.jsx("span",{className:"annotate-overlay-title-text",children:i.title||"untitled"}),O.jsx("span",{className:"annotate-overlay-title-sep",children:"·"}),O.jsx("span",{className:"annotate-overlay-title-url",children:i.url})]}),O.jsx(ln,{title:"Save screenshot",onClick:v,children:O.jsx(_h,{})}),O.jsx(ln,{title:"Clear annotations",icon:"circle-slash",disabled:i.annotations.length===0,onClick:m}),O.jsx(ln,{title:"Done annotating",icon:"check",onClick:()=>u.deselectFrame()})]}),O.jsxs("div",{ref:o,className:"annotate-overlay-canvas",children:[O.jsx("img",{ref:r,className:"annotate-modal-image",alt:"annotation",src:"data:image/png;base64,"+i.data}),O.jsx(Eh,{ref:s,active:!0,displayRef:r,screenRef:o,viewportWidth:i.viewportWidth,viewportHeight:i.viewportHeight,annotations:i.annotations,onAnnotationsChange:h,focusAnnotationId:f})]})]})})},yv=["left","middle","right"];async function gv(u,i,f,s){try{return await(await window.showSaveFilePicker({suggestedName:u,types:[{description:i,accept:{[f]:[s]}}]})).createWritable()}catch{return null}}function vv(u){const i=u.trim();if(!i||/^[a-z][a-z0-9+.-]*:\/\//i.test(i)||i.startsWith("about:")||i.startsWith("data:"))return i;const f=i.split(/[/?#]/,1)[0],s=f.includes("."),r=/^localhost(:\d+)?$/i.test(f),o=/:\d+$/.test(f),h=/^\d{1,3}(\.\d{1,3}){3}(:\d+)?$/.test(f);return r||h||o&&!s?"http://"+i:s||o?"https://"+i:"https://"+f+".com"+i.slice(f.length)}const _v=({model:u})=>{const[,i]=mt.useState(0);mt.useEffect(()=>u.subscribe(()=>i(H=>H+1)),[u]);const{tabs:f,mode:s,recording:r,liveFrame:o,annotateSession:h,pendingCapture:v}=u.state,m=s==="interactive",y=!!h,_=(h==null?void 0:h.frames.find(H=>H.id===h.selectedFrameId))??null,[p,b]=mt.useState(0),T=mt.useRef(null),D=mt.useRef(null),G=mt.useRef(null),W=mt.useRef(null),J=mt.useRef(null),Z=mt.useRef(null),$=mt.useRef(0),I=o&&o.viewportWidth&&o.viewportHeight?o.viewportWidth/o.viewportHeight:null,[B]=yh(W),it=(r==null?void 0:r.phase)!=="recording",X=mt.useMemo(()=>{var Gt;const ht=it?((Gt=J.current)==null?void 0:Gt.offsetHeight)??40:0,Yt=B.width-24,Ft=B.height-24;if(Yt<=0||Ft<=0)return;if(I===null)return{width:Yt,height:Ft};const ae=Ft-ht;let oe=Yt,Jt=oe/I;return Jt>ae&&(Jt=ae,oe=Jt*I),{width:oe,height:Jt+ht}},[B,I,it]);mt.useEffect(()=>{if(p===0)return;const H=Z.current;if(!H)return;H.classList.remove("flash"),H.offsetWidth,H.classList.add("flash");const ht=setTimeout(()=>H.classList.remove("flash"),2e3);return()=>{clearTimeout(ht),H.classList.remove("flash")}},[p]),mt.useEffect(()=>{var H;m&&((H=Z.current)==null||H.classList.remove("flash"))},[m]);function et(){b(H=>H+1)}const ut=mt.useCallback(async H=>{const ht=await gv(`playwright-recording-${Date.now()}.webm`,"WebM Video","video/webm",".webm");ht&&(await ht.write(H),await ht.close(),u.discardRecording())},[u]),st=f==null?void 0:f.find(H=>H.selected),at=!!st,[_t,pt]=mt.useState((st==null?void 0:st.url)??"");mt.useEffect(()=>{pt((st==null?void 0:st.url)??"")},[st==null?void 0:st.url]);function yt(H){const ht=(o==null?void 0:o.viewportWidth)??0,Yt=(o==null?void 0:o.viewportHeight)??0;if(!ht||!Yt)return{x:0,y:0};const Ft=wc(T.current);return Ft?Nr(Ft,ht,Yt,H.clientX,H.clientY):{x:0,y:0}}function ot(H,ht){const{x:Yt,y:Ft}=yt(ht);u[H](Yt,Ft,yv[ht.button]||"left")}function N(H){var ht;if(H.preventDefault(),(ht=D.current)==null||ht.focus(),!!at){if(!m){et();return}ot("mousedown",H)}}function V(H){m&&(H.preventDefault(),ot("mouseup",H))}function lt(H){if(!m)return;const ht=Date.now();if(ht-$.current<32)return;$.current=ht;const{x:Yt,y:Ft}=yt(H);u.mousemove(Yt,Ft)}function rt(H){m&&(H.preventDefault(),u.wheel(H.deltaX,H.deltaY))}function gt(H){m&&(H.preventDefault(),u.keydown(H.key))}function E(H){m&&(H.preventDefault(),u.keyup(H.key))}function R(H){if(H.key==="Enter"){const ht=vv(H.target.value);u.navigate(ht),H.currentTarget.blur()}}const k=st?void 0:"Select a session",w=(r==null?void 0:r.phase)==="recording",U=(r==null?void 0:r.phase)==="stopped",L=y?"Dashboard: annotate":w?"Dashboard: record":"Dashboard",P=!!_;return O.jsxs("main",{className:"dashboard-view"+(m?" interactive":"")+(y?" has-annotate-sidebar":""),"aria-label":L,children:[O.jsxs("div",{className:"dashboard-main",children:[O.jsxs("div",{ref:G,className:"toolbar",hidden:P,children:[O.jsx(ln,{ref:Z,className:"mode-toggle mode-interactive",title:m?"Disable interactive mode":"Enable interactive mode",toggled:m,disabled:!at,onClick:()=>{m?u.toggleInteractive():u.enterInteractive()},children:m?O.jsx(nv,{}):O.jsx(ev,{})}),O.jsx(ln,{className:"mode-annotate",title:y?"Add screenshot":"Take screenshot",disabled:!at||v,onClick:()=>{y?u.addAnnotateFrame():u.enterAnnotate("user")},children:O.jsx(av,{})}),O.jsx(ln,{className:"mode-toggle mode-record",title:w?"Stop recording":"Record video",icon:"record",toggled:w,disabled:!at||U,onClick:()=>{w?u.stopRecording():u.startRecording()},children:w&&O.jsx("span",{className:"mode-record-label",children:"Recording..."})})]}),O.jsx("div",{className:"viewport-wrapper",children:O.jsx("div",{ref:W,className:"viewport-main",children:O.jsxs("div",{className:"browser-window",style:X,children:[it&&O.jsxs("div",{ref:J,className:"browser-chrome",children:[O.jsx("button",{className:"nav-btn",title:"Back","aria-disabled":!m||void 0,onClick:()=>{if(!m){et();return}u.back()},children:O.jsx(Pg,{})}),O.jsx("button",{className:"nav-btn",title:"Forward","aria-disabled":!m||void 0,onClick:()=>{if(!m){et();return}u.forward()},children:O.jsx(tv,{})}),O.jsx("button",{className:"nav-btn",title:"Reload","aria-disabled":!m||void 0,onClick:()=>{if(!m){et();return}u.reload()},children:O.jsx(lv,{})}),O.jsx("div",{className:"omnibox-wrap",children:O.jsx("input",{id:"omnibox",className:"omnibox",type:"text",placeholder:"Search or enter URL",spellCheck:!1,autoComplete:"off",value:_t,onChange:H=>pt(H.target.value),onKeyDown:H=>{m&&R(H)},onFocus:H=>{if(!m){et(),H.target.blur();return}H.target.select()},"aria-disabled":!m||void 0,readOnly:!m})})]}),O.jsx("div",{ref:D,className:"screen",tabIndex:0,style:{display:o?"":"none"},onMouseDown:N,onMouseUp:V,onMouseMove:lt,onWheel:rt,onKeyDown:gt,onKeyUp:E,onContextMenu:H=>H.preventDefault(),children:O.jsx("img",{ref:T,id:"display",className:"display",alt:"screencast",src:o?"data:image/jpeg;base64,"+o.data:void 0})}),k&&O.jsx("div",{className:"screen-overlay"+(o?" has-frame":""),children:O.jsx("span",{children:k})})]})})})]}),_&&O.jsx(mv,{model:u,frame:_,focusAnnotationId:h==null?void 0:h.focusAnnotationId},_.id+((h==null?void 0:h.focusAnnotationId)??"")),h&&O.jsx(hv,{model:u,session:h,onSubmit:()=>u.submitAnnotateSession()}),U&&(r==null?void 0:r.phase)==="stopped"&&O.jsx(uv,{blob:r.blob,blobUrl:r.blobUrl,onSave:ut,onClose:()=>u.discardRecording()})]})},Pi=15,Mr=30,Ur=19,pv=29,Cc=256,Ir=Cc+1+pv,M1=2*Ir+1,Vi=256,bv=7,U1=16,C1=17,L1=18,vr=16,Lc=-1,Sv=1,pc=2,Ev=0,Ql=0,H1=1,Tv=3,ke=4,An=0,Th=1,bc=2,xn=-2,Av=-3,Xl=-5;function Zc(u){return Xc(u.map(([i,f])=>new Array(i).fill(f,0,i)))}function Xc(u){return u.reduce((i,f)=>i.concat(Array.isArray(f)?Xc(f):f),[])}const j1=[0,1,2,3].concat(...Zc([[2,4],[2,5],[4,6],[4,7],[8,8],[8,9],[16,10],[16,11],[32,12],[32,13],[64,14],[64,15],[2,0],[1,16],[1,17],[2,18],[2,19],[4,20],[4,21],[8,22],[8,23],[16,24],[16,25],[32,26],[32,27],[64,28],[64,29]]));function $t(){const u=this;function i(r){const o=u.dyn_tree,h=u.stat_desc.static_tree,v=u.stat_desc.extra_bits,m=u.stat_desc.extra_base,y=u.stat_desc.max_length;let _,p,b,T,D,G,W=0;for(T=0;T<=Pi;T++)r.bl_count[T]=0;for(o[r.heap[r.heap_max]*2+1]=0,_=r.heap_max+1;_<M1;_++)p=r.heap[_],T=o[o[p*2+1]*2+1]+1,T>y&&(T=y,W++),o[p*2+1]=T,!(p>u.max_code)&&(r.bl_count[T]++,D=0,p>=m&&(D=v[p-m]),G=o[p*2],r.opt_len+=G*(T+D),h&&(r.static_len+=G*(h[p*2+1]+D)));if(W!==0){do{for(T=y-1;r.bl_count[T]===0;)T--;r.bl_count[T]--,r.bl_count[T+1]+=2,r.bl_count[y]--,W-=2}while(W>0);for(T=y;T!==0;T--)for(p=r.bl_count[T];p!==0;)b=r.heap[--_],!(b>u.max_code)&&(o[b*2+1]!=T&&(r.opt_len+=(T-o[b*2+1])*o[b*2],o[b*2+1]=T),p--)}}function f(r,o){let h=0;do h|=r&1,r>>>=1,h<<=1;while(--o>0);return h>>>1}function s(r,o,h){const v=[];let m=0,y,_,p;for(y=1;y<=Pi;y++)v[y]=m=m+h[y-1]<<1;for(_=0;_<=o;_++)p=r[_*2+1],p!==0&&(r[_*2]=f(v[p]++,p))}u.build_tree=function(r){const o=u.dyn_tree,h=u.stat_desc.static_tree,v=u.stat_desc.elems;let m,y,_=-1,p;for(r.heap_len=0,r.heap_max=M1,m=0;m<v;m++)o[m*2]!==0?(r.heap[++r.heap_len]=_=m,r.depth[m]=0):o[m*2+1]=0;for(;r.heap_len<2;)p=r.heap[++r.heap_len]=_<2?++_:0,o[p*2]=1,r.depth[p]=0,r.opt_len--,h&&(r.static_len-=h[p*2+1]);for(u.max_code=_,m=Math.floor(r.heap_len/2);m>=1;m--)r.pqdownheap(o,m);p=v;do m=r.heap[1],r.heap[1]=r.heap[r.heap_len--],r.pqdownheap(o,1),y=r.heap[1],r.heap[--r.heap_max]=m,r.heap[--r.heap_max]=y,o[p*2]=o[m*2]+o[y*2],r.depth[p]=Math.max(r.depth[m],r.depth[y])+1,o[m*2+1]=o[y*2+1]=p,r.heap[1]=p++,r.pqdownheap(o,1);while(r.heap_len>=2);r.heap[--r.heap_max]=r.heap[1],i(r),s(o,u.max_code,r.bl_count)}}$t._length_code=[0,1,2,3,4,5,6,7].concat(...Zc([[2,8],[2,9],[2,10],[2,11],[4,12],[4,13],[4,14],[4,15],[8,16],[8,17],[8,18],[8,19],[16,20],[16,21],[16,22],[16,23],[32,24],[32,25],[32,26],[31,27],[1,28]]));$t.base_length=[0,1,2,3,4,5,6,7,8,10,12,14,16,20,24,28,32,40,48,56,64,80,96,112,128,160,192,224,0];$t.base_dist=[0,1,2,3,4,6,8,12,16,24,32,48,64,96,128,192,256,384,512,768,1024,1536,2048,3072,4096,6144,8192,12288,16384,24576];$t.d_code=function(u){return u<256?j1[u]:j1[256+(u>>>7)]};$t.extra_lbits=[0,0,0,0,0,0,0,0,1,1,1,1,2,2,2,2,3,3,3,3,4,4,4,4,5,5,5,5,0];$t.extra_dbits=[0,0,0,0,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13];$t.extra_blbits=[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,3,7];$t.bl_order=[16,17,18,0,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15];function Me(u,i,f,s,r){const o=this;o.static_tree=u,o.extra_bits=i,o.extra_base=f,o.elems=s,o.max_length=r}const xv=[12,140,76,204,44,172,108,236,28,156,92,220,60,188,124,252,2,130,66,194,34,162,98,226,18,146,82,210,50,178,114,242,10,138,74,202,42,170,106,234,26,154,90,218,58,186,122,250,6,134,70,198,38,166,102,230,22,150,86,214,54,182,118,246,14,142,78,206,46,174,110,238,30,158,94,222,62,190,126,254,1,129,65,193,33,161,97,225,17,145,81,209,49,177,113,241,9,137,73,201,41,169,105,233,25,153,89,217,57,185,121,249,5,133,69,197,37,165,101,229,21,149,85,213,53,181,117,245,13,141,77,205,45,173,109,237,29,157,93,221,61,189,125,253,19,275,147,403,83,339,211,467,51,307,179,435,115,371,243,499,11,267,139,395,75,331,203,459,43,299,171,427,107,363,235,491,27,283,155,411,91,347,219,475,59,315,187,443,123,379,251,507,7,263,135,391,71,327,199,455,39,295,167,423,103,359,231,487,23,279,151,407,87,343,215,471,55,311,183,439,119,375,247,503,15,271,143,399,79,335,207,463,47,303,175,431,111,367,239,495,31,287,159,415,95,351,223,479,63,319,191,447,127,383,255,511,0,64,32,96,16,80,48,112,8,72,40,104,24,88,56,120,4,68,36,100,20,84,52,116,3,131,67,195,35,163,99,227],wv=Zc([[144,8],[112,9],[24,7],[8,8]]);Me.static_ltree=Xc(xv.map((u,i)=>[u,wv[i]]));const Ov=[0,16,8,24,4,20,12,28,2,18,10,26,6,22,14,30,1,17,9,25,5,21,13,29,3,19,11,27,7,23],Rv=Zc([[30,5]]);Me.static_dtree=Xc(Ov.map((u,i)=>[u,Rv[i]]));Me.static_l_desc=new Me(Me.static_ltree,$t.extra_lbits,Cc+1,Ir,Pi);Me.static_d_desc=new Me(Me.static_dtree,$t.extra_dbits,0,Mr,Pi);Me.static_bl_desc=new Me(null,$t.extra_blbits,0,Ur,bv);const Dv=9,zv=8;function Nn(u,i,f,s,r){const o=this;o.good_length=u,o.max_lazy=i,o.nice_length=f,o.max_chain=s,o.func=r}const Ah=0,Oc=1,$a=2,Tn=[new Nn(0,0,0,0,Ah),new Nn(4,4,8,4,Oc),new Nn(4,5,16,8,Oc),new Nn(4,6,32,32,Oc),new Nn(4,4,16,16,$a),new Nn(8,16,32,32,$a),new Nn(8,16,128,128,$a),new Nn(8,32,128,256,$a),new Nn(32,128,258,1024,$a),new Nn(32,258,258,4096,$a)],Sc=["need dictionary","stream end","","","stream error","data error","","buffer error","",""],gn=0,Ec=1,Qi=2,Tc=3,Nv=32,_r=42,Ac=113,Fi=666,pr=8,Mv=0,br=1,Uv=2,ee=3,Rc=258,an=Rc+ee+1;function B1(u,i,f,s){const r=u[i*2],o=u[f*2];return r<o||r==o&&s[i]<=s[f]}function Cv(){const u=this;let i,f,s,r,o,h,v,m,y,_,p,b,T,D,G,W,J,Z,$,I,B,it,X,et,ut,st,at,_t,pt,yt,ot,N,V;const lt=new $t,rt=new $t,gt=new $t;u.depth=[];let E,R,k,w,U,L;u.bl_count=[],u.heap=[],ot=[],N=[],V=[];function P(){y=2*o,p[T-1]=0;for(let Y=0;Y<T-1;Y++)p[Y]=0;st=Tn[at].max_lazy,pt=Tn[at].good_length,yt=Tn[at].nice_length,ut=Tn[at].max_chain,B=0,J=0,X=0,Z=et=ee-1,I=0,b=0}function H(){let Y;for(Y=0;Y<Ir;Y++)ot[Y*2]=0;for(Y=0;Y<Mr;Y++)N[Y*2]=0;for(Y=0;Y<Ur;Y++)V[Y*2]=0;ot[Vi*2]=1,u.opt_len=u.static_len=0,R=k=0}function ht(){lt.dyn_tree=ot,lt.stat_desc=Me.static_l_desc,rt.dyn_tree=N,rt.stat_desc=Me.static_d_desc,gt.dyn_tree=V,gt.stat_desc=Me.static_bl_desc,U=0,L=0,w=8,H()}u.pqdownheap=function(Y,tt){const F=u.heap,nt=F[tt];let ct=tt<<1;for(;ct<=u.heap_len&&(ct<u.heap_len&&B1(Y,F[ct+1],F[ct],u.depth)&&ct++,!B1(Y,nt,F[ct],u.depth));)F[tt]=F[ct],tt=ct,ct<<=1;F[tt]=nt};function Yt(Y,tt){let F=-1,nt,ct=Y[1],St=0,wt=7,de=4;ct===0&&(wt=138,de=3),Y[(tt+1)*2+1]=65535;for(let Le=0;Le<=tt;Le++)nt=ct,ct=Y[(Le+1)*2+1],!(++St<wt&&nt==ct)&&(St<de?V[nt*2]+=St:nt!==0?(nt!=F&&V[nt*2]++,V[U1*2]++):St<=10?V[C1*2]++:V[L1*2]++,St=0,F=nt,ct===0?(wt=138,de=3):nt==ct?(wt=6,de=3):(wt=7,de=4))}function Ft(){let Y;for(Yt(ot,lt.max_code),Yt(N,rt.max_code),gt.build_tree(u),Y=Ur-1;Y>=3&&V[$t.bl_order[Y]*2+1]===0;Y--);return u.opt_len+=3*(Y+1)+5+5+4,Y}function ae(Y){u.pending_buf[u.pending++]=Y}function oe(Y){ae(Y&255),ae(Y>>>8&255)}function Jt(Y){ae(Y>>8&255),ae(Y&255&255)}function Gt(Y,tt){let F;const nt=tt;L>vr-nt?(F=Y,U|=F<<L&65535,oe(U),U=F>>>vr-L,L+=nt-vr):(U|=Y<<L&65535,L+=nt)}function kt(Y,tt){const F=Y*2;Gt(tt[F]&65535,tt[F+1]&65535)}function je(Y,tt){let F,nt=-1,ct,St=Y[1],wt=0,de=7,Le=4;for(St===0&&(de=138,Le=3),F=0;F<=tt;F++)if(ct=St,St=Y[(F+1)*2+1],!(++wt<de&&ct==St)){if(wt<Le)do kt(ct,V);while(--wt!==0);else ct!==0?(ct!=nt&&(kt(ct,V),wt--),kt(U1,V),Gt(wt-3,2)):wt<=10?(kt(C1,V),Gt(wt-3,3)):(kt(L1,V),Gt(wt-11,7));wt=0,nt=ct,St===0?(de=138,Le=3):ct==St?(de=6,Le=3):(de=7,Le=4)}}function Be(Y,tt,F){let nt;for(Gt(Y-257,5),Gt(tt-1,5),Gt(F-4,4),nt=0;nt<F;nt++)Gt(V[$t.bl_order[nt]*2+1],3);je(ot,Y-1),je(N,tt-1)}function qe(){L==16?(oe(U),U=0,L=0):L>=8&&(ae(U&255),U>>>=8,L-=8)}function Ce(){Gt(br<<1,3),kt(Vi,Me.static_ltree),qe(),1+w+10-L<9&&(Gt(br<<1,3),kt(Vi,Me.static_ltree),qe()),w=7}function Ae(Y,tt){let F,nt,ct;if(u.dist_buf[R]=Y,u.lc_buf[R]=tt&255,R++,Y===0?ot[tt*2]++:(k++,Y--,ot[($t._length_code[tt]+Cc+1)*2]++,N[$t.d_code(Y)*2]++),(R&8191)===0&&at>2){for(F=R*8,nt=B-J,ct=0;ct<Mr;ct++)F+=N[ct*2]*(5+$t.extra_dbits[ct]);if(F>>>=3,k<Math.floor(R/2)&&F<Math.floor(nt/2))return!0}return R==E-1}function wn(Y,tt){let F,nt,ct=0,St,wt;if(R!==0)do F=u.dist_buf[ct],nt=u.lc_buf[ct],ct++,F===0?kt(nt,Y):(St=$t._length_code[nt],kt(St+Cc+1,Y),wt=$t.extra_lbits[St],wt!==0&&(nt-=$t.base_length[St],Gt(nt,wt)),F--,St=$t.d_code(F),kt(St,tt),wt=$t.extra_dbits[St],wt!==0&&(F-=$t.base_dist[St],Gt(F,wt)));while(ct<R);kt(Vi,Y),w=Y[Vi*2+1]}function nl(){L>8?oe(U):L>0&&ae(U&255),U=0,L=0}function xe(Y,tt,F){nl(),w=8,oe(tt),oe(~tt),u.pending_buf.set(m.subarray(Y,Y+tt),u.pending),u.pending+=tt}function al(Y,tt,F){Gt((Mv<<1)+(F?1:0),3),xe(Y,tt)}function ll(Y,tt,F){let nt,ct,St=0;at>0?(lt.build_tree(u),rt.build_tree(u),St=Ft(),nt=u.opt_len+3+7>>>3,ct=u.static_len+3+7>>>3,ct<=nt&&(nt=ct)):nt=ct=tt+5,tt+4<=nt&&Y!=-1?al(Y,tt,F):ct==nt?(Gt((br<<1)+(F?1:0),3),wn(Me.static_ltree,Me.static_dtree)):(Gt((Uv<<1)+(F?1:0),3),Be(lt.max_code+1,rt.max_code+1,St+1),wn(ot,N)),H(),F&&nl()}function _e(Y){ll(J>=0?J:-1,B-J,Y),J=B,i.flush_pending()}function ea(){let Y,tt,F,nt;do{if(nt=y-X-B,nt===0&&B===0&&X===0)nt=o;else if(nt==-1)nt--;else if(B>=o+o-an){m.set(m.subarray(o,o+o),0),it-=o,B-=o,J-=o,Y=T,F=Y;do tt=p[--F]&65535,p[F]=tt>=o?tt-o:0;while(--Y!==0);Y=o,F=Y;do tt=_[--F]&65535,_[F]=tt>=o?tt-o:0;while(--Y!==0);nt+=o}if(i.avail_in===0)return;Y=i.read_buf(m,B+X,nt),X+=Y,X>=ee&&(b=m[B]&255,b=(b<<W^m[B+1]&255)&G)}while(X<an&&i.avail_in!==0)}function Jc(Y){let tt=65535,F;for(tt>s-5&&(tt=s-5);;){if(X<=1){if(ea(),X===0&&Y==Ql)return gn;if(X===0)break}if(B+=X,X=0,F=J+tt,(B===0||B>=F)&&(X=B-F,B=F,_e(!1),i.avail_out===0)||B-J>=o-an&&(_e(!1),i.avail_out===0))return gn}return _e(Y==ke),i.avail_out===0?Y==ke?Qi:gn:Y==ke?Tc:Ec}function Wl(Y){let tt=ut,F=B,nt,ct,St=et;const wt=B>o-an?B-(o-an):0;let de=yt;const Le=v,pn=B+Rc;let Ca=m[F+St-1],na=m[F+St];et>=pt&&(tt>>=2),de>X&&(de=X);do if(nt=Y,!(m[nt+St]!=na||m[nt+St-1]!=Ca||m[nt]!=m[F]||m[++nt]!=m[F+1])){F+=2,nt++;do;while(m[++F]==m[++nt]&&m[++F]==m[++nt]&&m[++F]==m[++nt]&&m[++F]==m[++nt]&&m[++F]==m[++nt]&&m[++F]==m[++nt]&&m[++F]==m[++nt]&&m[++F]==m[++nt]&&F<pn);if(ct=Rc-(pn-F),F=pn-Rc,ct>St){if(it=Y,St=ct,ct>=de)break;Ca=m[F+St-1],na=m[F+St]}}while((Y=_[Y&Le]&65535)>wt&&--tt!==0);return St<=X?St:X}function kc(Y){let tt=0,F;for(;;){if(X<an){if(ea(),X<an&&Y==Ql)return gn;if(X===0)break}if(X>=ee&&(b=(b<<W^m[B+(ee-1)]&255)&G,tt=p[b]&65535,_[B&v]=p[b],p[b]=B),tt!==0&&(B-tt&65535)<=o-an&&_t!=pc&&(Z=Wl(tt)),Z>=ee)if(F=Ae(B-it,Z-ee),X-=Z,Z<=st&&X>=ee){Z--;do B++,b=(b<<W^m[B+(ee-1)]&255)&G,tt=p[b]&65535,_[B&v]=p[b],p[b]=B;while(--Z!==0);B++}else B+=Z,Z=0,b=m[B]&255,b=(b<<W^m[B+1]&255)&G;else F=Ae(0,m[B]&255),X--,B++;if(F&&(_e(!1),i.avail_out===0))return gn}return _e(Y==ke),i.avail_out===0?Y==ke?Qi:gn:Y==ke?Tc:Ec}function Ic(Y){let tt=0,F,nt;for(;;){if(X<an){if(ea(),X<an&&Y==Ql)return gn;if(X===0)break}if(X>=ee&&(b=(b<<W^m[B+(ee-1)]&255)&G,tt=p[b]&65535,_[B&v]=p[b],p[b]=B),et=Z,$=it,Z=ee-1,tt!==0&&et<st&&(B-tt&65535)<=o-an&&(_t!=pc&&(Z=Wl(tt)),Z<=5&&(_t==Sv||Z==ee&&B-it>4096)&&(Z=ee-1)),et>=ee&&Z<=et){nt=B+X-ee,F=Ae(B-1-$,et-ee),X-=et-1,et-=2;do++B<=nt&&(b=(b<<W^m[B+(ee-1)]&255)&G,tt=p[b]&65535,_[B&v]=p[b],p[b]=B);while(--et!==0);if(I=0,Z=ee-1,B++,F&&(_e(!1),i.avail_out===0))return gn}else if(I!==0){if(F=Ae(0,m[B-1]&255),F&&_e(!1),B++,X--,i.avail_out===0)return gn}else I=1,B++,X--}return I!==0&&(F=Ae(0,m[B-1]&255),I=0),_e(Y==ke),i.avail_out===0?Y==ke?Qi:gn:Y==ke?Tc:Ec}function Ua(Y){return Y.total_in=Y.total_out=0,Y.msg=null,u.pending=0,u.pending_out=0,f=Ac,r=Ql,ht(),P(),An}u.deflateInit=function(Y,tt,F,nt,ct,St){return nt||(nt=pr),ct||(ct=zv),St||(St=Ev),Y.msg=null,tt==Lc&&(tt=6),ct<1||ct>Dv||nt!=pr||F<9||F>15||tt<0||tt>9||St<0||St>pc?xn:(Y.dstate=u,h=F,o=1<<h,v=o-1,D=ct+7,T=1<<D,G=T-1,W=Math.floor((D+ee-1)/ee),m=new Uint8Array(o*2),_=[],p=[],E=1<<ct+6,u.pending_buf=new Uint8Array(E*4),s=E*4,u.dist_buf=new Uint16Array(E),u.lc_buf=new Uint8Array(E),at=tt,_t=St,Ua(Y))},u.deflateEnd=function(){return f!=_r&&f!=Ac&&f!=Fi?xn:(u.lc_buf=null,u.dist_buf=null,u.pending_buf=null,p=null,_=null,m=null,u.dstate=null,f==Ac?Av:An)},u.deflateParams=function(Y,tt,F){let nt=An;return tt==Lc&&(tt=6),tt<0||tt>9||F<0||F>pc?xn:(Tn[at].func!=Tn[tt].func&&Y.total_in!==0&&(nt=Y.deflate(H1)),at!=tt&&(at=tt,st=Tn[at].max_lazy,pt=Tn[at].good_length,yt=Tn[at].nice_length,ut=Tn[at].max_chain),_t=F,nt)},u.deflateSetDictionary=function(Y,tt,F){let nt=F,ct,St=0;if(!tt||f!=_r)return xn;if(nt<ee)return An;for(nt>o-an&&(nt=o-an,St=F-nt),m.set(tt.subarray(St,St+nt),0),B=nt,J=nt,b=m[0]&255,b=(b<<W^m[1]&255)&G,ct=0;ct<=nt-ee;ct++)b=(b<<W^m[ct+(ee-1)]&255)&G,_[ct&v]=p[b],p[b]=ct;return An},u.deflate=function(Y,tt){let F,nt,ct,St,wt;if(tt>ke||tt<0)return xn;if(!Y.next_out||!Y.next_in&&Y.avail_in!==0||f==Fi&&tt!=ke)return Y.msg=Sc[bc-xn],xn;if(Y.avail_out===0)return Y.msg=Sc[bc-Xl],Xl;if(i=Y,St=r,r=tt,f==_r&&(nt=pr+(h-8<<4)<<8,ct=(at-1&255)>>1,ct>3&&(ct=3),nt|=ct<<6,B!==0&&(nt|=Nv),nt+=31-nt%31,f=Ac,Jt(nt)),u.pending!==0){if(i.flush_pending(),i.avail_out===0)return r=-1,An}else if(i.avail_in===0&&tt<=St&&tt!=ke)return i.msg=Sc[bc-Xl],Xl;if(f==Fi&&i.avail_in!==0)return Y.msg=Sc[bc-Xl],Xl;if(i.avail_in!==0||X!==0||tt!=Ql&&f!=Fi){switch(wt=-1,Tn[at].func){case Ah:wt=Jc(tt);break;case Oc:wt=kc(tt);break;case $a:wt=Ic(tt);break}if((wt==Qi||wt==Tc)&&(f=Fi),wt==gn||wt==Qi)return i.avail_out===0&&(r=-1),An;if(wt==Ec){if(tt==H1)Ce();else if(al(0,0,!1),tt==Tv)for(F=0;F<T;F++)p[F]=0;if(i.flush_pending(),i.avail_out===0)return r=-1,An}}return tt!=ke?An:Th}}function xh(){const u=this;u.next_in_index=0,u.next_out_index=0,u.avail_in=0,u.total_in=0,u.avail_out=0,u.total_out=0}xh.prototype={deflateInit(u,i){const f=this;return f.dstate=new Cv,i||(i=Pi),f.dstate.deflateInit(f,u,i)},deflate(u){const i=this;return i.dstate?i.dstate.deflate(i,u):xn},deflateEnd(){const u=this;if(!u.dstate)return xn;const i=u.dstate.deflateEnd();return u.dstate=null,i},deflateParams(u,i){const f=this;return f.dstate?f.dstate.deflateParams(f,u,i):xn},deflateSetDictionary(u,i){const f=this;return f.dstate?f.dstate.deflateSetDictionary(f,u,i):xn},read_buf(u,i,f){const s=this;let r=s.avail_in;return r>f&&(r=f),r===0?0:(s.avail_in-=r,u.set(s.next_in.subarray(s.next_in_index,s.next_in_index+r),i),s.next_in_index+=r,s.total_in+=r,r)},flush_pending(){const u=this;let i=u.dstate.pending;i>u.avail_out&&(i=u.avail_out),i!==0&&(u.next_out.set(u.dstate.pending_buf.subarray(u.dstate.pending_out,u.dstate.pending_out+i),u.next_out_index),u.next_out_index+=i,u.dstate.pending_out+=i,u.total_out+=i,u.avail_out-=i,u.dstate.pending-=i,u.dstate.pending===0&&(u.dstate.pending_out=0))}};function Lv(u){const i=this,f=new xh,s=Hv(u&&u.chunkSize?u.chunkSize:64*1024),r=Ql,o=new Uint8Array(s);let h=u?u.level:Lc;typeof h>"u"&&(h=Lc),f.deflateInit(h),f.next_out=o,i.append=function(v,m){let y,_,p=0,b=0,T=0;const D=[];if(v.length){f.next_in_index=0,f.next_in=v,f.avail_in=v.length;do{if(f.next_out_index=0,f.avail_out=s,y=f.deflate(r),y!=An)throw new Error("deflating: "+f.msg);f.next_out_index&&(f.next_out_index==s?D.push(new Uint8Array(o)):D.push(o.subarray(0,f.next_out_index))),T+=f.next_out_index,m&&f.next_in_index>0&&f.next_in_index!=p&&(m(f.next_in_index),p=f.next_in_index)}while(f.avail_in>0||f.avail_out===0);return D.length>1?(_=new Uint8Array(T),D.forEach(function(G){_.set(G,b),b+=G.length})):_=D[0]?new Uint8Array(D[0]):new Uint8Array,_}},i.flush=function(){let v,m,y=0,_=0;const p=[];do{if(f.next_out_index=0,f.avail_out=s,v=f.deflate(ke),v!=Th&&v!=An)throw new Error("deflating: "+f.msg);s-f.avail_out>0&&p.push(o.slice(0,f.next_out_index)),_+=f.next_out_index}while(f.avail_in>0||f.avail_out===0);return f.deflateEnd(),m=new Uint8Array(_),p.forEach(function(b){m.set(b,y),y+=b.length}),m}}function Hv(u){return u+5*(Math.floor(u/16383)+1)}const ce=4294967295,le=65535,Wr=8,jv=9,wh=0,Oh=99,Rh=67324752,$r=134695760,Dh=$r,Cr=33639248,zh=101010256,Lr=101075792,Nh=117853008,vn=22,ki=20,Ii=56,Bv=vn+ki+Ii,Mh=12,Uh=20,Hc=4,Ch=1,Lh=39169,Hh=10,jh=1,Pr=21589,Yv=28789,Gv=25461,Bh=6534,Hr=1,qv=6,Zv=2,Xv=4,Vv=6,jr=8,Br=2048,Yr=16,Qv=61440,Yh=16384,Gr=73,Sr=420,Fv=20,Y1=45,G1=51,Wi="/",tl=30,to=10,kl=14,Il=18,q1=new Date(2107,11,31),Z1=new Date(1980,0,1),At=void 0,Na="undefined",au="function";class X1{constructor(i){return class extends TransformStream{constructor(f,s){const r=new i(s);super({transform(o,h){h.enqueue(r.append(o))},flush(o){const h=r.flush();h&&o.enqueue(h)}})}}}}const Kv=64;let Gh=2;try{typeof navigator!=Na&&navigator.hardwareConcurrency&&(Gh=navigator.hardwareConcurrency)}catch{}const Jv={chunkSize:512*1024,maxWorkers:Gh,terminateWorkerTimeout:5e3,useWebWorkers:!0,useCompressionStream:!0,workerScripts:At,CompressionStreamNative:typeof CompressionStream!=Na&&CompressionStream,DecompressionStreamNative:typeof DecompressionStream!=Na&&DecompressionStream},Da=Object.assign({},Jv);function eo(){return Da}function qh(u){return Math.max(u.chunkSize,Kv)}function Zh(u){const{baseURL:i,chunkSize:f,maxWorkers:s,terminateWorkerTimeout:r,useCompressionStream:o,useWebWorkers:h,Deflate:v,Inflate:m,CompressionStream:y,DecompressionStream:_,workerScripts:p}=u;if(Oa("baseURL",i),Oa("chunkSize",f),Oa("maxWorkers",s),Oa("terminateWorkerTimeout",r),Oa("useCompressionStream",o),Oa("useWebWorkers",h),v&&(Da.CompressionStream=new X1(v)),m&&(Da.DecompressionStream=new X1(m)),Oa("CompressionStream",y),Oa("DecompressionStream",_),p!==At){const{deflate:b,inflate:T}=p;if((b||T)&&(Da.workerScripts||(Da.workerScripts={})),b){if(!Array.isArray(b))throw new Error("workerScripts.deflate must be an array");Da.workerScripts.deflate=b}if(T){if(!Array.isArray(T))throw new Error("workerScripts.inflate must be an array");Da.workerScripts.inflate=T}}}function Oa(u,i){i!==At&&(Da[u]=i)}function kv(){return"application/octet-stream"}const Xh=[];for(let u=0;u<256;u++){let i=u;for(let f=0;f<8;f++)i&1?i=i>>>1^3988292384:i=i>>>1;Xh[u]=i}class jc{constructor(i){this.crc=i||-1}append(i){let f=this.crc|0;for(let s=0,r=i.length|0;s<r;s++)f=f>>>8^Xh[(f^i[s])&255];this.crc=f}get(){return~this.crc}}class Vh extends TransformStream{constructor(){let i;const f=new jc;super({transform(s,r){f.append(s),r.enqueue(s)},flush(){const s=new Uint8Array(4);new DataView(s.buffer).setUint32(0,f.get()),i.value=s}}),i=this}}function Dc(u){if(typeof TextEncoder==Na){u=unescape(encodeURIComponent(u));const i=new Uint8Array(u.length);for(let f=0;f<i.length;f++)i[f]=u.charCodeAt(f);return i}else return new TextEncoder().encode(u)}const Ge={concat(u,i){if(u.length===0||i.length===0)return u.concat(i);const f=u[u.length-1],s=Ge.getPartial(f);return s===32?u.concat(i):Ge._shiftRight(i,s,f|0,u.slice(0,u.length-1))},bitLength(u){const i=u.length;if(i===0)return 0;const f=u[i-1];return(i-1)*32+Ge.getPartial(f)},clamp(u,i){if(u.length*32<i)return u;u=u.slice(0,Math.ceil(i/32));const f=u.length;return i=i&31,f>0&&i&&(u[f-1]=Ge.partial(i,u[f-1]&2147483648>>i-1,1)),u},partial(u,i,f){return u===32?i:(f?i|0:i<<32-u)+u*1099511627776},getPartial(u){return Math.round(u/1099511627776)||32},_shiftRight(u,i,f,s){for(s===void 0&&(s=[]);i>=32;i-=32)s.push(f),f=0;if(i===0)return s.concat(u);for(let h=0;h<u.length;h++)s.push(f|u[h]>>>i),f=u[h]<<32-i;const r=u.length?u[u.length-1]:0,o=Ge.getPartial(r);return s.push(Ge.partial(i+o&31,i+o>32?f:s.pop(),1)),s}},Bc={bytes:{fromBits(u){const f=Ge.bitLength(u)/8,s=new Uint8Array(f);let r;for(let o=0;o<f;o++)(o&3)===0&&(r=u[o/4]),s[o]=r>>>24,r<<=8;return s},toBits(u){const i=[];let f,s=0;for(f=0;f<u.length;f++)s=s<<8|u[f],(f&3)===3&&(i.push(s),s=0);return f&3&&i.push(Ge.partial(8*(f&3),s)),i}}},Qh={};Qh.sha1=class{constructor(u){const i=this;i.blockSize=512,i._init=[1732584193,4023233417,2562383102,271733878,3285377520],i._key=[1518500249,1859775393,2400959708,3395469782],u?(i._h=u._h.slice(0),i._buffer=u._buffer.slice(0),i._length=u._length):i.reset()}reset(){const u=this;return u._h=u._init.slice(0),u._buffer=[],u._length=0,u}update(u){const i=this;typeof u=="string"&&(u=Bc.utf8String.toBits(u));const f=i._buffer=Ge.concat(i._buffer,u),s=i._length,r=i._length=s+Ge.bitLength(u);if(r>9007199254740991)throw new Error("Cannot hash more than 2^53 - 1 bits");const o=new Uint32Array(f);let h=0;for(let v=i.blockSize+s-(i.blockSize+s&i.blockSize-1);v<=r;v+=i.blockSize)i._block(o.subarray(16*h,16*(h+1))),h+=1;return f.splice(0,16*h),i}finalize(){const u=this;let i=u._buffer;const f=u._h;i=Ge.concat(i,[Ge.partial(1,1)]);for(let s=i.length+2;s&15;s++)i.push(0);for(i.push(Math.floor(u._length/4294967296)),i.push(u._length|0);i.length;)u._block(i.splice(0,16));return u.reset(),f}_f(u,i,f,s){if(u<=19)return i&f|~i&s;if(u<=39)return i^f^s;if(u<=59)return i&f|i&s|f&s;if(u<=79)return i^f^s}_S(u,i){return i<<u|i>>>32-u}_block(u){const i=this,f=i._h,s=Array(80);for(let y=0;y<16;y++)s[y]=u[y];let r=f[0],o=f[1],h=f[2],v=f[3],m=f[4];for(let y=0;y<=79;y++){y>=16&&(s[y]=i._S(1,s[y-3]^s[y-8]^s[y-14]^s[y-16]));const _=i._S(5,r)+i._f(y,o,h,v)+m+s[y]+i._key[Math.floor(y/20)]|0;m=v,v=h,h=i._S(30,o),o=r,r=_}f[0]=f[0]+r|0,f[1]=f[1]+o|0,f[2]=f[2]+h|0,f[3]=f[3]+v|0,f[4]=f[4]+m|0}};const Fh={};Fh.aes=class{constructor(u){const i=this;i._tables=[[[],[],[],[],[]],[[],[],[],[],[]]],i._tables[0][0][0]||i._precompute();const f=i._tables[0][4],s=i._tables[1],r=u.length;let o,h,v,m=1;if(r!==4&&r!==6&&r!==8)throw new Error("invalid aes key size");for(i._key=[h=u.slice(0),v=[]],o=r;o<4*r+28;o++){let y=h[o-1];(o%r===0||r===8&&o%r===4)&&(y=f[y>>>24]<<24^f[y>>16&255]<<16^f[y>>8&255]<<8^f[y&255],o%r===0&&(y=y<<8^y>>>24^m<<24,m=m<<1^(m>>7)*283)),h[o]=h[o-r]^y}for(let y=0;o;y++,o--){const _=h[y&3?o:o-4];o<=4||y<4?v[y]=_:v[y]=s[0][f[_>>>24]]^s[1][f[_>>16&255]]^s[2][f[_>>8&255]]^s[3][f[_&255]]}}encrypt(u){return this._crypt(u,0)}decrypt(u){return this._crypt(u,1)}_precompute(){const u=this._tables[0],i=this._tables[1],f=u[4],s=i[4],r=[],o=[];let h,v,m,y;for(let _=0;_<256;_++)o[(r[_]=_<<1^(_>>7)*283)^_]=_;for(let _=h=0;!f[_];_^=v||1,h=o[h]||1){let p=h^h<<1^h<<2^h<<3^h<<4;p=p>>8^p&255^99,f[_]=p,s[p]=_,y=r[m=r[v=r[_]]];let b=y*16843009^m*65537^v*257^_*16843008,T=r[p]*257^p*16843008;for(let D=0;D<4;D++)u[D][_]=T=T<<24^T>>>8,i[D][p]=b=b<<24^b>>>8}for(let _=0;_<5;_++)u[_]=u[_].slice(0),i[_]=i[_].slice(0)}_crypt(u,i){if(u.length!==4)throw new Error("invalid aes block size");const f=this._key[i],s=f.length/4-2,r=[0,0,0,0],o=this._tables[i],h=o[0],v=o[1],m=o[2],y=o[3],_=o[4];let p=u[0]^f[0],b=u[i?3:1]^f[1],T=u[2]^f[2],D=u[i?1:3]^f[3],G=4,W,J,Z;for(let $=0;$<s;$++)W=h[p>>>24]^v[b>>16&255]^m[T>>8&255]^y[D&255]^f[G],J=h[b>>>24]^v[T>>16&255]^m[D>>8&255]^y[p&255]^f[G+1],Z=h[T>>>24]^v[D>>16&255]^m[p>>8&255]^y[b&255]^f[G+2],D=h[D>>>24]^v[p>>16&255]^m[b>>8&255]^y[T&255]^f[G+3],G+=4,p=W,b=J,T=Z;for(let $=0;$<4;$++)r[i?3&-$:$]=_[p>>>24]<<24^_[b>>16&255]<<16^_[T>>8&255]<<8^_[D&255]^f[G++],W=p,p=b,b=T,T=D,D=W;return r}};const Iv={getRandomValues(u){const i=new Uint32Array(u.buffer),f=s=>{let r=987654321;const o=4294967295;return function(){return r=36969*(r&65535)+(r>>16)&o,s=18e3*(s&65535)+(s>>16)&o,(((r<<16)+s&o)/4294967296+.5)*(Math.random()>.5?1:-1)}};for(let s=0,r;s<u.length;s+=4){const o=f((r||Math.random())*4294967296);r=o()*987654071,i[s/4]=o()*4294967296|0}return u}},Kh={};Kh.ctrGladman=class{constructor(u,i){this._prf=u,this._initIv=i,this._iv=i}reset(){this._iv=this._initIv}update(u){return this.calculate(this._prf,u,this._iv)}incWord(u){if((u>>24&255)===255){let i=u>>16&255,f=u>>8&255,s=u&255;i===255?(i=0,f===255?(f=0,s===255?s=0:++s):++f):++i,u=0,u+=i<<16,u+=f<<8,u+=s}else u+=1<<24;return u}incCounter(u){(u[0]=this.incWord(u[0]))===0&&(u[1]=this.incWord(u[1]))}calculate(u,i,f){let s;if(!(s=i.length))return[];const r=Ge.bitLength(i);for(let o=0;o<s;o+=4){this.incCounter(f);const h=u.encrypt(f);i[o]^=h[0],i[o+1]^=h[1],i[o+2]^=h[2],i[o+3]^=h[3]}return Ge.clamp(i,r)}};const el={importKey(u){return new el.hmacSha1(Bc.bytes.toBits(u))},pbkdf2(u,i,f,s){if(f=f||1e4,s<0||f<0)throw new Error("invalid params to pbkdf2");const r=(s>>5)+1<<2;let o,h,v,m,y;const _=new ArrayBuffer(r),p=new DataView(_);let b=0;const T=Ge;for(i=Bc.bytes.toBits(i),y=1;b<(r||1);y++){for(o=h=u.encrypt(T.concat(i,[y])),v=1;v<f;v++)for(h=u.encrypt(h),m=0;m<h.length;m++)o[m]^=h[m];for(v=0;b<(r||1)&&v<o.length;v++)p.setInt32(b,o[v]),b+=4}return _.slice(0,s/8)}};el.hmacSha1=class{constructor(u){const i=this,f=i._hash=Qh.sha1,s=[[],[]];i._baseHash=[new f,new f];const r=i._baseHash[0].blockSize/32;u.length>r&&(u=new f().update(u).finalize());for(let o=0;o<r;o++)s[0][o]=u[o]^909522486,s[1][o]=u[o]^1549556828;i._baseHash[0].update(s[0]),i._baseHash[1].update(s[1]),i._resultHash=new f(i._baseHash[0])}reset(){const u=this;u._resultHash=new u._hash(u._baseHash[0]),u._updated=!1}update(u){const i=this;i._updated=!0,i._resultHash.update(u)}digest(){const u=this,i=u._resultHash.finalize(),f=new u._hash(u._baseHash[1]).update(i).finalize();return u.reset(),f}encrypt(u){if(this._updated)throw new Error("encrypt on already updated hmac called!");return this.update(u),this.digest(u)}};const Wv=typeof crypto!=Na&&typeof crypto.getRandomValues==au,Jh="Invalid password",kh="Invalid signature",no="zipjs-abort-check-password";function Ih(u){return Wv?crypto.getRandomValues(u):Iv.getRandomValues(u)}const Fl=16,$v="raw",Wh={name:"PBKDF2"},Pv={name:"HMAC"},t4="SHA-1",e4=Object.assign({hash:Pv},Wh),qr=Object.assign({iterations:1e3,hash:{name:t4}},Wh),n4=["deriveBits"],tu=[8,12,16],Ki=[16,24,32],Ra=10,a4=[0,0,0,0],Vc=typeof crypto!=Na,lu=Vc&&crypto.subtle,$h=Vc&&typeof lu!=Na,Mn=Bc.bytes,l4=Fh.aes,i4=Kh.ctrGladman,u4=el.hmacSha1;let V1=Vc&&$h&&typeof lu.importKey==au,Q1=Vc&&$h&&typeof lu.deriveBits==au;class c4 extends TransformStream{constructor({password:i,rawPassword:f,signed:s,encryptionStrength:r,checkPasswordOnly:o}){super({start(){Object.assign(this,{ready:new Promise(h=>this.resolveReady=h),password:em(i,f),signed:s,strength:r-1,pending:new Uint8Array})},async transform(h,v){const m=this,{password:y,strength:_,resolveReady:p,ready:b}=m;y?(await f4(m,_,y,_n(h,0,tu[_]+2)),h=_n(h,tu[_]+2),o?v.error(new Error(no)):p()):await b;const T=new Uint8Array(h.length-Ra-(h.length-Ra)%Fl);v.enqueue(Ph(m,h,T,0,Ra,!0))},async flush(h){const{signed:v,ctr:m,hmac:y,pending:_,ready:p}=this;if(y&&m){await p;const b=_n(_,0,_.length-Ra),T=_n(_,_.length-Ra);let D=new Uint8Array;if(b.length){const G=nu(Mn,b);y.update(G);const W=m.update(G);D=eu(Mn,W)}if(v){const G=_n(eu(Mn,y.digest()),0,Ra);for(let W=0;W<Ra;W++)if(G[W]!=T[W])throw new Error(kh)}h.enqueue(D)}}})}}class s4 extends TransformStream{constructor({password:i,rawPassword:f,encryptionStrength:s}){let r;super({start(){Object.assign(this,{ready:new Promise(o=>this.resolveReady=o),password:em(i,f),strength:s-1,pending:new Uint8Array})},async transform(o,h){const v=this,{password:m,strength:y,resolveReady:_,ready:p}=v;let b=new Uint8Array;m?(b=await r4(v,y,m),_()):await p;const T=new Uint8Array(b.length+o.length-o.length%Fl);T.set(b,0),h.enqueue(Ph(v,o,T,b.length,0))},async flush(o){const{ctr:h,hmac:v,pending:m,ready:y}=this;if(v&&h){await y;let _=new Uint8Array;if(m.length){const p=h.update(nu(Mn,m));v.update(p),_=eu(Mn,p)}r.signature=eu(Mn,v.digest()).slice(0,Ra),o.enqueue(ao(_,r.signature))}}}),r=this}}function Ph(u,i,f,s,r,o){const{ctr:h,hmac:v,pending:m}=u,y=i.length-r;m.length&&(i=ao(m,i),f=h4(f,y-y%Fl));let _;for(_=0;_<=y-Fl;_+=Fl){const p=nu(Mn,_n(i,_,_+Fl));o&&v.update(p);const b=h.update(p);o||v.update(b),f.set(eu(Mn,b),_+s)}return u.pending=_n(i,_),f}async function f4(u,i,f,s){const r=await tm(u,i,f,_n(s,0,tu[i])),o=_n(s,tu[i]);if(r[0]!=o[0]||r[1]!=o[1])throw new Error(Jh)}async function r4(u,i,f){const s=Ih(new Uint8Array(tu[i])),r=await tm(u,i,f,s);return ao(s,r)}async function tm(u,i,f,s){u.password=null;const r=await o4($v,f,e4,!1,n4),o=await d4(Object.assign({salt:s},qr),r,8*(Ki[i]*2+2)),h=new Uint8Array(o),v=nu(Mn,_n(h,0,Ki[i])),m=nu(Mn,_n(h,Ki[i],Ki[i]*2)),y=_n(h,Ki[i]*2);return Object.assign(u,{keys:{key:v,authentication:m,passwordVerification:y},ctr:new i4(new l4(v),Array.from(a4)),hmac:new u4(m)}),y}async function o4(u,i,f,s,r){if(V1)try{return await lu.importKey(u,i,f,s,r)}catch{return V1=!1,el.importKey(i)}else return el.importKey(i)}async function d4(u,i,f){if(Q1)try{return await lu.deriveBits(u,i,f)}catch{return Q1=!1,el.pbkdf2(i,u.salt,qr.iterations,f)}else return el.pbkdf2(i,u.salt,qr.iterations,f)}function em(u,i){return i===At?Dc(u):i}function ao(u,i){let f=u;return u.length+i.length&&(f=new Uint8Array(u.length+i.length),f.set(u,0),f.set(i,u.length)),f}function h4(u,i){if(i&&i>u.length){const f=u;u=new Uint8Array(i),u.set(f,0)}return u}function _n(u,i,f){return u.subarray(i,f)}function eu(u,i){return u.fromBits(i)}function nu(u,i){return u.toBits(i)}const $i=12;class m4 extends TransformStream{constructor({password:i,passwordVerification:f,checkPasswordOnly:s}){super({start(){Object.assign(this,{password:i,passwordVerification:f}),nm(this,i)},transform(r,o){const h=this;if(h.password){const v=F1(h,r.subarray(0,$i));if(h.password=null,v.at(-1)!=h.passwordVerification)throw new Error(Jh);r=r.subarray($i)}s?o.error(new Error(no)):o.enqueue(F1(h,r))}})}}class y4 extends TransformStream{constructor({password:i,passwordVerification:f}){super({start(){Object.assign(this,{password:i,passwordVerification:f}),nm(this,i)},transform(s,r){const o=this;let h,v;if(o.password){o.password=null;const m=Ih(new Uint8Array($i));m[$i-1]=o.passwordVerification,h=new Uint8Array(s.length+m.length),h.set(K1(o,m),0),v=$i}else h=new Uint8Array(s.length),v=0;h.set(K1(o,s),v),r.enqueue(h)}})}}function F1(u,i){const f=new Uint8Array(i.length);for(let s=0;s<i.length;s++)f[s]=am(u)^i[s],lo(u,f[s]);return f}function K1(u,i){const f=new Uint8Array(i.length);for(let s=0;s<i.length;s++)f[s]=am(u)^i[s],lo(u,i[s]);return f}function nm(u,i){const f=[305419896,591751049,878082192];Object.assign(u,{keys:f,crcKey0:new jc(f[0]),crcKey2:new jc(f[2])});for(let s=0;s<i.length;s++)lo(u,i.charCodeAt(s))}function lo(u,i){let[f,s,r]=u.keys;u.crcKey0.append([i]),f=~u.crcKey0.get(),s=J1(Math.imul(J1(s+lm(f)),134775813)+1),u.crcKey2.append([s>>>24]),r=~u.crcKey2.get(),u.keys=[f,s,r]}function am(u){const i=u.keys[2]|2;return lm(Math.imul(i,i^1)>>>8)}function lm(u){return u&255}function J1(u){return u&4294967295}const im="Invalid uncompressed size",k1="deflate-raw";class g4 extends TransformStream{constructor(i,{chunkSize:f,CompressionStream:s,CompressionStreamNative:r}){super({});const{compressed:o,encrypted:h,useCompressionStream:v,zipCrypto:m,signed:y,level:_}=i,p=this;let b,T,D=super.readable;(!h||m)&&y&&(b=new Vh,D=Pn(D,b)),o&&(D=cm(D,v,{level:_,chunkSize:f},r,s)),h&&(m?D=Pn(D,new y4(i)):(T=new s4(i),D=Pn(D,T))),um(p,D,()=>{let G;h&&!m&&(G=T.signature),(!h||m)&&y&&(G=new DataView(b.value.buffer).getUint32(0)),p.signature=G})}}class v4 extends TransformStream{constructor(i,{chunkSize:f,DecompressionStream:s,DecompressionStreamNative:r}){super({});const{zipCrypto:o,encrypted:h,signed:v,signature:m,compressed:y,useCompressionStream:_}=i;let p,b,T=super.readable;h&&(o?T=Pn(T,new m4(i)):(b=new c4(i),T=Pn(T,b))),y&&(T=cm(T,_,{chunkSize:f},r,s)),(!h||o)&&v&&(p=new Vh,T=Pn(T,p)),um(this,T,()=>{if((!h||o)&&v){const D=new DataView(p.value.buffer);if(m!=D.getUint32(0,!1))throw new Error(kh)}})}}function um(u,i,f){i=Pn(i,new TransformStream({flush:f})),Object.defineProperty(u,"readable",{get(){return i}})}function cm(u,i,f,s,r){try{const o=i&&s?s:r;u=Pn(u,new o(k1,f))}catch(o){if(i)u=Pn(u,new r(k1,f));else throw o}return u}function Pn(u,i){return u.pipeThrough(i)}const _4="message",p4="start",b4="pull",I1="data",S4="ack",W1="close",sm="deflate",fm="inflate";class E4 extends TransformStream{constructor(i,f){super({});const s=this,{codecType:r}=i;let o;r.startsWith(sm)?o=g4:r.startsWith(fm)&&(o=v4),s.outputSize=0;let h=0;const v=new o(i,f),m=super.readable,y=new TransformStream({transform(p,b){p&&p.length&&(h+=p.length,b.enqueue(p))},flush(){Object.assign(s,{inputSize:h})}}),_=new TransformStream({transform(p,b){if(p&&p.length&&(b.enqueue(p),s.outputSize+=p.length,i.outputSize&&s.outputSize>i.outputSize))throw new Error(im)},flush(){const{signature:p}=v;Object.assign(s,{signature:p,inputSize:h})}});Object.defineProperty(s,"readable",{get(){return m.pipeThrough(y).pipeThrough(v).pipeThrough(_)}})}}class T4 extends TransformStream{constructor(i){let f;super({transform:s,flush(r){f&&f.length&&r.enqueue(f)}});function s(r,o){if(f){const h=new Uint8Array(f.length+r.length);h.set(f),h.set(r,f.length),r=h,f=null}r.length>i?(o.enqueue(r.slice(0,i)),s(r.slice(i),o)):f=r}}}let rm=typeof Worker!=Na;class Er{constructor(i,{readable:f,writable:s},{options:r,config:o,streamOptions:h,useWebWorkers:v,transferStreams:m,scripts:y},_){const{signal:p}=h;return Object.assign(i,{busy:!0,readable:f.pipeThrough(new T4(o.chunkSize)).pipeThrough(new A4(h),{signal:p}),writable:s,options:Object.assign({},r),scripts:y,transferStreams:m,terminate(){return new Promise(b=>{const{worker:T,busy:D}=i;T?(D?i.resolveTerminated=b:(T.terminate(),b()),i.interface=null):b()})},onTaskFinished(){const{resolveTerminated:b}=i;b&&(i.resolveTerminated=null,i.terminated=!0,i.worker.terminate(),b()),i.busy=!1,_(i)}}),(v&&rm?x4:om)(i,o)}}class A4 extends TransformStream{constructor({onstart:i,onprogress:f,size:s,onend:r}){let o=0;super({async start(){i&&await Tr(i,s)},async transform(h,v){o+=h.length,f&&await Tr(f,o,s),v.enqueue(h)},async flush(){r&&await Tr(r,o)}})}}async function Tr(u,...i){try{await u(...i)}catch{}}function om(u,i){return{run:()=>w4(u,i)}}function x4(u,i){const{baseURL:f,chunkSize:s}=i;if(!u.interface){let r;try{r=D4(u.scripts[0],f,u)}catch{return rm=!1,om(u,i)}Object.assign(u,{worker:r,interface:{run:()=>O4(u,{chunkSize:s})}})}return u.interface}async function w4({options:u,readable:i,writable:f,onTaskFinished:s},r){let o;try{o=new E4(u,r),await i.pipeThrough(o).pipeTo(f,{preventClose:!0,preventAbort:!0});const{signature:h,inputSize:v,outputSize:m}=o;return{signature:h,inputSize:v,outputSize:m}}catch(h){throw o&&(h.outputSize=o.outputSize),h}finally{s()}}async function O4(u,i){let f,s;const r=new Promise((b,T)=>{f=b,s=T});Object.assign(u,{reader:null,writer:null,resolveResult:f,rejectResult:s,result:r});const{readable:o,options:h,scripts:v}=u,{writable:m,closed:y}=R4(u.writable),_=zc({type:p4,scripts:v.slice(1),options:h,config:i,readable:o,writable:m},u);_||Object.assign(u,{reader:o.getReader(),writer:m.getWriter()});const p=await r;return _||await m.getWriter().close(),await y,p}function R4(u){let i;const f=new Promise(r=>i=r);return{writable:new WritableStream({async write(r){const o=u.getWriter();await o.ready,await o.write(r),o.releaseLock()},close(){i()},abort(r){return u.getWriter().abort(r)}}),closed:f}}let $1=!0,P1=!0;function D4(u,i,f){const s={type:"module"};let r,o;typeof u==au&&(u=u());try{r=new URL(u,i)}catch{r=u}if($1)try{o=new Worker(r)}catch{$1=!1,o=new Worker(r,s)}else o=new Worker(r,s);return o.addEventListener(_4,h=>z4(h,f)),o}function zc(u,{worker:i,writer:f,onTaskFinished:s,transferStreams:r}){try{const{value:o,readable:h,writable:v}=u,m=[];if(o&&(o.byteLength<o.buffer.byteLength?u.value=o.buffer.slice(0,o.byteLength):u.value=o.buffer,m.push(u.value)),r&&P1?(h&&m.push(h),v&&m.push(v)):u.readable=u.writable=null,m.length)try{return i.postMessage(u,m),!0}catch{P1=!1,u.readable=u.writable=null,i.postMessage(u)}else i.postMessage(u)}catch(o){throw f&&f.releaseLock(),s(),o}}async function z4({data:u},i){const{type:f,value:s,messageId:r,result:o,error:h}=u,{reader:v,writer:m,resolveResult:y,rejectResult:_,onTaskFinished:p}=i;try{if(h){const{message:T,stack:D,code:G,name:W,outputSize:J}=h,Z=new Error(T);Object.assign(Z,{stack:D,code:G,name:W,outputSize:J}),b(Z)}else{if(f==b4){const{value:T,done:D}=await v.read();zc({type:I1,value:T,done:D,messageId:r},i)}f==I1&&(await m.ready,await m.write(new Uint8Array(s)),zc({type:S4,messageId:r},i)),f==W1&&b(null,o)}}catch(T){zc({type:W1,messageId:r},i),b(T)}function b(T,D){T?_(T):y(D),m&&m.releaseLock(),p()}}let za=[];const Ar=[];let th=0;async function dm(u,i){const{options:f,config:s}=i,{transferStreams:r,useWebWorkers:o,useCompressionStream:h,codecType:v,compressed:m,signed:y,encrypted:_}=f,{workerScripts:p,maxWorkers:b}=s;i.transferStreams=r||r===At;const T=!m&&!y&&!_&&!i.transferStreams;return i.useWebWorkers=!T&&(o||o===At&&s.useWebWorkers),i.scripts=i.useWebWorkers&&p?p[v]:[],f.useCompressionStream=h||h===At&&s.useCompressionStream,(await D()).run();async function D(){const W=za.find(J=>!J.busy);if(W)return Zr(W),new Er(W,u,i,G);if(za.length<b){const J={indexWorker:th};return th++,za.push(J),new Er(J,u,i,G)}else return new Promise(J=>Ar.push({resolve:J,stream:u,workerOptions:i}))}function G(W){if(Ar.length){const[{resolve:J,stream:Z,workerOptions:$}]=Ar.splice(0,1);J(new Er(W,Z,$,G))}else W.worker?(Zr(W),N4(W,i)):za=za.filter(J=>J!=W)}}function N4(u,i){const{config:f}=i,{terminateWorkerTimeout:s}=f;Number.isFinite(s)&&s>=0&&(u.terminated?u.terminated=!1:u.terminateTimeout=setTimeout(async()=>{za=za.filter(r=>r!=u);try{await u.terminate()}catch{}},s))}function Zr(u){const{terminateTimeout:i}=u;i&&(clearTimeout(i),u.terminateTimeout=null)}async function M4(){await Promise.allSettled(za.map(u=>(Zr(u),u.terminate())))}const hm="HTTP error ",iu="HTTP Range not supported",mm="Writer iterator completed too soon",ym="Writer not initialized",U4="text/plain",C4="Content-Length",L4="Content-Range",H4="Accept-Ranges",j4="Range",B4="Content-Type",Y4="HEAD",io="GET",gm="bytes",G4=64*1024,uo="writable";class Qc{constructor(){this.size=0}init(){this.initialized=!0}}class Ma extends Qc{get readable(){const i=this,{chunkSize:f=G4}=i,s=new ReadableStream({start(){this.chunkOffset=0},async pull(r){const{offset:o=0,size:h,diskNumberStart:v}=s,{chunkOffset:m}=this,y=h===At?f:Math.min(f,h-m),_=await Ee(i,o+m,y,v);r.enqueue(_),m+f>h||h===At&&!_.length&&y?r.close():this.chunkOffset+=f}});return s}}class co extends Qc{constructor(){super();const i=this,f=new WritableStream({write(s){if(!i.initialized)throw new Error(ym);return i.writeUint8Array(s)}});Object.defineProperty(i,uo,{get(){return f}})}writeUint8Array(){}}class q4 extends Ma{constructor(i){super();let f=i.length;for(;i.charAt(f-1)=="=";)f--;const s=i.indexOf(",")+1;Object.assign(this,{dataURI:i,dataStart:s,size:Math.floor((f-s)*.75)})}readUint8Array(i,f){const{dataStart:s,dataURI:r}=this,o=new Uint8Array(f),h=Math.floor(i/3)*4,v=atob(r.substring(h+s,Math.ceil((i+f)/3)*4+s)),m=i-Math.floor(h/4)*3;let y=0;for(let _=m;_<m+f&&_<v.length;_++)o[_-m]=v.charCodeAt(_),y++;return y<o.length?o.subarray(0,y):o}}class Z4 extends co{constructor(i){super(),Object.assign(this,{data:"data:"+(i||"")+";base64,",pending:[]})}writeUint8Array(i){const f=this;let s=0,r=f.pending;const o=f.pending.length;for(f.pending="",s=0;s<Math.floor((o+i.length)/3)*3-o;s++)r+=String.fromCharCode(i[s]);for(;s<i.length;s++)f.pending+=String.fromCharCode(i[s]);r.length&&(r.length>2?f.data+=btoa(r):f.pending+=r)}getData(){return this.data+btoa(this.pending)}}class so extends Ma{constructor(i){super(),Object.assign(this,{blob:i,size:i.size})}async readUint8Array(i,f){const s=this,r=i+f;let h=await(i||r<s.size?s.blob.slice(i,r):s.blob).arrayBuffer();return h.byteLength>f&&(h=h.slice(i,r)),new Uint8Array(h)}}class vm extends Qc{constructor(i){super();const f=this,s=new TransformStream,r=[];i&&r.push([B4,i]),Object.defineProperty(f,uo,{get(){return s.writable}}),f.blob=new Response(s.readable,{headers:r}).blob()}getData(){return this.blob}}class X4 extends so{constructor(i){super(new Blob([i],{type:U4}))}}class V4 extends vm{constructor(i){super(i),Object.assign(this,{encoding:i,utf8:!i||i.toLowerCase()=="utf-8"})}async getData(){const{encoding:i,utf8:f}=this,s=await super.getData();if(s.text&&f)return s.text();{const r=new FileReader;return new Promise((o,h)=>{Object.assign(r,{onload:({target:v})=>o(v.result),onerror:()=>h(r.error)}),r.readAsText(s,i)})}}}class Q4 extends Ma{constructor(i,f){super(),_m(this,i,f)}async init(){await pm(this,Xr,eh),super.init()}readUint8Array(i,f){return bm(this,i,f,Xr,eh)}}class F4 extends Ma{constructor(i,f){super(),_m(this,i,f)}async init(){await pm(this,Vr,nh),super.init()}readUint8Array(i,f){return bm(this,i,f,Vr,nh)}}function _m(u,i,f){const{preventHeadRequest:s,useRangeHeader:r,forceRangeRequests:o,combineSizeEocd:h}=f;f=Object.assign({},f),delete f.preventHeadRequest,delete f.useRangeHeader,delete f.forceRangeRequests,delete f.combineSizeEocd,delete f.useXHR,Object.assign(u,{url:i,options:f,preventHeadRequest:s,useRangeHeader:r,forceRangeRequests:o,combineSizeEocd:h})}async function pm(u,i,f){const{url:s,preventHeadRequest:r,useRangeHeader:o,forceRangeRequests:h,combineSizeEocd:v}=u;if(I4(s)&&(o||h)&&(typeof r>"u"||r)){const m=await i(io,u,Sm(u,v?-vn:void 0));if(!h&&m.headers.get(H4)!=gm)throw new Error(iu);{v&&(u.eocdCache=new Uint8Array(await m.arrayBuffer()));let y;const _=m.headers.get(L4);if(_){const p=_.trim().split(/\s*\/\s*/);if(p.length){const b=p[1];b&&b!="*"&&(y=Number(b))}}y===At?await ah(u,i,f):u.size=y}}else await ah(u,i,f)}async function bm(u,i,f,s,r){const{useRangeHeader:o,forceRangeRequests:h,eocdCache:v,size:m,options:y}=u;if(o||h){if(v&&i==m-vn&&f==vn)return v;if(i>=m)return new Uint8Array;{i+f>m&&(f=m-i);const _=await s(io,u,Sm(u,i,f));if(_.status!=206)throw new Error(iu);return new Uint8Array(await _.arrayBuffer())}}else{const{data:_}=u;return _||await r(u,y),new Uint8Array(u.data.subarray(i,i+f))}}function Sm(u,i=0,f=1){return Object.assign({},fo(u),{[j4]:gm+"="+(i<0?i:i+"-"+(i+f-1))})}function fo({options:u}){const{headers:i}=u;if(i)return Symbol.iterator in i?Object.fromEntries(i):i}async function eh(u){await Em(u,Xr)}async function nh(u){await Em(u,Vr)}async function Em(u,i){const f=await i(io,u,fo(u));u.data=new Uint8Array(await f.arrayBuffer()),u.size||(u.size=u.data.length)}async function ah(u,i,f){if(u.preventHeadRequest)await f(u,u.options);else{const r=(await i(Y4,u,fo(u))).headers.get(C4);r?u.size=Number(r):await f(u,u.options)}}async function Xr(u,{options:i,url:f},s){const r=await fetch(f,Object.assign({},i,{method:u,headers:s}));if(r.status<400)return r;throw r.status==416?new Error(iu):new Error(hm+(r.statusText||r.status))}function Vr(u,{url:i},f){return new Promise((s,r)=>{const o=new XMLHttpRequest;if(o.addEventListener("load",()=>{if(o.status<400){const h=[];o.getAllResponseHeaders().trim().split(/[\r\n]+/).forEach(v=>{const m=v.trim().split(/\s*:\s*/);m[0]=m[0].trim().replace(/^[a-z]|-[a-z]/g,y=>y.toUpperCase()),h.push(m)}),s({status:o.status,arrayBuffer:()=>o.response,headers:new Map(h)})}else r(o.status==416?new Error(iu):new Error(hm+(o.statusText||o.status)))},!1),o.addEventListener("error",h=>r(h.detail?h.detail.error:new Error("Network error")),!1),o.open(u,i),f)for(const h of Object.entries(f))o.setRequestHeader(h[0],h[1]);o.responseType="arraybuffer",o.send()})}class Tm extends Ma{constructor(i,f={}){super(),Object.assign(this,{url:i,reader:f.useXHR?new F4(i,f):new Q4(i,f)})}set size(i){}get size(){return this.reader.size}async init(){await this.reader.init(),super.init()}readUint8Array(i,f){return this.reader.readUint8Array(i,f)}}class K4 extends Tm{constructor(i,f={}){f.useRangeHeader=!0,super(i,f)}}class J4 extends Ma{constructor(i){super(),i=new Uint8Array(i.buffer,i.byteOffset,i.byteLength),Object.assign(this,{array:i,size:i.length})}readUint8Array(i,f){return this.array.slice(i,i+f)}}class k4 extends co{init(i=0){Object.assign(this,{offset:0,array:new Uint8Array(i)}),super.init()}writeUint8Array(i){const f=this;if(f.offset+i.length>f.array.length){const s=f.array;f.array=new Uint8Array(s.length+i.length),f.array.set(s)}f.array.set(i,f.offset),f.offset+=i.length}getData(){return this.array}}class ro extends Ma{constructor(i){super(),this.readers=i}async init(){const i=this,{readers:f}=i;i.lastDiskNumber=0,i.lastDiskOffset=0,await Promise.all(f.map(async(s,r)=>{await s.init(),r!=f.length-1&&(i.lastDiskOffset+=s.size),i.size+=s.size})),super.init()}async readUint8Array(i,f,s=0){const r=this,{readers:o}=this;let h,v=s;v==-1&&(v=o.length-1);let m=i;for(;o[v]&&m>=o[v].size;)m-=o[v].size,v++;const y=o[v];if(y){const _=y.size;if(m+f<=_)h=await Ee(y,m,f);else{const p=_-m;h=new Uint8Array(f);const b=await Ee(y,m,p);h.set(b,0);const T=await r.readUint8Array(i+p,f-p,s);h.set(T,p),b.length+T.length<f&&(h=h.subarray(0,b.length+T.length))}}else h=new Uint8Array;return r.lastDiskNumber=Math.max(v,r.lastDiskNumber),h}}class Yc extends Qc{constructor(i,f=4294967295){super();const s=this;Object.assign(s,{diskNumber:0,diskOffset:0,size:0,maxSize:f,availableSize:f});let r,o,h;const v=new WritableStream({async write(_){const{availableSize:p}=s;if(h)_.length>=p?(await m(_.subarray(0,p)),await y(),s.diskOffset+=r.size,s.diskNumber++,h=null,await this.write(_.subarray(p))):await m(_);else{const{value:b,done:T}=await i.next();if(T&&!b)throw new Error(mm);r=b,r.size=0,r.maxSize&&(s.maxSize=r.maxSize),s.availableSize=s.maxSize,await ta(r),o=b.writable,h=o.getWriter(),await this.write(_)}},async close(){await h.ready,await y()}});Object.defineProperty(s,uo,{get(){return v}});async function m(_){const p=_.length;p&&(await h.ready,await h.write(_),r.size+=p,s.size+=p,s.availableSize-=p)}async function y(){await h.close()}}}class Fc{constructor(i){return Array.isArray(i)&&(i=new ro(i)),i instanceof ReadableStream&&(i={readable:i}),i}}class oo{constructor(i){return i.writable===At&&typeof i.next==au&&(i=new Yc(i)),i instanceof WritableStream&&(i={writable:i}),i.size===At&&(i.size=0),i instanceof Yc||Object.assign(i,{diskNumber:0,diskOffset:0,availableSize:1/0,maxSize:1/0}),i}}function I4(u){const{baseURL:i}=eo(),{protocol:f}=new URL(u,i);return f=="http:"||f=="https:"}async function ta(u,i){if(u.init&&!u.initialized)await u.init(i);else return Promise.resolve()}function Ee(u,i,f,s){return u.readUint8Array(i,f,s)}const W4=ro,$4=Yc,Am="filename",xm="rawFilename",ho="comment",wm="rawComment",mo="uncompressedSize",Om="compressedSize",Rm="offset",Qr="diskNumberStart",Gc="lastModDate",Fr="rawLastModDate",yo="lastAccessDate",P4="rawLastAccessDate",go="creationDate",t_="rawCreationDate",Dm="internalFileAttribute",zm="internalFileAttributes",Nm="externalFileAttribute",Mm="externalFileAttributes",Um="msDosCompatible",vo="zip64",Cm="encrypted",Lm="version",Hm="versionMadeBy",jm="zipCrypto",Nc="directory",Bm="executable",Ym="compressionMethod",Gm="signature",qm="extraField",e_=[Am,xm,Om,mo,Gc,Fr,ho,wm,yo,go,Rm,Qr,Qr,Dm,zm,Nm,Mm,Um,vo,Cm,Lm,Hm,jm,Nc,Bm,Ym,Gm,qm,"bitFlag","filenameUTF8","commentUTF8","rawExtraField","extraFieldZip64","extraFieldUnicodePath","extraFieldUnicodeComment","extraFieldAES","extraFieldNTFS","extraFieldExtendedTimestamp"];class qc{constructor(i){e_.forEach(f=>this[f]=i[f])}}const n_="filenameEncoding",a_="commentEncoding",l_="decodeText",i_="extractPrependedData",u_="extractAppendedData",Zm="password",Xm="rawPassword",Vm="passThrough",Qm="signal",c_="checkPasswordOnly",s_="checkOverlappingEntryOnly",f_="checkOverlappingEntry",r_="checkSignature",Fm="useWebWorkers",Km="useCompressionStream",o_="transferStreams",Jm="preventClose",d_="encryptionStrength",h_="extendedTimestamp",m_="keepOrder",y_="level",g_="bufferedWrite",v_="dataDescriptorSignature",__="useUnicodeFileNames",p_="dataDescriptor",km="supportZip64SplitFile",b_="encodeText",lh="offset",Im="usdz",Wm="\0☺☻♥♦♣♠•◘○◙♂♀♪♫☼►◄↕‼¶§▬↨↑↓→←∟↔▲▼ !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~⌂ÇüéâäàåçêëèïîìÄÅÉæÆôöòûùÿÖÜ¢£¥₧ƒáíóúñÑªº¿⌐¬½¼¡«»░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞φε∩≡±≥≤⌠⌡÷≈°∙·√ⁿ²■ ".split(""),S_=Wm.length==256;function E_(u){if(S_){let i="";for(let f=0;f<u.length;f++)i+=Wm[u[f]];return i}else return new TextDecoder().decode(u)}function Mc(u,i){return i&&i.trim().toLowerCase()=="cp437"?E_(u):new TextDecoder(i).decode(u)}const xr="File format is not recognized",T_="End of central directory not found",A_="End of Zip64 central directory locator not found",x_="Central directory header not found",w_="Local file header not found",O_="Zip64 extra field not found",R_="File contains encrypted entry",D_="Encryption method not supported",ih="Compression method not supported",uh="Split zip file",z_="Overlapping entry found",ch="utf-8",sh="cp437",N_=[[mo,ce],[Om,ce],[Rm,ce],[Qr,le]],M_={[le]:{getValue:Pt,bytes:4},[ce]:{getValue:Jl,bytes:8}};class U_{constructor(i,f={}){Object.assign(this,{reader:new Fc(i),options:f,config:eo(),readRanges:[]})}async*getEntriesGenerator(i={}){const f=this;let{reader:s}=f;const{config:r}=f;if(await ta(s),(s.size===At||!s.readUint8Array)&&(s=new so(await new Response(s.readable).blob()),await ta(s)),s.size<vn)throw new Error(xr);s.chunkSize=qh(r);const o=await G_(s,zh,s.size,vn,le*16);if(!o){const st=await Ee(s,0,4),at=ne(st);throw Pt(at)==$r?new Error(uh):new Error(T_)}const h=ne(o);let v=Pt(h,12),m=Pt(h,16);const y=o.offset,_=Te(h,20),p=y+vn+_;let b=Te(h,4);const T=s.lastDiskNumber||0;let D=Te(h,6),G=Te(h,8),W=0,J=0;if(m==ce||v==ce||G==le||D==le){const st=await Ee(s,o.offset-ki,ki),at=ne(st);if(Pt(at,0)==Nh){m=Jl(at,8);let _t=await Ee(s,m,Ii,-1),pt=ne(_t);const yt=o.offset-ki-Ii;if(Pt(pt,0)!=Lr&&m!=yt){const ot=m;m=yt,m>ot&&(W=m-ot),_t=await Ee(s,m,Ii,-1),pt=ne(_t)}if(Pt(pt,0)!=Lr)throw new Error(A_);b==le&&(b=Pt(pt,16)),D==le&&(D=Pt(pt,20)),G==le&&(G=Jl(pt,32)),v==ce&&(v=Jl(pt,40)),m-=v}}if(m>=s.size&&(W=s.size-m-v-vn,m=s.size-v-vn),T!=b)throw new Error(uh);if(m<0)throw new Error(xr);let Z=0,$=await Ee(s,m,v,D),I=ne($);if(v){const st=o.offset-v;if(Pt(I,Z)!=Cr&&m!=st){const at=m;m=st,m>at&&(W+=m-at),$=await Ee(s,m,v,D),I=ne($)}}const B=o.offset-m-(s.lastDiskOffset||0);if(v!=B&&B>=0&&(v=B,$=await Ee(s,m,v,D),I=ne($)),m<0||m>=s.size)throw new Error(xr);const it=Ne(f,i,n_),X=Ne(f,i,a_);for(let st=0;st<G;st++){const at=new C_(s,r,f.options);if(Pt(I,Z)!=Cr)throw new Error(x_);$m(at,I,Z+6);const _t=!!at.bitFlag.languageEncodingFlag,pt=Z+46,yt=pt+at.filenameLength,ot=yt+at.extraFieldLength,N=Te(I,Z+4),V=N>>8==0,lt=N>>8==3,rt=$.subarray(pt,yt),gt=Te(I,Z+32),E=ot+gt,R=$.subarray(ot,E),k=_t,w=_t,U=Pt(I,Z+38),L=V&&(Kl(I,Z+38)&Yr)==Yr||lt&&(U>>16&Qv)==Yh||rt.length&&rt.at(-1)==Wi.charCodeAt(0),P=lt&&(U>>16&Gr)!=0,H=Pt(I,Z+42)+W;Object.assign(at,{versionMadeBy:N,msDosCompatible:V,compressedSize:0,uncompressedSize:0,commentLength:gt,directory:L,offset:H,diskNumberStart:Te(I,Z+34),internalFileAttributes:Te(I,Z+36),externalFileAttributes:U,rawFilename:rt,filenameUTF8:k,commentUTF8:w,rawExtraField:$.subarray(yt,ot),executable:P}),at.internalFileAttribute=at.internalFileAttributes,at.externalFileAttribute=at.externalFileAttributes;const ht=Ne(f,i,l_)||Mc,Yt=k?ch:it||sh,Ft=w?ch:X||sh;let ae=ht(rt,Yt);ae===At&&(ae=Mc(rt,Yt));let oe=ht(R,Ft);oe===At&&(oe=Mc(R,Ft)),Object.assign(at,{rawComment:R,filename:ae,comment:oe,directory:L||ae.endsWith(Wi)}),J=Math.max(H,J),Pm(at,at,I,Z+6),at.zipCrypto=at.encrypted&&!at.extraFieldAES;const Jt=new qc(at);Jt.getData=(kt,je)=>at.getData(kt,Jt,f.readRanges,je),Jt.arrayBuffer=async kt=>{const je=new TransformStream,[Be]=await Promise.all([new Response(je.readable).arrayBuffer(),at.getData(je,Jt,f.readRanges,kt)]);return Be},Z=E;const{onprogress:Gt}=i;if(Gt)try{await Gt(st+1,G,new qc(at))}catch{}yield Jt}const et=Ne(f,i,i_),ut=Ne(f,i,u_);return et&&(f.prependedData=J>0?await Ee(s,0,J):new Uint8Array),f.comment=_?await Ee(s,y+vn,_):new Uint8Array,ut&&(f.appendedData=p<s.size?await Ee(s,p,s.size-p):new Uint8Array),!0}async getEntries(i={}){const f=[];for await(const s of this.getEntriesGenerator(i))f.push(s);return f}async close(){}}class C_{constructor(i,f,s){Object.assign(this,{reader:i,config:f,options:s})}async getData(i,f,s,r={}){const o=this,{reader:h,offset:v,diskNumberStart:m,extraFieldAES:y,extraFieldZip64:_,compressionMethod:p,config:b,bitFlag:T,signature:D,rawLastModDate:G,uncompressedSize:W,compressedSize:J}=o,{dataDescriptor:Z}=T,$=f.localDirectory={},I=await Ee(h,v,tl,m),B=ne(I);let it=Ne(o,r,Zm),X=Ne(o,r,Xm);const et=Ne(o,r,Vm);if(it=it&&it.length&&it,X=X&&X.length&&X,y&&y.originalCompressionMethod!=Oh)throw new Error(ih);if(p!=wh&&p!=Wr&&!et)throw new Error(ih);if(Pt(B,0)!=Rh)throw new Error(w_);$m($,B,4);const{extraFieldLength:ut,filenameLength:st,lastAccessDate:at,creationDate:_t}=$;$.rawExtraField=ut?await Ee(h,v+tl+st,ut,m):new Uint8Array,Pm(o,$,B,4,!0),Object.assign(f,{lastAccessDate:at,creationDate:_t});const pt=o.encrypted&&$.encrypted&&!et,yt=pt&&!y;if(et||(f.zipCrypto=yt),pt){if(!yt&&y.strength===At)throw new Error(D_);if(!it&&!X)throw new Error(R_)}const ot=v+tl+st+ut,N=J,V=h.readable;Object.assign(V,{diskNumberStart:m,offset:ot,size:N});const lt=Ne(o,r,Qm),rt=Ne(o,r,c_);let gt=Ne(o,r,f_);const E=Ne(o,r,s_);E&&(gt=!0);const{onstart:R,onprogress:k,onend:w}=r,U={options:{codecType:fm,password:it,rawPassword:X,zipCrypto:yt,encryptionStrength:y&&y.strength,signed:Ne(o,r,r_)&&!et,passwordVerification:yt&&(Z?G>>>8&255:D>>>24&255),outputSize:W,signature:D,compressed:p!=0&&!et,encrypted:o.encrypted&&!et,useWebWorkers:Ne(o,r,Fm),useCompressionStream:Ne(o,r,Km),transferStreams:Ne(o,r,o_),checkPasswordOnly:rt},config:b,streamOptions:{signal:lt,size:N,onstart:R,onprogress:k,onend:w}};gt&&await Y_({reader:h,fileEntry:f,offset:v,diskNumberStart:m,signature:D,compressedSize:J,uncompressedSize:W,dataOffset:ot,dataDescriptor:Z||$.bitFlag.dataDescriptor,extraFieldZip64:_||$.extraFieldZip64,readRanges:s});let L;try{if(!E){rt&&(i=new WritableStream),i=new oo(i),await ta(i,et?J:W),{writable:L}=i;const{outputSize:P}=await dm({readable:V,writable:L},U);if(i.size+=P,P!=(et?J:W))throw new Error(im)}}catch(P){if(P.outputSize!==At&&(i.size+=P.outputSize),!rt||P.message!=no)throw P}finally{!Ne(o,r,Jm)&&L&&!L.locked&&await L.getWriter().close()}return rt||E?At:i.getData?i.getData():L}}function $m(u,i,f){const s=u.rawBitFlag=Te(i,f+2),r=(s&Hr)==Hr,o=Pt(i,f+6);Object.assign(u,{encrypted:r,version:Te(i,f),bitFlag:{level:(s&qv)>>1,dataDescriptor:(s&jr)==jr,languageEncodingFlag:(s&Br)==Br},rawLastModDate:o,lastModDate:q_(o),filenameLength:Te(i,f+22),extraFieldLength:Te(i,f+24)})}function Pm(u,i,f,s,r){const{rawExtraField:o}=i,h=i.extraField=new Map,v=ne(new Uint8Array(o));let m=0;try{for(;m<o.length;){const J=Te(v,m),Z=Te(v,m+2);h.set(J,{type:J,data:o.slice(m+4,m+4+Z)}),m+=4+Z}}catch{}const y=Te(f,s+4);Object.assign(i,{signature:Pt(f,s+to),compressedSize:Pt(f,s+kl),uncompressedSize:Pt(f,s+Il)});const _=h.get(Ch);_&&(L_(_,i),i.extraFieldZip64=_);const p=h.get(Yv);p&&(fh(p,Am,xm,i,u),i.extraFieldUnicodePath=p);const b=h.get(Gv);b&&(fh(b,ho,wm,i,u),i.extraFieldUnicodeComment=b);const T=h.get(Lh);T?(H_(T,i,y),i.extraFieldAES=T):i.compressionMethod=y;const D=h.get(Hh);D&&(j_(D,i),i.extraFieldNTFS=D);const G=h.get(Pr);G&&(B_(G,i,r),i.extraFieldExtendedTimestamp=G);const W=h.get(Bh);W&&(i.extraFieldUSDZ=W)}function L_(u,i){i.zip64=!0;const f=ne(u.data),s=N_.filter(([r,o])=>i[r]==o);for(let r=0,o=0;r<s.length;r++){const[h,v]=s[r];if(i[h]==v){const m=M_[v];i[h]=u[h]=m.getValue(f,o),o+=m.bytes}else if(u[h])throw new Error(O_)}}function fh(u,i,f,s,r){const o=ne(u.data),h=new jc;h.append(r[f]);const v=ne(new Uint8Array(4));v.setUint32(0,h.get(),!0);const m=Pt(o,1);Object.assign(u,{version:Kl(o,0),[i]:Mc(u.data.subarray(5)),valid:!r.bitFlag.languageEncodingFlag&&m==Pt(v,0)}),u.valid&&(s[i]=u[i],s[i+"UTF8"]=!0)}function H_(u,i,f){const s=ne(u.data),r=Kl(s,4);Object.assign(u,{vendorVersion:Kl(s,0),vendorId:Kl(s,2),strength:r,originalCompressionMethod:f,compressionMethod:Te(s,5)}),i.compressionMethod=u.compressionMethod}function j_(u,i){const f=ne(u.data);let s=4,r;try{for(;s<u.data.length&&!r;){const o=Te(f,s),h=Te(f,s+2);o==jh&&(r=u.data.slice(s+4,s+4+h)),s+=4+h}}catch{}try{if(r&&r.length==24){const o=ne(r),h=o.getBigUint64(0,!0),v=o.getBigUint64(8,!0),m=o.getBigUint64(16,!0);Object.assign(u,{rawLastModDate:h,rawLastAccessDate:v,rawCreationDate:m});const y=wr(h),_=wr(v),p=wr(m),b={lastModDate:y,lastAccessDate:_,creationDate:p};Object.assign(u,b),Object.assign(i,b)}}catch{}}function B_(u,i,f){const s=ne(u.data),r=Kl(s,0),o=[],h=[];f?((r&1)==1&&(o.push(Gc),h.push(Fr)),(r&2)==2&&(o.push(yo),h.push(P4)),(r&4)==4&&(o.push(go),h.push(t_))):u.data.length>=5&&(o.push(Gc),h.push(Fr));let v=1;o.forEach((m,y)=>{if(u.data.length>=v+4){const _=Pt(s,v);i[m]=u[m]=new Date(_*1e3);const p=h[y];u[p]=_}v+=4})}async function Y_({reader:u,fileEntry:i,offset:f,diskNumberStart:s,signature:r,compressedSize:o,uncompressedSize:h,dataOffset:v,dataDescriptor:m,extraFieldZip64:y,readRanges:_}){let p=0;if(s)for(let D=0;D<s;D++){const G=u.readers[D];p+=G.size}let b=0;if(m&&(y?b=Uh:b=Mh),b){const D=await Ee(u,v+o,b+Hc,s);if(Pt(ne(D),0)==Dh){const W=Pt(ne(D),4);let J,Z;y?(J=Jl(ne(D),8),Z=Jl(ne(D),16)):(J=Pt(ne(D),8),Z=Pt(ne(D),12)),(i.encrypted&&!i.zipCrypto||W==r)&&J==o&&Z==h&&(b+=Hc)}}const T={start:p+f,end:p+v+o+b,fileEntry:i};for(const D of _)if(D.fileEntry!=i&&T.start>=D.start&&T.start<D.end){const G=new Error(z_);throw G.overlappingEntry=D.fileEntry,G}_.push(T)}async function G_(u,i,f,s,r){const o=new Uint8Array(4),h=ne(o);Z_(h,0,i);const v=s+r;return await m(s)||await m(Math.min(v,f));async function m(y){const _=f-y,p=await Ee(u,_,y);for(let b=p.length-s;b>=0;b--)if(p[b]==o[0]&&p[b+1]==o[1]&&p[b+2]==o[2]&&p[b+3]==o[3])return{offset:_+b,buffer:p.slice(b,b+s).buffer}}}function Ne(u,i,f){return i[f]===At?u.options[f]:i[f]}function q_(u){const i=(u&4294901760)>>16,f=u&65535;try{return new Date(1980+((i&65024)>>9),((i&480)>>5)-1,i&31,(f&63488)>>11,(f&2016)>>5,(f&31)*2,0)}catch{}}function wr(u){return new Date(Number(u/BigInt(1e4)-BigInt(116444736e5)))}function Kl(u,i){return u.getUint8(i)}function Te(u,i){return u.getUint16(i,!0)}function Pt(u,i){return u.getUint32(i,!0)}function Jl(u,i){return Number(u.getBigUint64(i,!0))}function Z_(u,i,f){u.setUint32(i,f,!0)}function ne(u){return new DataView(u.buffer)}const t3="File already exists",e3="Zip file comment exceeds 64KB",n3="File entry comment exceeds 64KB",a3="File entry name exceeds 64KB",Kr="Version exceeds 65535",l3="The strength must equal 1, 2, or 3",i3="Extra field type exceeds 65535",u3="Extra field data exceeds 64KB",Kc="Zip64 is not supported (make sure 'keepOrder' is set to 'true')",c3="Undefined uncompressed size",s3="Zip file not empty",rh=new Uint8Array([7,0,2,0,65,69,3,0,0]);let Or=0;const oh=[];class f3{constructor(i,f={}){i=new oo(i);const s=i.availableSize!==At&&i.availableSize>0&&i.availableSize!==1/0&&i.maxSize!==At&&i.maxSize>0&&i.maxSize!==1/0;Object.assign(this,{writer:i,addSplitZipSignature:s,options:f,config:eo(),files:new Map,filenames:new Set,offset:f[lh]===At?i.size||i.writable.size||0:f[lh],pendingEntriesSize:0,pendingAddFileCalls:new Set,bufferedWrites:0})}async prependZip(i){if(this.filenames.size)throw new Error(s3);i=new Fc(i);const f=new U_(i.readable),s=await f.getEntries();await f.close(),await i.readable.pipeTo(this.writer.writable,{preventClose:!0,preventAbort:!0}),this.writer.size=this.offset=i.size,this.filenames=new Set(s.map(r=>r.filename)),this.files=new Map(s.map(r=>{const{version:o,compressionMethod:h,lastModDate:v,lastAccessDate:m,creationDate:y,rawFilename:_,bitFlag:p,encrypted:b,uncompressedSize:T,compressedSize:D,diskOffset:G,diskNumber:W,zip64:J}=r;let{rawExtraFieldZip64:Z,rawExtraFieldAES:$,rawExtraFieldExtendedTimestamp:I,rawExtraFieldNTFS:B,rawExtraField:it}=r;const{level:X,languageEncodingFlag:et,dataDescriptor:ut}=p;Z=Z||new Uint8Array,$=$||new Uint8Array,I=I||new Uint8Array,B=B||new Uint8Array,it=it||new Uint8Array;const st=zt(Z,$,I,B,it),at=J&&T>ce,_t=J&&D>ce,{headerArray:pt,headerView:yt}=r3({version:o,bitFlag:o3(X,et,ut,b,h),compressionMethod:h,uncompressedSize:T,compressedSize:D,lastModDate:v,rawFilename:_,zip64CompressedSize:_t,zip64UncompressedSize:at,extraFieldLength:st});return Object.assign(r,{zip64UncompressedSize:at,zip64CompressedSize:_t,zip64Offset:J&&this.offset-G>ce,zip64DiskNumberStart:J&&W>le,rawExtraFieldZip64:Z,rawExtraFieldAES:$,rawExtraFieldExtendedTimestamp:I,rawExtraFieldNTFS:B,rawExtraField:it,extendedTimestamp:I.length>0||B.length>0,extraFieldExtendedTimestampFlag:1+(m?2:0)+(y?4:0),headerArray:pt,headerView:yt}),[r.filename,r]}))}async add(i="",f,s={}){const r=this,{pendingAddFileCalls:o,config:h}=r;Or<h.maxWorkers?Or++:await new Promise(m=>oh.push(m));let v;try{if(i=i.trim(),r.filenames.has(i))throw new Error(t3);return r.filenames.add(i),v=V_(r,i,f,s),o.add(v),await v}catch(m){throw r.filenames.delete(i),m}finally{o.delete(v);const m=oh.shift();m?m():Or--}}remove(i){const{filenames:f,files:s}=this;if(typeof i=="string"&&(i=s.get(i)),i&&i.filename!==At){const{filename:r}=i;if(f.has(r)&&s.has(r))return f.delete(r),s.delete(r),!0}return!1}async close(i=new Uint8Array,f={}){const s=this,{pendingAddFileCalls:r,writer:o}=this,{writable:h}=o;for(;r.size;)await Promise.allSettled(Array.from(r));return await $_(this,i,f),Ct(s,f,Jm)||await h.getWriter().close(),o.getData?o.getData():h}}class X_{constructor(i={}){const{readable:f,writable:s}=new TransformStream;this.readable=f,this.zipWriter=new f3(s,i)}transform(i){const{readable:f,writable:s}=new TransformStream({flush:()=>{this.zipWriter.close()}});return this.zipWriter.add(i,f),{readable:this.readable,writable:s}}writable(i){const{readable:f,writable:s}=new TransformStream;return this.zipWriter.add(i,f),s}close(i=void 0,f={}){return this.zipWriter.close(i,f)}}async function V_(u,i,f,s){i=i.trim();const r=Ct(u,s,Um),o=Ct(u,s,Hm,r?20:768),h=Ct(u,s,Bm);if(o>le)throw new Error(Kr);let v=Ct(u,s,Mm,0);v===0&&(v=Ct(u,s,Nm,0)),!s[Nc]&&i.endsWith(Wi)&&(s[Nc]=!0),Ct(u,s,Nc)?(i.endsWith(Wi)||(i+=Wi),v===0&&(v=Yr,r||(v|=(Yh|Gr|Sr)<<16))):!r&&v===0&&(h?v=(Gr|Sr)<<16:v=Sr<<16);const y=Ct(u,s,b_,Dc);let _=y(i);if(_===At&&(_=Dc(i)),zt(_)>le)throw new Error(a3);const p=s[ho]||"";let b=y(p);if(b===At&&(b=Dc(p)),zt(b)>le)throw new Error(n3);const T=Ct(u,s,Lm,Fv);if(T>le)throw new Error(Kr);const D=Ct(u,s,Gc,new Date),G=Ct(u,s,yo),W=Ct(u,s,go);let J=Ct(u,s,zm,0);J===0&&(J=Ct(u,s,Dm,0));const Z=Ct(u,s,Vm);let $,I;Z||($=Ct(u,s,Zm),I=Ct(u,s,Xm));const B=Ct(u,s,d_,3),it=Ct(u,s,jm),X=Ct(u,s,h_,!0),et=Ct(u,s,m_,!0),ut=Ct(u,s,y_),st=Ct(u,s,Fm),at=Ct(u,s,g_),_t=Ct(u,s,v_,!1),pt=Ct(u,s,Qm),yt=Ct(u,s,__,!0),ot=Ct(u,s,Km),N=Ct(u,s,Ym);let V=Ct(u,s,p_);at&&V===At&&(V=!1),(V===At||it)&&(V=!0);let lt=Ct(u,s,vo);if(!it&&($!==At||I!==At)&&!(B>=1&&B<=3))throw new Error(l3);let rt=new Uint8Array;const gt=s[qm];if(gt){let Be=0,qe=0;gt.forEach(Ce=>Be+=4+zt(Ce)),rt=new Uint8Array(Be),gt.forEach((Ce,Ae)=>{if(Ae>le)throw new Error(i3);if(zt(Ce)>le)throw new Error(u3);re(rt,new Uint16Array([Ae]),qe),re(rt,new Uint16Array([zt(Ce)]),qe+2),re(rt,Ce,qe+4),qe+=4+zt(Ce)})}let E=0,R=0,k=0;if(Z&&(k=s[mo],k===At))throw new Error(c3);const w=lt===!0;f&&(f=new Fc(f),await ta(f),Z?(s.uncompressedSize=k,E=hh(k)):f.size===At?(V=!0,(lt||lt===At)&&(lt=!0,k=E=ce+1)):(s.uncompressedSize=k=f.size,E=hh(k)));const{diskOffset:U,diskNumber:L,maxSize:P}=u.writer,H=w||k>ce,ht=w||E>ce,Yt=w||u.offset+u.pendingEntriesSize-U>ce,ae=Ct(u,s,km,!0)&&w||L+Math.ceil(u.pendingEntriesSize/P)>le;if(Yt||H||ht||ae){if(lt===!1||!et)throw new Error(Kc);lt=!0}lt=lt||!1;const oe=Ct(u,s,Cm);s=Object.assign({},s,{rawFilename:_,rawComment:b,version:T,versionMadeBy:o,lastModDate:D,lastAccessDate:G,creationDate:W,rawExtraField:rt,zip64:lt,zip64UncompressedSize:H,zip64CompressedSize:ht,zip64Offset:Yt,zip64DiskNumberStart:ae,password:$,rawPassword:I,level:!ot&&u.config.CompressionStream===At&&u.config.CompressionStreamNative===At?0:ut,useWebWorkers:st,encryptionStrength:B,extendedTimestamp:X,zipCrypto:it,bufferedWrite:at,keepOrder:et,useUnicodeFileNames:yt,dataDescriptor:V,dataDescriptorSignature:_t,signal:pt,msDosCompatible:r,internalFileAttribute:J,internalFileAttributes:J,externalFileAttribute:v,externalFileAttributes:v,useCompressionStream:ot,passThrough:Z,encrypted:!!($&&zt($)||I&&zt(I))||Z&&oe,signature:s[Gm],compressionMethod:N,uncompressedSize:k,offset:u.offset-U,diskNumberStart:L});const Jt=K_(s),Gt=k_(s),kt=zt(Jt.localHeaderArray,Gt.dataDescriptorArray);R=kt+E,u.options[Im]&&(R+=R+64),u.pendingEntriesSize+=R;let je;try{je=await Q_(u,i,f,{headerInfo:Jt,dataDescriptorInfo:Gt,metadataSize:kt},s)}finally{u.pendingEntriesSize-=R}return Object.assign(je,{name:i,comment:p,extraField:gt}),new qc(je)}async function Q_(u,i,f,s,r){const{files:o,writer:h}=u,{keepOrder:v,dataDescriptor:m,signal:y}=r,{headerInfo:_}=s,p=u.options[Im],b=Array.from(o.values()).pop();let T={},D,G,W,J,Z,$,I;o.set(i,T);try{let et;v&&(et=b&&b.lock,B()),(r.bufferedWrite||u.writerLocked||u.bufferedWrites&&v||!m)&&!p?($=new TransformStream,$.size=0,D=!0,u.bufferedWrites++,await ta(h)):($=h,await it()),await ta($);const{writable:ut,diskOffset:st}=h;if(u.addSplitZipSignature){delete u.addSplitZipSignature;const ot=new Uint8Array(4),N=Ue(ot);Dt(N,0,$r),await $n(h,ot),u.offset+=4}p&&J_(s,u.offset-st);const{localHeaderView:at,localHeaderArray:_t}=_;D||(await et,await X(ut));const{diskNumber:pt}=h;Z=!0,T.diskNumberStart=pt,D?I=new Response($.readable).blob():await $n($,_t),T=await F_(f,$,T,s,u.config,r);const{zip64:yt}=T;if(Z=!1,o.set(i,T),T.filename=i,D){const[ot]=await Promise.all([I,$.writable.getWriter().close(),et]);await it(),J=!0,T.diskNumberStart=h.diskNumber,T.offset=u.offset-h.diskOffset,yt&&dh(T),W_(T,at,r),await X(ut),await $n(h,_t),await ot.stream().pipeTo(ut,{preventClose:!0,preventAbort:!0,signal:y}),h.size+=$.size,J=!1}else T.offset=u.offset-st,yt&&dh(T);if(T.offset>ce&&!yt)throw new Error(Kc);return u.offset+=T.size,T}catch(et){if(D&&J||!D&&Z){if(u.hasCorruptedEntries=!0,et)try{et.corruptedEntry=!0}catch{}D?u.offset+=$.size:u.offset=$.size}throw o.delete(i),et}finally{D&&u.bufferedWrites--,W&&W(),G&&G()}function B(){T.lock=new Promise(et=>W=et)}async function it(){u.writerLocked=!0;const{lockWriter:et}=u;u.lockWriter=new Promise(ut=>G=()=>{u.writerLocked=!1,ut()}),await et}async function X(et){zt(_.localHeaderArray)>h.availableSize&&(h.availableSize=0,await $n(et,new Uint8Array))}}async function F_(u,i,{diskNumberStart:f,lock:s},r,o,h){const{headerInfo:v,dataDescriptorInfo:m,metadataSize:y}=r,{headerArray:_,headerView:p,lastModDate:b,rawLastModDate:T,encrypted:D,compressed:G,version:W,compressionMethod:J,rawExtraFieldZip64:Z,localExtraFieldZip64Length:$,rawExtraFieldExtendedTimestamp:I,extraFieldExtendedTimestampFlag:B,rawExtraFieldNTFS:it,rawExtraFieldAES:X}=v,{dataDescriptorArray:et}=m,{rawFilename:ut,lastAccessDate:st,creationDate:at,password:_t,rawPassword:pt,level:yt,zip64:ot,zip64UncompressedSize:N,zip64CompressedSize:V,zip64Offset:lt,zip64DiskNumberStart:rt,zipCrypto:gt,dataDescriptor:E,directory:R,executable:k,versionMadeBy:w,rawComment:U,rawExtraField:L,useWebWorkers:P,onstart:H,onprogress:ht,onend:Yt,signal:Ft,encryptionStrength:ae,extendedTimestamp:oe,msDosCompatible:Jt,internalFileAttributes:Gt,externalFileAttributes:kt,useCompressionStream:je,passThrough:Be}=h,qe={lock:s,versionMadeBy:w,zip64:ot,directory:!!R,executable:!!k,filenameUTF8:!0,rawFilename:ut,commentUTF8:!0,rawComment:U,rawExtraFieldZip64:Z,localExtraFieldZip64Length:$,rawExtraFieldExtendedTimestamp:I,rawExtraFieldNTFS:it,rawExtraFieldAES:X,rawExtraField:L,extendedTimestamp:oe,msDosCompatible:Jt,internalFileAttributes:Gt,externalFileAttributes:kt,diskNumberStart:f};let{signature:Ce,uncompressedSize:Ae}=h,wn=0;Be||(Ae=0);const{writable:nl}=i;if(u){u.chunkSize=qh(o);const xe=u.readable,al=u.size,ll={options:{codecType:sm,level:yt,rawPassword:pt,password:_t,encryptionStrength:ae,zipCrypto:D&&gt,passwordVerification:D&&gt&&T>>8&255,signed:!Be,compressed:G&&!Be,encrypted:D&&!Be,useWebWorkers:P,useCompressionStream:je,transferStreams:!1},config:o,streamOptions:{signal:Ft,size:al,onstart:H,onprogress:ht,onend:Yt}};try{const _e=await dm({readable:xe,writable:nl},ll);wn=_e.outputSize,i.size+=wn,Be||(Ae=_e.inputSize,Ce=_e.signature)}catch(_e){throw _e.outputSize!==At&&(i.size+=_e.outputSize),_e}}return I_({signature:Ce,compressedSize:wn,uncompressedSize:Ae,headerInfo:v,dataDescriptorInfo:m},h),E&&await $n(i,et),Object.assign(qe,{uncompressedSize:Ae,compressedSize:wn,lastModDate:b,rawLastModDate:T,creationDate:at,lastAccessDate:st,encrypted:D,zipCrypto:gt,size:y+wn,compressionMethod:J,version:W,headerArray:_,headerView:p,signature:Ce,extraFieldExtendedTimestampFlag:B,zip64UncompressedSize:N,zip64CompressedSize:V,zip64Offset:lt,zip64DiskNumberStart:rt}),qe}function K_(u){const{rawFilename:i,lastModDate:f,lastAccessDate:s,creationDate:r,level:o,zip64:h,zipCrypto:v,useUnicodeFileNames:m,dataDescriptor:y,directory:_,rawExtraField:p,encryptionStrength:b,extendedTimestamp:T,passThrough:D,encrypted:G,zip64UncompressedSize:W,zip64CompressedSize:J,zip64Offset:Z,zip64DiskNumberStart:$,uncompressedSize:I,offset:B,diskNumberStart:it}=u;let{version:X,compressionMethod:et}=u;const ut=!_&&(o>0||o===At&&et!==0);let st;const at=D||!ut,_t=h&&(u.bufferedWrite||!W&&!J||at);if(h){let U=4;W&&(U+=8),J&&(U+=8),Z&&(U+=8),$&&(U+=4),st=new Uint8Array(U);const L=Ue(st);if(Lt(L,0,Ch),Lt(L,2,zt(st)-4),_t){const P=Ue(st);let H=4;W&&(ve(P,H,BigInt(I)),H+=8),J&&at&&(ve(P,H,BigInt(I)),H+=8),Z&&(ve(P,H,BigInt(B)),H+=8),$&&(Dt(P,H,it),H+=4)}}else st=new Uint8Array;let pt;if(G&&!v){pt=new Uint8Array(zt(rh)+2);const U=Ue(pt);Lt(U,0,Lh),re(pt,rh,2),Jr(U,8,b)}else pt=new Uint8Array;let yt,ot,N;if(T){ot=new Uint8Array(9+(s?4:0)+(r?4:0));const U=Ue(ot);Lt(U,0,Pr),Lt(U,2,zt(ot)-4),N=1+(s?2:0)+(r?4:0),Jr(U,4,N);let L=5;Dt(U,L,Math.floor(f.getTime()/1e3)),L+=4,s&&(Dt(U,L,Math.floor(s.getTime()/1e3)),L+=4),r&&Dt(U,L,Math.floor(r.getTime()/1e3));try{yt=new Uint8Array(36);const P=Ue(yt),H=Rr(f);Lt(P,0,Hh),Lt(P,2,32),Lt(P,8,jh),Lt(P,10,24),ve(P,12,H),ve(P,20,Rr(s)||H),ve(P,28,Rr(r)||H)}catch{yt=new Uint8Array}}else yt=ot=new Uint8Array;et===At&&(et=ut?Wr:wh),h&&(X=X>Y1?X:Y1),G&&!v&&(X=X>G1?X:G1,pt[9]=et,et=Oh);const V=_t?zt(st):0,lt=V+zt(pt,ot,yt,p),{headerArray:rt,headerView:gt,rawLastModDate:E}=r3({version:X,bitFlag:o3(o,m,y,G,et),compressionMethod:et,uncompressedSize:I,lastModDate:f<Z1?Z1:f>q1?q1:f,rawFilename:i,zip64CompressedSize:J,zip64UncompressedSize:W,extraFieldLength:lt});let R=tl;const k=new Uint8Array(R+zt(i)+lt),w=Ue(k);return Dt(w,0,Rh),re(k,rt,4),re(k,i,R),R+=zt(i),_t&&re(k,st,R),R+=V,re(k,pt,R),R+=zt(pt),re(k,ot,R),R+=zt(ot),re(k,yt,R),R+=zt(yt),re(k,p,R),y&&(Dt(w,kl+4,0),Dt(w,Il+4,0)),{localHeaderArray:k,localHeaderView:w,headerArray:rt,headerView:gt,lastModDate:f,rawLastModDate:E,encrypted:G,compressed:ut,version:X,compressionMethod:et,extraFieldExtendedTimestampFlag:N,rawExtraFieldZip64:st,localExtraFieldZip64Length:V,rawExtraFieldExtendedTimestamp:ot,rawExtraFieldNTFS:yt,rawExtraFieldAES:pt,extraFieldLength:lt}}function J_(u,i){const{headerInfo:f}=u;let{localHeaderArray:s,extraFieldLength:r}=f,o=Ue(s),h=64-(i+zt(s))%64;h<4&&(h+=64);const v=new Uint8Array(h),m=Ue(v);Lt(m,0,Bh),Lt(m,2,h-2);const y=s;f.localHeaderArray=s=new Uint8Array(zt(y)+h),re(s,y),re(s,v,zt(y)),o=Ue(s),Lt(o,28,r+h),u.metadataSize+=h}function k_({zip64:u,dataDescriptor:i,dataDescriptorSignature:f}){let s=new Uint8Array,r,o=0,h=u?Uh:Mh;return f&&(h+=Hc),i&&(s=new Uint8Array(h),r=Ue(s),f&&(o=Hc,Dt(r,0,Dh))),{dataDescriptorArray:s,dataDescriptorView:r,dataDescriptorOffset:o}}function I_({signature:u,compressedSize:i,uncompressedSize:f,headerInfo:s,dataDescriptorInfo:r},{zip64:o,zipCrypto:h,dataDescriptor:v}){const{headerView:m,encrypted:y}=s,{dataDescriptorView:_,dataDescriptorOffset:p}=r;(!y||h)&&u!==At&&(Dt(m,to,u),v&&Dt(_,p,u)),o?v&&(ve(_,p+4,BigInt(i)),ve(_,p+12,BigInt(f))):(Dt(m,kl,i),Dt(m,Il,f),v&&(Dt(_,p+4,i),Dt(_,p+8,f)))}function W_({rawFilename:u,encrypted:i,zip64:f,localExtraFieldZip64Length:s,signature:r,compressedSize:o,uncompressedSize:h,offset:v,diskNumberStart:m,zip64UncompressedSize:y,zip64CompressedSize:_,zip64Offset:p,zip64DiskNumberStart:b},T,{dataDescriptor:D}){if(D||(i||Dt(T,to+4,r),f||(Dt(T,kl+4,o),Dt(T,Il+4,h))),f&&s){let G=tl+zt(u)+4;y&&(ve(T,G,BigInt(h)),G+=8),_&&(ve(T,G,BigInt(o)),G+=8),p&&(ve(T,G,BigInt(v)),G+=8),b&&Dt(T,G,m)}}function dh({compressedSize:u,uncompressedSize:i,offset:f,diskNumberStart:s,zip64UncompressedSize:r,zip64CompressedSize:o,zip64Offset:h,zip64DiskNumberStart:v,rawExtraFieldZip64:m}){const y=Ue(m);let _=4;r&&(ve(y,_,BigInt(i)),_+=8),o&&(ve(y,_,BigInt(u)),_+=8),h&&(ve(y,_,BigInt(f)),_+=8),v&&Dt(y,_,s)}async function $_(u,i,f){const{files:s,writer:r}=u,{diskOffset:o}=r;let{diskNumber:h}=r,v=0,m=0,y=u.offset-o,_=s.size;for(const[,I]of s){const{rawFilename:B,rawExtraFieldZip64:it,rawExtraFieldAES:X,rawComment:et,rawExtraFieldNTFS:ut,rawExtraField:st,extendedTimestamp:at,extraFieldExtendedTimestampFlag:_t,lastModDate:pt}=I;let yt;if(at){yt=new Uint8Array(9);const ot=Ue(yt);Lt(ot,0,Pr),Lt(ot,2,5),Jr(ot,4,_t),Dt(ot,5,Math.floor(pt.getTime()/1e3))}else yt=new Uint8Array;I.rawExtraFieldExtendedTimestamp=yt,m+=46+zt(B,et,it,X,ut,yt,st)}const p=new Uint8Array(m),b=Ue(p);await ta(r);let T=0;for(const[I,B]of Array.from(s.values()).entries()){const{offset:it,rawFilename:X,rawExtraFieldZip64:et,rawExtraFieldAES:ut,rawExtraFieldExtendedTimestamp:st,rawExtraFieldNTFS:at,rawExtraField:_t,rawComment:pt,versionMadeBy:yt,headerArray:ot,headerView:N,zip64:V,zip64UncompressedSize:lt,zip64CompressedSize:rt,zip64DiskNumberStart:gt,zip64Offset:E,internalFileAttributes:R,externalFileAttributes:k,diskNumberStart:w,uncompressedSize:U,compressedSize:L}=B,P=zt(et,ut,st,at,_t);Dt(b,v,Cr),Lt(b,v+4,yt),lt||Dt(N,Il,U),rt||Dt(N,kl,L),re(p,ot,v+6);let H=v+tl;if(Lt(b,H,P),H+=2,Lt(b,H,zt(pt)),H+=2,Lt(b,H,V&&gt?le:w),H+=2,Lt(b,H,R),H+=2,k&&Dt(b,H,k),H+=4,Dt(b,H,V&&E?ce:it),H+=4,re(p,X,H),H+=zt(X),re(p,et,H),H+=zt(et),re(p,ut,H),H+=zt(ut),re(p,st,H),H+=zt(st),re(p,at,H),H+=zt(at),re(p,_t,H),H+=zt(_t),re(p,pt,H),v-T>r.availableSize&&(r.availableSize=0,await $n(r,p.slice(T,v)),T=v),v=H,f.onprogress)try{await f.onprogress(I+1,s.size,new qc(B))}catch{}}await $n(r,T?p.slice(T):p);let D=r.diskNumber;const{availableSize:G}=r;G<vn&&D++;let W=Ct(u,f,vo);if(y>ce||m>ce||_>le||D>le){if(W===!1)throw new Error(Kc);W=!0}const J=new Uint8Array(W?Bv:vn),Z=Ue(J);v=0,W&&(Dt(Z,0,Lr),ve(Z,4,BigInt(44)),Lt(Z,12,45),Lt(Z,14,45),Dt(Z,16,D),Dt(Z,20,h),ve(Z,24,BigInt(_)),ve(Z,32,BigInt(_)),ve(Z,40,BigInt(m)),ve(Z,48,BigInt(y)),Dt(Z,56,Nh),ve(Z,64,BigInt(y)+BigInt(m)),Dt(Z,72,D+1),Ct(u,f,km,!0)&&(D=le,h=le),_=le,y=ce,m=ce,v+=Ii+ki),Dt(Z,v,zh),Lt(Z,v+4,D),Lt(Z,v+6,h),Lt(Z,v+8,_),Lt(Z,v+10,_),Dt(Z,v+12,m),Dt(Z,v+16,y);const $=zt(i);if($)if($<=le)Lt(Z,v+20,$);else throw new Error(e3);await $n(r,J),$&&await $n(r,i)}async function $n(u,i){const{writable:f}=u,s=f.getWriter();try{await s.ready,u.size+=zt(i),await s.write(i)}finally{s.releaseLock()}}function Rr(u){if(u)return(BigInt(u.getTime())+BigInt(116444736e5))*BigInt(1e4)}function Ct(u,i,f,s){const r=i[f]===At?u.options[f]:i[f];return r===At?s:r}function hh(u){return u+5*(Math.floor(u/16383)+1)}function Jr(u,i,f){u.setUint8(i,f)}function Lt(u,i,f){u.setUint16(i,f,!0)}function Dt(u,i,f){u.setUint32(i,f,!0)}function ve(u,i,f){u.setBigUint64(i,f,!0)}function re(u,i,f){u.set(i,f)}function Ue(u){return new DataView(u.buffer)}function zt(...u){let i=0;return u.forEach(f=>f&&(i+=f.length)),i}function r3({version:u,bitFlag:i,compressionMethod:f,uncompressedSize:s,compressedSize:r,lastModDate:o,rawFilename:h,zip64CompressedSize:v,zip64UncompressedSize:m,extraFieldLength:y}){const _=new Uint8Array(tl-4),p=Ue(_);Lt(p,0,u),Lt(p,2,i),Lt(p,4,f);const b=new Uint32Array(1),T=Ue(b);Lt(T,0,(o.getHours()<<6|o.getMinutes())<<5|o.getSeconds()/2),Lt(T,2,(o.getFullYear()-1980<<4|o.getMonth()+1)<<5|o.getDate());const D=b[0];return Dt(p,6,D),(v||r!==At)&&Dt(p,kl,v?ce:r),(m||s!==At)&&Dt(p,Il,m?ce:s),Lt(p,22,zt(h)),Lt(p,24,y),{headerArray:_,headerView:p,rawLastModDate:D}}function o3(u,i,f,s,r){let o=0;return i&&(o=o|Br),f&&(o=o|jr),(r==Wr||r==jv)&&(u>=0&&u<=3&&(o=o|Vv),u>3&&u<=5&&(o=o|Xv),u==9&&(o=o|Zv)),s&&(o=o|Hr),o}Zh({Deflate:Lv});const P_=Object.freeze(Object.defineProperty({__proto__:null,BlobReader:so,BlobWriter:vm,Data64URIReader:q4,Data64URIWriter:Z4,ERR_DUPLICATED_NAME:t3,ERR_HTTP_RANGE:iu,ERR_INVALID_COMMENT:e3,ERR_INVALID_ENCRYPTION_STRENGTH:l3,ERR_INVALID_ENTRY_COMMENT:n3,ERR_INVALID_ENTRY_NAME:a3,ERR_INVALID_EXTRAFIELD_DATA:u3,ERR_INVALID_EXTRAFIELD_TYPE:i3,ERR_INVALID_VERSION:Kr,ERR_ITERATOR_COMPLETED_TOO_SOON:mm,ERR_UNDEFINED_UNCOMPRESSED_SIZE:c3,ERR_UNSUPPORTED_FORMAT:Kc,ERR_WRITER_NOT_INITIALIZED:ym,ERR_ZIP_NOT_EMPTY:s3,GenericReader:Fc,GenericWriter:oo,HttpRangeReader:K4,HttpReader:Tm,Reader:Ma,SplitDataReader:ro,SplitDataWriter:Yc,SplitZipReader:W4,SplitZipWriter:$4,TextReader:X4,TextWriter:V4,Uint8ArrayReader:J4,Uint8ArrayWriter:k4,Writer:co,ZipWriter:f3,ZipWriterStream:X_,configure:Zh,getMimeType:kv,initStream:ta,readUint8Array:Ee,terminateWorkers:M4},Symbol.toStringTag,{value:"Module"})),Vl=P_;async function tp(u,i){Vl.configure({useWebWorkers:!1});const f=new Vl.ZipWriter(new Vl.BlobWriter("application/zip")),s=[];i&&s.push(i,"");for(let r=0;r<u.length;r++){const o=r+1,h=u[r],v=h.sessionTitle||"session",m=h.title||"tab",y=`screenshot ${o}: ${v} / ${m} @ ${h.url} (${h.viewportWidth}x${h.viewportHeight})`;if(s.push(`## ${y}`),h.data){const _=`annotations-${o}.png`;await f.add(_,new Vl.Uint8ArrayReader(Uint8Array.fromBase64(h.data))),s.push(`- [Screenshot ${o}](${_})`)}if(h.ariaSnapshot){const _=`annotations-${o}.yaml`,b=[...h.annotations.map(T=>`# { x: ${T.x}, y: ${T.y}, width: ${T.width}, height: ${T.height} }: ${T.text}`),h.ariaSnapshot].join(`
`);await f.add(_,new Vl.TextReader(b)),s.push(`- [Aria snapshot ${o}](${_})`)}for(const _ of h.annotations)_.text&&s.push(`- { x: ${_.x}, y: ${_.y}, width: ${_.width}, height: ${_.height} }: ${_.text}`);s.push("")}return await f.add("feedback.md",new Vl.TextReader(s.join(`
`))),f.close()}const ep={sessions:[],clientInfo:void 0,loadingSessions:!0,tabs:null,liveFrame:void 0,annotateSession:null,pendingCapture:!1,mode:"readonly",recording:null};class np{constructor(i){this.state=ep,this._listeners=new Set,this._requestId=0,this._client=i,i.on("sessions",f=>this._emit({sessions:f.sessions,clientInfo:f.clientInfo,loadingSessions:!1})),i.on("tabs",f=>this._emit({tabs:f.tabs})),i.on("frame",f=>this._emit({liveFrame:f})),i.on("annotate",()=>this.enterAnnotate("cli")),i.on("cancelAnnotate",()=>this.cancelAnnotate(!1))}subscribe(i){return this._listeners.add(i),()=>{this._listeners.delete(i)}}sessionByGuid(i){return this.state.sessions.find(f=>f.browser.guid===i)}closeSession(i){this._client.closeSession({browser:i.browser.guid})}setVisible(i){this._client.setVisible({visible:i})}selectTab(i){this._client.selectTab({browser:i.browser,context:i.context,page:i.page})}closeTab(i){this._client.closeTab({browser:i.browser,context:i.context,page:i.page})}newTab(i,f){this._client.newTab({browser:i,context:f})}navigate(i){this._client.navigate({url:i})}back(){this._client.back()}forward(){this._client.forward()}reload(){this._client.reload()}mousemove(i,f){this._client.mousemove({x:i,y:f})}mousedown(i,f,s){this._client.mousedown({x:i,y:f,button:s})}mouseup(i,f,s){this._client.mouseup({x:i,y:f,button:s})}wheel(i,f){this._client.wheel({deltaX:i,deltaY:f})}keydown(i){this._client.keydown({key:i})}keyup(i){this._client.keyup({key:i})}toggleInteractive(){const i=this.state.mode==="interactive"?"readonly":"interactive";i==="interactive"?this._enterInteractive():this._emit({mode:i})}enterInteractive(){this._enterInteractive()}enterAnnotate(i){this._enterAnnotate(i)}addAnnotateFrame(){this._addAnnotateFrame()}selectAnnotateFrame(i,f){const s=this.state.annotateSession;!s||!s.frames.find(r=>r.id===i)||this._emit({annotateSession:{...s,selectedFrameId:i,focusAnnotationId:f??null},mode:"annotate"})}toggleSelectFrame(i){const f=this.state.annotateSession;f&&(f.selectedFrameId===i?this._emit({annotateSession:{...f,selectedFrameId:null,focusAnnotationId:null},mode:"readonly"}):this.selectAnnotateFrame(i))}deselectFrame(){const i=this.state.annotateSession;!i||i.selectedFrameId===null||this._emit({annotateSession:{...i,selectedFrameId:null,focusAnnotationId:null},mode:"readonly"})}removeAnnotateFrame(i){const f=this.state.annotateSession;if(!f)return;const s=f.frames.filter(o=>o.id!==i);if(s.length===0){this.cancelAnnotate();return}const r=f.selectedFrameId===i?null:f.selectedFrameId;this._emit({annotateSession:{...f,frames:s,selectedFrameId:r}})}updateFrameAnnotations(i,f){const s=this.state.annotateSession;if(!s)return;const r=s.frames.map(o=>o.id===i?{...o,annotations:f}:o);this._emit({annotateSession:{...s,frames:r}})}updateFeedback(i){const f=this.state.annotateSession;f&&this._emit({annotateSession:{...f,feedback:i}})}completeAnnotation(){this._completeAnnotation()}startRecording(){this._startRecording()}stopRecording(){this._stopRecording()}discardRecording(){this._discardRecording()}cancelAnnotate(i=!0){var s;this._requestId++;const f=this.state;i&&((s=f.annotateSession)==null?void 0:s.initiator)==="cli"&&this._client.cancelAnnotation(),this._emit({mode:f.mode==="annotate"?"readonly":f.mode,annotateSession:null,pendingCapture:!1})}async submitAnnotateSession(){const i=this.state.annotateSession;if(!i)return;const f=[];for(const s of i.frames){const r=await ap(s);f.push({data:r??s.data,ariaSnapshot:s.ariaSnapshot,annotations:s.annotations.map(o=>({x:o.x,y:o.y,width:o.width,height:o.height,text:o.text})),sessionTitle:s.sessionTitle,title:s.title,url:s.url,viewportWidth:s.viewportWidth,viewportHeight:s.viewportHeight})}if(i.initiator==="cli")await this._client.submitAnnotation({frames:f,feedback:i.feedback});else{const s=await tp(f,i.feedback),r=new Date().toISOString().replace(/[:.]/g,"-");if(!await bh(s,`annotations-${r}.zip`))return}this.cancelAnnotate()}async _enterInteractive(){var f;const i=this.state;this._emit({mode:"interactive",annotateSession:(f=i.annotateSession)!=null&&f.selectedFrameId?{...i.annotateSession,selectedFrameId:null,focusAnnotationId:null}:i.annotateSession})}async _enterAnnotate(i){const f=this.state;if(f.annotateSession){i==="cli"&&f.annotateSession.initiator!=="cli"&&this._emit({annotateSession:{...f.annotateSession,initiator:"cli"}}),await this._addAnnotateFrame();return}await this._discardRecording(),await this._addAnnotateFrame(i)}async _addAnnotateFrame(i){var y,_;if(this.state.pendingCapture)return;const f=++this._requestId;this._emit({pendingCapture:!0});let s;try{s=await this._client.screenshot()}catch{}if(f!==this._requestId)return;if(!s){this._emit({pendingCapture:!1});return}const r=(y=this.state.tabs)==null?void 0:y.find(p=>p.selected),o=((_=this.state.sessions.find(p=>p.browser.guid===(r==null?void 0:r.browser)))==null?void 0:_.title)??"",h={id:"frm-"+Math.random().toString(36).slice(2,10),data:s.data,viewportWidth:s.viewportWidth,viewportHeight:s.viewportHeight,ariaSnapshot:s.ariaSnapshot,sessionTitle:o,title:(r==null?void 0:r.title)??"",url:(r==null?void 0:r.url)??"",annotations:[]},v=this.state.annotateSession,m=v?{...v,frames:[...v.frames,h],selectedFrameId:h.id,focusAnnotationId:null}:{initiator:i??"user",frames:[h],selectedFrameId:h.id,focusAnnotationId:null,feedback:""};this._emit({annotateSession:m,pendingCapture:!1,mode:"annotate"})}async _completeAnnotation(){var f;((f=this.state.annotateSession)==null?void 0:f.initiator)==="cli"?await this.submitAnnotateSession().catch(()=>{}):this.cancelAnnotate()}async _startRecording(){this.state.annotateSession&&this.cancelAnnotate(),await this._client.startRecording(),this._emit({recording:{phase:"recording"}})}async _stopRecording(){const{streamId:i}=await this._client.stopRecording(),f=[];for(;;){const{data:o,eof:h}=await this._client.readStream({streamId:i});if(o&&f.push(lp(o,"video/webm")),h)break}const s=new Blob(f,{type:"video/webm"}),r=URL.createObjectURL(s);this._emit({recording:{phase:"stopped",blob:s,blobUrl:r}})}async _discardRecording(){var f,s;const i=this.state;if(((f=i.recording)==null?void 0:f.phase)==="recording")try{const{streamId:r}=await this._client.stopRecording();for(;;){const{eof:o}=await this._client.readStream({streamId:r});if(o)break}}catch{}((s=i.recording)==null?void 0:s.phase)==="stopped"&&URL.revokeObjectURL(i.recording.blobUrl),this._emit({recording:null})}_emit(i){this.state={...this.state,...i};for(const f of this._listeners)f()}}async function ap(u){const i=new Image;i.src="data:image/png;base64,"+u.data;try{await i.decode()}catch{return}const f=await ph(i,u.viewportWidth,u.viewportHeight,u.annotations);if(!f)return;const s=await f.arrayBuffer();return new Uint8Array(s).toBase64()}function lp(u,i){return new Blob([Uint8Array.fromBase64(u)],{type:i})}class ip{constructor(i){this._lastId=0,this._pending=new Map,this._sendQueue=[],this._closed=!1,this._ws=new WebSocket(i),this._ws.onopen=()=>{for(const f of this._sendQueue||[])this._ws.send(f);this._sendQueue=void 0,this.onopen&&this.onopen()},this._ws.onmessage=f=>{let s;try{s=JSON.parse(f.data)}catch{this._ws.close();return}if(s.id!==void 0){const r=this._pending.get(s.id);r&&(this._pending.delete(s.id),s.error?r.reject(new Error(s.error)):r.resolve(s.result))}else s.method&&this.onevent&&this.onevent(s.method,s.params)},this._ws.onclose=f=>{this._closed=!0,this._sendQueue=void 0;for(const{reject:s}of this._pending.values())s(new Error("Connection closed"));this._pending.clear(),this.onclose&&this.onclose(f.reason)},this._ws.onerror=()=>{}}sendNoReply(i,f){this.send(i,f).catch(()=>{})}send(i,f){if(this._closed)return Promise.reject(new Error("Connection closed"));const s=++this._lastId,r=JSON.stringify({id:s,method:i,params:f});return this._sendQueue?this._sendQueue.push(r):this._ws.send(r),new Promise((o,h)=>{this._pending.set(s,{resolve:o,reject:h})})}close(){this._ws.close()}}class _o{constructor(i){this._listeners=new Map,this._transport=i,this._transport.onopen=()=>{var f;(f=this.onopen)==null||f.call(this)},this._transport.onevent=(f,s)=>{this._fireEvent(f,s)},this._transport.onclose=f=>{var s;(s=this.onclose)==null||s.call(this,f)}}static create(i){const f=new ip(i),s=new _o(f);return new Proxy(s,{get(r,o,h){if(typeof o=="symbol"||o in r)return Reflect.get(r,o,h);if(o!=="then")return v=>r._transport.send(o,v)}})}_fireEvent(i,f){const s=this._listeners.get(i);if(s)for(const r of s)r(f)}on(i,f){let s=this._listeners.get(i);s||(s=new Set,this._listeners.set(i,s)),s.add(f)}off(i,f){var s;(s=this._listeners.get(i))==null||s.delete(f)}close(){this._transport.close()}}const up=()=>{const[u,i]=mt.useState(!1),[f,s]=Qg(),r=mt.useRef(null);return mt.useEffect(()=>{if(!u)return;const o=v=>{r.current&&!r.current.contains(v.target)&&i(!1)},h=v=>{v.key==="Escape"&&i(!1)};return document.addEventListener("mousedown",o),document.addEventListener("keydown",h),()=>{document.removeEventListener("mousedown",o),document.removeEventListener("keydown",h)}},[u]),O.jsxs("div",{ref:r,className:"settings-button-container",children:[O.jsx(ln,{className:"settings-gear-btn",title:"Settings",toggled:u,onClick:()=>i(!u),children:O.jsx(iv,{})}),u&&O.jsx("div",{className:"settings-popup",children:O.jsxs("div",{className:"setting-row",children:[O.jsx("span",{className:"setting-label",children:"Theme"}),O.jsx("div",{className:"setting-options",children:qg.map(o=>O.jsx("div",{className:"setting-option"+(f===o.value?" selected":""),onClick:()=>{s(o.value),i(!1)},children:o.label},o.value))})]})})]})},mh=new Map;function cp({name:u,items:i=[],id:f,render:s,icon:r,isError:o,isWarning:h,isInfo:v,selectedItem:m,onAccepted:y,onSelected:_,onHighlighted:p,onIconClicked:b,noItemsMessage:T,dataTestId:D,notSelectable:G,ariaLabel:W}){const J=Wn.useRef(null),[Z,$]=Wn.useState();return Wn.useEffect(()=>{p==null||p(Z)},[p,Z]),Wn.useEffect(()=>{const I=J.current;if(!I)return;const B=()=>{mh.set(u,I.scrollTop)};return I.addEventListener("scroll",B,{passive:!0}),()=>I.removeEventListener("scroll",B)},[u]),Wn.useEffect(()=>{J.current&&(J.current.scrollTop=mh.get(u)||0)},[u]),O.jsx("div",{className:Ji("list-view vbox",u+"-list-view"),role:i.length>0?"listbox":void 0,"aria-label":W,children:O.jsxs("div",{className:Ji("list-view-content",G&&"not-selectable"),tabIndex:0,onKeyDown:I=>{var et;if(m&&I.key==="Enter"){y==null||y(m,i.indexOf(m));return}if(I.key!=="ArrowDown"&&I.key!=="ArrowUp")return;I.stopPropagation(),I.preventDefault();const B=m?i.indexOf(m):-1;let it=B;I.key==="ArrowDown"&&(B===-1?it=0:it=Math.min(B+1,i.length-1)),I.key==="ArrowUp"&&(B===-1?it=i.length-1:it=Math.max(B-1,0));const X=(et=J.current)==null?void 0:et.children.item(it);Yg(X||void 0),p==null||p(void 0),_==null||_(i[it],it),$(void 0)},ref:J,children:[T&&i.length===0&&O.jsx("div",{className:"list-view-empty",children:T}),i.map((I,B)=>{const it=s(I,B);return O.jsxs("div",{onDoubleClick:()=>y==null?void 0:y(I,B),role:"option",className:Ji("list-view-entry",m===I&&"selected",!G&&Z===I&&"highlighted",(o==null?void 0:o(I,B))&&"error",(h==null?void 0:h(I,B))&&"warning",(v==null?void 0:v(I,B))&&"info"),"aria-selected":m===I,onClick:()=>_==null?void 0:_(I,B),onMouseEnter:()=>$(I),onMouseLeave:()=>$(void 0),children:[r&&O.jsx("div",{className:"codicon "+(r(I,B)||"codicon-blank"),style:{minWidth:16,marginRight:4},onDoubleClick:X=>{X.preventDefault(),X.stopPropagation()},onClick:X=>{X.stopPropagation(),X.preventDefault(),b==null||b(I,B)}}),typeof it=="string"?O.jsx("div",{style:{textOverflow:"ellipsis",overflow:"hidden"},children:it}):it]},(f==null?void 0:f(I,B))||B)})]})})}const sp=cp;function fp(u){try{const f=new URL(u).hostname.replace(/^www\./,"");return f?f[0].toUpperCase():""}catch{return""}}function rp(u,i){if(!u||u==="Global")return u;let f=u;if(!u.startsWith("/")&&!u.startsWith("\\\\")&&!/^[A-Za-z]:[\\/]/.test(u)&&u.includes("/")&&(f="/"+u),i){if(f===i)return"~";if(f.startsWith(i+"/")||f.startsWith(i+"\\"))return"~"+f.slice(i.length)}return f}const op=({tab:u,model:i})=>O.jsxs(O.Fragment,{children:[u.faviconUrl?O.jsx("img",{className:"sidebar-tab-favicon",src:u.faviconUrl,alt:"","aria-hidden":"true"}):O.jsx("span",{className:"sidebar-tab-favicon placeholder","aria-hidden":"true",children:fp(u.url)}),O.jsxs("span",{className:"sidebar-tab-text",children:[O.jsx("span",{className:"sidebar-tab-title",children:u.title||"New Tab"}),O.jsx("span",{className:"sidebar-tab-url",children:u.url||"about:blank"})]}),O.jsx(ln,{className:"sidebar-tab-close",icon:"close",title:"Close tab",onClick:f=>{f.stopPropagation(),i.closeTab(u)}})]}),dp=({model:u})=>{const{sessions:i,clientInfo:f,loadingSessions:s,tabs:r}=u.state,o=i,h=mt.useMemo(()=>{const y=new Map;for(const _ of r??[]){let p=y.get(_.browser);p||(p=new Map,y.set(_.browser,p));let b=p.get(_.context);b||(b=[],p.set(_.context,b)),b.push(_)}return y},[r]),v=mt.useMemo(()=>{var y;return(y=r==null?void 0:r.find(_=>_.selected))==null?void 0:y.context},[r]),m=mt.useMemo(()=>{const y=new Map;for(const D of o){const G=D.workspaceDir||"Global";let W=y.get(G);W||(W=[],y.set(G,W)),W.push(D)}for(const D of y.values())D.sort((G,W)=>G.title.localeCompare(W.title));const _=(f==null?void 0:f.workspaceDir)||"Global",p=[...y.entries()],b=p.filter(([D])=>D===_),T=p.filter(([D])=>D!==_).sort((D,G)=>D[0].localeCompare(G[0]));return[...b,...T]},[o,f==null?void 0:f.workspaceDir]);return O.jsxs("nav",{className:"dashboard-shell-sidebar","aria-label":"Sessions",children:[O.jsxs("div",{className:"dashboard-shell-sidebar-header",children:[O.jsx("h2",{className:"dashboard-shell-sidebar-title",children:"Sessions"}),O.jsx(up,{})]}),O.jsxs("div",{className:"dashboard-shell-sidebar-content",children:[s&&O.jsx("p",{className:"sidebar-empty",role:"status","aria-live":"polite",children:"Loading sessions..."}),!s&&o.length===0&&O.jsx("p",{className:"sidebar-empty",role:"status","aria-live":"polite",children:"No open sessions."}),m.map(([y,_])=>{const p=rp(y,f==null?void 0:f.homeDir);return O.jsxs("section",{className:"workspace-group","aria-label":`Workspace ${p}`,children:[O.jsx("h3",{className:"workspace-header",children:O.jsx("span",{className:"workspace-path-full",title:p,children:p})}),_.map(b=>{var $;const T=b.browser.guid,D=b.browser.browserName,G=($=b.browser.launchOptions)==null?void 0:$.channel,W=h.get(T),J=W?[...W.entries()]:[];return(r===null?[{contextGuid:null,tabs:void 0}]:J.length===0?[{contextGuid:null,tabs:[]}]:J.map(([I,B])=>({contextGuid:I,tabs:B}))).map((I,B)=>{var et;const it=(et=I.tabs)==null?void 0:et.find(ut=>ut.context===v&&ut.selected),X=`${T}-${I.contextGuid??`placeholder-${B}`}`;return O.jsxs("section",{className:"sidebar-session session-chip"+(it?" active":""),"aria-label":`Session ${b.title}`,children:[O.jsxs("header",{className:"sidebar-session-row",children:[O.jsxs("div",{className:"session-browser-icon-wrap",title:G||D,children:[O.jsx("span",{className:"session-browser-icon","aria-hidden":"true",children:O.jsx($g,{browserName:D,channel:G})}),O.jsx(ln,{className:"session-browser-close",icon:"close",title:"Close session",onClick:()=>u.closeSession(b)})]}),O.jsx("span",{className:"session-chip-name",children:b.title}),O.jsx("div",{className:"sidebar-session-row-actions",children:I.contextGuid&&O.jsx(ln,{className:"sidebar-session-new-tab",icon:"add",title:"New tab",onClick:()=>u.newTab(T,I.contextGuid)})})]}),I.tabs===void 0?O.jsx("p",{className:"sidebar-tabs-loading",role:"status","aria-live":"polite",children:"Loading tabs..."}):O.jsx(sp,{name:`sidebar-tabs-${X}`,ariaLabel:`${b.title} tabs`,items:I.tabs,id:ut=>ut.page,selectedItem:it,onSelected:ut=>u.selectTab(ut),noItemsMessage:"No tabs open.",render:ut=>O.jsx(op,{tab:ut,model:u})})]},X)})})]},y)})]})]})},hp=50,mp=({sidebarSize:u,sidebarHidden:i=!1,sidebarIsFirst:f=!1,orientation:s="vertical",minSidebarSize:r=hp,settingName:o,sidebar:h,main:v})=>{const m=Math.max(r,u)*window.devicePixelRatio,[y,_]=x1(o?o+"."+s+":size":void 0,m),[p,b]=x1(o?o+"."+s+":size":void 0,m),[T,D]=Wn.useState(null),[G,W]=jg();let J;s==="vertical"?(J=p/window.devicePixelRatio,G&&G.height<J&&(J=G.height-10)):(J=y/window.devicePixelRatio,G&&G.width<J&&(J=G.width-10)),document.body.style.userSelect=T?"none":"inherit";let Z={};return s==="vertical"?f?Z={top:T?0:J-4,bottom:T?0:void 0,height:T?"initial":8}:Z={bottom:T?0:J-4,top:T?0:void 0,height:T?"initial":8}:f?Z={left:T?0:J-4,right:T?0:void 0,width:T?"initial":8}:Z={right:T?0:J-4,left:T?0:void 0,width:T?"initial":8},O.jsxs("div",{className:Ji("split-view",s,f&&"sidebar-first"),ref:W,children:[O.jsx("div",{className:"split-view-main",children:v}),!i&&O.jsx("div",{style:{flexBasis:J},className:"split-view-sidebar",children:h}),!i&&O.jsx("div",{style:Z,className:"split-view-resizer",onMouseDown:$=>D({offset:s==="vertical"?$.clientY:$.clientX,size:J}),onMouseUp:()=>D(null),onMouseMove:$=>{if(!$.buttons)D(null);else if(T){const B=(s==="vertical"?$.clientY:$.clientX)-T.offset,it=f?T.size+B:T.size-B,et=$.target.parentElement.getBoundingClientRect(),ut=Math.min(Math.max(r,it),(s==="vertical"?et.height:et.width)-r);s==="vertical"?b(ut*window.devicePixelRatio):_(ut*window.devicePixelRatio)}}})]})};Zg();const yp=new URLSearchParams(location.search).get("ws")??"",gp=_o.create("/"+yp),Uc=new np(gp),d3=()=>Uc.setVisible(!document.hidden);document.addEventListener("visibilitychange",d3);document.hidden&&d3();const vp=()=>{const[,u]=mt.useState(0);return mt.useEffect(()=>Uc.subscribe(()=>u(i=>i+1)),[]),O.jsx(mp,{orientation:"horizontal",sidebarIsFirst:!0,sidebarSize:320,minSidebarSize:220,settingName:"dashboardSessionSidebar",sidebar:O.jsx(dp,{model:Uc}),main:O.jsx("div",{className:"dashboard-shell-main",children:O.jsx(_v,{model:Uc})})})},xc=document.querySelector("#root"),_p=xc.__dashboardRoot??(xc.__dashboardRoot=Hg.createRoot(xc));_p.render(O.jsx(vp,{}));
